Class: ThePlaidApi::AccountsGetRequestOptions

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/accounts_get_request_options.rb

Overview

An optional object to filter ‘/accounts/get` results.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_ids: SKIP, additional_properties: nil) ⇒ AccountsGetRequestOptions

Returns a new instance of AccountsGetRequestOptions.



35
36
37
38
39
40
41
# File 'lib/the_plaid_api/models/accounts_get_request_options.rb', line 35

def initialize(account_ids: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_ids =  unless  == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_idsArray[String]

An array of ‘account_ids` to retrieve for the Account.

Returns:

  • (Array[String])


14
15
16
# File 'lib/the_plaid_api/models/accounts_get_request_options.rb', line 14

def 
  @account_ids
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/the_plaid_api/models/accounts_get_request_options.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('account_ids') ? hash['account_ids'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AccountsGetRequestOptions.new(account_ids: ,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/the_plaid_api/models/accounts_get_request_options.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_ids'] = 'account_ids'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/the_plaid_api/models/accounts_get_request_options.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/the_plaid_api/models/accounts_get_request_options.rb', line 24

def self.optionals
  %w[
    account_ids
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



70
71
72
73
74
# File 'lib/the_plaid_api/models/accounts_get_request_options.rb', line 70

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_ids: #{@account_ids.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



63
64
65
66
67
# File 'lib/the_plaid_api/models/accounts_get_request_options.rb', line 63

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_ids: #{@account_ids}, additional_properties:"\
  " #{@additional_properties}>"
end