Class: ThePlaidApi::Address
- Defined in:
- lib/the_plaid_api/models/address.rb
Overview
A physical mailing address.
Instance Attribute Summary collapse
-
#data ⇒ AddressData
Data about the components comprising an address.
-
#primary ⇒ TrueClass | FalseClass
When ‘true`, identifies the address as the primary address on an account.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(data:, primary: SKIP, additional_properties: nil) ⇒ Address
constructor
A new instance of Address.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(data:, primary: SKIP, additional_properties: nil) ⇒ Address
Returns a new instance of Address.
40 41 42 43 44 45 46 47 |
# File 'lib/the_plaid_api/models/address.rb', line 40 def initialize(data:, primary: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @data = data @primary = primary unless primary == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#data ⇒ AddressData
Data about the components comprising an address.
14 15 16 |
# File 'lib/the_plaid_api/models/address.rb', line 14 def data @data end |
#primary ⇒ TrueClass | FalseClass
When ‘true`, identifies the address as the primary address on an account.
18 19 20 |
# File 'lib/the_plaid_api/models/address.rb', line 18 def primary @primary end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/the_plaid_api/models/address.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. data = AddressData.from_hash(hash['data']) if hash['data'] primary = hash.key?('primary') ? hash['primary'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Address.new(data: data, primary: primary, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/the_plaid_api/models/address.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['data'] = 'data' @_hash['primary'] = 'primary' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/the_plaid_api/models/address.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/the_plaid_api/models/address.rb', line 29 def self.optionals %w[ primary ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/the_plaid_api/models/address.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} data: #{@data.inspect}, primary: #{@primary.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/the_plaid_api/models/address.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} data: #{@data}, primary: #{@primary}, additional_properties:"\ " #{@additional_properties}>" end |