Class: ThePlaidApi::AddressMatchScore

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/address_match_score.rb

Overview

Score found by matching address provided by the API with the address on the account at the financial institution. The score can range from 0 to 100 where 100 is a perfect match and 0 is a no match. If the account contains multiple owners, the maximum match score is filled.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(score: SKIP, is_postal_code_match: SKIP, additional_properties: nil) ⇒ AddressMatchScore

Returns a new instance of AddressMatchScore.



51
52
53
54
55
56
57
58
59
# File 'lib/the_plaid_api/models/address_match_score.rb', line 51

def initialize(score: SKIP, is_postal_code_match: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @score = score unless score == SKIP
  @is_postal_code_match = is_postal_code_match unless is_postal_code_match == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#is_postal_code_matchTrueClass | FalseClass

postal code was provided for both and was a match

Returns:

  • (TrueClass | FalseClass)


25
26
27
# File 'lib/the_plaid_api/models/address_match_score.rb', line 25

def is_postal_code_match
  @is_postal_code_match
end

#scoreInteger

Match score for address. 100 is a perfect match, 99-90 is a strong match, 89-70 is a partial match, anything below 70 is considered a weak match. Typically, the match threshold should be set to a score of 70 or higher. If the address is missing from either the API or financial institution, this is null.

Returns:

  • (Integer)


21
22
23
# File 'lib/the_plaid_api/models/address_match_score.rb', line 21

def score
  @score
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/the_plaid_api/models/address_match_score.rb', line 62

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  score = hash.key?('score') ? hash['score'] : SKIP
  is_postal_code_match =
    hash.key?('is_postal_code_match') ? hash['is_postal_code_match'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AddressMatchScore.new(score: score,
                        is_postal_code_match: is_postal_code_match,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



28
29
30
31
32
33
# File 'lib/the_plaid_api/models/address_match_score.rb', line 28

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['score'] = 'score'
  @_hash['is_postal_code_match'] = 'is_postal_code_match'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
47
48
49
# File 'lib/the_plaid_api/models/address_match_score.rb', line 44

def self.nullables
  %w[
    score
    is_postal_code_match
  ]
end

.optionalsObject

An array for optional fields



36
37
38
39
40
41
# File 'lib/the_plaid_api/models/address_match_score.rb', line 36

def self.optionals
  %w[
    score
    is_postal_code_match
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



91
92
93
94
95
# File 'lib/the_plaid_api/models/address_match_score.rb', line 91

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} score: #{@score.inspect}, is_postal_code_match:"\
  " #{@is_postal_code_match.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
# File 'lib/the_plaid_api/models/address_match_score.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} score: #{@score}, is_postal_code_match: #{@is_postal_code_match},"\
  " additional_properties: #{@additional_properties}>"
end