Class: ThePlaidApi::AffordabilityInsights

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/affordability_insights.rb

Overview

Affordability insights focus on providing signal on the ability of a borrower to repay their loan without experiencing financial strain. It provides insights on factors such a user’s monthly income and expenses, disposable income, average expenditure, etc., helping lenders gauge the level of affordability of a borrower.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(expenditure: SKIP, income: SKIP, additional_properties: nil) ⇒ AffordabilityInsights

Returns a new instance of AffordabilityInsights.



50
51
52
53
54
55
56
57
# File 'lib/the_plaid_api/models/affordability_insights.rb', line 50

def initialize(expenditure: SKIP, income: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @expenditure = expenditure unless expenditure == SKIP
  @income = income unless income == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#expenditureExpenditureInsights

Comprehensive analysis of spending patterns, categorizing expenses into essential, non-essential, and other categories.

Returns:



19
20
21
# File 'lib/the_plaid_api/models/affordability_insights.rb', line 19

def expenditure
  @expenditure
end

#incomeIncomeInsights

Comprehensive income analysis including total income, income excluding transfers, and inbound transfer amounts.

Returns:



24
25
26
# File 'lib/the_plaid_api/models/affordability_insights.rb', line 24

def income
  @income
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/the_plaid_api/models/affordability_insights.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  expenditure = ExpenditureInsights.from_hash(hash['expenditure']) if hash['expenditure']
  income = IncomeInsights.from_hash(hash['income']) if hash['income']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AffordabilityInsights.new(expenditure: expenditure,
                            income: income,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
# File 'lib/the_plaid_api/models/affordability_insights.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['expenditure'] = 'expenditure'
  @_hash['income'] = 'income'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
46
47
48
# File 'lib/the_plaid_api/models/affordability_insights.rb', line 43

def self.nullables
  %w[
    expenditure
    income
  ]
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
# File 'lib/the_plaid_api/models/affordability_insights.rb', line 35

def self.optionals
  %w[
    expenditure
    income
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



88
89
90
91
92
# File 'lib/the_plaid_api/models/affordability_insights.rb', line 88

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} expenditure: #{@expenditure.inspect}, income: #{@income.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



81
82
83
84
85
# File 'lib/the_plaid_api/models/affordability_insights.rb', line 81

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} expenditure: #{@expenditure}, income: #{@income}, additional_properties:"\
  " #{@additional_properties}>"
end