Class: ThePlaidApi::AmountWithCurrency

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/amount_with_currency.rb

Overview

A monetary amount with its associated currency information, supporting both official and unofficial currency codes.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(amount: SKIP, iso_currency_code: SKIP, unofficial_currency_code: SKIP, additional_properties: nil) ⇒ AmountWithCurrency

Returns a new instance of AmountWithCurrency.



64
65
66
67
68
69
70
71
72
73
# File 'lib/the_plaid_api/models/amount_with_currency.rb', line 64

def initialize(amount: SKIP, iso_currency_code: SKIP,
               unofficial_currency_code: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @amount = amount unless amount == SKIP
  @iso_currency_code = iso_currency_code unless iso_currency_code == SKIP
  @unofficial_currency_code = unofficial_currency_code unless unofficial_currency_code == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#amountFloat

If the parent object represents a category of transactions, such as ‘total_amount`, `transfers_in`, `total_income`, etc. the `amount` represents the sum of all of the transactions in the group. If the parent object is `cash_flow`, the `amount` represents the total value of all the inflows minus all the outflows across all the accounts in the report in the given time window. If the parent object is `minimum_balance`, the `amount` represents the lowest balance of the account during the given time window.

Returns:

  • (Float)


22
23
24
# File 'lib/the_plaid_api/models/amount_with_currency.rb', line 22

def amount
  @amount
end

#iso_currency_codeString

The ISO-4217 currency code of the amount. Always ‘null` if `unofficial_currency_code` is non-`null`.

Returns:

  • (String)


27
28
29
# File 'lib/the_plaid_api/models/amount_with_currency.rb', line 27

def iso_currency_code
  @iso_currency_code
end

#unofficial_currency_codeString

The unofficial currency code associated with the amount. Always ‘null` if `iso_currency_code` is non-`null`. See the [currency code schema](plaid.com/docs/api/accounts#currency-code-schema) for a full listing of supported `unofficial_currency_code`s.

Returns:

  • (String)


35
36
37
# File 'lib/the_plaid_api/models/amount_with_currency.rb', line 35

def unofficial_currency_code
  @unofficial_currency_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/the_plaid_api/models/amount_with_currency.rb', line 76

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  amount = hash.key?('amount') ? hash['amount'] : SKIP
  iso_currency_code =
    hash.key?('iso_currency_code') ? hash['iso_currency_code'] : SKIP
  unofficial_currency_code =
    hash.key?('unofficial_currency_code') ? hash['unofficial_currency_code'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AmountWithCurrency.new(amount: amount,
                         iso_currency_code: iso_currency_code,
                         unofficial_currency_code: unofficial_currency_code,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



38
39
40
41
42
43
44
# File 'lib/the_plaid_api/models/amount_with_currency.rb', line 38

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['amount'] = 'amount'
  @_hash['iso_currency_code'] = 'iso_currency_code'
  @_hash['unofficial_currency_code'] = 'unofficial_currency_code'
  @_hash
end

.nullablesObject

An array for nullable fields



56
57
58
59
60
61
62
# File 'lib/the_plaid_api/models/amount_with_currency.rb', line 56

def self.nullables
  %w[
    amount
    iso_currency_code
    unofficial_currency_code
  ]
end

.optionalsObject

An array for optional fields



47
48
49
50
51
52
53
# File 'lib/the_plaid_api/models/amount_with_currency.rb', line 47

def self.optionals
  %w[
    amount
    iso_currency_code
    unofficial_currency_code
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



109
110
111
112
113
114
# File 'lib/the_plaid_api/models/amount_with_currency.rb', line 109

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} amount: #{@amount.inspect}, iso_currency_code:"\
  " #{@iso_currency_code.inspect}, unofficial_currency_code:"\
  " #{@unofficial_currency_code.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



101
102
103
104
105
106
# File 'lib/the_plaid_api/models/amount_with_currency.rb', line 101

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} amount: #{@amount}, iso_currency_code: #{@iso_currency_code},"\
  " unofficial_currency_code: #{@unofficial_currency_code}, additional_properties:"\
  " #{@additional_properties}>"
end