Class: ThePlaidApi::AssetHoldings

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/asset_holdings.rb

Overview

Documentation not found in the MISMO model viewer and not provided by Freddie Mac.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(asset_holding:, additional_properties: nil) ⇒ AssetHoldings

Returns a new instance of AssetHoldings.



34
35
36
37
38
39
40
# File 'lib/the_plaid_api/models/asset_holdings.rb', line 34

def initialize(asset_holding:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @asset_holding = asset_holding
  @additional_properties = additional_properties
end

Instance Attribute Details

#asset_holdingArray[AssetHolding]

TODO: Write general description for this method

Returns:



15
16
17
# File 'lib/the_plaid_api/models/asset_holdings.rb', line 15

def asset_holding
  @asset_holding
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/the_plaid_api/models/asset_holdings.rb', line 43

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  asset_holding = nil
  unless hash['ASSET_HOLDING'].nil?
    asset_holding = []
    hash['ASSET_HOLDING'].each do |structure|
      asset_holding << (AssetHolding.from_hash(structure) if structure)
    end
  end

  asset_holding = nil unless hash.key?('ASSET_HOLDING')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AssetHoldings.new(asset_holding: asset_holding,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/the_plaid_api/models/asset_holdings.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['asset_holding'] = 'ASSET_HOLDING'
  @_hash
end

.nullablesObject

An array for nullable fields



30
31
32
# File 'lib/the_plaid_api/models/asset_holdings.rb', line 30

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
# File 'lib/the_plaid_api/models/asset_holdings.rb', line 25

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
82
# File 'lib/the_plaid_api/models/asset_holdings.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} asset_holding: #{@asset_holding.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



71
72
73
74
75
# File 'lib/the_plaid_api/models/asset_holdings.rb', line 71

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} asset_holding: #{@asset_holding}, additional_properties:"\
  " #{@additional_properties}>"
end