Class: ThePlaidApi::AssetOwner

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/asset_owner.rb

Overview

Documentation not found in the MISMO model viewer and not provided by Freddie Mac.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(asset_owner_text:, additional_properties: nil) ⇒ AssetOwner

Returns a new instance of AssetOwner.



36
37
38
39
40
41
42
# File 'lib/the_plaid_api/models/asset_owner.rb', line 36

def initialize(asset_owner_text:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @asset_owner_text = asset_owner_text
  @additional_properties = additional_properties
end

Instance Attribute Details

#asset_owner_textString

Account Owner Full Name.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/asset_owner.rb', line 15

def asset_owner_text
  @asset_owner_text
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/the_plaid_api/models/asset_owner.rb', line 45

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  asset_owner_text =
    hash.key?('AssetOwnerText') ? hash['AssetOwnerText'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AssetOwner.new(asset_owner_text: asset_owner_text,
                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/the_plaid_api/models/asset_owner.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['asset_owner_text'] = 'AssetOwnerText'
  @_hash
end

.nullablesObject

An array for nullable fields



30
31
32
33
34
# File 'lib/the_plaid_api/models/asset_owner.rb', line 30

def self.nullables
  %w[
    asset_owner_text
  ]
end

.optionalsObject

An array for optional fields



25
26
27
# File 'lib/the_plaid_api/models/asset_owner.rb', line 25

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



72
73
74
75
76
# File 'lib/the_plaid_api/models/asset_owner.rb', line 72

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} asset_owner_text: #{@asset_owner_text.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



65
66
67
68
69
# File 'lib/the_plaid_api/models/asset_owner.rb', line 65

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} asset_owner_text: #{@asset_owner_text}, additional_properties:"\
  " #{@additional_properties}>"
end