Class: ThePlaidApi::AssetReportAuditCopyPdfGetRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/asset_report_audit_copy_pdf_get_request.rb

Overview

AssetReportAuditCopyPDFGetRequest defines the request schema for ‘/asset_report/audit_copy/pdf/get`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(audit_copy_token:, client_id: SKIP, secret: SKIP, options: SKIP, additional_properties: nil) ⇒ AssetReportAuditCopyPdfGetRequest

Returns a new instance of AssetReportAuditCopyPdfGetRequest.



58
59
60
61
62
63
64
65
66
67
68
# File 'lib/the_plaid_api/models/asset_report_audit_copy_pdf_get_request.rb', line 58

def initialize(audit_copy_token:, client_id: SKIP, secret: SKIP,
               options: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @audit_copy_token = audit_copy_token
  @options = options unless options == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#audit_copy_tokenString

The ‘audit_copy_token` granting access to the Audit Copy you would like to get as a PDF.

Returns:

  • (String)


27
28
29
# File 'lib/the_plaid_api/models/asset_report_audit_copy_pdf_get_request.rb', line 27

def audit_copy_token
  @audit_copy_token
end

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/asset_report_audit_copy_pdf_get_request.rb', line 17

def client_id
  @client_id
end

#optionsAssetReportPdfGetRequestOptions

An optional object to filter or add data to ‘/asset_report/get` results. If provided, must be non-`null`.



32
33
34
# File 'lib/the_plaid_api/models/asset_report_audit_copy_pdf_get_request.rb', line 32

def options
  @options
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/asset_report_audit_copy_pdf_get_request.rb', line 22

def secret
  @secret
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/the_plaid_api/models/asset_report_audit_copy_pdf_get_request.rb', line 71

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  audit_copy_token =
    hash.key?('audit_copy_token') ? hash['audit_copy_token'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  options = AssetReportPdfGetRequestOptions.from_hash(hash['options']) if hash['options']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AssetReportAuditCopyPdfGetRequest.new(audit_copy_token: audit_copy_token,
                                        client_id: client_id,
                                        secret: secret,
                                        options: options,
                                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



35
36
37
38
39
40
41
42
# File 'lib/the_plaid_api/models/asset_report_audit_copy_pdf_get_request.rb', line 35

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['audit_copy_token'] = 'audit_copy_token'
  @_hash['options'] = 'options'
  @_hash
end

.nullablesObject

An array for nullable fields



54
55
56
# File 'lib/the_plaid_api/models/asset_report_audit_copy_pdf_get_request.rb', line 54

def self.nullables
  []
end

.optionalsObject

An array for optional fields



45
46
47
48
49
50
51
# File 'lib/the_plaid_api/models/asset_report_audit_copy_pdf_get_request.rb', line 45

def self.optionals
  %w[
    client_id
    secret
    options
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



105
106
107
108
109
110
# File 'lib/the_plaid_api/models/asset_report_audit_copy_pdf_get_request.rb', line 105

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\
  " audit_copy_token: #{@audit_copy_token.inspect}, options: #{@options.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



97
98
99
100
101
102
# File 'lib/the_plaid_api/models/asset_report_audit_copy_pdf_get_request.rb', line 97

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, audit_copy_token:"\
  " #{@audit_copy_token}, options: #{@options}, additional_properties:"\
  " #{@additional_properties}>"
end