Class: ThePlaidApi::AssetReportCreateResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::AssetReportCreateResponse
- Defined in:
- lib/the_plaid_api/models/asset_report_create_response.rb
Overview
AssetReportCreateResponse defines the response schema for ‘/asset_report/create`
Instance Attribute Summary collapse
-
#asset_report_id ⇒ String
A unique ID identifying an Asset Report.
-
#asset_report_token ⇒ String
A token that can be provided to endpoints such as ‘/asset_report/get` or `/asset_report/pdf/get` to fetch or update an Asset Report.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(asset_report_token:, asset_report_id:, request_id:, additional_properties: nil) ⇒ AssetReportCreateResponse
constructor
A new instance of AssetReportCreateResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(asset_report_token:, asset_report_id:, request_id:, additional_properties: nil) ⇒ AssetReportCreateResponse
Returns a new instance of AssetReportCreateResponse.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/the_plaid_api/models/asset_report_create_response.rb', line 48 def initialize(asset_report_token:, asset_report_id:, request_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @asset_report_token = asset_report_token @asset_report_id = asset_report_id @request_id = request_id @additional_properties = additional_properties end |
Instance Attribute Details
#asset_report_id ⇒ String
A unique ID identifying an Asset Report. Like all Plaid identifiers, this ID is case sensitive.
21 22 23 |
# File 'lib/the_plaid_api/models/asset_report_create_response.rb', line 21 def asset_report_id @asset_report_id end |
#asset_report_token ⇒ String
A token that can be provided to endpoints such as ‘/asset_report/get` or `/asset_report/pdf/get` to fetch or update an Asset Report.
16 17 18 |
# File 'lib/the_plaid_api/models/asset_report_create_response.rb', line 16 def asset_report_token @asset_report_token end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
27 28 29 |
# File 'lib/the_plaid_api/models/asset_report_create_response.rb', line 27 def request_id @request_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/the_plaid_api/models/asset_report_create_response.rb', line 60 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. asset_report_token = hash.key?('asset_report_token') ? hash['asset_report_token'] : nil asset_report_id = hash.key?('asset_report_id') ? hash['asset_report_id'] : nil request_id = hash.key?('request_id') ? hash['request_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AssetReportCreateResponse.new(asset_report_token: asset_report_token, asset_report_id: asset_report_id, request_id: request_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
30 31 32 33 34 35 36 |
# File 'lib/the_plaid_api/models/asset_report_create_response.rb', line 30 def self.names @_hash = {} if @_hash.nil? @_hash['asset_report_token'] = 'asset_report_token' @_hash['asset_report_id'] = 'asset_report_id' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/the_plaid_api/models/asset_report_create_response.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/the_plaid_api/models/asset_report_create_response.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 98 |
# File 'lib/the_plaid_api/models/asset_report_create_response.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} asset_report_token: #{@asset_report_token.inspect}, asset_report_id:"\ " #{@asset_report_id.inspect}, request_id: #{@request_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
85 86 87 88 89 90 |
# File 'lib/the_plaid_api/models/asset_report_create_response.rb', line 85 def to_s class_name = self.class.name.split('::').last "<#{class_name} asset_report_token: #{@asset_report_token}, asset_report_id:"\ " #{@asset_report_id}, request_id: #{@request_id}, additional_properties:"\ " #{@additional_properties}>" end |