Class: ThePlaidApi::AssetReportFreddie

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/asset_report_freddie.rb

Overview

An object representing an Asset Report with Freddie Mac schema.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(loans:, parties:, services:, additional_properties: nil) ⇒ AssetReportFreddie

Returns a new instance of AssetReportFreddie.



45
46
47
48
49
50
51
52
53
# File 'lib/the_plaid_api/models/asset_report_freddie.rb', line 45

def initialize(loans:, parties:, services:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @loans = loans
  @parties = parties
  @services = services
  @additional_properties = additional_properties
end

Instance Attribute Details

#loansLoans

A collection of loans that are part of a single deal.

Returns:



14
15
16
# File 'lib/the_plaid_api/models/asset_report_freddie.rb', line 14

def loans
  @loans
end

#partiesParties

A collection of objects that define specific parties to a deal. This includes the direct participating parties, such as borrower and seller and the indirect parties such as the credit report provider.

Returns:



20
21
22
# File 'lib/the_plaid_api/models/asset_report_freddie.rb', line 20

def parties
  @parties
end

#servicesServices

A collection of objects that describe requests and responses for services.

Returns:



24
25
26
# File 'lib/the_plaid_api/models/asset_report_freddie.rb', line 24

def services
  @services
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/the_plaid_api/models/asset_report_freddie.rb', line 56

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  loans = Loans.from_hash(hash['LOANS']) if hash['LOANS']
  parties = Parties.from_hash(hash['PARTIES']) if hash['PARTIES']
  services = Services.from_hash(hash['SERVICES']) if hash['SERVICES']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AssetReportFreddie.new(loans: loans,
                         parties: parties,
                         services: services,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
# File 'lib/the_plaid_api/models/asset_report_freddie.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['loans'] = 'LOANS'
  @_hash['parties'] = 'PARTIES'
  @_hash['services'] = 'SERVICES'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
# File 'lib/the_plaid_api/models/asset_report_freddie.rb', line 41

def self.nullables
  []
end

.optionalsObject

An array for optional fields



36
37
38
# File 'lib/the_plaid_api/models/asset_report_freddie.rb', line 36

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



86
87
88
89
90
# File 'lib/the_plaid_api/models/asset_report_freddie.rb', line 86

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} loans: #{@loans.inspect}, parties: #{@parties.inspect}, services:"\
  " #{@services.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



79
80
81
82
83
# File 'lib/the_plaid_api/models/asset_report_freddie.rb', line 79

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} loans: #{@loans}, parties: #{@parties}, services: #{@services},"\
  " additional_properties: #{@additional_properties}>"
end