Class: ThePlaidApi::AssetReportType

Inherits:
Object
  • Object
show all
Defined in:
lib/the_plaid_api/models/asset_report_type.rb

Overview

Indicates either a Fast Asset Report, which will contain only current identity and balance information, or a Full Asset Report, which will also contain historical balance information and transaction data.

Constant Summary collapse

ASSET_REPORT_TYPE =
[
  # TODO: Write general description for FULL
  FULL = 'FULL'.freeze,

  # TODO: Write general description for FAST
  FAST = 'FAST'.freeze
].freeze

Class Method Summary collapse

Class Method Details

.from_value(value, default_value = FULL) ⇒ Object



25
26
27
28
29
30
31
32
33
34
35
36
# File 'lib/the_plaid_api/models/asset_report_type.rb', line 25

def self.from_value(value, default_value = FULL)
  return default_value if value.nil?

  str = value.to_s.strip

  case str.downcase
  when 'full' then FULL
  when 'fast' then FAST
  else
    default_value
  end
end

.validate(value) ⇒ Object



19
20
21
22
23
# File 'lib/the_plaid_api/models/asset_report_type.rb', line 19

def self.validate(value)
  return false if value.nil?

  ASSET_REPORT_TYPE.include?(value)
end