Class: ThePlaidApi::Assets

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/assets.rb

Overview

Documentation not found in the MISMO model viewer and not provided by Freddie Mac.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(asset:, additional_properties: nil) ⇒ Assets

Returns a new instance of Assets.



35
36
37
38
39
40
41
# File 'lib/the_plaid_api/models/assets.rb', line 35

def initialize(asset:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @asset = asset
  @additional_properties = additional_properties
end

Instance Attribute Details

#assetArray[Asset]

Documentation not found in the MISMO model viewer and not provided by Freddie Mac.

Returns:



16
17
18
# File 'lib/the_plaid_api/models/assets.rb', line 16

def asset
  @asset
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/the_plaid_api/models/assets.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  asset = nil
  unless hash['ASSET'].nil?
    asset = []
    hash['ASSET'].each do |structure|
      asset << (Asset.from_hash(structure) if structure)
    end
  end

  asset = nil unless hash.key?('ASSET')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Assets.new(asset: asset,
             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



19
20
21
22
23
# File 'lib/the_plaid_api/models/assets.rb', line 19

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['asset'] = 'ASSET'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/the_plaid_api/models/assets.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



26
27
28
# File 'lib/the_plaid_api/models/assets.rb', line 26

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
82
# File 'lib/the_plaid_api/models/assets.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} asset: #{@asset.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
# File 'lib/the_plaid_api/models/assets.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} asset: #{@asset}, additional_properties: #{@additional_properties}>"
end