Class: ThePlaidApi::AssetsErrorWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/assets_error_webhook.rb

Overview

Fired when Asset Report generation has failed. The resulting ‘error` will have an `error_type` of `ASSET_REPORT_ERROR`.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, error:, asset_report_id:, environment:, user_id: SKIP, additional_properties: nil) ⇒ AssetsErrorWebhook

Returns a new instance of AssetsErrorWebhook.



71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/the_plaid_api/models/assets_error_webhook.rb', line 71

def initialize(webhook_type:, webhook_code:, error:, asset_report_id:,
               environment:, user_id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @error = error
  @asset_report_id = asset_report_id
  @user_id = user_id unless user_id == SKIP
  @environment = environment
  @additional_properties = additional_properties
end

Instance Attribute Details

#asset_report_idString

The ID associated with the Asset Report.

Returns:

  • (String)


35
36
37
# File 'lib/the_plaid_api/models/assets_error_webhook.rb', line 35

def asset_report_id
  @asset_report_id
end

#environmentWebhookEnvironmentValues

The Plaid environment the webhook was sent from



43
44
45
# File 'lib/the_plaid_api/models/assets_error_webhook.rb', line 43

def environment
  @environment
end

#errorError

Errors are identified by ‘error_code` and categorized by `error_type`. Use these in preference to HTTP status codes to identify and handle specific errors. HTTP status codes are set and provide the broadest categorization of errors: 4xx codes are for developer- or user-related errors, and 5xx codes are for Plaid-related errors, and the status will be 2xx in non-error cases. An Item with a non-`null` error object will only be part of an API response when calling `/item/get` to view Item status. Otherwise, error fields will be `null` if no error has occurred; if an error has occurred, an error code will be returned instead.

Returns:



31
32
33
# File 'lib/the_plaid_api/models/assets_error_webhook.rb', line 31

def error
  @error
end

#user_idString

The ‘user_id` corresponding to the User ID the webhook has fired for.

Returns:

  • (String)


39
40
41
# File 'lib/the_plaid_api/models/assets_error_webhook.rb', line 39

def user_id
  @user_id
end

#webhook_codeString

‘ERROR`

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/assets_error_webhook.rb', line 19

def webhook_code
  @webhook_code
end

#webhook_typeString

‘ASSETS`

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/assets_error_webhook.rb', line 15

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/the_plaid_api/models/assets_error_webhook.rb', line 86

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  error = Error.from_hash(hash['error']) if hash['error']
  asset_report_id =
    hash.key?('asset_report_id') ? hash['asset_report_id'] : nil
  environment = hash.key?('environment') ? hash['environment'] : nil
  user_id = hash.key?('user_id') ? hash['user_id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AssetsErrorWebhook.new(webhook_type: webhook_type,
                         webhook_code: webhook_code,
                         error: error,
                         asset_report_id: asset_report_id,
                         environment: environment,
                         user_id: user_id,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



46
47
48
49
50
51
52
53
54
55
# File 'lib/the_plaid_api/models/assets_error_webhook.rb', line 46

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['error'] = 'error'
  @_hash['asset_report_id'] = 'asset_report_id'
  @_hash['user_id'] = 'user_id'
  @_hash['environment'] = 'environment'
  @_hash
end

.nullablesObject

An array for nullable fields



65
66
67
68
69
# File 'lib/the_plaid_api/models/assets_error_webhook.rb', line 65

def self.nullables
  %w[
    error
  ]
end

.optionalsObject

An array for optional fields



58
59
60
61
62
# File 'lib/the_plaid_api/models/assets_error_webhook.rb', line 58

def self.optionals
  %w[
    user_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



124
125
126
127
128
129
130
# File 'lib/the_plaid_api/models/assets_error_webhook.rb', line 124

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, error: #{@error.inspect}, asset_report_id:"\
  " #{@asset_report_id.inspect}, user_id: #{@user_id.inspect}, environment:"\
  " #{@environment.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



116
117
118
119
120
121
# File 'lib/the_plaid_api/models/assets_error_webhook.rb', line 116

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, error:"\
  " #{@error}, asset_report_id: #{@asset_report_id}, user_id: #{@user_id}, environment:"\
  " #{@environment}, additional_properties: #{@additional_properties}>"
end