Class: ThePlaidApi::AuthDefaultUpdateWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/auth_default_update_webhook.rb

Overview

Plaid will trigger a ‘DEFAULT_UPDATE` webhook for Items that undergo a change in Auth data. This is generally caused by data partners notifying Plaid of a change in their account numbering system or to their routing numbers. To avoid returned transactions, customers that receive a `DEFAULT_UPDATE` webhook with the `account_ids_with_updated_auth` object populated should immediately discontinue all usages of existing Auth data for those accounts and call `/auth/get` or `/processor/auth/get` to obtain updated account and routing numbers.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, item_id:, account_ids_with_new_auth:, account_ids_with_updated_auth:, error:, environment:, additional_properties: nil) ⇒ AuthDefaultUpdateWebhook

Returns a new instance of AuthDefaultUpdateWebhook.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/the_plaid_api/models/auth_default_update_webhook.rb', line 84

def initialize(webhook_type:, webhook_code:, item_id:,
               account_ids_with_new_auth:, account_ids_with_updated_auth:,
               error:, environment:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @item_id = item_id
  @account_ids_with_new_auth = 
  @account_ids_with_updated_auth = 
  @error = error
  @environment = environment
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_ids_with_new_authArray[String]

An array of ‘account_id`’s for accounts that contain new auth.

Returns:

  • (Array[String])


33
34
35
# File 'lib/the_plaid_api/models/auth_default_update_webhook.rb', line 33

def 
  @account_ids_with_new_auth
end

#account_ids_with_updated_authHash[String, Object]

An object with keys of ‘account_id`’s that are mapped to their respective auth attributes that changed. ‘ACCOUNT_NUMBER` and `ROUTING_NUMBER` are the two potential values that can be flagged as updated. Example: `{ “XMBvvyMGQ1UoLbKByoMqH3nXMj84ALSdE5B58”: [“ACCOUNT_NUMBER”] }`

Returns:

  • (Hash[String, Object])


40
41
42
# File 'lib/the_plaid_api/models/auth_default_update_webhook.rb', line 40

def 
  @account_ids_with_updated_auth
end

#environmentWebhookEnvironmentValues

The Plaid environment the webhook was sent from



56
57
58
# File 'lib/the_plaid_api/models/auth_default_update_webhook.rb', line 56

def environment
  @environment
end

#errorError

Errors are identified by ‘error_code` and categorized by `error_type`. Use these in preference to HTTP status codes to identify and handle specific errors. HTTP status codes are set and provide the broadest categorization of errors: 4xx codes are for developer- or user-related errors, and 5xx codes are for Plaid-related errors, and the status will be 2xx in non-error cases. An Item with a non-`null` error object will only be part of an API response when calling `/item/get` to view Item status. Otherwise, error fields will be `null` if no error has occurred; if an error has occurred, an error code will be returned instead.

Returns:



52
53
54
# File 'lib/the_plaid_api/models/auth_default_update_webhook.rb', line 52

def error
  @error
end

#item_idString

The ‘item_id` of the Item associated with this webhook, warning, or error

Returns:

  • (String)


29
30
31
# File 'lib/the_plaid_api/models/auth_default_update_webhook.rb', line 29

def item_id
  @item_id
end

#webhook_codeString

‘DEFAULT_UPDATE`

Returns:

  • (String)


25
26
27
# File 'lib/the_plaid_api/models/auth_default_update_webhook.rb', line 25

def webhook_code
  @webhook_code
end

#webhook_typeString

‘AUTH`

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/auth_default_update_webhook.rb', line 21

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/the_plaid_api/models/auth_default_update_webhook.rb', line 101

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  item_id = hash.key?('item_id') ? hash['item_id'] : nil
   =
    hash.key?('account_ids_with_new_auth') ? hash['account_ids_with_new_auth'] : nil
   =
    hash.key?('account_ids_with_updated_auth') ? hash['account_ids_with_updated_auth'] : nil
  error = Error.from_hash(hash['error']) if hash['error']
  environment = hash.key?('environment') ? hash['environment'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AuthDefaultUpdateWebhook.new(webhook_type: webhook_type,
                               webhook_code: webhook_code,
                               item_id: item_id,
                               account_ids_with_new_auth: ,
                               account_ids_with_updated_auth: ,
                               error: error,
                               environment: environment,
                               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/the_plaid_api/models/auth_default_update_webhook.rb', line 59

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['item_id'] = 'item_id'
  @_hash['account_ids_with_new_auth'] = 'account_ids_with_new_auth'
  @_hash['account_ids_with_updated_auth'] =
    'account_ids_with_updated_auth'
  @_hash['error'] = 'error'
  @_hash['environment'] = 'environment'
  @_hash
end

.nullablesObject

An array for nullable fields



78
79
80
81
82
# File 'lib/the_plaid_api/models/auth_default_update_webhook.rb', line 78

def self.nullables
  %w[
    error
  ]
end

.optionalsObject

An array for optional fields



73
74
75
# File 'lib/the_plaid_api/models/auth_default_update_webhook.rb', line 73

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



143
144
145
146
147
148
149
150
# File 'lib/the_plaid_api/models/auth_default_update_webhook.rb', line 143

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, item_id: #{@item_id.inspect}, account_ids_with_new_auth:"\
  " #{@account_ids_with_new_auth.inspect}, account_ids_with_updated_auth:"\
  " #{@account_ids_with_updated_auth.inspect}, error: #{@error.inspect}, environment:"\
  " #{@environment.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



134
135
136
137
138
139
140
# File 'lib/the_plaid_api/models/auth_default_update_webhook.rb', line 134

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, item_id:"\
  " #{@item_id}, account_ids_with_new_auth: #{@account_ids_with_new_auth},"\
  " account_ids_with_updated_auth: #{@account_ids_with_updated_auth}, error: #{@error},"\
  " environment: #{@environment}, additional_properties: #{@additional_properties}>"
end