Class: ThePlaidApi::AuthGetRequestOptions

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/auth_get_request_options.rb

Overview

An optional object to filter ‘/auth/get` results.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_ids: SKIP, additional_properties: nil) ⇒ AuthGetRequestOptions

Returns a new instance of AuthGetRequestOptions.



37
38
39
40
41
42
43
# File 'lib/the_plaid_api/models/auth_get_request_options.rb', line 37

def initialize(account_ids: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_ids =  unless  == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_idsArray[String]

A list of ‘account_ids` to retrieve for the Item. Note: An error will be returned if a provided `account_id` is not associated with the Item.

Returns:

  • (Array[String])


16
17
18
# File 'lib/the_plaid_api/models/auth_get_request_options.rb', line 16

def 
  @account_ids
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/the_plaid_api/models/auth_get_request_options.rb', line 46

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('account_ids') ? hash['account_ids'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AuthGetRequestOptions.new(account_ids: ,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



19
20
21
22
23
# File 'lib/the_plaid_api/models/auth_get_request_options.rb', line 19

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_ids'] = 'account_ids'
  @_hash
end

.nullablesObject

An array for nullable fields



33
34
35
# File 'lib/the_plaid_api/models/auth_get_request_options.rb', line 33

def self.nullables
  []
end

.optionalsObject

An array for optional fields



26
27
28
29
30
# File 'lib/the_plaid_api/models/auth_get_request_options.rb', line 26

def self.optionals
  %w[
    account_ids
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



72
73
74
75
76
# File 'lib/the_plaid_api/models/auth_get_request_options.rb', line 72

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_ids: #{@account_ids.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



65
66
67
68
69
# File 'lib/the_plaid_api/models/auth_get_request_options.rb', line 65

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_ids: #{@account_ids}, additional_properties:"\
  " #{@additional_properties}>"
end