Class: ThePlaidApi::AuthGetResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/auth_get_response.rb

Overview

AuthGetResponse defines the response schema for ‘/auth/get`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(accounts:, numbers:, item:, request_id:, additional_properties: nil) ⇒ AuthGetResponse

Returns a new instance of AuthGetResponse.



55
56
57
58
59
60
61
62
63
64
65
# File 'lib/the_plaid_api/models/auth_get_response.rb', line 55

def initialize(accounts:, numbers:, item:, request_id:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @accounts = accounts
  @numbers = numbers
  @item = item
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#accountsArray[Account]

The ‘accounts` for which numbers are being retrieved.

Returns:



14
15
16
# File 'lib/the_plaid_api/models/auth_get_response.rb', line 14

def accounts
  @accounts
end

#itemItem

Metadata about the Item.

Returns:



27
28
29
# File 'lib/the_plaid_api/models/auth_get_response.rb', line 27

def item
  @item
end

#numbersAuthGetNumbers

An object containing identifying numbers used for making electronic transfers to and from the ‘accounts`. The identifying number type (ACH, EFT, IBAN, or BACS) used will depend on the country of the account. An account may have more than one number type. If a particular identifying number type is not used by any `accounts` for which data has been requested, the array for that type will be empty.

Returns:



23
24
25
# File 'lib/the_plaid_api/models/auth_get_response.rb', line 23

def numbers
  @numbers
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


33
34
35
# File 'lib/the_plaid_api/models/auth_get_response.rb', line 33

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/the_plaid_api/models/auth_get_response.rb', line 68

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  accounts = nil
  unless hash['accounts'].nil?
    accounts = []
    hash['accounts'].each do |structure|
      accounts << (Account.from_hash(structure) if structure)
    end
  end

  accounts = nil unless hash.key?('accounts')
  numbers = AuthGetNumbers.from_hash(hash['numbers']) if hash['numbers']
  item = Item.from_hash(hash['item']) if hash['item']
  request_id = hash.key?('request_id') ? hash['request_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AuthGetResponse.new(accounts: accounts,
                      numbers: numbers,
                      item: item,
                      request_id: request_id,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



36
37
38
39
40
41
42
43
# File 'lib/the_plaid_api/models/auth_get_response.rb', line 36

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['accounts'] = 'accounts'
  @_hash['numbers'] = 'numbers'
  @_hash['item'] = 'item'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



51
52
53
# File 'lib/the_plaid_api/models/auth_get_response.rb', line 51

def self.nullables
  []
end

.optionalsObject

An array for optional fields



46
47
48
# File 'lib/the_plaid_api/models/auth_get_response.rb', line 46

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



109
110
111
112
113
114
# File 'lib/the_plaid_api/models/auth_get_response.rb', line 109

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} accounts: #{@accounts.inspect}, numbers: #{@numbers.inspect}, item:"\
  " #{@item.inspect}, request_id: #{@request_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



102
103
104
105
106
# File 'lib/the_plaid_api/models/auth_get_response.rb', line 102

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} accounts: #{@accounts}, numbers: #{@numbers}, item: #{@item}, request_id:"\
  " #{@request_id}, additional_properties: #{@additional_properties}>"
end