Class: ThePlaidApi::AuthSupportedMethods

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/auth_supported_methods.rb

Overview

Metadata specifically related to which auth methods an institution supports.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(instant_auth:, instant_match:, automated_micro_deposits:, instant_micro_deposits:, additional_properties: nil) ⇒ AuthSupportedMethods

Returns a new instance of AuthSupportedMethods.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/the_plaid_api/models/auth_supported_methods.rb', line 48

def initialize(instant_auth:, instant_match:, automated_micro_deposits:,
               instant_micro_deposits:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @instant_auth = instant_auth
  @instant_match = instant_match
  @automated_micro_deposits = automated_micro_deposits
  @instant_micro_deposits = instant_micro_deposits
  @additional_properties = additional_properties
end

Instance Attribute Details

#automated_micro_depositsTrueClass | FalseClass

Indicates if automated microdeposits are supported.

Returns:

  • (TrueClass | FalseClass)


22
23
24
# File 'lib/the_plaid_api/models/auth_supported_methods.rb', line 22

def automated_micro_deposits
  @automated_micro_deposits
end

#instant_authTrueClass | FalseClass

Indicates if instant auth is supported.

Returns:

  • (TrueClass | FalseClass)


14
15
16
# File 'lib/the_plaid_api/models/auth_supported_methods.rb', line 14

def instant_auth
  @instant_auth
end

#instant_matchTrueClass | FalseClass

Indicates if instant match is supported.

Returns:

  • (TrueClass | FalseClass)


18
19
20
# File 'lib/the_plaid_api/models/auth_supported_methods.rb', line 18

def instant_match
  @instant_match
end

#instant_micro_depositsTrueClass | FalseClass

Indicates if instant microdeposits are supported.

Returns:

  • (TrueClass | FalseClass)


26
27
28
# File 'lib/the_plaid_api/models/auth_supported_methods.rb', line 26

def instant_micro_deposits
  @instant_micro_deposits
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/the_plaid_api/models/auth_supported_methods.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  instant_auth = hash.key?('instant_auth') ? hash['instant_auth'] : nil
  instant_match = hash.key?('instant_match') ? hash['instant_match'] : nil
  automated_micro_deposits =
    hash.key?('automated_micro_deposits') ? hash['automated_micro_deposits'] : nil
  instant_micro_deposits =
    hash.key?('instant_micro_deposits') ? hash['instant_micro_deposits'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AuthSupportedMethods.new(instant_auth: instant_auth,
                           instant_match: instant_match,
                           automated_micro_deposits: automated_micro_deposits,
                           instant_micro_deposits: instant_micro_deposits,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/the_plaid_api/models/auth_supported_methods.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['instant_auth'] = 'instant_auth'
  @_hash['instant_match'] = 'instant_match'
  @_hash['automated_micro_deposits'] = 'automated_micro_deposits'
  @_hash['instant_micro_deposits'] = 'instant_micro_deposits'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/the_plaid_api/models/auth_supported_methods.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
# File 'lib/the_plaid_api/models/auth_supported_methods.rb', line 39

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



96
97
98
99
100
101
102
# File 'lib/the_plaid_api/models/auth_supported_methods.rb', line 96

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} instant_auth: #{@instant_auth.inspect}, instant_match:"\
  " #{@instant_match.inspect}, automated_micro_deposits: #{@automated_micro_deposits.inspect},"\
  " instant_micro_deposits: #{@instant_micro_deposits.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



88
89
90
91
92
93
# File 'lib/the_plaid_api/models/auth_supported_methods.rb', line 88

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} instant_auth: #{@instant_auth}, instant_match: #{@instant_match},"\
  " automated_micro_deposits: #{@automated_micro_deposits}, instant_micro_deposits:"\
  " #{@instant_micro_deposits}, additional_properties: #{@additional_properties}>"
end