Class: ThePlaidApi::AuthVerifyRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/auth_verify_request.rb

Overview

AuthVerifyRequest defines the request schema for ‘/auth/verify`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(numbers:, client_id: SKIP, secret: SKIP, legal_name: SKIP, additional_properties: nil) ⇒ AuthVerifyRequest

Returns a new instance of AuthVerifyRequest.



58
59
60
61
62
63
64
65
66
67
68
# File 'lib/the_plaid_api/models/auth_verify_request.rb', line 58

def initialize(numbers:, client_id: SKIP, secret: SKIP, legal_name: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @legal_name = legal_name unless legal_name == SKIP
  @numbers = numbers
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/auth_verify_request.rb', line 16

def client_id
  @client_id
end

Account owner’s legal name

Returns:

  • (String)


25
26
27
# File 'lib/the_plaid_api/models/auth_verify_request.rb', line 25

def legal_name
  @legal_name
end

#numbersAuthVerifyRequestNumbers

An object containing identifying account numbers for verification via Database Auth



30
31
32
# File 'lib/the_plaid_api/models/auth_verify_request.rb', line 30

def numbers
  @numbers
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/auth_verify_request.rb', line 21

def secret
  @secret
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/the_plaid_api/models/auth_verify_request.rb', line 71

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  numbers = AuthVerifyRequestNumbers.from_hash(hash['numbers']) if hash['numbers']
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  legal_name = hash.key?('legal_name') ? hash['legal_name'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AuthVerifyRequest.new(numbers: numbers,
                        client_id: client_id,
                        secret: secret,
                        legal_name: legal_name,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
# File 'lib/the_plaid_api/models/auth_verify_request.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['legal_name'] = 'legal_name'
  @_hash['numbers'] = 'numbers'
  @_hash
end

.nullablesObject

An array for nullable fields



52
53
54
55
56
# File 'lib/the_plaid_api/models/auth_verify_request.rb', line 52

def self.nullables
  %w[
    legal_name
  ]
end

.optionalsObject

An array for optional fields



43
44
45
46
47
48
49
# File 'lib/the_plaid_api/models/auth_verify_request.rb', line 43

def self.optionals
  %w[
    client_id
    secret
    legal_name
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



103
104
105
106
107
108
# File 'lib/the_plaid_api/models/auth_verify_request.rb', line 103

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, legal_name:"\
  " #{@legal_name.inspect}, numbers: #{@numbers.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



96
97
98
99
100
# File 'lib/the_plaid_api/models/auth_verify_request.rb', line 96

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, legal_name: #{@legal_name},"\
  " numbers: #{@numbers}, additional_properties: #{@additional_properties}>"
end