Class: ThePlaidApi::AutomaticallyVerifiedWebhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::AutomaticallyVerifiedWebhook
- Defined in:
- lib/the_plaid_api/models/automatically_verified_webhook.rb
Overview
Fired when an Item is verified via automated micro-deposits. We recommend communicating to your users when this event is received to notify them that their account is verified and ready for use.
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ‘account_id` of the account associated with the webhook.
-
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from.
-
#error ⇒ Error
Errors are identified by ‘error_code` and categorized by `error_type`.
-
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error.
-
#webhook_code ⇒ String
‘AUTOMATICALLY_VERIFIED`.
-
#webhook_type ⇒ String
‘AUTH`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, account_id:, item_id:, environment:, error: SKIP, additional_properties: nil) ⇒ AutomaticallyVerifiedWebhook
constructor
A new instance of AutomaticallyVerifiedWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, account_id:, item_id:, environment:, error: SKIP, additional_properties: nil) ⇒ AutomaticallyVerifiedWebhook
Returns a new instance of AutomaticallyVerifiedWebhook.
72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/the_plaid_api/models/automatically_verified_webhook.rb', line 72 def initialize(webhook_type:, webhook_code:, account_id:, item_id:, environment:, error: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @account_id = account_id @item_id = item_id @environment = environment @error = error unless error == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
The ‘account_id` of the account associated with the webhook
24 25 26 |
# File 'lib/the_plaid_api/models/automatically_verified_webhook.rb', line 24 def account_id @account_id end |
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from
32 33 34 |
# File 'lib/the_plaid_api/models/automatically_verified_webhook.rb', line 32 def environment @environment end |
#error ⇒ Error
Errors are identified by ‘error_code` and categorized by `error_type`. Use these in preference to HTTP status codes to identify and handle specific errors. HTTP status codes are set and provide the broadest categorization of errors: 4xx codes are for developer- or user-related errors, and 5xx codes are for Plaid-related errors, and the status will be 2xx in non-error cases. An Item with a non-`null` error object will only be part of an API response when calling `/item/get` to view Item status. Otherwise, error fields will be `null` if no error has occurred; if an error has occurred, an error code will be returned instead.
44 45 46 |
# File 'lib/the_plaid_api/models/automatically_verified_webhook.rb', line 44 def error @error end |
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error
28 29 30 |
# File 'lib/the_plaid_api/models/automatically_verified_webhook.rb', line 28 def item_id @item_id end |
#webhook_code ⇒ String
‘AUTOMATICALLY_VERIFIED`
20 21 22 |
# File 'lib/the_plaid_api/models/automatically_verified_webhook.rb', line 20 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘AUTH`
16 17 18 |
# File 'lib/the_plaid_api/models/automatically_verified_webhook.rb', line 16 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/the_plaid_api/models/automatically_verified_webhook.rb', line 87 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil account_id = hash.key?('account_id') ? hash['account_id'] : nil item_id = hash.key?('item_id') ? hash['item_id'] : nil environment = hash.key?('environment') ? hash['environment'] : nil error = Error.from_hash(hash['error']) if hash['error'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AutomaticallyVerifiedWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, account_id: account_id, item_id: item_id, environment: environment, error: error, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/the_plaid_api/models/automatically_verified_webhook.rb', line 47 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['account_id'] = 'account_id' @_hash['item_id'] = 'item_id' @_hash['environment'] = 'environment' @_hash['error'] = 'error' @_hash end |
.nullables ⇒ Object
An array for nullable fields
66 67 68 69 70 |
# File 'lib/the_plaid_api/models/automatically_verified_webhook.rb', line 66 def self.nullables %w[ error ] end |
.optionals ⇒ Object
An array for optional fields
59 60 61 62 63 |
# File 'lib/the_plaid_api/models/automatically_verified_webhook.rb', line 59 def self.optionals %w[ error ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
124 125 126 127 128 129 130 |
# File 'lib/the_plaid_api/models/automatically_verified_webhook.rb', line 124 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, account_id: #{@account_id.inspect}, item_id:"\ " #{@item_id.inspect}, environment: #{@environment.inspect}, error: #{@error.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
116 117 118 119 120 121 |
# File 'lib/the_plaid_api/models/automatically_verified_webhook.rb', line 116 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, account_id:"\ " #{@account_id}, item_id: #{@item_id}, environment: #{@environment}, error: #{@error},"\ " additional_properties: #{@additional_properties}>" end |