Class: ThePlaidApi::BankTransferBalanceGetRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::BankTransferBalanceGetRequest
- Defined in:
- lib/the_plaid_api/models/bank_transfer_balance_get_request.rb
Overview
Defines the request schema for ‘/bank_transfer/balance/get`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#origination_account_id ⇒ String
If multiple origination accounts are available, ‘origination_account_id` must be used to specify the account for which balance will be returned.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_id: SKIP, secret: SKIP, origination_account_id: SKIP, additional_properties: nil) ⇒ BankTransferBalanceGetRequest
constructor
A new instance of BankTransferBalanceGetRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_id: SKIP, secret: SKIP, origination_account_id: SKIP, additional_properties: nil) ⇒ BankTransferBalanceGetRequest
Returns a new instance of BankTransferBalanceGetRequest.
53 54 55 56 57 58 59 60 61 62 |
# File 'lib/the_plaid_api/models/bank_transfer_balance_get_request.rb', line 53 def initialize(client_id: SKIP, secret: SKIP, origination_account_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @origination_account_id = origination_account_id unless origination_account_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/the_plaid_api/models/bank_transfer_balance_get_request.rb', line 16 def client_id @client_id end |
#origination_account_id ⇒ String
If multiple origination accounts are available, ‘origination_account_id` must be used to specify the account for which balance will be returned.
26 27 28 |
# File 'lib/the_plaid_api/models/bank_transfer_balance_get_request.rb', line 26 def origination_account_id @origination_account_id end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
21 22 23 |
# File 'lib/the_plaid_api/models/bank_transfer_balance_get_request.rb', line 21 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/the_plaid_api/models/bank_transfer_balance_get_request.rb', line 65 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP origination_account_id = hash.key?('origination_account_id') ? hash['origination_account_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BankTransferBalanceGetRequest.new(client_id: client_id, secret: secret, origination_account_id: origination_account_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 |
# File 'lib/the_plaid_api/models/bank_transfer_balance_get_request.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['origination_account_id'] = 'origination_account_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
47 48 49 50 51 |
# File 'lib/the_plaid_api/models/bank_transfer_balance_get_request.rb', line 47 def self.nullables %w[ origination_account_id ] end |
.optionals ⇒ Object
An array for optional fields
38 39 40 41 42 43 44 |
# File 'lib/the_plaid_api/models/bank_transfer_balance_get_request.rb', line 38 def self.optionals %w[ client_id secret origination_account_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
96 97 98 99 100 101 |
# File 'lib/the_plaid_api/models/bank_transfer_balance_get_request.rb', line 96 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\ " origination_account_id: #{@origination_account_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
89 90 91 92 93 |
# File 'lib/the_plaid_api/models/bank_transfer_balance_get_request.rb', line 89 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, origination_account_id:"\ " #{@origination_account_id}, additional_properties: #{@additional_properties}>" end |