Class: ThePlaidApi::BankTransferSweep

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/bank_transfer_sweep.rb

Overview

BankTransferSweep describes a sweep transfer.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id:, created_at:, amount:, iso_currency_code:, additional_properties: nil) ⇒ BankTransferSweep

Returns a new instance of BankTransferSweep.



49
50
51
52
53
54
55
56
57
58
59
# File 'lib/the_plaid_api/models/bank_transfer_sweep.rb', line 49

def initialize(id:, created_at:, amount:, iso_currency_code:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id
  @created_at = created_at
  @amount = amount
  @iso_currency_code = iso_currency_code
  @additional_properties = additional_properties
end

Instance Attribute Details

#amountString

The amount of the sweep.

Returns:

  • (String)


23
24
25
# File 'lib/the_plaid_api/models/bank_transfer_sweep.rb', line 23

def amount
  @amount
end

#created_atDateTime

The datetime when the sweep occurred, in RFC 3339 format.

Returns:

  • (DateTime)


19
20
21
# File 'lib/the_plaid_api/models/bank_transfer_sweep.rb', line 19

def created_at
  @created_at
end

#idString

Identifier of the sweep.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/bank_transfer_sweep.rb', line 15

def id
  @id
end

#iso_currency_codeString

The currency of the sweep, e.g. “USD”.

Returns:

  • (String)


27
28
29
# File 'lib/the_plaid_api/models/bank_transfer_sweep.rb', line 27

def iso_currency_code
  @iso_currency_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/the_plaid_api/models/bank_transfer_sweep.rb', line 62

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  created_at = if hash.key?('created_at')
                 (DateTimeHelper.from_rfc3339(hash['created_at']) if hash['created_at'])
               end
  amount = hash.key?('amount') ? hash['amount'] : nil
  iso_currency_code =
    hash.key?('iso_currency_code') ? hash['iso_currency_code'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BankTransferSweep.new(id: id,
                        created_at: created_at,
                        amount: amount,
                        iso_currency_code: iso_currency_code,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



30
31
32
33
34
35
36
37
# File 'lib/the_plaid_api/models/bank_transfer_sweep.rb', line 30

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['created_at'] = 'created_at'
  @_hash['amount'] = 'amount'
  @_hash['iso_currency_code'] = 'iso_currency_code'
  @_hash
end

.nullablesObject

An array for nullable fields



45
46
47
# File 'lib/the_plaid_api/models/bank_transfer_sweep.rb', line 45

def self.nullables
  []
end

.optionalsObject

An array for optional fields



40
41
42
# File 'lib/the_plaid_api/models/bank_transfer_sweep.rb', line 40

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



102
103
104
105
106
107
# File 'lib/the_plaid_api/models/bank_transfer_sweep.rb', line 102

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, created_at: #{@created_at.inspect}, amount:"\
  " #{@amount.inspect}, iso_currency_code: #{@iso_currency_code.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_custom_created_atObject



89
90
91
# File 'lib/the_plaid_api/models/bank_transfer_sweep.rb', line 89

def to_custom_created_at
  DateTimeHelper.to_rfc3339(created_at)
end

#to_sObject

Provides a human-readable string representation of the object.



94
95
96
97
98
99
# File 'lib/the_plaid_api/models/bank_transfer_sweep.rb', line 94

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, created_at: #{@created_at}, amount: #{@amount},"\
  " iso_currency_code: #{@iso_currency_code}, additional_properties:"\
  " #{@additional_properties}>"
end