Class: ThePlaidApi::BankTransferSweepListRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/bank_transfer_sweep_list_request.rb

Overview

BankTransferSweepListRequest defines the request schema for ‘/bank_transfer/sweep/list`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(client_id: SKIP, secret: SKIP, origination_account_id: SKIP, start_time: SKIP, end_time: SKIP, count: 25, additional_properties: nil) ⇒ BankTransferSweepListRequest

Returns a new instance of BankTransferSweepListRequest.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/the_plaid_api/models/bank_transfer_sweep_list_request.rb', line 76

def initialize(client_id: SKIP, secret: SKIP, origination_account_id: SKIP,
               start_time: SKIP, end_time: SKIP, count: 25,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @origination_account_id =  unless  == SKIP
  @start_time = start_time unless start_time == SKIP
  @end_time = end_time unless end_time == SKIP
  @count = count unless count == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


18
19
20
# File 'lib/the_plaid_api/models/bank_transfer_sweep_list_request.rb', line 18

def client_id
  @client_id
end

#countInteger

The maximum number of sweeps to return.

Returns:

  • (Integer)


40
41
42
# File 'lib/the_plaid_api/models/bank_transfer_sweep_list_request.rb', line 40

def count
  @count
end

#end_timeDateTime

The end ‘created` datetime of sweeps to return (RFC 3339 format).

Returns:

  • (DateTime)


36
37
38
# File 'lib/the_plaid_api/models/bank_transfer_sweep_list_request.rb', line 36

def end_time
  @end_time
end

#origination_account_idString

If multiple origination accounts are available, ‘origination_account_id` must be used to specify the account that the sweeps belong to.

Returns:

  • (String)


28
29
30
# File 'lib/the_plaid_api/models/bank_transfer_sweep_list_request.rb', line 28

def 
  @origination_account_id
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


23
24
25
# File 'lib/the_plaid_api/models/bank_transfer_sweep_list_request.rb', line 23

def secret
  @secret
end

#start_timeDateTime

The start ‘created` datetime of sweeps to return (RFC 3339 format).

Returns:

  • (DateTime)


32
33
34
# File 'lib/the_plaid_api/models/bank_transfer_sweep_list_request.rb', line 32

def start_time
  @start_time
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/the_plaid_api/models/bank_transfer_sweep_list_request.rb', line 92

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
   =
    hash.key?('origination_account_id') ? hash['origination_account_id'] : SKIP
  start_time = if hash.key?('start_time')
                 (DateTimeHelper.from_rfc3339(hash['start_time']) if hash['start_time'])
               else
                 SKIP
               end
  end_time = if hash.key?('end_time')
               (DateTimeHelper.from_rfc3339(hash['end_time']) if hash['end_time'])
             else
               SKIP
             end
  count = hash['count'] ||= 25

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BankTransferSweepListRequest.new(client_id: client_id,
                                   secret: secret,
                                   origination_account_id: ,
                                   start_time: start_time,
                                   end_time: end_time,
                                   count: count,
                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



43
44
45
46
47
48
49
50
51
52
# File 'lib/the_plaid_api/models/bank_transfer_sweep_list_request.rb', line 43

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['origination_account_id'] = 'origination_account_id'
  @_hash['start_time'] = 'start_time'
  @_hash['end_time'] = 'end_time'
  @_hash['count'] = 'count'
  @_hash
end

.nullablesObject

An array for nullable fields



67
68
69
70
71
72
73
74
# File 'lib/the_plaid_api/models/bank_transfer_sweep_list_request.rb', line 67

def self.nullables
  %w[
    origination_account_id
    start_time
    end_time
    count
  ]
end

.optionalsObject

An array for optional fields



55
56
57
58
59
60
61
62
63
64
# File 'lib/the_plaid_api/models/bank_transfer_sweep_list_request.rb', line 55

def self.optionals
  %w[
    client_id
    secret
    origination_account_id
    start_time
    end_time
    count
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



146
147
148
149
150
151
152
# File 'lib/the_plaid_api/models/bank_transfer_sweep_list_request.rb', line 146

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\
  " origination_account_id: #{@origination_account_id.inspect}, start_time:"\
  " #{@start_time.inspect}, end_time: #{@end_time.inspect}, count: #{@count.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_custom_end_timeObject



133
134
135
# File 'lib/the_plaid_api/models/bank_transfer_sweep_list_request.rb', line 133

def to_custom_end_time
  DateTimeHelper.to_rfc3339(end_time)
end

#to_custom_start_timeObject



129
130
131
# File 'lib/the_plaid_api/models/bank_transfer_sweep_list_request.rb', line 129

def to_custom_start_time
  DateTimeHelper.to_rfc3339(start_time)
end

#to_sObject

Provides a human-readable string representation of the object.



138
139
140
141
142
143
# File 'lib/the_plaid_api/models/bank_transfer_sweep_list_request.rb', line 138

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, origination_account_id:"\
  " #{@origination_account_id}, start_time: #{@start_time}, end_time: #{@end_time}, count:"\
  " #{@count}, additional_properties: #{@additional_properties}>"
end