Class: ThePlaidApi::BankTransfersEventsUpdateWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/bank_transfers_events_update_webhook.rb

Overview

Fired when new bank transfer events are available. Receiving this webhook indicates you should fetch the new events from ‘/bank_transfer/event/sync`.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, environment:, additional_properties: nil) ⇒ BankTransfersEventsUpdateWebhook

Returns a new instance of BankTransfersEventsUpdateWebhook.



44
45
46
47
48
49
50
51
52
53
# File 'lib/the_plaid_api/models/bank_transfers_events_update_webhook.rb', line 44

def initialize(webhook_type:, webhook_code:, environment:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @environment = environment
  @additional_properties = additional_properties
end

Instance Attribute Details

#environmentWebhookEnvironmentValues

The Plaid environment the webhook was sent from



23
24
25
# File 'lib/the_plaid_api/models/bank_transfers_events_update_webhook.rb', line 23

def environment
  @environment
end

#webhook_codeString

‘BANK_TRANSFERS_EVENTS_UPDATE`

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/bank_transfers_events_update_webhook.rb', line 19

def webhook_code
  @webhook_code
end

#webhook_typeString

‘BANK_TRANSFERS`

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/bank_transfers_events_update_webhook.rb', line 15

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/the_plaid_api/models/bank_transfers_events_update_webhook.rb', line 56

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  environment = hash.key?('environment') ? hash['environment'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BankTransfersEventsUpdateWebhook.new(webhook_type: webhook_type,
                                       webhook_code: webhook_code,
                                       environment: environment,
                                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/the_plaid_api/models/bank_transfers_events_update_webhook.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['environment'] = 'environment'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/the_plaid_api/models/bank_transfers_events_update_webhook.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
# File 'lib/the_plaid_api/models/bank_transfers_events_update_webhook.rb', line 35

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



86
87
88
89
90
91
# File 'lib/the_plaid_api/models/bank_transfers_events_update_webhook.rb', line 86

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, environment: #{@environment.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



79
80
81
82
83
# File 'lib/the_plaid_api/models/bank_transfers_events_update_webhook.rb', line 79

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code},"\
  " environment: #{@environment}, additional_properties: #{@additional_properties}>"
end