Class: ThePlaidApi::BankTransfersEventsUpdateWebhookForAuth
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::BankTransfersEventsUpdateWebhookForAuth
- Defined in:
- lib/the_plaid_api/models/bank_transfers_events_update_webhook_for_auth.rb
Overview
Fired when new ACH events are available. To begin receiving this webhook, you must first register your webhook listener endpoint via the [webhooks page in the Dashboard](dashboard.plaid.com/team/webhooks). The ‘BANK_TRANSFERS_EVENTS_UPDATE` webhook can be used to track the progress of ACH transfers used in [micro-deposit verification](docs/auth/coverage/microdeposit-events/). Receiving this webhook indicates you should fetch the new events from `/bank_transfer/event/sync`. Note that [Transfer](plaid.com/docs/transfer) customers should use Transfer webhooks instead of using `BANK_TRANSFERS_EVENTS_UPDATE`; see [micro-deposit events documentation](plaid.com/docs/auth/coverage/microdeposit-events/) for more details.
Instance Attribute Summary collapse
-
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from.
-
#webhook_code ⇒ String
‘BANK_TRANSFERS_EVENTS_UPDATE`.
-
#webhook_type ⇒ String
‘BANK_TRANSFERS`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, environment:, additional_properties: nil) ⇒ BankTransfersEventsUpdateWebhookForAuth
constructor
A new instance of BankTransfersEventsUpdateWebhookForAuth.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, environment:, additional_properties: nil) ⇒ BankTransfersEventsUpdateWebhookForAuth
Returns a new instance of BankTransfersEventsUpdateWebhookForAuth.
55 56 57 58 59 60 61 62 63 64 |
# File 'lib/the_plaid_api/models/bank_transfers_events_update_webhook_for_auth.rb', line 55 def initialize(webhook_type:, webhook_code:, environment:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @environment = environment @additional_properties = additional_properties end |
Instance Attribute Details
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from
34 35 36 |
# File 'lib/the_plaid_api/models/bank_transfers_events_update_webhook_for_auth.rb', line 34 def environment @environment end |
#webhook_code ⇒ String
‘BANK_TRANSFERS_EVENTS_UPDATE`
30 31 32 |
# File 'lib/the_plaid_api/models/bank_transfers_events_update_webhook_for_auth.rb', line 30 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘BANK_TRANSFERS`
26 27 28 |
# File 'lib/the_plaid_api/models/bank_transfers_events_update_webhook_for_auth.rb', line 26 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/the_plaid_api/models/bank_transfers_events_update_webhook_for_auth.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil environment = hash.key?('environment') ? hash['environment'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BankTransfersEventsUpdateWebhookForAuth.new(webhook_type: webhook_type, webhook_code: webhook_code, environment: environment, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 |
# File 'lib/the_plaid_api/models/bank_transfers_events_update_webhook_for_auth.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['environment'] = 'environment' @_hash end |
.nullables ⇒ Object
An array for nullable fields
51 52 53 |
# File 'lib/the_plaid_api/models/bank_transfers_events_update_webhook_for_auth.rb', line 51 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
46 47 48 |
# File 'lib/the_plaid_api/models/bank_transfers_events_update_webhook_for_auth.rb', line 46 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
97 98 99 100 101 102 |
# File 'lib/the_plaid_api/models/bank_transfers_events_update_webhook_for_auth.rb', line 97 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, environment: #{@environment.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
90 91 92 93 94 |
# File 'lib/the_plaid_api/models/bank_transfers_events_update_webhook_for_auth.rb', line 90 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code},"\ " environment: #{@environment}, additional_properties: #{@additional_properties}>" end |