Class: ThePlaidApi::BaseReportAverageMonthlyBalances

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/base_report_average_monthly_balances.rb

Overview

Average balance in dollar amount per month

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(start_date:, end_date:, average_balance:, additional_properties: nil) ⇒ BaseReportAverageMonthlyBalances

Returns a new instance of BaseReportAverageMonthlyBalances.



46
47
48
49
50
51
52
53
54
55
# File 'lib/the_plaid_api/models/base_report_average_monthly_balances.rb', line 46

def initialize(start_date:, end_date:, average_balance:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @start_date = start_date
  @end_date = end_date
  @average_balance = average_balance
  @additional_properties = additional_properties
end

Instance Attribute Details

#average_balanceCreditAmountWithCurrency

This contains an amount, denominated in the currency specified by either ‘iso_currency_code` or `unofficial_currency_code`



25
26
27
# File 'lib/the_plaid_api/models/base_report_average_monthly_balances.rb', line 25

def average_balance
  @average_balance
end

#end_dateString

The end date of this time period. The date will be returned in an ISO 8601 format (YYYY-MM-DD).

Returns:

  • (String)


20
21
22
# File 'lib/the_plaid_api/models/base_report_average_monthly_balances.rb', line 20

def end_date
  @end_date
end

#start_dateString

The start date of this time period. The date will be returned in an ISO 8601 format (YYYY-MM-DD).

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/base_report_average_monthly_balances.rb', line 15

def start_date
  @start_date
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/the_plaid_api/models/base_report_average_monthly_balances.rb', line 58

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  start_date = hash.key?('start_date') ? hash['start_date'] : nil
  end_date = hash.key?('end_date') ? hash['end_date'] : nil
  average_balance = CreditAmountWithCurrency.from_hash(hash['average_balance']) if
    hash['average_balance']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BaseReportAverageMonthlyBalances.new(start_date: start_date,
                                       end_date: end_date,
                                       average_balance: average_balance,
                                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



28
29
30
31
32
33
34
# File 'lib/the_plaid_api/models/base_report_average_monthly_balances.rb', line 28

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['start_date'] = 'start_date'
  @_hash['end_date'] = 'end_date'
  @_hash['average_balance'] = 'average_balance'
  @_hash
end

.nullablesObject

An array for nullable fields



42
43
44
# File 'lib/the_plaid_api/models/base_report_average_monthly_balances.rb', line 42

def self.nullables
  []
end

.optionalsObject

An array for optional fields



37
38
39
# File 'lib/the_plaid_api/models/base_report_average_monthly_balances.rb', line 37

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
94
# File 'lib/the_plaid_api/models/base_report_average_monthly_balances.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} start_date: #{@start_date.inspect}, end_date: #{@end_date.inspect},"\
  " average_balance: #{@average_balance.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/the_plaid_api/models/base_report_average_monthly_balances.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} start_date: #{@start_date}, end_date: #{@end_date}, average_balance:"\
  " #{@average_balance}, additional_properties: #{@additional_properties}>"
end