Class: ThePlaidApi::BaseReportLongestGapInsights

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/base_report_longest_gap_insights.rb

Overview

Largest number of days between sequential transactions per calendar month

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(start_date: SKIP, end_date: SKIP, days: SKIP, additional_properties: nil) ⇒ BaseReportLongestGapInsights

Returns a new instance of BaseReportLongestGapInsights.



52
53
54
55
56
57
58
59
60
61
# File 'lib/the_plaid_api/models/base_report_longest_gap_insights.rb', line 52

def initialize(start_date: SKIP, end_date: SKIP, days: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @start_date = start_date unless start_date == SKIP
  @end_date = end_date unless end_date == SKIP
  @days = days unless days == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#daysInteger

Largest number of days between sequential transactions for this time period.

Returns:

  • (Integer)


25
26
27
# File 'lib/the_plaid_api/models/base_report_longest_gap_insights.rb', line 25

def days
  @days
end

#end_dateDate

The end date of this time period. The date will be returned in an ISO 8601 format (YYYY-MM-DD).

Returns:

  • (Date)


20
21
22
# File 'lib/the_plaid_api/models/base_report_longest_gap_insights.rb', line 20

def end_date
  @end_date
end

#start_dateDate

The start date of this time period. The date will be returned in an ISO 8601 format (YYYY-MM-DD).

Returns:

  • (Date)


15
16
17
# File 'lib/the_plaid_api/models/base_report_longest_gap_insights.rb', line 15

def start_date
  @start_date
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/the_plaid_api/models/base_report_longest_gap_insights.rb', line 64

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  start_date = hash.key?('start_date') ? hash['start_date'] : SKIP
  end_date = hash.key?('end_date') ? hash['end_date'] : SKIP
  days = hash.key?('days') ? hash['days'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BaseReportLongestGapInsights.new(start_date: start_date,
                                   end_date: end_date,
                                   days: days,
                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



28
29
30
31
32
33
34
# File 'lib/the_plaid_api/models/base_report_longest_gap_insights.rb', line 28

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['start_date'] = 'start_date'
  @_hash['end_date'] = 'end_date'
  @_hash['days'] = 'days'
  @_hash
end

.nullablesObject

An array for nullable fields



46
47
48
49
50
# File 'lib/the_plaid_api/models/base_report_longest_gap_insights.rb', line 46

def self.nullables
  %w[
    days
  ]
end

.optionalsObject

An array for optional fields



37
38
39
40
41
42
43
# File 'lib/the_plaid_api/models/base_report_longest_gap_insights.rb', line 37

def self.optionals
  %w[
    start_date
    end_date
    days
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



94
95
96
97
98
# File 'lib/the_plaid_api/models/base_report_longest_gap_insights.rb', line 94

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} start_date: #{@start_date.inspect}, end_date: #{@end_date.inspect}, days:"\
  " #{@days.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



87
88
89
90
91
# File 'lib/the_plaid_api/models/base_report_longest_gap_insights.rb', line 87

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} start_date: #{@start_date}, end_date: #{@end_date}, days: #{@days},"\
  " additional_properties: #{@additional_properties}>"
end