Class: ThePlaidApi::BeaconAccountRiskEvaluateAccountAttributes

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb

Overview

The attributes object contains data that can be used to assess account risk. Examples of data include: ‘days_since_first_plaid_connection`: The number of days since the first time the Item was connected to an application via Plaid `plaid_connections_count_7d`: The number of times the Item has been connected to applications via Plaid over the past 7 days `plaid_connections_count_30d`: The number of times the Item has been connected to applications via Plaid over the past 30 days `total_plaid_connections_count`: The number of times the Item has been connected to applications via Plaid For the full list and detailed documentation of core attributes available, or to request that core attributes not be returned, contact Sales or your Plaid account manager

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(days_since_first_plaid_connection: SKIP, is_account_closed: SKIP, is_account_frozen_or_restricted: SKIP, total_plaid_connections_count: SKIP, plaid_connections_count_7d: SKIP, plaid_connections_count_30d: SKIP, failed_plaid_non_oauth_authentication_attempts_count_3d: SKIP, plaid_non_oauth_authentication_attempts_count_3d: SKIP, failed_plaid_non_oauth_authentication_attempts_count_7d: SKIP, plaid_non_oauth_authentication_attempts_count_7d: SKIP, failed_plaid_non_oauth_authentication_attempts_count_30d: SKIP, plaid_non_oauth_authentication_attempts_count_30d: SKIP, distinct_ip_addresses_count_3d: SKIP, distinct_ip_addresses_count_7d: SKIP, distinct_ip_addresses_count_30d: SKIP, distinct_ip_addresses_count_90d: SKIP, distinct_user_agents_count_3d: SKIP, distinct_user_agents_count_7d: SKIP, distinct_user_agents_count_30d: SKIP, distinct_user_agents_count_90d: SKIP, address_change_count_28d: SKIP, email_change_count_28d: SKIP, phone_change_count_28d: SKIP, address_change_count_90d: SKIP, email_change_count_90d: SKIP, phone_change_count_90d: SKIP, days_since_account_opening: SKIP, days_since_first_observed_transaction: SKIP, additional_properties: nil) ⇒ BeaconAccountRiskEvaluateAccountAttributes

Returns a new instance of BeaconAccountRiskEvaluateAccountAttributes.



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 285

def initialize(
  days_since_first_plaid_connection: SKIP, is_account_closed: SKIP,
  is_account_frozen_or_restricted: SKIP,
  total_plaid_connections_count: SKIP, plaid_connections_count_7d: SKIP,
  plaid_connections_count_30d: SKIP,
  failed_plaid_non_oauth_authentication_attempts_count_3d: SKIP,
  plaid_non_oauth_authentication_attempts_count_3d: SKIP,
  failed_plaid_non_oauth_authentication_attempts_count_7d: SKIP,
  plaid_non_oauth_authentication_attempts_count_7d: SKIP,
  failed_plaid_non_oauth_authentication_attempts_count_30d: SKIP,
  plaid_non_oauth_authentication_attempts_count_30d: SKIP,
  distinct_ip_addresses_count_3d: SKIP,
  distinct_ip_addresses_count_7d: SKIP,
  distinct_ip_addresses_count_30d: SKIP,
  distinct_ip_addresses_count_90d: SKIP,
  distinct_user_agents_count_3d: SKIP, distinct_user_agents_count_7d: SKIP,
  distinct_user_agents_count_30d: SKIP,
  distinct_user_agents_count_90d: SKIP, address_change_count_28d: SKIP,
  email_change_count_28d: SKIP, phone_change_count_28d: SKIP,
  address_change_count_90d: SKIP, email_change_count_90d: SKIP,
  phone_change_count_90d: SKIP, days_since_account_opening: SKIP,
  days_since_first_observed_transaction: SKIP, additional_properties: nil
)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  unless days_since_first_plaid_connection == SKIP
    @days_since_first_plaid_connection =
      days_since_first_plaid_connection
  end
  @is_account_closed =  unless  == SKIP
  unless  == SKIP
    @is_account_frozen_or_restricted =
      
  end
  unless total_plaid_connections_count == SKIP
    @total_plaid_connections_count =
      total_plaid_connections_count
  end
  unless plaid_connections_count_7d == SKIP
    @plaid_connections_count_7d =
      plaid_connections_count_7d
  end
  unless plaid_connections_count_30d == SKIP
    @plaid_connections_count_30d =
      plaid_connections_count_30d
  end
  unless failed_plaid_non_oauth_authentication_attempts_count_3d == SKIP
    @failed_plaid_non_oauth_authentication_attempts_count_3d =
      failed_plaid_non_oauth_authentication_attempts_count_3d
  end
  unless plaid_non_oauth_authentication_attempts_count_3d == SKIP
    @plaid_non_oauth_authentication_attempts_count_3d =
      plaid_non_oauth_authentication_attempts_count_3d
  end
  unless failed_plaid_non_oauth_authentication_attempts_count_7d == SKIP
    @failed_plaid_non_oauth_authentication_attempts_count_7d =
      failed_plaid_non_oauth_authentication_attempts_count_7d
  end
  unless plaid_non_oauth_authentication_attempts_count_7d == SKIP
    @plaid_non_oauth_authentication_attempts_count_7d =
      plaid_non_oauth_authentication_attempts_count_7d
  end
  unless failed_plaid_non_oauth_authentication_attempts_count_30d == SKIP
    @failed_plaid_non_oauth_authentication_attempts_count_30d =
      failed_plaid_non_oauth_authentication_attempts_count_30d
  end
  unless plaid_non_oauth_authentication_attempts_count_30d == SKIP
    @plaid_non_oauth_authentication_attempts_count_30d =
      plaid_non_oauth_authentication_attempts_count_30d
  end
  unless distinct_ip_addresses_count_3d == SKIP
    @distinct_ip_addresses_count_3d =
      distinct_ip_addresses_count_3d
  end
  unless distinct_ip_addresses_count_7d == SKIP
    @distinct_ip_addresses_count_7d =
      distinct_ip_addresses_count_7d
  end
  unless distinct_ip_addresses_count_30d == SKIP
    @distinct_ip_addresses_count_30d =
      distinct_ip_addresses_count_30d
  end
  unless distinct_ip_addresses_count_90d == SKIP
    @distinct_ip_addresses_count_90d =
      distinct_ip_addresses_count_90d
  end
  unless distinct_user_agents_count_3d == SKIP
    @distinct_user_agents_count_3d =
      distinct_user_agents_count_3d
  end
  unless distinct_user_agents_count_7d == SKIP
    @distinct_user_agents_count_7d =
      distinct_user_agents_count_7d
  end
  unless distinct_user_agents_count_30d == SKIP
    @distinct_user_agents_count_30d =
      distinct_user_agents_count_30d
  end
  unless distinct_user_agents_count_90d == SKIP
    @distinct_user_agents_count_90d =
      distinct_user_agents_count_90d
  end
  @address_change_count_28d = address_change_count_28d unless address_change_count_28d == SKIP
  @email_change_count_28d = email_change_count_28d unless email_change_count_28d == SKIP
  @phone_change_count_28d = phone_change_count_28d unless phone_change_count_28d == SKIP
  @address_change_count_90d = address_change_count_90d unless address_change_count_90d == SKIP
  @email_change_count_90d = email_change_count_90d unless email_change_count_90d == SKIP
  @phone_change_count_90d = phone_change_count_90d unless phone_change_count_90d == SKIP
  unless  == SKIP
    @days_since_account_opening =
      
  end
  unless days_since_first_observed_transaction == SKIP
    @days_since_first_observed_transaction =
      days_since_first_observed_transaction
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#address_change_count_28dInteger

The number of times the account’s addresses on file have changed over the past 28 days

Returns:

  • (Integer)


127
128
129
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 127

def address_change_count_28d
  @address_change_count_28d
end

#address_change_count_90dInteger

The number of times the account’s addresses on file have changed over the past 90 days

Returns:

  • (Integer)


142
143
144
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 142

def address_change_count_90d
  @address_change_count_90d
end

#days_since_account_openingInteger

The number of days since the bank account was opened, as reported by the financial institution

Returns:

  • (Integer)


157
158
159
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 157

def 
  @days_since_account_opening
end

#days_since_first_observed_transactionInteger

The number of days since the oldest transaction available to Plaid for this account. This measure, combined with Plaid connection history, can be used to infer the age of the account

Returns:

  • (Integer)


163
164
165
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 163

def days_since_first_observed_transaction
  @days_since_first_observed_transaction
end

#days_since_first_plaid_connectionInteger

The number of days since the first time the Item was connected to an application via Plaid

Returns:

  • (Integer)


25
26
27
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 25

def days_since_first_plaid_connection
  @days_since_first_plaid_connection
end

#distinct_ip_addresses_count_30dInteger

The number of distinct IP addresses linked to the same bank account during Plaid authentication in the last 30 days

Returns:

  • (Integer)


97
98
99
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 97

def distinct_ip_addresses_count_30d
  @distinct_ip_addresses_count_30d
end

#distinct_ip_addresses_count_3dInteger

The number of distinct IP addresses linked to the same bank account during Plaid authentication in the last 3 days

Returns:

  • (Integer)


87
88
89
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 87

def distinct_ip_addresses_count_3d
  @distinct_ip_addresses_count_3d
end

#distinct_ip_addresses_count_7dInteger

The number of distinct IP addresses linked to the same bank account during Plaid authentication in the last 7 days

Returns:

  • (Integer)


92
93
94
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 92

def distinct_ip_addresses_count_7d
  @distinct_ip_addresses_count_7d
end

#distinct_ip_addresses_count_90dInteger

The number of distinct IP addresses linked to the same bank account during Plaid authentication in the last 90 days

Returns:

  • (Integer)


102
103
104
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 102

def distinct_ip_addresses_count_90d
  @distinct_ip_addresses_count_90d
end

#distinct_user_agents_count_30dInteger

The number of distinct user agents linked to the same bank account during Plaid authentication in the last 30 days

Returns:

  • (Integer)


117
118
119
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 117

def distinct_user_agents_count_30d
  @distinct_user_agents_count_30d
end

#distinct_user_agents_count_3dInteger

The number of distinct user agents linked to the same bank account during Plaid authentication in the last 3 days

Returns:

  • (Integer)


107
108
109
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 107

def distinct_user_agents_count_3d
  @distinct_user_agents_count_3d
end

#distinct_user_agents_count_7dInteger

The number of distinct user agents linked to the same bank account during Plaid authentication in the last 7 days

Returns:

  • (Integer)


112
113
114
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 112

def distinct_user_agents_count_7d
  @distinct_user_agents_count_7d
end

#distinct_user_agents_count_90dInteger

The number of distinct user agents linked to the same bank account during Plaid authentication in the last 90 days

Returns:

  • (Integer)


122
123
124
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 122

def distinct_user_agents_count_90d
  @distinct_user_agents_count_90d
end

#email_change_count_28dInteger

The number of times the account’s email addresses on file have changed over the past 28 days

Returns:

  • (Integer)


132
133
134
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 132

def email_change_count_28d
  @email_change_count_28d
end

#email_change_count_90dInteger

The number of times the account’s email addresses on file have changed over the past 90 days

Returns:

  • (Integer)


147
148
149
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 147

def email_change_count_90d
  @email_change_count_90d
end

#failed_plaid_non_oauth_authentication_attempts_count_30dInteger

The number of failed non-OAuth authentication attempts via Plaid for this bank account over the past 30 days

Returns:

  • (Integer)


77
78
79
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 77

def failed_plaid_non_oauth_authentication_attempts_count_30d
  @failed_plaid_non_oauth_authentication_attempts_count_30d
end

#failed_plaid_non_oauth_authentication_attempts_count_3dInteger

The number of failed non-OAuth authentication attempts via Plaid for this bank account over the past 3 days

Returns:

  • (Integer)


57
58
59
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 57

def failed_plaid_non_oauth_authentication_attempts_count_3d
  @failed_plaid_non_oauth_authentication_attempts_count_3d
end

#failed_plaid_non_oauth_authentication_attempts_count_7dInteger

The number of failed non-OAuth authentication attempts via Plaid for this bank account over the past 7 days

Returns:

  • (Integer)


67
68
69
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 67

def failed_plaid_non_oauth_authentication_attempts_count_7d
  @failed_plaid_non_oauth_authentication_attempts_count_7d
end

#is_account_closedTrueClass | FalseClass

Indicates if the account has been closed by the financial institution or the consumer, or is at risk of being closed

Returns:

  • (TrueClass | FalseClass)


30
31
32
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 30

def 
  @is_account_closed
end

#is_account_frozen_or_restrictedTrueClass | FalseClass

Indicates whether the account has withdrawals and transfers disabled or if access to the account is restricted. This could be due to a freeze by the credit issuer, legal restrictions (e.g., sanctions), or regulatory requirements limiting monthly withdrawals, among other reasons

Returns:

  • (TrueClass | FalseClass)


37
38
39
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 37

def 
  @is_account_frozen_or_restricted
end

#phone_change_count_28dInteger

The number of times the account’s phone numbers on file have changed over the past 28 days

Returns:

  • (Integer)


137
138
139
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 137

def phone_change_count_28d
  @phone_change_count_28d
end

#phone_change_count_90dInteger

The number of times the account’s phone numbers on file have changed over the past 90 days

Returns:

  • (Integer)


152
153
154
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 152

def phone_change_count_90d
  @phone_change_count_90d
end

#plaid_connections_count_30dInteger

The number of times the Item has been connected to applications via Plaid over the past 30 days

Returns:

  • (Integer)


52
53
54
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 52

def plaid_connections_count_30d
  @plaid_connections_count_30d
end

#plaid_connections_count_7dInteger

The number of times the Item has been connected to applications via Plaid over the past 7 days

Returns:

  • (Integer)


47
48
49
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 47

def plaid_connections_count_7d
  @plaid_connections_count_7d
end

#plaid_non_oauth_authentication_attempts_count_30dInteger

The number of non-OAuth authentication attempts via Plaid for this bank account over the past 30 days

Returns:

  • (Integer)


82
83
84
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 82

def plaid_non_oauth_authentication_attempts_count_30d
  @plaid_non_oauth_authentication_attempts_count_30d
end

#plaid_non_oauth_authentication_attempts_count_3dInteger

The number of non-OAuth authentication attempts via Plaid for this bank account over the past 3 days

Returns:

  • (Integer)


62
63
64
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 62

def plaid_non_oauth_authentication_attempts_count_3d
  @plaid_non_oauth_authentication_attempts_count_3d
end

#plaid_non_oauth_authentication_attempts_count_7dInteger

The number of non-OAuth authentication attempts via Plaid for this bank account over the past 7 days

Returns:

  • (Integer)


72
73
74
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 72

def plaid_non_oauth_authentication_attempts_count_7d
  @plaid_non_oauth_authentication_attempts_count_7d
end

#total_plaid_connections_countInteger

The total number of times the item has been connected to applications via Plaid

Returns:

  • (Integer)


42
43
44
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 42

def total_plaid_connections_count
  @total_plaid_connections_count
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 406

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  days_since_first_plaid_connection =
    hash.key?('days_since_first_plaid_connection') ? hash['days_since_first_plaid_connection'] : SKIP
   =
    hash.key?('is_account_closed') ? hash['is_account_closed'] : SKIP
   =
    hash.key?('is_account_frozen_or_restricted') ? hash['is_account_frozen_or_restricted'] : SKIP
  total_plaid_connections_count =
    hash.key?('total_plaid_connections_count') ? hash['total_plaid_connections_count'] : SKIP
  plaid_connections_count_7d =
    hash.key?('plaid_connections_count_7d') ? hash['plaid_connections_count_7d'] : SKIP
  plaid_connections_count_30d =
    hash.key?('plaid_connections_count_30d') ? hash['plaid_connections_count_30d'] : SKIP
  failed_plaid_non_oauth_authentication_attempts_count_3d =
    hash.key?('failed_plaid_non_oauth_authentication_attempts_count_3d') ? hash['failed_plaid_non_oauth_authentication_attempts_count_3d'] : SKIP
  plaid_non_oauth_authentication_attempts_count_3d =
    hash.key?('plaid_non_oauth_authentication_attempts_count_3d') ? hash['plaid_non_oauth_authentication_attempts_count_3d'] : SKIP
  failed_plaid_non_oauth_authentication_attempts_count_7d =
    hash.key?('failed_plaid_non_oauth_authentication_attempts_count_7d') ? hash['failed_plaid_non_oauth_authentication_attempts_count_7d'] : SKIP
  plaid_non_oauth_authentication_attempts_count_7d =
    hash.key?('plaid_non_oauth_authentication_attempts_count_7d') ? hash['plaid_non_oauth_authentication_attempts_count_7d'] : SKIP
  failed_plaid_non_oauth_authentication_attempts_count_30d =
    hash.key?('failed_plaid_non_oauth_authentication_attempts_count_30d') ? hash['failed_plaid_non_oauth_authentication_attempts_count_30d'] : SKIP
  plaid_non_oauth_authentication_attempts_count_30d =
    hash.key?('plaid_non_oauth_authentication_attempts_count_30d') ? hash['plaid_non_oauth_authentication_attempts_count_30d'] : SKIP
  distinct_ip_addresses_count_3d =
    hash.key?('distinct_ip_addresses_count_3d') ? hash['distinct_ip_addresses_count_3d'] : SKIP
  distinct_ip_addresses_count_7d =
    hash.key?('distinct_ip_addresses_count_7d') ? hash['distinct_ip_addresses_count_7d'] : SKIP
  distinct_ip_addresses_count_30d =
    hash.key?('distinct_ip_addresses_count_30d') ? hash['distinct_ip_addresses_count_30d'] : SKIP
  distinct_ip_addresses_count_90d =
    hash.key?('distinct_ip_addresses_count_90d') ? hash['distinct_ip_addresses_count_90d'] : SKIP
  distinct_user_agents_count_3d =
    hash.key?('distinct_user_agents_count_3d') ? hash['distinct_user_agents_count_3d'] : SKIP
  distinct_user_agents_count_7d =
    hash.key?('distinct_user_agents_count_7d') ? hash['distinct_user_agents_count_7d'] : SKIP
  distinct_user_agents_count_30d =
    hash.key?('distinct_user_agents_count_30d') ? hash['distinct_user_agents_count_30d'] : SKIP
  distinct_user_agents_count_90d =
    hash.key?('distinct_user_agents_count_90d') ? hash['distinct_user_agents_count_90d'] : SKIP
  address_change_count_28d =
    hash.key?('address_change_count_28d') ? hash['address_change_count_28d'] : SKIP
  email_change_count_28d =
    hash.key?('email_change_count_28d') ? hash['email_change_count_28d'] : SKIP
  phone_change_count_28d =
    hash.key?('phone_change_count_28d') ? hash['phone_change_count_28d'] : SKIP
  address_change_count_90d =
    hash.key?('address_change_count_90d') ? hash['address_change_count_90d'] : SKIP
  email_change_count_90d =
    hash.key?('email_change_count_90d') ? hash['email_change_count_90d'] : SKIP
  phone_change_count_90d =
    hash.key?('phone_change_count_90d') ? hash['phone_change_count_90d'] : SKIP
   =
    hash.key?('days_since_account_opening') ? hash['days_since_account_opening'] : SKIP
  days_since_first_observed_transaction =
    hash.key?('days_since_first_observed_transaction') ? hash['days_since_first_observed_transaction'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BeaconAccountRiskEvaluateAccountAttributes.new(days_since_first_plaid_connection: days_since_first_plaid_connection,
                                                 is_account_closed: ,
                                                 is_account_frozen_or_restricted: ,
                                                 total_plaid_connections_count: total_plaid_connections_count,
                                                 plaid_connections_count_7d: plaid_connections_count_7d,
                                                 plaid_connections_count_30d: plaid_connections_count_30d,
                                                 failed_plaid_non_oauth_authentication_attempts_count_3d: failed_plaid_non_oauth_authentication_attempts_count_3d,
                                                 plaid_non_oauth_authentication_attempts_count_3d: plaid_non_oauth_authentication_attempts_count_3d,
                                                 failed_plaid_non_oauth_authentication_attempts_count_7d: failed_plaid_non_oauth_authentication_attempts_count_7d,
                                                 plaid_non_oauth_authentication_attempts_count_7d: plaid_non_oauth_authentication_attempts_count_7d,
                                                 failed_plaid_non_oauth_authentication_attempts_count_30d: failed_plaid_non_oauth_authentication_attempts_count_30d,
                                                 plaid_non_oauth_authentication_attempts_count_30d: plaid_non_oauth_authentication_attempts_count_30d,
                                                 distinct_ip_addresses_count_3d: distinct_ip_addresses_count_3d,
                                                 distinct_ip_addresses_count_7d: distinct_ip_addresses_count_7d,
                                                 distinct_ip_addresses_count_30d: distinct_ip_addresses_count_30d,
                                                 distinct_ip_addresses_count_90d: distinct_ip_addresses_count_90d,
                                                 distinct_user_agents_count_3d: distinct_user_agents_count_3d,
                                                 distinct_user_agents_count_7d: distinct_user_agents_count_7d,
                                                 distinct_user_agents_count_30d: distinct_user_agents_count_30d,
                                                 distinct_user_agents_count_90d: distinct_user_agents_count_90d,
                                                 address_change_count_28d: address_change_count_28d,
                                                 email_change_count_28d: email_change_count_28d,
                                                 phone_change_count_28d: phone_change_count_28d,
                                                 address_change_count_90d: address_change_count_90d,
                                                 email_change_count_90d: email_change_count_90d,
                                                 phone_change_count_90d: phone_change_count_90d,
                                                 days_since_account_opening: ,
                                                 days_since_first_observed_transaction: days_since_first_observed_transaction,
                                                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 166

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['days_since_first_plaid_connection'] =
    'days_since_first_plaid_connection'
  @_hash['is_account_closed'] = 'is_account_closed'
  @_hash['is_account_frozen_or_restricted'] =
    'is_account_frozen_or_restricted'
  @_hash['total_plaid_connections_count'] =
    'total_plaid_connections_count'
  @_hash['plaid_connections_count_7d'] = 'plaid_connections_count_7d'
  @_hash['plaid_connections_count_30d'] = 'plaid_connections_count_30d'
  @_hash['failed_plaid_non_oauth_authentication_attempts_count_3d'] =
    'failed_plaid_non_oauth_authentication_attempts_count_3d'
  @_hash['plaid_non_oauth_authentication_attempts_count_3d'] =
    'plaid_non_oauth_authentication_attempts_count_3d'
  @_hash['failed_plaid_non_oauth_authentication_attempts_count_7d'] =
    'failed_plaid_non_oauth_authentication_attempts_count_7d'
  @_hash['plaid_non_oauth_authentication_attempts_count_7d'] =
    'plaid_non_oauth_authentication_attempts_count_7d'
  @_hash['failed_plaid_non_oauth_authentication_attempts_count_30d'] =
    'failed_plaid_non_oauth_authentication_attempts_count_30d'
  @_hash['plaid_non_oauth_authentication_attempts_count_30d'] =
    'plaid_non_oauth_authentication_attempts_count_30d'
  @_hash['distinct_ip_addresses_count_3d'] =
    'distinct_ip_addresses_count_3d'
  @_hash['distinct_ip_addresses_count_7d'] =
    'distinct_ip_addresses_count_7d'
  @_hash['distinct_ip_addresses_count_30d'] =
    'distinct_ip_addresses_count_30d'
  @_hash['distinct_ip_addresses_count_90d'] =
    'distinct_ip_addresses_count_90d'
  @_hash['distinct_user_agents_count_3d'] =
    'distinct_user_agents_count_3d'
  @_hash['distinct_user_agents_count_7d'] =
    'distinct_user_agents_count_7d'
  @_hash['distinct_user_agents_count_30d'] =
    'distinct_user_agents_count_30d'
  @_hash['distinct_user_agents_count_90d'] =
    'distinct_user_agents_count_90d'
  @_hash['address_change_count_28d'] = 'address_change_count_28d'
  @_hash['email_change_count_28d'] = 'email_change_count_28d'
  @_hash['phone_change_count_28d'] = 'phone_change_count_28d'
  @_hash['address_change_count_90d'] = 'address_change_count_90d'
  @_hash['email_change_count_90d'] = 'email_change_count_90d'
  @_hash['phone_change_count_90d'] = 'phone_change_count_90d'
  @_hash['days_since_account_opening'] = 'days_since_account_opening'
  @_hash['days_since_first_observed_transaction'] =
    'days_since_first_observed_transaction'
  @_hash
end

.nullablesObject

An array for nullable fields



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 252

def self.nullables
  %w[
    days_since_first_plaid_connection
    is_account_closed
    is_account_frozen_or_restricted
    total_plaid_connections_count
    plaid_connections_count_7d
    plaid_connections_count_30d
    failed_plaid_non_oauth_authentication_attempts_count_3d
    plaid_non_oauth_authentication_attempts_count_3d
    failed_plaid_non_oauth_authentication_attempts_count_7d
    plaid_non_oauth_authentication_attempts_count_7d
    failed_plaid_non_oauth_authentication_attempts_count_30d
    plaid_non_oauth_authentication_attempts_count_30d
    distinct_ip_addresses_count_3d
    distinct_ip_addresses_count_7d
    distinct_ip_addresses_count_30d
    distinct_ip_addresses_count_90d
    distinct_user_agents_count_3d
    distinct_user_agents_count_7d
    distinct_user_agents_count_30d
    distinct_user_agents_count_90d
    address_change_count_28d
    email_change_count_28d
    phone_change_count_28d
    address_change_count_90d
    email_change_count_90d
    phone_change_count_90d
    days_since_account_opening
    days_since_first_observed_transaction
  ]
end

.optionalsObject

An array for optional fields



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 218

def self.optionals
  %w[
    days_since_first_plaid_connection
    is_account_closed
    is_account_frozen_or_restricted
    total_plaid_connections_count
    plaid_connections_count_7d
    plaid_connections_count_30d
    failed_plaid_non_oauth_authentication_attempts_count_3d
    plaid_non_oauth_authentication_attempts_count_3d
    failed_plaid_non_oauth_authentication_attempts_count_7d
    plaid_non_oauth_authentication_attempts_count_7d
    failed_plaid_non_oauth_authentication_attempts_count_30d
    plaid_non_oauth_authentication_attempts_count_30d
    distinct_ip_addresses_count_3d
    distinct_ip_addresses_count_7d
    distinct_ip_addresses_count_30d
    distinct_ip_addresses_count_90d
    distinct_user_agents_count_3d
    distinct_user_agents_count_7d
    distinct_user_agents_count_30d
    distinct_user_agents_count_90d
    address_change_count_28d
    email_change_count_28d
    phone_change_count_28d
    address_change_count_90d
    email_change_count_90d
    phone_change_count_90d
    days_since_account_opening
    days_since_first_observed_transaction
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 544

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} days_since_first_plaid_connection:"\
  " #{@days_since_first_plaid_connection.inspect}, is_account_closed:"\
  " #{@is_account_closed.inspect}, is_account_frozen_or_restricted:"\
  " #{@is_account_frozen_or_restricted.inspect}, total_plaid_connections_count:"\
  " #{@total_plaid_connections_count.inspect}, plaid_connections_count_7d:"\
  " #{@plaid_connections_count_7d.inspect}, plaid_connections_count_30d:"\
  " #{@plaid_connections_count_30d.inspect},"\
  ' failed_plaid_non_oauth_authentication_attempts_count_3d:'\
  " #{@failed_plaid_non_oauth_authentication_attempts_count_3d.inspect},"\
  ' plaid_non_oauth_authentication_attempts_count_3d:'\
  " #{@plaid_non_oauth_authentication_attempts_count_3d.inspect},"\
  ' failed_plaid_non_oauth_authentication_attempts_count_7d:'\
  " #{@failed_plaid_non_oauth_authentication_attempts_count_7d.inspect},"\
  ' plaid_non_oauth_authentication_attempts_count_7d:'\
  " #{@plaid_non_oauth_authentication_attempts_count_7d.inspect},"\
  ' failed_plaid_non_oauth_authentication_attempts_count_30d:'\
  " #{@failed_plaid_non_oauth_authentication_attempts_count_30d.inspect},"\
  ' plaid_non_oauth_authentication_attempts_count_30d:'\
  " #{@plaid_non_oauth_authentication_attempts_count_30d.inspect},"\
  " distinct_ip_addresses_count_3d: #{@distinct_ip_addresses_count_3d.inspect},"\
  " distinct_ip_addresses_count_7d: #{@distinct_ip_addresses_count_7d.inspect},"\
  " distinct_ip_addresses_count_30d: #{@distinct_ip_addresses_count_30d.inspect},"\
  " distinct_ip_addresses_count_90d: #{@distinct_ip_addresses_count_90d.inspect},"\
  " distinct_user_agents_count_3d: #{@distinct_user_agents_count_3d.inspect},"\
  " distinct_user_agents_count_7d: #{@distinct_user_agents_count_7d.inspect},"\
  " distinct_user_agents_count_30d: #{@distinct_user_agents_count_30d.inspect},"\
  " distinct_user_agents_count_90d: #{@distinct_user_agents_count_90d.inspect},"\
  " address_change_count_28d: #{@address_change_count_28d.inspect}, email_change_count_28d:"\
  " #{@email_change_count_28d.inspect}, phone_change_count_28d:"\
  " #{@phone_change_count_28d.inspect}, address_change_count_90d:"\
  " #{@address_change_count_90d.inspect}, email_change_count_90d:"\
  " #{@email_change_count_90d.inspect}, phone_change_count_90d:"\
  " #{@phone_change_count_90d.inspect}, days_since_account_opening:"\
  " #{@days_since_account_opening.inspect}, days_since_first_observed_transaction:"\
  " #{@days_since_first_observed_transaction.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_account_attributes.rb', line 507

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} days_since_first_plaid_connection: #{@days_since_first_plaid_connection},"\
  " is_account_closed: #{@is_account_closed}, is_account_frozen_or_restricted:"\
  " #{@is_account_frozen_or_restricted}, total_plaid_connections_count:"\
  " #{@total_plaid_connections_count}, plaid_connections_count_7d:"\
  " #{@plaid_connections_count_7d}, plaid_connections_count_30d:"\
  " #{@plaid_connections_count_30d}, failed_plaid_non_oauth_authentication_attempts_count_3d:"\
  " #{@failed_plaid_non_oauth_authentication_attempts_count_3d},"\
  ' plaid_non_oauth_authentication_attempts_count_3d:'\
  " #{@plaid_non_oauth_authentication_attempts_count_3d},"\
  ' failed_plaid_non_oauth_authentication_attempts_count_7d:'\
  " #{@failed_plaid_non_oauth_authentication_attempts_count_7d},"\
  ' plaid_non_oauth_authentication_attempts_count_7d:'\
  " #{@plaid_non_oauth_authentication_attempts_count_7d},"\
  ' failed_plaid_non_oauth_authentication_attempts_count_30d:'\
  " #{@failed_plaid_non_oauth_authentication_attempts_count_30d},"\
  ' plaid_non_oauth_authentication_attempts_count_30d:'\
  " #{@plaid_non_oauth_authentication_attempts_count_30d}, distinct_ip_addresses_count_3d:"\
  " #{@distinct_ip_addresses_count_3d}, distinct_ip_addresses_count_7d:"\
  " #{@distinct_ip_addresses_count_7d}, distinct_ip_addresses_count_30d:"\
  " #{@distinct_ip_addresses_count_30d}, distinct_ip_addresses_count_90d:"\
  " #{@distinct_ip_addresses_count_90d}, distinct_user_agents_count_3d:"\
  " #{@distinct_user_agents_count_3d}, distinct_user_agents_count_7d:"\
  " #{@distinct_user_agents_count_7d}, distinct_user_agents_count_30d:"\
  " #{@distinct_user_agents_count_30d}, distinct_user_agents_count_90d:"\
  " #{@distinct_user_agents_count_90d}, address_change_count_28d:"\
  " #{@address_change_count_28d}, email_change_count_28d: #{@email_change_count_28d},"\
  " phone_change_count_28d: #{@phone_change_count_28d}, address_change_count_90d:"\
  " #{@address_change_count_90d}, email_change_count_90d: #{@email_change_count_90d},"\
  " phone_change_count_90d: #{@phone_change_count_90d}, days_since_account_opening:"\
  " #{@days_since_account_opening}, days_since_first_observed_transaction:"\
  " #{@days_since_first_observed_transaction}, additional_properties:"\
  " #{@additional_properties}>"
end