Class: ThePlaidApi::BeaconAccountRiskEvaluateEvaluationReason

Inherits:
Object
  • Object
show all
Defined in:
lib/the_plaid_api/models/beacon_account_risk_evaluate_evaluation_reason.rb

Overview

Description of the reason you want to evaluate risk. ‘ONBOARDING`: user links a first bank account as part of the onboarding flow of your platform. `NEW_ACCOUNT`: user links another bank account or replaces the currently linked bank account on your platform. `INFORMATION_CHANGE`: user changes their information on your platform, e.g., updating their phone number. `DORMANT_USER`: you decide to re-evaluate a user that becomes active after a period of inactivity. `OTHER`: any other reasons not listed here Possible values: `ONBOARDING`, `NEW_ACCOUNT`, `INFORMATION_CHANGE`, `DORMANT_USER`, `OTHER`

Constant Summary collapse

BEACON_ACCOUNT_RISK_EVALUATE_EVALUATION_REASON =
[
  # TODO: Write general description for ONBOARDING
  ONBOARDING = 'ONBOARDING'.freeze,

  # TODO: Write general description for NEW_ACCOUNT
  NEW_ACCOUNT = 'NEW_ACCOUNT'.freeze,

  # TODO: Write general description for INFORMATION_CHANGE
  INFORMATION_CHANGE = 'INFORMATION_CHANGE'.freeze,

  # TODO: Write general description for DORMANT_USER
  DORMANT_USER = 'DORMANT_USER'.freeze,

  # TODO: Write general description for OTHER
  OTHER = 'OTHER'.freeze
].freeze

Class Method Summary collapse

Class Method Details

.from_value(value, default_value = ONBOARDING) ⇒ Object



40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_evaluation_reason.rb', line 40

def self.from_value(value, default_value = ONBOARDING)
  return default_value if value.nil?

  str = value.to_s.strip

  case str.downcase
  when 'onboarding' then ONBOARDING
  when 'new_account' then NEW_ACCOUNT
  when 'information_change' then INFORMATION_CHANGE
  when 'dormant_user' then DORMANT_USER
  when 'other' then OTHER
  else
    default_value
  end
end

.validate(value) ⇒ Object



34
35
36
37
38
# File 'lib/the_plaid_api/models/beacon_account_risk_evaluate_evaluation_reason.rb', line 34

def self.validate(value)
  return false if value.nil?

  BEACON_ACCOUNT_RISK_EVALUATE_EVALUATION_REASON.include?(value)
end