Class: ThePlaidApi::BeaconAuditTrailSource

Inherits:
Object
  • Object
show all
Defined in:
lib/the_plaid_api/models/beacon_audit_trail_source.rb

Overview

A type indicating what caused a resource to be changed or updated. ‘dashboard` - The resource was created or updated by a member of your team via the Plaid dashboard. `api` - The resource was created or updated via the Plaid API. `system` - The resource was created or updated automatically by a part of the Plaid Beacon system. For example, if another business using Plaid Beacon created a fraud report that matched one of your users, your matching user’s status would automatically be updated and the audit trail source would be ‘system`. `bulk_import` - The resource was created or updated as part of a bulk import process. For example, if your company provided a CSV of user data as part of your initial onboarding, the audit trail source would be `bulk_import`.

Constant Summary collapse

BEACON_AUDIT_TRAIL_SOURCE =
[
  # TODO: Write general description for DASHBOARD
  DASHBOARD = 'dashboard'.freeze,

  # TODO: Write general description for API
  API = 'api'.freeze,

  # TODO: Write general description for SYSTEM
  SYSTEM = 'system'.freeze,

  # TODO: Write general description for BULK_IMPORT
  BULK_IMPORT = 'bulk_import'.freeze
].freeze

Class Method Summary collapse

Class Method Details

.from_value(value, default_value = DASHBOARD) ⇒ Object



39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/the_plaid_api/models/beacon_audit_trail_source.rb', line 39

def self.from_value(value, default_value = DASHBOARD)
  return default_value if value.nil?

  str = value.to_s.strip

  case str.downcase
  when 'dashboard' then DASHBOARD
  when 'api' then API
  when 'system' then SYSTEM
  when 'bulk_import' then BULK_IMPORT
  else
    default_value
  end
end

.validate(value) ⇒ Object



33
34
35
36
37
# File 'lib/the_plaid_api/models/beacon_audit_trail_source.rb', line 33

def self.validate(value)
  return false if value.nil?

  BEACON_AUDIT_TRAIL_SOURCE.include?(value)
end