Class: ThePlaidApi::BeaconBankAccounts

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/beacon_bank_accounts.rb

Overview

A collection of Bank Accounts linked to an Item that is associated with this Beacon User.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(item_id:, accounts:, additional_properties: nil) ⇒ BeaconBankAccounts

Returns a new instance of BeaconBankAccounts.



39
40
41
42
43
44
45
46
# File 'lib/the_plaid_api/models/beacon_bank_accounts.rb', line 39

def initialize(item_id:, accounts:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @item_id = item_id
  @accounts = accounts
  @additional_properties = additional_properties
end

Instance Attribute Details

#accountsArray[BeaconBankAccountInsights]

The Plaid Item ID the Bank Accounts belong to.

Returns:



19
20
21
# File 'lib/the_plaid_api/models/beacon_bank_accounts.rb', line 19

def accounts
  @accounts
end

#item_idString

The Plaid Item ID the Bank Accounts belong to.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/beacon_bank_accounts.rb', line 15

def item_id
  @item_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/the_plaid_api/models/beacon_bank_accounts.rb', line 49

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  item_id = hash.key?('item_id') ? hash['item_id'] : nil
  # Parameter is an array, so we need to iterate through it
  accounts = nil
  unless hash['accounts'].nil?
    accounts = []
    hash['accounts'].each do |structure|
      accounts << (BeaconBankAccountInsights.from_hash(structure) if structure)
    end
  end

  accounts = nil unless hash.key?('accounts')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BeaconBankAccounts.new(item_id: item_id,
                         accounts: accounts,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/the_plaid_api/models/beacon_bank_accounts.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['item_id'] = 'item_id'
  @_hash['accounts'] = 'accounts'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
# File 'lib/the_plaid_api/models/beacon_bank_accounts.rb', line 35

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
# File 'lib/the_plaid_api/models/beacon_bank_accounts.rb', line 30

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



86
87
88
89
90
# File 'lib/the_plaid_api/models/beacon_bank_accounts.rb', line 86

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} item_id: #{@item_id.inspect}, accounts: #{@accounts.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



79
80
81
82
83
# File 'lib/the_plaid_api/models/beacon_bank_accounts.rb', line 79

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} item_id: #{@item_id}, accounts: #{@accounts}, additional_properties:"\
  " #{@additional_properties}>"
end