Class: ThePlaidApi::BeaconDuplicateDetectedWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/beacon_duplicate_detected_webhook.rb

Overview

Fired when a Beacon User created within your organization matches one of your existing users.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, beacon_duplicate_id:, environment:, additional_properties: nil) ⇒ BeaconDuplicateDetectedWebhook

Returns a new instance of BeaconDuplicateDetectedWebhook.



49
50
51
52
53
54
55
56
57
58
59
# File 'lib/the_plaid_api/models/beacon_duplicate_detected_webhook.rb', line 49

def initialize(webhook_type:, webhook_code:, beacon_duplicate_id:,
               environment:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @beacon_duplicate_id = beacon_duplicate_id
  @environment = environment
  @additional_properties = additional_properties
end

Instance Attribute Details

#beacon_duplicate_idString

The ID of the associated Beacon Duplicate.

Returns:

  • (String)


23
24
25
# File 'lib/the_plaid_api/models/beacon_duplicate_detected_webhook.rb', line 23

def beacon_duplicate_id
  @beacon_duplicate_id
end

#environmentWebhookEnvironmentValues

The Plaid environment the webhook was sent from



27
28
29
# File 'lib/the_plaid_api/models/beacon_duplicate_detected_webhook.rb', line 27

def environment
  @environment
end

#webhook_codeString

‘DUPLICATE_DETECTED`

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/beacon_duplicate_detected_webhook.rb', line 19

def webhook_code
  @webhook_code
end

#webhook_typeString

‘BEACON`

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/beacon_duplicate_detected_webhook.rb', line 15

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/the_plaid_api/models/beacon_duplicate_detected_webhook.rb', line 62

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  beacon_duplicate_id =
    hash.key?('beacon_duplicate_id') ? hash['beacon_duplicate_id'] : nil
  environment = hash.key?('environment') ? hash['environment'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BeaconDuplicateDetectedWebhook.new(webhook_type: webhook_type,
                                     webhook_code: webhook_code,
                                     beacon_duplicate_id: beacon_duplicate_id,
                                     environment: environment,
                                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



30
31
32
33
34
35
36
37
# File 'lib/the_plaid_api/models/beacon_duplicate_detected_webhook.rb', line 30

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['beacon_duplicate_id'] = 'beacon_duplicate_id'
  @_hash['environment'] = 'environment'
  @_hash
end

.nullablesObject

An array for nullable fields



45
46
47
# File 'lib/the_plaid_api/models/beacon_duplicate_detected_webhook.rb', line 45

def self.nullables
  []
end

.optionalsObject

An array for optional fields



40
41
42
# File 'lib/the_plaid_api/models/beacon_duplicate_detected_webhook.rb', line 40

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



96
97
98
99
100
101
# File 'lib/the_plaid_api/models/beacon_duplicate_detected_webhook.rb', line 96

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, beacon_duplicate_id: #{@beacon_duplicate_id.inspect},"\
  " environment: #{@environment.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



88
89
90
91
92
93
# File 'lib/the_plaid_api/models/beacon_duplicate_detected_webhook.rb', line 88

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code},"\
  " beacon_duplicate_id: #{@beacon_duplicate_id}, environment: #{@environment},"\
  " additional_properties: #{@additional_properties}>"
end