Class: ThePlaidApi::BeaconReportSyndicationGetResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/beacon_report_syndication_get_response.rb

Overview

A Beacon Report Syndication represents a Beacon Report created either by your organization or another Beacon customer that matches a specific Beacon User you’ve created. The ‘analysis` field in the response indicates which fields matched between the originally reported Beacon User and the Beacon User that the report was syndicated to. The `report` field in the response contains a subset of information from the original report.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id:, beacon_user_id:, report:, analysis:, request_id:, additional_properties: nil) ⇒ BeaconReportSyndicationGetResponse

Returns a new instance of BeaconReportSyndicationGetResponse.



67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/the_plaid_api/models/beacon_report_syndication_get_response.rb', line 67

def initialize(id:, beacon_user_id:, report:, analysis:, request_id:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id
  @beacon_user_id = beacon_user_id
  @report = report
  @analysis = analysis
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#analysisBeaconReportSyndicationAnalysis

Analysis of which fields matched between the originally reported Beacon User and the Beacon User that the report was syndicated to.



38
39
40
# File 'lib/the_plaid_api/models/beacon_report_syndication_get_response.rb', line 38

def analysis
  @analysis
end

#beacon_user_idString

ID of the associated Beacon User.

Returns:

  • (String)


23
24
25
# File 'lib/the_plaid_api/models/beacon_report_syndication_get_response.rb', line 23

def beacon_user_id
  @beacon_user_id
end

#idString

ID of the associated Beacon Report Syndication.

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/beacon_report_syndication_get_response.rb', line 19

def id
  @id
end

#reportBeaconReportSyndicationOriginalReport

A subset of information from a Beacon Report that has been syndicated to a matching Beacon User in your program. The ‘id` field in the response is the ID of the original report that was syndicated. If the original report was created by your organization, the field will be filled with the ID of the report. Otherwise, the field will be `null` indicating that the original report was created by another Beacon customer.



33
34
35
# File 'lib/the_plaid_api/models/beacon_report_syndication_get_response.rb', line 33

def report
  @report
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


44
45
46
# File 'lib/the_plaid_api/models/beacon_report_syndication_get_response.rb', line 44

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/the_plaid_api/models/beacon_report_syndication_get_response.rb', line 81

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  beacon_user_id =
    hash.key?('beacon_user_id') ? hash['beacon_user_id'] : nil
  report = BeaconReportSyndicationOriginalReport.from_hash(hash['report']) if hash['report']
  analysis = BeaconReportSyndicationAnalysis.from_hash(hash['analysis']) if hash['analysis']
  request_id = hash.key?('request_id') ? hash['request_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BeaconReportSyndicationGetResponse.new(id: id,
                                         beacon_user_id: beacon_user_id,
                                         report: report,
                                         analysis: analysis,
                                         request_id: request_id,
                                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



47
48
49
50
51
52
53
54
55
# File 'lib/the_plaid_api/models/beacon_report_syndication_get_response.rb', line 47

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['beacon_user_id'] = 'beacon_user_id'
  @_hash['report'] = 'report'
  @_hash['analysis'] = 'analysis'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



63
64
65
# File 'lib/the_plaid_api/models/beacon_report_syndication_get_response.rb', line 63

def self.nullables
  []
end

.optionalsObject

An array for optional fields



58
59
60
# File 'lib/the_plaid_api/models/beacon_report_syndication_get_response.rb', line 58

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



117
118
119
120
121
122
# File 'lib/the_plaid_api/models/beacon_report_syndication_get_response.rb', line 117

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, beacon_user_id: #{@beacon_user_id.inspect}, report:"\
  " #{@report.inspect}, analysis: #{@analysis.inspect}, request_id: #{@request_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



109
110
111
112
113
114
# File 'lib/the_plaid_api/models/beacon_report_syndication_get_response.rb', line 109

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, beacon_user_id: #{@beacon_user_id}, report: #{@report},"\
  " analysis: #{@analysis}, request_id: #{@request_id}, additional_properties:"\
  " #{@additional_properties}>"
end