Class: ThePlaidApi::BeaconReportSyndicationListRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::BeaconReportSyndicationListRequest
- Defined in:
- lib/the_plaid_api/models/beacon_report_syndication_list_request.rb
Overview
Request input for listing Beacon Report Syndications
Instance Attribute Summary collapse
-
#beacon_user_id ⇒ String
ID of the associated Beacon User.
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#cursor ⇒ String
An identifier that determines which page of results you receive.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(beacon_user_id:, cursor: SKIP, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ BeaconReportSyndicationListRequest
constructor
A new instance of BeaconReportSyndicationListRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(beacon_user_id:, cursor: SKIP, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ BeaconReportSyndicationListRequest
Returns a new instance of BeaconReportSyndicationListRequest.
57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/the_plaid_api/models/beacon_report_syndication_list_request.rb', line 57 def initialize(beacon_user_id:, cursor: SKIP, client_id: SKIP, secret: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @beacon_user_id = beacon_user_id @cursor = cursor unless cursor == SKIP @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#beacon_user_id ⇒ String
ID of the associated Beacon User.
14 15 16 |
# File 'lib/the_plaid_api/models/beacon_report_syndication_list_request.rb', line 14 def beacon_user_id @beacon_user_id end |
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
24 25 26 |
# File 'lib/the_plaid_api/models/beacon_report_syndication_list_request.rb', line 24 def client_id @client_id end |
#cursor ⇒ String
An identifier that determines which page of results you receive.
18 19 20 |
# File 'lib/the_plaid_api/models/beacon_report_syndication_list_request.rb', line 18 def cursor @cursor end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
29 30 31 |
# File 'lib/the_plaid_api/models/beacon_report_syndication_list_request.rb', line 29 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/the_plaid_api/models/beacon_report_syndication_list_request.rb', line 70 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. beacon_user_id = hash.key?('beacon_user_id') ? hash['beacon_user_id'] : nil cursor = hash.key?('cursor') ? hash['cursor'] : SKIP client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BeaconReportSyndicationListRequest.new(beacon_user_id: beacon_user_id, cursor: cursor, client_id: client_id, secret: secret, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
32 33 34 35 36 37 38 39 |
# File 'lib/the_plaid_api/models/beacon_report_syndication_list_request.rb', line 32 def self.names @_hash = {} if @_hash.nil? @_hash['beacon_user_id'] = 'beacon_user_id' @_hash['cursor'] = 'cursor' @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash end |
.nullables ⇒ Object
An array for nullable fields
51 52 53 54 55 |
# File 'lib/the_plaid_api/models/beacon_report_syndication_list_request.rb', line 51 def self.nullables %w[ cursor ] end |
.optionals ⇒ Object
An array for optional fields
42 43 44 45 46 47 48 |
# File 'lib/the_plaid_api/models/beacon_report_syndication_list_request.rb', line 42 def self.optionals %w[ cursor client_id secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
103 104 105 106 107 108 |
# File 'lib/the_plaid_api/models/beacon_report_syndication_list_request.rb', line 103 def inspect class_name = self.class.name.split('::').last "<#{class_name} beacon_user_id: #{@beacon_user_id.inspect}, cursor: #{@cursor.inspect},"\ " client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
96 97 98 99 100 |
# File 'lib/the_plaid_api/models/beacon_report_syndication_list_request.rb', line 96 def to_s class_name = self.class.name.split('::').last "<#{class_name} beacon_user_id: #{@beacon_user_id}, cursor: #{@cursor}, client_id:"\ " #{@client_id}, secret: #{@secret}, additional_properties: #{@additional_properties}>" end |