Class: ThePlaidApi::BeaconSyndicatedReportDepositoryAccountMatchAnalysis

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/beacon_syndicated_report_depository_account_match_analysis.rb

Overview

Analysis of whether this account matched between the originally reported Beacon User and the Beacon User that the report syndicated to.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_mask:, routing_number:, match_status:, additional_properties: nil) ⇒ BeaconSyndicatedReportDepositoryAccountMatchAnalysis

Returns a new instance of BeaconSyndicatedReportDepositoryAccountMatchAnalysis.



53
54
55
56
57
58
59
60
61
62
# File 'lib/the_plaid_api/models/beacon_syndicated_report_depository_account_match_analysis.rb', line 53

def initialize(account_mask:, routing_number:, match_status:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_mask = 
  @routing_number = routing_number
  @match_status = match_status
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_maskString

The last 2-4 numeric characters of this account’s account number.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/beacon_syndicated_report_depository_account_match_analysis.rb', line 15

def 
  @account_mask
end

#match_statusBeaconMatchSummaryCode

An enum indicating the match type between two Beacon Users. ‘match` indicates that the provided input data was a strong match against the other Beacon User. `partial_match` indicates the data approximately matched the other Beacon User. For example, “Knope” vs. “Knope-Wyatt” for last name. `no_match` indicates that Plaid was able to compare this field against the other Beacon User and it did not match the provided input data. `no_data` indicates that Plaid was unable to compare this field against the original Beacon User because the field was not present in one of the Beacon Users.



32
33
34
# File 'lib/the_plaid_api/models/beacon_syndicated_report_depository_account_match_analysis.rb', line 32

def match_status
  @match_status
end

#routing_numberString

The routing number of the account.

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/beacon_syndicated_report_depository_account_match_analysis.rb', line 19

def routing_number
  @routing_number
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/the_plaid_api/models/beacon_syndicated_report_depository_account_match_analysis.rb', line 65

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('account_mask') ? hash['account_mask'] : nil
  routing_number =
    hash.key?('routing_number') ? hash['routing_number'] : nil
  match_status = hash.key?('match_status') ? hash['match_status'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BeaconSyndicatedReportDepositoryAccountMatchAnalysis.new(account_mask: ,
                                                           routing_number: routing_number,
                                                           match_status: match_status,
                                                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



35
36
37
38
39
40
41
# File 'lib/the_plaid_api/models/beacon_syndicated_report_depository_account_match_analysis.rb', line 35

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_mask'] = 'account_mask'
  @_hash['routing_number'] = 'routing_number'
  @_hash['match_status'] = 'match_status'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/the_plaid_api/models/beacon_syndicated_report_depository_account_match_analysis.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
# File 'lib/the_plaid_api/models/beacon_syndicated_report_depository_account_match_analysis.rb', line 44

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



96
97
98
99
100
101
# File 'lib/the_plaid_api/models/beacon_syndicated_report_depository_account_match_analysis.rb', line 96

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_mask: #{@account_mask.inspect}, routing_number:"\
  " #{@routing_number.inspect}, match_status: #{@match_status.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



89
90
91
92
93
# File 'lib/the_plaid_api/models/beacon_syndicated_report_depository_account_match_analysis.rb', line 89

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_mask: #{@account_mask}, routing_number: #{@routing_number},"\
  " match_status: #{@match_status}, additional_properties: #{@additional_properties}>"
end