Class: ThePlaidApi::BeaconUserAccountInsightsGetResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::BeaconUserAccountInsightsGetResponse
- Defined in:
- lib/the_plaid_api/models/beacon_user_account_insights_get_response.rb
Overview
The response schema for ‘/beacon/user/account/insights/get`
Instance Attribute Summary collapse
-
#bank_account_insights ⇒ BeaconBankAccounts
A collection of Bank Accounts linked to an Item that is associated with this Beacon User.
-
#beacon_user_id ⇒ String
ID of the associated Beacon User.
-
#created_at ⇒ DateTime
An ISO8601 formatted timestamp.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
-
#updated_at ⇒ DateTime
An ISO8601 formatted timestamp.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(beacon_user_id:, created_at:, updated_at:, bank_account_insights:, request_id:, additional_properties: nil) ⇒ BeaconUserAccountInsightsGetResponse
constructor
A new instance of BeaconUserAccountInsightsGetResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_created_at ⇒ Object
- #to_custom_updated_at ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(beacon_user_id:, created_at:, updated_at:, bank_account_insights:, request_id:, additional_properties: nil) ⇒ BeaconUserAccountInsightsGetResponse
Returns a new instance of BeaconUserAccountInsightsGetResponse.
58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/the_plaid_api/models/beacon_user_account_insights_get_response.rb', line 58 def initialize(beacon_user_id:, created_at:, updated_at:, bank_account_insights:, request_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @beacon_user_id = beacon_user_id @created_at = created_at @updated_at = updated_at @bank_account_insights = bank_account_insights @request_id = request_id @additional_properties = additional_properties end |
Instance Attribute Details
#bank_account_insights ⇒ BeaconBankAccounts
A collection of Bank Accounts linked to an Item that is associated with this Beacon User.
29 30 31 |
# File 'lib/the_plaid_api/models/beacon_user_account_insights_get_response.rb', line 29 def bank_account_insights @bank_account_insights end |
#beacon_user_id ⇒ String
ID of the associated Beacon User.
15 16 17 |
# File 'lib/the_plaid_api/models/beacon_user_account_insights_get_response.rb', line 15 def beacon_user_id @beacon_user_id end |
#created_at ⇒ DateTime
An ISO8601 formatted timestamp.
19 20 21 |
# File 'lib/the_plaid_api/models/beacon_user_account_insights_get_response.rb', line 19 def created_at @created_at end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
35 36 37 |
# File 'lib/the_plaid_api/models/beacon_user_account_insights_get_response.rb', line 35 def request_id @request_id end |
#updated_at ⇒ DateTime
An ISO8601 formatted timestamp. This field indicates the last time the resource was modified.
24 25 26 |
# File 'lib/the_plaid_api/models/beacon_user_account_insights_get_response.rb', line 24 def updated_at @updated_at end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/the_plaid_api/models/beacon_user_account_insights_get_response.rb', line 73 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. beacon_user_id = hash.key?('beacon_user_id') ? hash['beacon_user_id'] : nil created_at = if hash.key?('created_at') (DateTimeHelper.from_rfc3339(hash['created_at']) if hash['created_at']) end updated_at = if hash.key?('updated_at') (DateTimeHelper.from_rfc3339(hash['updated_at']) if hash['updated_at']) end bank_account_insights = BeaconBankAccounts.from_hash(hash['bank_account_insights']) if hash['bank_account_insights'] request_id = hash.key?('request_id') ? hash['request_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BeaconUserAccountInsightsGetResponse.new(beacon_user_id: beacon_user_id, created_at: created_at, updated_at: updated_at, bank_account_insights: bank_account_insights, request_id: request_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
38 39 40 41 42 43 44 45 46 |
# File 'lib/the_plaid_api/models/beacon_user_account_insights_get_response.rb', line 38 def self.names @_hash = {} if @_hash.nil? @_hash['beacon_user_id'] = 'beacon_user_id' @_hash['created_at'] = 'created_at' @_hash['updated_at'] = 'updated_at' @_hash['bank_account_insights'] = 'bank_account_insights' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 |
# File 'lib/the_plaid_api/models/beacon_user_account_insights_get_response.rb', line 54 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 |
# File 'lib/the_plaid_api/models/beacon_user_account_insights_get_response.rb', line 49 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
122 123 124 125 126 127 128 |
# File 'lib/the_plaid_api/models/beacon_user_account_insights_get_response.rb', line 122 def inspect class_name = self.class.name.split('::').last "<#{class_name} beacon_user_id: #{@beacon_user_id.inspect}, created_at:"\ " #{@created_at.inspect}, updated_at: #{@updated_at.inspect}, bank_account_insights:"\ " #{@bank_account_insights.inspect}, request_id: #{@request_id.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_custom_created_at ⇒ Object
105 106 107 |
# File 'lib/the_plaid_api/models/beacon_user_account_insights_get_response.rb', line 105 def to_custom_created_at DateTimeHelper.to_rfc3339(created_at) end |
#to_custom_updated_at ⇒ Object
109 110 111 |
# File 'lib/the_plaid_api/models/beacon_user_account_insights_get_response.rb', line 109 def to_custom_updated_at DateTimeHelper.to_rfc3339(updated_at) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
114 115 116 117 118 119 |
# File 'lib/the_plaid_api/models/beacon_user_account_insights_get_response.rb', line 114 def to_s class_name = self.class.name.split('::').last "<#{class_name} beacon_user_id: #{@beacon_user_id}, created_at: #{@created_at}, updated_at:"\ " #{@updated_at}, bank_account_insights: #{@bank_account_insights}, request_id:"\ " #{@request_id}, additional_properties: #{@additional_properties}>" end |