Class: ThePlaidApi::BeaconUserDepositoryAccount

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/beacon_user_depository_account.rb

Overview

Depository account information for the associated user.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_mask:, routing_number:, added_at:, additional_properties: nil) ⇒ BeaconUserDepositoryAccount

Returns a new instance of BeaconUserDepositoryAccount.



44
45
46
47
48
49
50
51
52
53
# File 'lib/the_plaid_api/models/beacon_user_depository_account.rb', line 44

def initialize(account_mask:, routing_number:, added_at:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_mask = 
  @routing_number = routing_number
  @added_at = added_at
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_maskString

The last 2-4 numeric characters of this account’s account number.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/beacon_user_depository_account.rb', line 15

def 
  @account_mask
end

#added_atDateTime

An ISO8601 formatted timestamp.

Returns:

  • (DateTime)


23
24
25
# File 'lib/the_plaid_api/models/beacon_user_depository_account.rb', line 23

def added_at
  @added_at
end

#routing_numberString

The routing number of the account.

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/beacon_user_depository_account.rb', line 19

def routing_number
  @routing_number
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/the_plaid_api/models/beacon_user_depository_account.rb', line 56

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('account_mask') ? hash['account_mask'] : nil
  routing_number =
    hash.key?('routing_number') ? hash['routing_number'] : nil
  added_at = if hash.key?('added_at')
               (DateTimeHelper.from_rfc3339(hash['added_at']) if hash['added_at'])
             end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BeaconUserDepositoryAccount.new(account_mask: ,
                                  routing_number: routing_number,
                                  added_at: added_at,
                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/the_plaid_api/models/beacon_user_depository_account.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_mask'] = 'account_mask'
  @_hash['routing_number'] = 'routing_number'
  @_hash['added_at'] = 'added_at'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/the_plaid_api/models/beacon_user_depository_account.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
# File 'lib/the_plaid_api/models/beacon_user_depository_account.rb', line 35

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



93
94
95
96
97
98
# File 'lib/the_plaid_api/models/beacon_user_depository_account.rb', line 93

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_mask: #{@account_mask.inspect}, routing_number:"\
  " #{@routing_number.inspect}, added_at: #{@added_at.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_custom_added_atObject



81
82
83
# File 'lib/the_plaid_api/models/beacon_user_depository_account.rb', line 81

def to_custom_added_at
  DateTimeHelper.to_rfc3339(added_at)
end

#to_sObject

Provides a human-readable string representation of the object.



86
87
88
89
90
# File 'lib/the_plaid_api/models/beacon_user_depository_account.rb', line 86

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_mask: #{@account_mask}, routing_number: #{@routing_number},"\
  " added_at: #{@added_at}, additional_properties: #{@additional_properties}>"
end