Class: ThePlaidApi::BeaconUserRequestDepositoryAccount
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::BeaconUserRequestDepositoryAccount
- Defined in:
- lib/the_plaid_api/models/beacon_user_request_depository_account.rb
Overview
Depository account information for the associated user.
Instance Attribute Summary collapse
-
#account_number ⇒ String
Must be a valid US Bank Account Number.
-
#routing_number ⇒ String
The routing number of the account.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_number:, routing_number:, additional_properties: nil) ⇒ BeaconUserRequestDepositoryAccount
constructor
A new instance of BeaconUserRequestDepositoryAccount.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_number:, routing_number:, additional_properties: nil) ⇒ BeaconUserRequestDepositoryAccount
Returns a new instance of BeaconUserRequestDepositoryAccount.
38 39 40 41 42 43 44 45 |
# File 'lib/the_plaid_api/models/beacon_user_request_depository_account.rb', line 38 def initialize(account_number:, routing_number:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_number = account_number @routing_number = routing_number @additional_properties = additional_properties end |
Instance Attribute Details
#account_number ⇒ String
Must be a valid US Bank Account Number
14 15 16 |
# File 'lib/the_plaid_api/models/beacon_user_request_depository_account.rb', line 14 def account_number @account_number end |
#routing_number ⇒ String
The routing number of the account.
18 19 20 |
# File 'lib/the_plaid_api/models/beacon_user_request_depository_account.rb', line 18 def routing_number @routing_number end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/the_plaid_api/models/beacon_user_request_depository_account.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_number = hash.key?('account_number') ? hash['account_number'] : nil routing_number = hash.key?('routing_number') ? hash['routing_number'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BeaconUserRequestDepositoryAccount.new(account_number: account_number, routing_number: routing_number, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/the_plaid_api/models/beacon_user_request_depository_account.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['account_number'] = 'account_number' @_hash['routing_number'] = 'routing_number' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/the_plaid_api/models/beacon_user_request_depository_account.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/the_plaid_api/models/beacon_user_request_depository_account.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/the_plaid_api/models/beacon_user_request_depository_account.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_number: #{@account_number.inspect}, routing_number:"\ " #{@routing_number.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/the_plaid_api/models/beacon_user_request_depository_account.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_number: #{@account_number}, routing_number: #{@routing_number},"\ " additional_properties: #{@additional_properties}>" end |