Class: ThePlaidApi::BeaconUserReviewRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/beacon_user_review_request.rb

Overview

Request input for updating the status of a Beacon User

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(beacon_user_id:, status:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ BeaconUserReviewRequest

Returns a new instance of BeaconUserReviewRequest.



58
59
60
61
62
63
64
65
66
67
68
# File 'lib/the_plaid_api/models/beacon_user_review_request.rb', line 58

def initialize(beacon_user_id:, status:, client_id: SKIP, secret: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @beacon_user_id = beacon_user_id
  @status = status
  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#beacon_user_idString

ID of the associated Beacon User.

Returns:

  • (String)


14
15
16
# File 'lib/the_plaid_api/models/beacon_user_review_request.rb', line 14

def beacon_user_id
  @beacon_user_id
end

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


28
29
30
# File 'lib/the_plaid_api/models/beacon_user_review_request.rb', line 28

def client_id
  @client_id
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


33
34
35
# File 'lib/the_plaid_api/models/beacon_user_review_request.rb', line 33

def secret
  @secret
end

#statusBeaconUserStatus

A status of a Beacon User. ‘rejected`: The Beacon User has been rejected for fraud. Users can be automatically or manually rejected. `pending_review`: The Beacon User has been marked for review. `cleared`: The Beacon User has been cleared of fraud.

Returns:



22
23
24
# File 'lib/the_plaid_api/models/beacon_user_review_request.rb', line 22

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/the_plaid_api/models/beacon_user_review_request.rb', line 71

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  beacon_user_id =
    hash.key?('beacon_user_id') ? hash['beacon_user_id'] : nil
  status = hash.key?('status') ? hash['status'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BeaconUserReviewRequest.new(beacon_user_id: beacon_user_id,
                              status: status,
                              client_id: client_id,
                              secret: secret,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



36
37
38
39
40
41
42
43
# File 'lib/the_plaid_api/models/beacon_user_review_request.rb', line 36

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['beacon_user_id'] = 'beacon_user_id'
  @_hash['status'] = 'status'
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash
end

.nullablesObject

An array for nullable fields



54
55
56
# File 'lib/the_plaid_api/models/beacon_user_review_request.rb', line 54

def self.nullables
  []
end

.optionalsObject

An array for optional fields



46
47
48
49
50
51
# File 'lib/the_plaid_api/models/beacon_user_review_request.rb', line 46

def self.optionals
  %w[
    client_id
    secret
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



104
105
106
107
108
109
# File 'lib/the_plaid_api/models/beacon_user_review_request.rb', line 104

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} beacon_user_id: #{@beacon_user_id.inspect}, status: #{@status.inspect},"\
  " client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



97
98
99
100
101
# File 'lib/the_plaid_api/models/beacon_user_review_request.rb', line 97

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} beacon_user_id: #{@beacon_user_id}, status: #{@status}, client_id:"\
  " #{@client_id}, secret: #{@secret}, additional_properties: #{@additional_properties}>"
end