Class: ThePlaidApi::BeaconUserUpdateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/beacon_user_update_request.rb

Overview

Request input for updating the identity data of a Beacon User.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(beacon_user_id:, user: SKIP, access_tokens: SKIP, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ BeaconUserUpdateRequest

Returns a new instance of BeaconUserUpdateRequest.



70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/the_plaid_api/models/beacon_user_update_request.rb', line 70

def initialize(beacon_user_id:, user: SKIP, access_tokens: SKIP,
               client_id: SKIP, secret: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @beacon_user_id = beacon_user_id
  @user = user unless user == SKIP
  @access_tokens = access_tokens unless access_tokens == SKIP
  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#access_tokensArray[String]

Send this array of access tokens to add accounts to this user for evaluation. This will add accounts to this Beacon User. If left null only existing accounts will be returned in response. A maximum of 50 accounts total can be added to a Beacon User.

Returns:

  • (Array[String])


28
29
30
# File 'lib/the_plaid_api/models/beacon_user_update_request.rb', line 28

def access_tokens
  @access_tokens
end

#beacon_user_idString

ID of the associated Beacon User.

Returns:

  • (String)


14
15
16
# File 'lib/the_plaid_api/models/beacon_user_update_request.rb', line 14

def beacon_user_id
  @beacon_user_id
end

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


34
35
36
# File 'lib/the_plaid_api/models/beacon_user_update_request.rb', line 34

def client_id
  @client_id
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


39
40
41
# File 'lib/the_plaid_api/models/beacon_user_update_request.rb', line 39

def secret
  @secret
end

#userBeaconUserUpdateRequestData

A subset of a Beacon User’s data which is used to patch the existing identity data associated with a Beacon User. At least one field must be provided. If left unset or null, user data will not be patched.



20
21
22
# File 'lib/the_plaid_api/models/beacon_user_update_request.rb', line 20

def user
  @user
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/the_plaid_api/models/beacon_user_update_request.rb', line 84

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  beacon_user_id =
    hash.key?('beacon_user_id') ? hash['beacon_user_id'] : nil
  user = BeaconUserUpdateRequestData.from_hash(hash['user']) if hash['user']
  access_tokens = hash.key?('access_tokens') ? hash['access_tokens'] : SKIP
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BeaconUserUpdateRequest.new(beacon_user_id: beacon_user_id,
                              user: user,
                              access_tokens: access_tokens,
                              client_id: client_id,
                              secret: secret,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



42
43
44
45
46
47
48
49
50
# File 'lib/the_plaid_api/models/beacon_user_update_request.rb', line 42

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['beacon_user_id'] = 'beacon_user_id'
  @_hash['user'] = 'user'
  @_hash['access_tokens'] = 'access_tokens'
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash
end

.nullablesObject

An array for nullable fields



63
64
65
66
67
68
# File 'lib/the_plaid_api/models/beacon_user_update_request.rb', line 63

def self.nullables
  %w[
    user
    access_tokens
  ]
end

.optionalsObject

An array for optional fields



53
54
55
56
57
58
59
60
# File 'lib/the_plaid_api/models/beacon_user_update_request.rb', line 53

def self.optionals
  %w[
    user
    access_tokens
    client_id
    secret
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



120
121
122
123
124
125
# File 'lib/the_plaid_api/models/beacon_user_update_request.rb', line 120

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} beacon_user_id: #{@beacon_user_id.inspect}, user: #{@user.inspect},"\
  " access_tokens: #{@access_tokens.inspect}, client_id: #{@client_id.inspect}, secret:"\
  " #{@secret.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



112
113
114
115
116
117
# File 'lib/the_plaid_api/models/beacon_user_update_request.rb', line 112

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} beacon_user_id: #{@beacon_user_id}, user: #{@user}, access_tokens:"\
  " #{@access_tokens}, client_id: #{@client_id}, secret: #{@secret}, additional_properties:"\
  " #{@additional_properties}>"
end