Class: ThePlaidApi::BetaPartnerCustomerV1EnableRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/beta_partner_customer_v1_enable_request.rb

Overview

Request schema for ‘/beta/partner/customer/v1/enable`.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(end_customer_client_id:, client_id: SKIP, secret: SKIP, products: SKIP, additional_properties: nil) ⇒ BetaPartnerCustomerV1EnableRequest

Returns a new instance of BetaPartnerCustomerV1EnableRequest.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_enable_request.rb', line 57

def initialize(end_customer_client_id:, client_id: SKIP, secret: SKIP,
               products: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @end_customer_client_id = end_customer_client_id
  @products = products unless products == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_enable_request.rb', line 16

def client_id
  @client_id
end

#end_customer_client_idString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


26
27
28
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_enable_request.rb', line 26

def end_customer_client_id
  @end_customer_client_id
end

#productsArray[Products]

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:



31
32
33
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_enable_request.rb', line 31

def products
  @products
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_enable_request.rb', line 21

def secret
  @secret
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_enable_request.rb', line 70

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  end_customer_client_id =
    hash.key?('end_customer_client_id') ? hash['end_customer_client_id'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  products = hash.key?('products') ? hash['products'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BetaPartnerCustomerV1EnableRequest.new(end_customer_client_id: end_customer_client_id,
                                         client_id: client_id,
                                         secret: secret,
                                         products: products,
                                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



34
35
36
37
38
39
40
41
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_enable_request.rb', line 34

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['end_customer_client_id'] = 'end_customer_client_id'
  @_hash['products'] = 'products'
  @_hash
end

.nullablesObject

An array for nullable fields



53
54
55
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_enable_request.rb', line 53

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
47
48
49
50
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_enable_request.rb', line 44

def self.optionals
  %w[
    client_id
    secret
    products
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



104
105
106
107
108
109
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_enable_request.rb', line 104

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\
  " end_customer_client_id: #{@end_customer_client_id.inspect}, products:"\
  " #{@products.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



96
97
98
99
100
101
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_enable_request.rb', line 96

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, end_customer_client_id:"\
  " #{@end_customer_client_id}, products: #{@products}, additional_properties:"\
  " #{@additional_properties}>"
end