Class: ThePlaidApi::BetaPartnerCustomerV1EnableResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/beta_partner_customer_v1_enable_response.rb

Overview

Response schema for ‘/beta/partner/customer/v1/enable`.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(end_customer_client_id: SKIP, status: SKIP, product_statuses: SKIP, production_secret: SKIP, request_id: SKIP, additional_properties: nil) ⇒ BetaPartnerCustomerV1EnableResponse

Returns a new instance of BetaPartnerCustomerV1EnableResponse.



73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_enable_response.rb', line 73

def initialize(end_customer_client_id: SKIP, status: SKIP,
               product_statuses: SKIP, production_secret: SKIP,
               request_id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @end_customer_client_id = end_customer_client_id unless end_customer_client_id == SKIP
  @status = status unless status == SKIP
  @product_statuses = product_statuses unless product_statuses == SKIP
  @production_secret = production_secret unless production_secret == SKIP
  @request_id = request_id unless request_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#end_customer_client_idString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_enable_response.rb', line 14

def end_customer_client_id
  @end_customer_client_id
end

#product_statusesObject

Mapping of product names to their current status.

Returns:

  • (Object)


34
35
36
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_enable_response.rb', line 34

def product_statuses
  @product_statuses
end

#production_secretString

Mapping of product names to their current status.

Returns:

  • (String)


38
39
40
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_enable_response.rb', line 38

def production_secret
  @production_secret
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


44
45
46
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_enable_response.rb', line 44

def request_id
  @request_id
end

#statusPartnerEndCustomerStatus

The status of the given end customer. ‘UNDER_REVIEW`: The end customer has been created and enabled in the Sandbox environment. The end customer must be manually reviewed by the Plaid team before it can be enabled in Production, at which point its status will automatically transition to `PENDING_ENABLEMENT` or `DENIED`. `PENDING_ENABLEMENT`: The end customer is ready to be fully enabled in the Production environment. Call the `/partner/customer/enable` endpoint to enable the end customer in full Production. `ACTIVE`: The end customer has been fully enabled in all environments. `DENIED`: The end customer has been created and enabled in the Sandbox environment, but it did not pass review by the Plaid team and therefore cannot be enabled for Production access. Talk to your Account Manager for more information.



30
31
32
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_enable_response.rb', line 30

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_enable_response.rb', line 88

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  end_customer_client_id =
    hash.key?('end_customer_client_id') ? hash['end_customer_client_id'] : SKIP
  status = hash.key?('status') ? hash['status'] : SKIP
  product_statuses =
    hash.key?('product_statuses') ? hash['product_statuses'] : SKIP
  production_secret =
    hash.key?('production_secret') ? hash['production_secret'] : SKIP
  request_id = hash.key?('request_id') ? hash['request_id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BetaPartnerCustomerV1EnableResponse.new(end_customer_client_id: end_customer_client_id,
                                          status: status,
                                          product_statuses: product_statuses,
                                          production_secret: production_secret,
                                          request_id: request_id,
                                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



47
48
49
50
51
52
53
54
55
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_enable_response.rb', line 47

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['end_customer_client_id'] = 'end_customer_client_id'
  @_hash['status'] = 'status'
  @_hash['product_statuses'] = 'product_statuses'
  @_hash['production_secret'] = 'production_secret'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



69
70
71
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_enable_response.rb', line 69

def self.nullables
  []
end

.optionalsObject

An array for optional fields



58
59
60
61
62
63
64
65
66
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_enable_response.rb', line 58

def self.optionals
  %w[
    end_customer_client_id
    status
    product_statuses
    production_secret
    request_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



126
127
128
129
130
131
132
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_enable_response.rb', line 126

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} end_customer_client_id: #{@end_customer_client_id.inspect}, status:"\
  " #{@status.inspect}, product_statuses: #{@product_statuses.inspect}, production_secret:"\
  " #{@production_secret.inspect}, request_id: #{@request_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



118
119
120
121
122
123
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_enable_response.rb', line 118

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} end_customer_client_id: #{@end_customer_client_id}, status: #{@status},"\
  " product_statuses: #{@product_statuses}, production_secret: #{@production_secret},"\
  " request_id: #{@request_id}, additional_properties: #{@additional_properties}>"
end