Class: ThePlaidApi::BetaPartnerCustomerV1GetResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::BetaPartnerCustomerV1GetResponse
- Defined in:
- lib/the_plaid_api/models/beta_partner_customer_v1_get_response.rb
Overview
Response schema for ‘/beta/partner/customer/v1/get`.
Instance Attribute Summary collapse
-
#end_customer ⇒ BetaPartnerEndCustomer
The details for an end customer.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(end_customer: SKIP, request_id: SKIP, additional_properties: nil) ⇒ BetaPartnerCustomerV1GetResponse
constructor
A new instance of BetaPartnerCustomerV1GetResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(end_customer: SKIP, request_id: SKIP, additional_properties: nil) ⇒ BetaPartnerCustomerV1GetResponse
Returns a new instance of BetaPartnerCustomerV1GetResponse.
43 44 45 46 47 48 49 50 51 |
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_get_response.rb', line 43 def initialize(end_customer: SKIP, request_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @end_customer = end_customer unless end_customer == SKIP @request_id = request_id unless request_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#end_customer ⇒ BetaPartnerEndCustomer
The details for an end customer.
14 15 16 |
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_get_response.rb', line 14 def end_customer @end_customer end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
20 21 22 |
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_get_response.rb', line 20 def request_id @request_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_get_response.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. end_customer = BetaPartnerEndCustomer.from_hash(hash['end_customer']) if hash['end_customer'] request_id = hash.key?('request_id') ? hash['request_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BetaPartnerCustomerV1GetResponse.new(end_customer: end_customer, request_id: request_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_get_response.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['end_customer'] = 'end_customer' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_get_response.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_get_response.rb', line 31 def self.optionals %w[ end_customer request_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
83 84 85 86 87 |
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_get_response.rb', line 83 def inspect class_name = self.class.name.split('::').last "<#{class_name} end_customer: #{@end_customer.inspect}, request_id: #{@request_id.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
76 77 78 79 80 |
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_get_response.rb', line 76 def to_s class_name = self.class.name.split('::').last "<#{class_name} end_customer: #{@end_customer}, request_id: #{@request_id},"\ " additional_properties: #{@additional_properties}>" end |