Class: ThePlaidApi::BetaPartnerCustomerV1UpdateResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/beta_partner_customer_v1_update_response.rb

Overview

Response schema for ‘/beta/partner/customer/v1/update`.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(end_customer: SKIP, request_id: SKIP, additional_properties: nil) ⇒ BetaPartnerCustomerV1UpdateResponse

Returns a new instance of BetaPartnerCustomerV1UpdateResponse.



43
44
45
46
47
48
49
50
51
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_update_response.rb', line 43

def initialize(end_customer: SKIP, request_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @end_customer = end_customer unless end_customer == SKIP
  @request_id = request_id unless request_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#end_customerBetaPartnerEndCustomer

The details for an end customer.



14
15
16
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_update_response.rb', line 14

def end_customer
  @end_customer
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


20
21
22
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_update_response.rb', line 20

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_update_response.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  end_customer = BetaPartnerEndCustomer.from_hash(hash['end_customer']) if
    hash['end_customer']
  request_id = hash.key?('request_id') ? hash['request_id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BetaPartnerCustomerV1UpdateResponse.new(end_customer: end_customer,
                                          request_id: request_id,
                                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_update_response.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['end_customer'] = 'end_customer'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_update_response.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_update_response.rb', line 31

def self.optionals
  %w[
    end_customer
    request_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



83
84
85
86
87
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_update_response.rb', line 83

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} end_customer: #{@end_customer.inspect}, request_id: #{@request_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



76
77
78
79
80
# File 'lib/the_plaid_api/models/beta_partner_customer_v1_update_response.rb', line 76

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} end_customer: #{@end_customer}, request_id: #{@request_id},"\
  " additional_properties: #{@additional_properties}>"
end