Class: ThePlaidApi::BusinessFieldMatchSummary

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/business_field_match_summary.rb

Overview

Summary of how a specific business field matched against data provider results

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(summary:, additional_properties: nil) ⇒ BusinessFieldMatchSummary

Returns a new instance of BusinessFieldMatchSummary.



45
46
47
48
49
50
51
# File 'lib/the_plaid_api/models/business_field_match_summary.rb', line 45

def initialize(summary:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @summary = summary
  @additional_properties = additional_properties
end

Instance Attribute Details

#summaryMatchSummaryCode1

An enum indicating the match type between data provided by user and data checked against an external data source. ‘match` indicates that the provided input data was a strong match against external data. `partial_match` indicates the data approximately matched against external data. For example, “Knope” vs. “Knope-Wyatt” for last name. `no_match` indicates that Plaid was able to perform a check against an external data source and it did not match the provided input data. `no_data` indicates that Plaid was unable to find external data to compare against the provided input data. `no_input` indicates that Plaid was unable to perform a check because no information was provided for this field by the end user.

Returns:



26
27
28
# File 'lib/the_plaid_api/models/business_field_match_summary.rb', line 26

def summary
  @summary
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/the_plaid_api/models/business_field_match_summary.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  summary = hash.key?('summary') ? hash['summary'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BusinessFieldMatchSummary.new(summary: summary,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
# File 'lib/the_plaid_api/models/business_field_match_summary.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['summary'] = 'summary'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
# File 'lib/the_plaid_api/models/business_field_match_summary.rb', line 41

def self.nullables
  []
end

.optionalsObject

An array for optional fields



36
37
38
# File 'lib/the_plaid_api/models/business_field_match_summary.rb', line 36

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/the_plaid_api/models/business_field_match_summary.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} summary: #{@summary.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
# File 'lib/the_plaid_api/models/business_field_match_summary.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} summary: #{@summary}, additional_properties: #{@additional_properties}>"
end