Class: ThePlaidApi::BusinessVerificationCreateRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::BusinessVerificationCreateRequest
- Defined in:
- lib/the_plaid_api/models/business_verification_create_request.rb
Overview
Request input for creating a business verification
Instance Attribute Summary collapse
-
#business ⇒ BusinessVerificationCreateRequestBusiness
Business information provided in the verification request.
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#client_user_id ⇒ String
A unique ID that identifies the end user in your system.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_user_id:, business: SKIP, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ BusinessVerificationCreateRequest
constructor
A new instance of BusinessVerificationCreateRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_user_id:, business: SKIP, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ BusinessVerificationCreateRequest
Returns a new instance of BusinessVerificationCreateRequest.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/the_plaid_api/models/business_verification_create_request.rb', line 63 def initialize(client_user_id:, business: SKIP, client_id: SKIP, secret: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_user_id = client_user_id @business = business unless business == SKIP @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#business ⇒ BusinessVerificationCreateRequestBusiness
Business information provided in the verification request
24 25 26 |
# File 'lib/the_plaid_api/models/business_verification_create_request.rb', line 24 def business @business end |
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
30 31 32 |
# File 'lib/the_plaid_api/models/business_verification_create_request.rb', line 30 def client_id @client_id end |
#client_user_id ⇒ String
A unique ID that identifies the end user in your system. Either a ‘user_id` or the `client_user_id` must be provided. This ID can also be used to associate user-specific data from other Plaid products. Financial Account Matching requires this field and the `/link/token/create` `client_user_id` to be consistent. Personally identifiable information, such as an email address or phone number, should not be used in the `client_user_id`.
20 21 22 |
# File 'lib/the_plaid_api/models/business_verification_create_request.rb', line 20 def client_user_id @client_user_id end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
35 36 37 |
# File 'lib/the_plaid_api/models/business_verification_create_request.rb', line 35 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/the_plaid_api/models/business_verification_create_request.rb', line 76 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_user_id = hash.key?('client_user_id') ? hash['client_user_id'] : nil business = BusinessVerificationCreateRequestBusiness.from_hash(hash['business']) if hash['business'] client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BusinessVerificationCreateRequest.new(client_user_id: client_user_id, business: business, client_id: client_id, secret: secret, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
38 39 40 41 42 43 44 45 |
# File 'lib/the_plaid_api/models/business_verification_create_request.rb', line 38 def self.names @_hash = {} if @_hash.nil? @_hash['client_user_id'] = 'client_user_id' @_hash['business'] = 'business' @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash end |
.nullables ⇒ Object
An array for nullable fields
57 58 59 60 61 |
# File 'lib/the_plaid_api/models/business_verification_create_request.rb', line 57 def self.nullables %w[ business ] end |
.optionals ⇒ Object
An array for optional fields
48 49 50 51 52 53 54 |
# File 'lib/the_plaid_api/models/business_verification_create_request.rb', line 48 def self.optionals %w[ business client_id secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
110 111 112 113 114 115 |
# File 'lib/the_plaid_api/models/business_verification_create_request.rb', line 110 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_user_id: #{@client_user_id.inspect}, business: #{@business.inspect},"\ " client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
103 104 105 106 107 |
# File 'lib/the_plaid_api/models/business_verification_create_request.rb', line 103 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_user_id: #{@client_user_id}, business: #{@business}, client_id:"\ " #{@client_id}, secret: #{@secret}, additional_properties: #{@additional_properties}>" end |