Class: ThePlaidApi::BusinessWebsite

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/business_website.rb

Overview

Website associated with a business

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(url:, additional_properties: nil) ⇒ BusinessWebsite

Returns a new instance of BusinessWebsite.



35
36
37
38
39
40
41
# File 'lib/the_plaid_api/models/business_website.rb', line 35

def initialize(url:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @url = url
  @additional_properties = additional_properties
end

Instance Attribute Details

#urlString

URL of the business website

Returns:

  • (String)


14
15
16
# File 'lib/the_plaid_api/models/business_website.rb', line 14

def url
  @url
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/the_plaid_api/models/business_website.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  url = hash.key?('url') ? hash['url'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BusinessWebsite.new(url: url,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/the_plaid_api/models/business_website.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['url'] = 'url'
  @_hash
end

.nullablesObject

An array for nullable fields



29
30
31
32
33
# File 'lib/the_plaid_api/models/business_website.rb', line 29

def self.nullables
  %w[
    url
  ]
end

.optionalsObject

An array for optional fields



24
25
26
# File 'lib/the_plaid_api/models/business_website.rb', line 24

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



69
70
71
72
# File 'lib/the_plaid_api/models/business_website.rb', line 69

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} url: #{@url.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



63
64
65
66
# File 'lib/the_plaid_api/models/business_website.rb', line 63

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} url: #{@url}, additional_properties: #{@additional_properties}>"
end