Class: ThePlaidApi::CashFlowUpdatesExpectedDepositMissedWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/cash_flow_updates_expected_deposit_missed_webhook.rb

Overview

For each user’s item enabled for Cash Flow Updates, this webhook will fire when an update detects that an expected deposit was missed. Upon receiving the webhook, call ‘/cra/monitoring_insights/get` to retrieve the updated insights.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, status:, user_id:, environment:, additional_properties: nil) ⇒ CashFlowUpdatesExpectedDepositMissedWebhook

Returns a new instance of CashFlowUpdatesExpectedDepositMissedWebhook.



56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/the_plaid_api/models/cash_flow_updates_expected_deposit_missed_webhook.rb', line 56

def initialize(webhook_type:, webhook_code:, status:, user_id:,
               environment:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @status = status
  @user_id = user_id
  @environment = environment
  @additional_properties = additional_properties
end

Instance Attribute Details

#environmentWebhookEnvironmentValues

The Plaid environment the webhook was sent from



33
34
35
# File 'lib/the_plaid_api/models/cash_flow_updates_expected_deposit_missed_webhook.rb', line 33

def environment
  @environment
end

#statusMonitoringInsightsStatus

Enum for the status of the insights



25
26
27
# File 'lib/the_plaid_api/models/cash_flow_updates_expected_deposit_missed_webhook.rb', line 25

def status
  @status
end

#user_idString

The ‘user_id` that the report is associated with

Returns:

  • (String)


29
30
31
# File 'lib/the_plaid_api/models/cash_flow_updates_expected_deposit_missed_webhook.rb', line 29

def user_id
  @user_id
end

#webhook_codeString

‘EXPECTED_DEPOSIT_MISSED`

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/cash_flow_updates_expected_deposit_missed_webhook.rb', line 21

def webhook_code
  @webhook_code
end

#webhook_typeString

‘CASH_FLOW_UPDATES`

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/cash_flow_updates_expected_deposit_missed_webhook.rb', line 17

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/the_plaid_api/models/cash_flow_updates_expected_deposit_missed_webhook.rb', line 70

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  status = hash.key?('status') ? hash['status'] : nil
  user_id = hash.key?('user_id') ? hash['user_id'] : nil
  environment = hash.key?('environment') ? hash['environment'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CashFlowUpdatesExpectedDepositMissedWebhook.new(webhook_type: webhook_type,
                                                  webhook_code: webhook_code,
                                                  status: status,
                                                  user_id: user_id,
                                                  environment: environment,
                                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



36
37
38
39
40
41
42
43
44
# File 'lib/the_plaid_api/models/cash_flow_updates_expected_deposit_missed_webhook.rb', line 36

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['status'] = 'status'
  @_hash['user_id'] = 'user_id'
  @_hash['environment'] = 'environment'
  @_hash
end

.nullablesObject

An array for nullable fields



52
53
54
# File 'lib/the_plaid_api/models/cash_flow_updates_expected_deposit_missed_webhook.rb', line 52

def self.nullables
  []
end

.optionalsObject

An array for optional fields



47
48
49
# File 'lib/the_plaid_api/models/cash_flow_updates_expected_deposit_missed_webhook.rb', line 47

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



105
106
107
108
109
110
# File 'lib/the_plaid_api/models/cash_flow_updates_expected_deposit_missed_webhook.rb', line 105

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, status: #{@status.inspect}, user_id: #{@user_id.inspect},"\
  " environment: #{@environment.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



97
98
99
100
101
102
# File 'lib/the_plaid_api/models/cash_flow_updates_expected_deposit_missed_webhook.rb', line 97

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, status:"\
  " #{@status}, user_id: #{@user_id}, environment: #{@environment}, additional_properties:"\
  " #{@additional_properties}>"
end