Class: ThePlaidApi::CashFlowUpdatesInsightsWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/cash_flow_updates_insights_webhook.rb

Overview

For each user’s Item enabled for Cash Flow Updates, this webhook will fire between one and four times a day with information on the status of the update. This webhook will not fire immediately upon enrollment in Cash Flow Updates. Upon receiving the webhook, call ‘/cra/monitoring_insights/get` to retrieve the updated insights. At approximately the same time as the `INSIGHTS_UPDATED` webhook, any event-driven `CASH_FLOW_UPDATES` webhooks (e.g. `LOW_BALANCE_DETECTED`, `LARGE_DEPOSIT_DETECTED`) that were triggered by the update will also fire. This webhook has been replaced by the `CASH_FLOW_INSIGHTS_UPDATED` webhook for all customers who began using Plaid Check on or after December 10, 2025.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, status:, user_id:, environment:, additional_properties: nil) ⇒ CashFlowUpdatesInsightsWebhook

Returns a new instance of CashFlowUpdatesInsightsWebhook.



62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/the_plaid_api/models/cash_flow_updates_insights_webhook.rb', line 62

def initialize(webhook_type:, webhook_code:, status:, user_id:,
               environment:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @status = status
  @user_id = user_id
  @environment = environment
  @additional_properties = additional_properties
end

Instance Attribute Details

#environmentWebhookEnvironmentValues

The Plaid environment the webhook was sent from



39
40
41
# File 'lib/the_plaid_api/models/cash_flow_updates_insights_webhook.rb', line 39

def environment
  @environment
end

#statusMonitoringInsightsStatus

Enum for the status of the insights



31
32
33
# File 'lib/the_plaid_api/models/cash_flow_updates_insights_webhook.rb', line 31

def status
  @status
end

#user_idString

The ‘user_id` that the report is associated with

Returns:

  • (String)


35
36
37
# File 'lib/the_plaid_api/models/cash_flow_updates_insights_webhook.rb', line 35

def user_id
  @user_id
end

#webhook_codeString

‘INSIGHTS_UPDATED`

Returns:

  • (String)


27
28
29
# File 'lib/the_plaid_api/models/cash_flow_updates_insights_webhook.rb', line 27

def webhook_code
  @webhook_code
end

#webhook_typeString

‘CASH_FLOW_UPDATES`

Returns:

  • (String)


23
24
25
# File 'lib/the_plaid_api/models/cash_flow_updates_insights_webhook.rb', line 23

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/the_plaid_api/models/cash_flow_updates_insights_webhook.rb', line 76

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  status = hash.key?('status') ? hash['status'] : nil
  user_id = hash.key?('user_id') ? hash['user_id'] : nil
  environment = hash.key?('environment') ? hash['environment'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CashFlowUpdatesInsightsWebhook.new(webhook_type: webhook_type,
                                     webhook_code: webhook_code,
                                     status: status,
                                     user_id: user_id,
                                     environment: environment,
                                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



42
43
44
45
46
47
48
49
50
# File 'lib/the_plaid_api/models/cash_flow_updates_insights_webhook.rb', line 42

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['status'] = 'status'
  @_hash['user_id'] = 'user_id'
  @_hash['environment'] = 'environment'
  @_hash
end

.nullablesObject

An array for nullable fields



58
59
60
# File 'lib/the_plaid_api/models/cash_flow_updates_insights_webhook.rb', line 58

def self.nullables
  []
end

.optionalsObject

An array for optional fields



53
54
55
# File 'lib/the_plaid_api/models/cash_flow_updates_insights_webhook.rb', line 53

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



111
112
113
114
115
116
# File 'lib/the_plaid_api/models/cash_flow_updates_insights_webhook.rb', line 111

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, status: #{@status.inspect}, user_id: #{@user_id.inspect},"\
  " environment: #{@environment.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



103
104
105
106
107
108
# File 'lib/the_plaid_api/models/cash_flow_updates_insights_webhook.rb', line 103

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, status:"\
  " #{@status}, user_id: #{@user_id}, environment: #{@environment}, additional_properties:"\
  " #{@additional_properties}>"
end