Class: ThePlaidApi::CashFlowUpdatesNewIncomeStreamWebhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CashFlowUpdatesNewIncomeStreamWebhook
- Defined in:
- lib/the_plaid_api/models/cash_flow_updates_new_income_stream_webhook.rb
Overview
For each user’s item enabled for Cash Flow Updates, this webhook will fire when an update includes a new income stream. Upon receiving the webhook, call ‘/cra/monitoring_insights/get` to retrieve the updated insights.
Instance Attribute Summary collapse
-
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from.
-
#status ⇒ MonitoringInsightsStatus
Enum for the status of the insights.
-
#user_id ⇒ String
The ‘user_id` that the report is associated with.
-
#webhook_code ⇒ String
‘NEW_INCOME_STREAM_DETECTED`.
-
#webhook_type ⇒ String
‘CASH_FLOW_UPDATES`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, status:, user_id:, environment:, additional_properties: nil) ⇒ CashFlowUpdatesNewIncomeStreamWebhook
constructor
A new instance of CashFlowUpdatesNewIncomeStreamWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, status:, user_id:, environment:, additional_properties: nil) ⇒ CashFlowUpdatesNewIncomeStreamWebhook
Returns a new instance of CashFlowUpdatesNewIncomeStreamWebhook.
55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/the_plaid_api/models/cash_flow_updates_new_income_stream_webhook.rb', line 55 def initialize(webhook_type:, webhook_code:, status:, user_id:, environment:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @status = status @user_id = user_id @environment = environment @additional_properties = additional_properties end |
Instance Attribute Details
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from
32 33 34 |
# File 'lib/the_plaid_api/models/cash_flow_updates_new_income_stream_webhook.rb', line 32 def environment @environment end |
#status ⇒ MonitoringInsightsStatus
Enum for the status of the insights
24 25 26 |
# File 'lib/the_plaid_api/models/cash_flow_updates_new_income_stream_webhook.rb', line 24 def status @status end |
#user_id ⇒ String
The ‘user_id` that the report is associated with
28 29 30 |
# File 'lib/the_plaid_api/models/cash_flow_updates_new_income_stream_webhook.rb', line 28 def user_id @user_id end |
#webhook_code ⇒ String
‘NEW_INCOME_STREAM_DETECTED`
20 21 22 |
# File 'lib/the_plaid_api/models/cash_flow_updates_new_income_stream_webhook.rb', line 20 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘CASH_FLOW_UPDATES`
16 17 18 |
# File 'lib/the_plaid_api/models/cash_flow_updates_new_income_stream_webhook.rb', line 16 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/the_plaid_api/models/cash_flow_updates_new_income_stream_webhook.rb', line 69 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil status = hash.key?('status') ? hash['status'] : nil user_id = hash.key?('user_id') ? hash['user_id'] : nil environment = hash.key?('environment') ? hash['environment'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CashFlowUpdatesNewIncomeStreamWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, status: status, user_id: user_id, environment: environment, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
35 36 37 38 39 40 41 42 43 |
# File 'lib/the_plaid_api/models/cash_flow_updates_new_income_stream_webhook.rb', line 35 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['status'] = 'status' @_hash['user_id'] = 'user_id' @_hash['environment'] = 'environment' @_hash end |
.nullables ⇒ Object
An array for nullable fields
51 52 53 |
# File 'lib/the_plaid_api/models/cash_flow_updates_new_income_stream_webhook.rb', line 51 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
46 47 48 |
# File 'lib/the_plaid_api/models/cash_flow_updates_new_income_stream_webhook.rb', line 46 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
104 105 106 107 108 109 |
# File 'lib/the_plaid_api/models/cash_flow_updates_new_income_stream_webhook.rb', line 104 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, status: #{@status.inspect}, user_id: #{@user_id.inspect},"\ " environment: #{@environment.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
96 97 98 99 100 101 |
# File 'lib/the_plaid_api/models/cash_flow_updates_new_income_stream_webhook.rb', line 96 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, status:"\ " #{@status}, user_id: #{@user_id}, environment: #{@environment}, additional_properties:"\ " #{@additional_properties}>" end |