Class: ThePlaidApi::CashflowAccountInsights

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/cashflow_account_insights.rb

Overview

Insights on the account level. These are only returned for Credit and Depository type accounts.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(historical_balances:, monthly_summaries:, additional_properties: nil) ⇒ CashflowAccountInsights

Returns a new instance of CashflowAccountInsights.



40
41
42
43
44
45
46
47
48
# File 'lib/the_plaid_api/models/cashflow_account_insights.rb', line 40

def initialize(historical_balances:, monthly_summaries:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @historical_balances = historical_balances
  @monthly_summaries = monthly_summaries
  @additional_properties = additional_properties
end

Instance Attribute Details

#historical_balancesArray[CashflowReportHistoricalBalance]

Calculated data about the historical balances on the account. Available for ‘credit` and `depository` type accounts.



16
17
18
# File 'lib/the_plaid_api/models/cashflow_account_insights.rb', line 16

def historical_balances
  @historical_balances
end

#monthly_summariesArray[CashflowReportMonthlySummary]

Monthly summary statistics derived from transaction-level data.

Returns:



20
21
22
# File 'lib/the_plaid_api/models/cashflow_account_insights.rb', line 20

def monthly_summaries
  @monthly_summaries
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/the_plaid_api/models/cashflow_account_insights.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  historical_balances = nil
  unless hash['historical_balances'].nil?
    historical_balances = []
    hash['historical_balances'].each do |structure|
      historical_balances << (CashflowReportHistoricalBalance.from_hash(structure) if structure)
    end
  end

  historical_balances = nil unless hash.key?('historical_balances')
  # Parameter is an array, so we need to iterate through it
  monthly_summaries = nil
  unless hash['monthly_summaries'].nil?
    monthly_summaries = []
    hash['monthly_summaries'].each do |structure|
      monthly_summaries << (CashflowReportMonthlySummary.from_hash(structure) if structure)
    end
  end

  monthly_summaries = nil unless hash.key?('monthly_summaries')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CashflowAccountInsights.new(historical_balances: historical_balances,
                              monthly_summaries: monthly_summaries,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/the_plaid_api/models/cashflow_account_insights.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['historical_balances'] = 'historical_balances'
  @_hash['monthly_summaries'] = 'monthly_summaries'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
# File 'lib/the_plaid_api/models/cashflow_account_insights.rb', line 36

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
# File 'lib/the_plaid_api/models/cashflow_account_insights.rb', line 31

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



97
98
99
100
101
# File 'lib/the_plaid_api/models/cashflow_account_insights.rb', line 97

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} historical_balances: #{@historical_balances.inspect}, monthly_summaries:"\
  " #{@monthly_summaries.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



90
91
92
93
94
# File 'lib/the_plaid_api/models/cashflow_account_insights.rb', line 90

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} historical_balances: #{@historical_balances}, monthly_summaries:"\
  " #{@monthly_summaries}, additional_properties: #{@additional_properties}>"
end