Class: ThePlaidApi::CashflowReportGetRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/cashflow_report_get_request.rb

Overview

CashflowReportGetRequest defines the request schema for ‘/cashflow_report/get`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(access_token:, days_requested:, client_id: SKIP, secret: SKIP, count: 100, cursor: SKIP, options: SKIP, additional_properties: nil) ⇒ CashflowReportGetRequest

Returns a new instance of CashflowReportGetRequest.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/the_plaid_api/models/cashflow_report_get_request.rb', line 75

def initialize(access_token:, days_requested:, client_id: SKIP,
               secret: SKIP, count: 100, cursor: SKIP, options: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @access_token = access_token
  @secret = secret unless secret == SKIP
  @days_requested = days_requested
  @count = count unless count == SKIP
  @cursor = cursor unless cursor == SKIP
  @options = options unless options == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#access_tokenString

The access token associated with the Item data is being requested for.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/cashflow_report_get_request.rb', line 21

def access_token
  @access_token
end

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/cashflow_report_get_request.rb', line 17

def client_id
  @client_id
end

#countInteger

Number of transactions to fetch per call

Returns:

  • (Integer)


34
35
36
# File 'lib/the_plaid_api/models/cashflow_report_get_request.rb', line 34

def count
  @count
end

#cursorString

The cursor value represents the last update requested. Pass in the empty string “” in the first call.

Returns:

  • (String)


39
40
41
# File 'lib/the_plaid_api/models/cashflow_report_get_request.rb', line 39

def cursor
  @cursor
end

#days_requestedInteger

Number of days to retrieve transactions data for (1 to 730)

Returns:

  • (Integer)


30
31
32
# File 'lib/the_plaid_api/models/cashflow_report_get_request.rb', line 30

def days_requested
  @days_requested
end

#optionsCashflowReportGetRequestOptions

An optional object to be used with the request. If specified, ‘options` must not be `null`.



44
45
46
# File 'lib/the_plaid_api/models/cashflow_report_get_request.rb', line 44

def options
  @options
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


26
27
28
# File 'lib/the_plaid_api/models/cashflow_report_get_request.rb', line 26

def secret
  @secret
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/the_plaid_api/models/cashflow_report_get_request.rb', line 92

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  access_token = hash.key?('access_token') ? hash['access_token'] : nil
  days_requested =
    hash.key?('days_requested') ? hash['days_requested'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  count = hash['count'] ||= 100
  cursor = hash.key?('cursor') ? hash['cursor'] : SKIP
  options = CashflowReportGetRequestOptions.from_hash(hash['options']) if hash['options']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CashflowReportGetRequest.new(access_token: access_token,
                               days_requested: days_requested,
                               client_id: client_id,
                               secret: secret,
                               count: count,
                               cursor: cursor,
                               options: options,
                               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



47
48
49
50
51
52
53
54
55
56
57
# File 'lib/the_plaid_api/models/cashflow_report_get_request.rb', line 47

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['access_token'] = 'access_token'
  @_hash['secret'] = 'secret'
  @_hash['days_requested'] = 'days_requested'
  @_hash['count'] = 'count'
  @_hash['cursor'] = 'cursor'
  @_hash['options'] = 'options'
  @_hash
end

.nullablesObject

An array for nullable fields



71
72
73
# File 'lib/the_plaid_api/models/cashflow_report_get_request.rb', line 71

def self.nullables
  []
end

.optionalsObject

An array for optional fields



60
61
62
63
64
65
66
67
68
# File 'lib/the_plaid_api/models/cashflow_report_get_request.rb', line 60

def self.optionals
  %w[
    client_id
    secret
    count
    cursor
    options
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



132
133
134
135
136
137
138
# File 'lib/the_plaid_api/models/cashflow_report_get_request.rb', line 132

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, access_token: #{@access_token.inspect},"\
  " secret: #{@secret.inspect}, days_requested: #{@days_requested.inspect}, count:"\
  " #{@count.inspect}, cursor: #{@cursor.inspect}, options: #{@options.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



124
125
126
127
128
129
# File 'lib/the_plaid_api/models/cashflow_report_get_request.rb', line 124

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, access_token: #{@access_token}, secret:"\
  " #{@secret}, days_requested: #{@days_requested}, count: #{@count}, cursor: #{@cursor},"\
  " options: #{@options}, additional_properties: #{@additional_properties}>"
end