Class: ThePlaidApi::CashflowReportTransactionsGetRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/cashflow_report_transactions_get_request.rb

Overview

CashflowReportTransactionsGetRequest defines the request schema for ‘/cashflow_report/transactions/get`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(access_token:, client_id: SKIP, secret: SKIP, count: 100, cursor: SKIP, options: SKIP, additional_properties: nil) ⇒ CashflowReportTransactionsGetRequest

Returns a new instance of CashflowReportTransactionsGetRequest.



70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_request.rb', line 70

def initialize(access_token:, client_id: SKIP, secret: SKIP, count: 100,
               cursor: SKIP, options: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @access_token = access_token
  @secret = secret unless secret == SKIP
  @count = count unless count == SKIP
  @cursor = cursor unless cursor == SKIP
  @options = options unless options == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#access_tokenString

The access token associated with the Item data is being requested for.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_request.rb', line 21

def access_token
  @access_token
end

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_request.rb', line 17

def client_id
  @client_id
end

#countInteger

Number of transactions to fetch per call

Returns:

  • (Integer)


30
31
32
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_request.rb', line 30

def count
  @count
end

#cursorString

The cursor value represents the last update requested. Pass in the empty string “” in the first call.

Returns:

  • (String)


35
36
37
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_request.rb', line 35

def cursor
  @cursor
end

#optionsCashflowReportTransactionsGetRequestOptions

An optional object to be used with the request. If specified, ‘options` must not be `null`.



40
41
42
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_request.rb', line 40

def options
  @options
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


26
27
28
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_request.rb', line 26

def secret
  @secret
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_request.rb', line 85

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  access_token = hash.key?('access_token') ? hash['access_token'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  count = hash['count'] ||= 100
  cursor = hash.key?('cursor') ? hash['cursor'] : SKIP
  options = CashflowReportTransactionsGetRequestOptions.from_hash(hash['options']) if
    hash['options']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CashflowReportTransactionsGetRequest.new(access_token: access_token,
                                           client_id: client_id,
                                           secret: secret,
                                           count: count,
                                           cursor: cursor,
                                           options: options,
                                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



43
44
45
46
47
48
49
50
51
52
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_request.rb', line 43

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['access_token'] = 'access_token'
  @_hash['secret'] = 'secret'
  @_hash['count'] = 'count'
  @_hash['cursor'] = 'cursor'
  @_hash['options'] = 'options'
  @_hash
end

.nullablesObject

An array for nullable fields



66
67
68
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_request.rb', line 66

def self.nullables
  []
end

.optionalsObject

An array for optional fields



55
56
57
58
59
60
61
62
63
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_request.rb', line 55

def self.optionals
  %w[
    client_id
    secret
    count
    cursor
    options
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



123
124
125
126
127
128
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_request.rb', line 123

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, access_token: #{@access_token.inspect},"\
  " secret: #{@secret.inspect}, count: #{@count.inspect}, cursor: #{@cursor.inspect}, options:"\
  " #{@options.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



115
116
117
118
119
120
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_request.rb', line 115

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, access_token: #{@access_token}, secret:"\
  " #{@secret}, count: #{@count}, cursor: #{@cursor}, options: #{@options},"\
  " additional_properties: #{@additional_properties}>"
end