Class: ThePlaidApi::CashflowReportTransactionsGetResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/cashflow_report_transactions_get_response.rb

Overview

CashflowReportTransactionsGetResponse defines the response schema for ‘/cashflow_report/transactions/get`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(accounts:, transactions:, total_transactions:, item:, next_cursor:, has_more:, request_id:, additional_properties: nil) ⇒ CashflowReportTransactionsGetResponse

Returns a new instance of CashflowReportTransactionsGetResponse.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_response.rb', line 76

def initialize(accounts:, transactions:, total_transactions:, item:,
               next_cursor:, has_more:, request_id:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @accounts = accounts
  @transactions = transactions
  @total_transactions = total_transactions
  @item = item
  @next_cursor = next_cursor
  @has_more = has_more
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#accountsArray[BusinessAccount]

An array containing the ‘accounts` associated with the Item for which transactions are being returned. Each transaction can be mapped to its corresponding account via the `account_id` field.

Returns:



17
18
19
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_response.rb', line 17

def accounts
  @accounts
end

#has_moreTrueClass | FalseClass

Represents if more than requested count of transactions exists to be fetched

Returns:

  • (TrueClass | FalseClass)


45
46
47
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_response.rb', line 45

def has_more
  @has_more
end

#itemItem

Metadata about the Item.

Returns:



35
36
37
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_response.rb', line 35

def item
  @item
end

#next_cursorString

Cursor used for fetching any future updates after the latest update provided in this response.

Returns:

  • (String)


40
41
42
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_response.rb', line 40

def next_cursor
  @next_cursor
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


51
52
53
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_response.rb', line 51

def request_id
  @request_id
end

#total_transactionsInteger

The total number of transactions available within the date range specified. If ‘total_transactions` is larger than the size of the `transactions` array, more transactions are available and can be fetched via manipulating the `offset` parameter.

Returns:

  • (Integer)


31
32
33
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_response.rb', line 31

def total_transactions
  @total_transactions
end

#transactionsArray[CashflowReportTransaction]

An array containing transactions from the account. Transactions are returned in reverse chronological order, with the most recent at the beginning of the array. The maximum number of transactions returned is determined by the ‘count` parameter.

Returns:



24
25
26
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_response.rb', line 24

def transactions
  @transactions
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_response.rb', line 93

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  accounts = nil
  unless hash['accounts'].nil?
    accounts = []
    hash['accounts'].each do |structure|
      accounts << (BusinessAccount.from_hash(structure) if structure)
    end
  end

  accounts = nil unless hash.key?('accounts')
  # Parameter is an array, so we need to iterate through it
  transactions = nil
  unless hash['transactions'].nil?
    transactions = []
    hash['transactions'].each do |structure|
      transactions << (CashflowReportTransaction.from_hash(structure) if structure)
    end
  end

  transactions = nil unless hash.key?('transactions')
  total_transactions =
    hash.key?('total_transactions') ? hash['total_transactions'] : nil
  item = Item.from_hash(hash['item']) if hash['item']
  next_cursor = hash.key?('next_cursor') ? hash['next_cursor'] : nil
  has_more = hash.key?('has_more') ? hash['has_more'] : nil
  request_id = hash.key?('request_id') ? hash['request_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CashflowReportTransactionsGetResponse.new(accounts: accounts,
                                            transactions: transactions,
                                            total_transactions: total_transactions,
                                            item: item,
                                            next_cursor: next_cursor,
                                            has_more: has_more,
                                            request_id: request_id,
                                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



54
55
56
57
58
59
60
61
62
63
64
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_response.rb', line 54

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['accounts'] = 'accounts'
  @_hash['transactions'] = 'transactions'
  @_hash['total_transactions'] = 'total_transactions'
  @_hash['item'] = 'item'
  @_hash['next_cursor'] = 'next_cursor'
  @_hash['has_more'] = 'has_more'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



72
73
74
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_response.rb', line 72

def self.nullables
  []
end

.optionalsObject

An array for optional fields



67
68
69
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_response.rb', line 67

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



152
153
154
155
156
157
158
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_response.rb', line 152

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} accounts: #{@accounts.inspect}, transactions: #{@transactions.inspect},"\
  " total_transactions: #{@total_transactions.inspect}, item: #{@item.inspect}, next_cursor:"\
  " #{@next_cursor.inspect}, has_more: #{@has_more.inspect}, request_id:"\
  " #{@request_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



143
144
145
146
147
148
149
# File 'lib/the_plaid_api/models/cashflow_report_transactions_get_response.rb', line 143

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} accounts: #{@accounts}, transactions: #{@transactions}, total_transactions:"\
  " #{@total_transactions}, item: #{@item}, next_cursor: #{@next_cursor}, has_more:"\
  " #{@has_more}, request_id: #{@request_id}, additional_properties:"\
  " #{@additional_properties}>"
end