Class: ThePlaidApi::Category

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/category.rb

Overview

Information describing a transaction category

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(category_id:, group:, hierarchy:, additional_properties: nil) ⇒ Category

Returns a new instance of Category.



46
47
48
49
50
51
52
53
54
# File 'lib/the_plaid_api/models/category.rb', line 46

def initialize(category_id:, group:, hierarchy:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @category_id = category_id
  @group = group
  @hierarchy = hierarchy
  @additional_properties = additional_properties
end

Instance Attribute Details

#category_idString

An identifying number for the category. ‘category_id` is a Plaid-specific identifier and does not necessarily correspond to merchant category codes.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/category.rb', line 15

def category_id
  @category_id
end

#groupString

‘place` for physical transactions or `special` for other transactions such as bank charges.

Returns:

  • (String)


20
21
22
# File 'lib/the_plaid_api/models/category.rb', line 20

def group
  @group
end

#hierarchyArray[String]

A hierarchical array of the categories to which this ‘category_id` belongs.

Returns:

  • (Array[String])


25
26
27
# File 'lib/the_plaid_api/models/category.rb', line 25

def hierarchy
  @hierarchy
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/the_plaid_api/models/category.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  category_id = hash.key?('category_id') ? hash['category_id'] : nil
  group = hash.key?('group') ? hash['group'] : nil
  hierarchy = hash.key?('hierarchy') ? hash['hierarchy'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Category.new(category_id: category_id,
               group: group,
               hierarchy: hierarchy,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



28
29
30
31
32
33
34
# File 'lib/the_plaid_api/models/category.rb', line 28

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['category_id'] = 'category_id'
  @_hash['group'] = 'group'
  @_hash['hierarchy'] = 'hierarchy'
  @_hash
end

.nullablesObject

An array for nullable fields



42
43
44
# File 'lib/the_plaid_api/models/category.rb', line 42

def self.nullables
  []
end

.optionalsObject

An array for optional fields



37
38
39
# File 'lib/the_plaid_api/models/category.rb', line 37

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



87
88
89
90
91
# File 'lib/the_plaid_api/models/category.rb', line 87

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} category_id: #{@category_id.inspect}, group: #{@group.inspect}, hierarchy:"\
  " #{@hierarchy.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



80
81
82
83
84
# File 'lib/the_plaid_api/models/category.rb', line 80

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} category_id: #{@category_id}, group: #{@group}, hierarchy: #{@hierarchy},"\
  " additional_properties: #{@additional_properties}>"
end