Class: ThePlaidApi::CategoryInsights

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/category_insights.rb

Overview

Insights on a user’s top personal finance categories.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(primary_category_insights: SKIP, detailed_category_insights: SKIP, additional_properties: nil) ⇒ CategoryInsights

Returns a new instance of CategoryInsights.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/the_plaid_api/models/category_insights.rb', line 43

def initialize(primary_category_insights: SKIP,
               detailed_category_insights: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  unless primary_category_insights == SKIP
    @primary_category_insights =
      primary_category_insights
  end
  unless detailed_category_insights == SKIP
    @detailed_category_insights =
      detailed_category_insights
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#detailed_category_insightsArray[CategoryInsightDetails]

List of insights of top detailed personal finance categories ranked by outflow.

Returns:



20
21
22
# File 'lib/the_plaid_api/models/category_insights.rb', line 20

def detailed_category_insights
  @detailed_category_insights
end

#primary_category_insightsArray[CategoryInsightDetails]

List of insights of top primary personal finance categories ranked by outflow.

Returns:



15
16
17
# File 'lib/the_plaid_api/models/category_insights.rb', line 15

def primary_category_insights
  @primary_category_insights
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/the_plaid_api/models/category_insights.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  primary_category_insights = nil
  unless hash['primary_category_insights'].nil?
    primary_category_insights = []
    hash['primary_category_insights'].each do |structure|
      primary_category_insights << (CategoryInsightDetails.from_hash(structure) if structure)
    end
  end

  primary_category_insights = SKIP unless hash.key?('primary_category_insights')
  # Parameter is an array, so we need to iterate through it
  detailed_category_insights = nil
  unless hash['detailed_category_insights'].nil?
    detailed_category_insights = []
    hash['detailed_category_insights'].each do |structure|
      detailed_category_insights << (CategoryInsightDetails.from_hash(structure) if structure)
    end
  end

  detailed_category_insights = SKIP unless hash.key?('detailed_category_insights')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CategoryInsights.new(primary_category_insights: primary_category_insights,
                       detailed_category_insights: detailed_category_insights,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/the_plaid_api/models/category_insights.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['primary_category_insights'] = 'primary_category_insights'
  @_hash['detailed_category_insights'] = 'detailed_category_insights'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/the_plaid_api/models/category_insights.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/the_plaid_api/models/category_insights.rb', line 31

def self.optionals
  %w[
    primary_category_insights
    detailed_category_insights
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



107
108
109
110
111
112
# File 'lib/the_plaid_api/models/category_insights.rb', line 107

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} primary_category_insights: #{@primary_category_insights.inspect},"\
  " detailed_category_insights: #{@detailed_category_insights.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



99
100
101
102
103
104
# File 'lib/the_plaid_api/models/category_insights.rb', line 99

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} primary_category_insights: #{@primary_category_insights},"\
  " detailed_category_insights: #{@detailed_category_insights}, additional_properties:"\
  " #{@additional_properties}>"
end