Class: ThePlaidApi::ClientCustomization

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/client_customization.rb

Overview

Custom client fields

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(custom_entity_id: SKIP, additional_properties: nil) ⇒ ClientCustomization

Returns a new instance of ClientCustomization.



37
38
39
40
41
42
43
# File 'lib/the_plaid_api/models/client_customization.rb', line 37

def initialize(custom_entity_id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @custom_entity_id = custom_entity_id unless custom_entity_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#custom_entity_idString

Custom entity ID that maps to a merchant or counterparty. This is different from the ‘merchant_entity_id` as well as the `entity_id` on the counterparties object to meet client specific needs.

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/client_customization.rb', line 16

def custom_entity_id
  @custom_entity_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/the_plaid_api/models/client_customization.rb', line 46

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  custom_entity_id =
    hash.key?('custom_entity_id') ? hash['custom_entity_id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ClientCustomization.new(custom_entity_id: custom_entity_id,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



19
20
21
22
23
# File 'lib/the_plaid_api/models/client_customization.rb', line 19

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['custom_entity_id'] = 'custom_entity_id'
  @_hash
end

.nullablesObject

An array for nullable fields



33
34
35
# File 'lib/the_plaid_api/models/client_customization.rb', line 33

def self.nullables
  []
end

.optionalsObject

An array for optional fields



26
27
28
29
30
# File 'lib/the_plaid_api/models/client_customization.rb', line 26

def self.optionals
  %w[
    custom_entity_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



73
74
75
76
77
# File 'lib/the_plaid_api/models/client_customization.rb', line 73

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} custom_entity_id: #{@custom_entity_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



66
67
68
69
70
# File 'lib/the_plaid_api/models/client_customization.rb', line 66

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} custom_entity_id: #{@custom_entity_id}, additional_properties:"\
  " #{@additional_properties}>"
end