Class: ThePlaidApi::ConsentEventsGetResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/consent_events_get_response.rb

Overview

Describes a historical log of item consent events.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(request_id:, consent_events:, additional_properties: nil) ⇒ ConsentEventsGetResponse

Returns a new instance of ConsentEventsGetResponse.



40
41
42
43
44
45
46
47
# File 'lib/the_plaid_api/models/consent_events_get_response.rb', line 40

def initialize(request_id:, consent_events:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @request_id = request_id
  @consent_events = consent_events
  @additional_properties = additional_properties
end

Instance Attribute Details

A list of consent events.

Returns:



20
21
22
# File 'lib/the_plaid_api/models/consent_events_get_response.rb', line 20

def consent_events
  @consent_events
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/consent_events_get_response.rb', line 16

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/the_plaid_api/models/consent_events_get_response.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  request_id = hash.key?('request_id') ? hash['request_id'] : nil
  # Parameter is an array, so we need to iterate through it
  consent_events = nil
  unless hash['consent_events'].nil?
    consent_events = []
    hash['consent_events'].each do |structure|
      consent_events << (ConsentEvent.from_hash(structure) if structure)
    end
  end

  consent_events = nil unless hash.key?('consent_events')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ConsentEventsGetResponse.new(request_id: request_id,
                               consent_events: consent_events,
                               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/the_plaid_api/models/consent_events_get_response.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['request_id'] = 'request_id'
  @_hash['consent_events'] = 'consent_events'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
# File 'lib/the_plaid_api/models/consent_events_get_response.rb', line 36

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
# File 'lib/the_plaid_api/models/consent_events_get_response.rb', line 31

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



87
88
89
90
91
# File 'lib/the_plaid_api/models/consent_events_get_response.rb', line 87

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} request_id: #{@request_id.inspect}, consent_events:"\
  " #{@consent_events.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



80
81
82
83
84
# File 'lib/the_plaid_api/models/consent_events_get_response.rb', line 80

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} request_id: #{@request_id}, consent_events: #{@consent_events},"\
  " additional_properties: #{@additional_properties}>"
end