Class: ThePlaidApi::CounterpartyNumbersInternational

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/counterparty_numbers_international.rb

Overview

Account numbers using the International Bank Account Number and BIC/SWIFT code format.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(iban: SKIP, bic: SKIP, additional_properties: nil) ⇒ CounterpartyNumbersInternational

Returns a new instance of CounterpartyNumbersInternational.



45
46
47
48
49
50
51
52
# File 'lib/the_plaid_api/models/counterparty_numbers_international.rb', line 45

def initialize(iban: SKIP, bic: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @iban = iban unless iban == SKIP
  @bic = bic unless bic == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#bicString

Bank identifier code (BIC) for this counterparty.

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/counterparty_numbers_international.rb', line 19

def bic
  @bic
end

#ibanString

International Bank Account Number (IBAN).

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/counterparty_numbers_international.rb', line 15

def iban
  @iban
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/the_plaid_api/models/counterparty_numbers_international.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  iban = hash.key?('iban') ? hash['iban'] : SKIP
  bic = hash.key?('bic') ? hash['bic'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CounterpartyNumbersInternational.new(iban: iban,
                                       bic: bic,
                                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/the_plaid_api/models/counterparty_numbers_international.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['iban'] = 'iban'
  @_hash['bic'] = 'bic'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
41
42
43
# File 'lib/the_plaid_api/models/counterparty_numbers_international.rb', line 38

def self.nullables
  %w[
    iban
    bic
  ]
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/the_plaid_api/models/counterparty_numbers_international.rb', line 30

def self.optionals
  %w[
    iban
    bic
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



83
84
85
86
87
# File 'lib/the_plaid_api/models/counterparty_numbers_international.rb', line 83

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} iban: #{@iban.inspect}, bic: #{@bic.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



76
77
78
79
80
# File 'lib/the_plaid_api/models/counterparty_numbers_international.rb', line 76

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} iban: #{@iban}, bic: #{@bic}, additional_properties:"\
  " #{@additional_properties}>"
end