Class: ThePlaidApi::CraBankIncomeCompleteWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/cra_bank_income_complete_webhook.rb

Overview

Fired when a bank income report has finished generating or failed to generate, triggered by calling ‘/cra/bank_income/get`.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, user_id:, environment:, result: SKIP, additional_properties: nil) ⇒ CraBankIncomeCompleteWebhook

Returns a new instance of CraBankIncomeCompleteWebhook.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/the_plaid_api/models/cra_bank_income_complete_webhook.rb', line 59

def initialize(webhook_type:, webhook_code:, user_id:, environment:,
               result: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @user_id = user_id
  @result = result unless result == SKIP
  @environment = environment
  @additional_properties = additional_properties
end

Instance Attribute Details

#environmentWebhookEnvironmentValues

The Plaid environment the webhook was sent from



34
35
36
# File 'lib/the_plaid_api/models/cra_bank_income_complete_webhook.rb', line 34

def environment
  @environment
end

#resultCraBankIncomeCompleteResult

The result of the bank income report generation ‘SUCCESS`: The bank income report was successfully generated and can be retrieved via `/cra/bank_income/get`. `FAILURE`: The bank income report failed to be generated



30
31
32
# File 'lib/the_plaid_api/models/cra_bank_income_complete_webhook.rb', line 30

def result
  @result
end

#user_idString

The ‘user_id` corresponding to the user the webhook has fired for.

Returns:

  • (String)


23
24
25
# File 'lib/the_plaid_api/models/cra_bank_income_complete_webhook.rb', line 23

def user_id
  @user_id
end

#webhook_codeString

‘BANK_INCOME_COMPLETE`

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/cra_bank_income_complete_webhook.rb', line 19

def webhook_code
  @webhook_code
end

#webhook_typeString

‘CRA_INCOME`

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/cra_bank_income_complete_webhook.rb', line 15

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/the_plaid_api/models/cra_bank_income_complete_webhook.rb', line 73

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  user_id = hash.key?('user_id') ? hash['user_id'] : nil
  environment = hash.key?('environment') ? hash['environment'] : nil
  result = hash.key?('result') ? hash['result'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CraBankIncomeCompleteWebhook.new(webhook_type: webhook_type,
                                   webhook_code: webhook_code,
                                   user_id: user_id,
                                   environment: environment,
                                   result: result,
                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
45
# File 'lib/the_plaid_api/models/cra_bank_income_complete_webhook.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['user_id'] = 'user_id'
  @_hash['result'] = 'result'
  @_hash['environment'] = 'environment'
  @_hash
end

.nullablesObject

An array for nullable fields



55
56
57
# File 'lib/the_plaid_api/models/cra_bank_income_complete_webhook.rb', line 55

def self.nullables
  []
end

.optionalsObject

An array for optional fields



48
49
50
51
52
# File 'lib/the_plaid_api/models/cra_bank_income_complete_webhook.rb', line 48

def self.optionals
  %w[
    result
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



108
109
110
111
112
113
# File 'lib/the_plaid_api/models/cra_bank_income_complete_webhook.rb', line 108

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, user_id: #{@user_id.inspect}, result: #{@result.inspect},"\
  " environment: #{@environment.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



100
101
102
103
104
105
# File 'lib/the_plaid_api/models/cra_bank_income_complete_webhook.rb', line 100

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, user_id:"\
  " #{@user_id}, result: #{@result}, environment: #{@environment}, additional_properties:"\
  " #{@additional_properties}>"
end