Class: ThePlaidApi::CraBankIncomeErrorWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/cra_bank_income_error_webhook.rb

Overview

Fired when a bank income report has failed to generate

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, user_id:, environment:, additional_properties: nil) ⇒ CraBankIncomeErrorWebhook

Returns a new instance of CraBankIncomeErrorWebhook.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/the_plaid_api/models/cra_bank_income_error_webhook.rb', line 48

def initialize(webhook_type:, webhook_code:, user_id:, environment:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @user_id = user_id
  @environment = environment
  @additional_properties = additional_properties
end

Instance Attribute Details

#environmentWebhookEnvironmentValues

The Plaid environment the webhook was sent from



26
27
28
# File 'lib/the_plaid_api/models/cra_bank_income_error_webhook.rb', line 26

def environment
  @environment
end

#user_idString

The ‘user_id` corresponding to the user the webhook has fired for.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/cra_bank_income_error_webhook.rb', line 22

def user_id
  @user_id
end

#webhook_codeString

‘ERROR`

Returns:

  • (String)


18
19
20
# File 'lib/the_plaid_api/models/cra_bank_income_error_webhook.rb', line 18

def webhook_code
  @webhook_code
end

#webhook_typeString

‘CRA_INCOME`

Returns:

  • (String)


14
15
16
# File 'lib/the_plaid_api/models/cra_bank_income_error_webhook.rb', line 14

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/the_plaid_api/models/cra_bank_income_error_webhook.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  user_id = hash.key?('user_id') ? hash['user_id'] : nil
  environment = hash.key?('environment') ? hash['environment'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CraBankIncomeErrorWebhook.new(webhook_type: webhook_type,
                                webhook_code: webhook_code,
                                user_id: user_id,
                                environment: environment,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/the_plaid_api/models/cra_bank_income_error_webhook.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['user_id'] = 'user_id'
  @_hash['environment'] = 'environment'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/the_plaid_api/models/cra_bank_income_error_webhook.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
# File 'lib/the_plaid_api/models/cra_bank_income_error_webhook.rb', line 39

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



94
95
96
97
98
99
# File 'lib/the_plaid_api/models/cra_bank_income_error_webhook.rb', line 94

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, user_id: #{@user_id.inspect}, environment:"\
  " #{@environment.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



86
87
88
89
90
91
# File 'lib/the_plaid_api/models/cra_bank_income_error_webhook.rb', line 86

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, user_id:"\
  " #{@user_id}, environment: #{@environment}, additional_properties:"\
  " #{@additional_properties}>"
end