Class: ThePlaidApi::CraBankIncomeIncomeProvider

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/cra_bank_income_income_provider.rb

Overview

The object containing data about the income provider.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name:, is_normalized:, additional_properties: nil) ⇒ CraBankIncomeIncomeProvider

Returns a new instance of CraBankIncomeIncomeProvider.



39
40
41
42
43
44
45
46
# File 'lib/the_plaid_api/models/cra_bank_income_income_provider.rb', line 39

def initialize(name:, is_normalized:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @name = name
  @is_normalized = is_normalized
  @additional_properties = additional_properties
end

Instance Attribute Details

#is_normalizedTrueClass | FalseClass

Indicates whether the income provider name is normalized by comparing it against a canonical set of known providers.

Returns:

  • (TrueClass | FalseClass)


19
20
21
# File 'lib/the_plaid_api/models/cra_bank_income_income_provider.rb', line 19

def is_normalized
  @is_normalized
end

#nameString

The name of the income provider.

Returns:

  • (String)


14
15
16
# File 'lib/the_plaid_api/models/cra_bank_income_income_provider.rb', line 14

def name
  @name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/the_plaid_api/models/cra_bank_income_income_provider.rb', line 49

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : nil
  is_normalized = hash.key?('is_normalized') ? hash['is_normalized'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CraBankIncomeIncomeProvider.new(name: name,
                                  is_normalized: is_normalized,
                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/the_plaid_api/models/cra_bank_income_income_provider.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash['is_normalized'] = 'is_normalized'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
# File 'lib/the_plaid_api/models/cra_bank_income_income_provider.rb', line 35

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
# File 'lib/the_plaid_api/models/cra_bank_income_income_provider.rb', line 30

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



77
78
79
80
81
# File 'lib/the_plaid_api/models/cra_bank_income_income_provider.rb', line 77

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, is_normalized: #{@is_normalized.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



70
71
72
73
74
# File 'lib/the_plaid_api/models/cra_bank_income_income_provider.rb', line 70

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, is_normalized: #{@is_normalized}, additional_properties:"\
  " #{@additional_properties}>"
end