Class: ThePlaidApi::CraCheckReportBaseReportGetRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/cra_check_report_base_report_get_request.rb

Overview

BaseReportGetRequest defines the request schema for ‘/cra/check_report/base_report/get`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(client_id: SKIP, secret: SKIP, user_id: SKIP, third_party_user_token: SKIP, item_ids: SKIP, user_token: SKIP, user_tier: SKIP, additional_properties: nil) ⇒ CraCheckReportBaseReportGetRequest

Returns a new instance of CraCheckReportBaseReportGetRequest.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/the_plaid_api/models/cra_check_report_base_report_get_request.rb', line 86

def initialize(client_id: SKIP, secret: SKIP, user_id: SKIP,
               third_party_user_token: SKIP, item_ids: SKIP,
               user_token: SKIP, user_tier: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @user_id = user_id unless user_id == SKIP
  @third_party_user_token = third_party_user_token unless third_party_user_token == SKIP
  @item_ids = item_ids unless item_ids == SKIP
  @user_token = user_token unless user_token == SKIP
  @user_tier = user_tier unless user_tier == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/cra_check_report_base_report_get_request.rb', line 17

def client_id
  @client_id
end

#item_idsArray[String]

The item IDs to include in the Base Report. If not provided, all items associated with the user will be included.

Returns:

  • (Array[String])


38
39
40
# File 'lib/the_plaid_api/models/cra_check_report_base_report_get_request.rb', line 38

def item_ids
  @item_ids
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/cra_check_report_base_report_get_request.rb', line 22

def secret
  @secret
end

#third_party_user_tokenString

The third-party user token associated with the requested User data.

Returns:

  • (String)


33
34
35
# File 'lib/the_plaid_api/models/cra_check_report_base_report_get_request.rb', line 33

def third_party_user_token
  @third_party_user_token
end

#user_idString

A unique user identifier, created by ‘/user/create`. Integrations that began using `/user/create` after December 10, 2025 use this field to identify a user instead of the `user_token`. For more details, see [new user APIs](plaid.com/docs/api/users/user-apis).

Returns:

  • (String)


29
30
31
# File 'lib/the_plaid_api/models/cra_check_report_base_report_get_request.rb', line 29

def user_id
  @user_id
end

#user_tierCraUserTier

The tier of the user.

Returns:



50
51
52
# File 'lib/the_plaid_api/models/cra_check_report_base_report_get_request.rb', line 50

def user_tier
  @user_tier
end

#user_tokenString

The user token associated with the User data is being requested for. This field is used only by customers with pre-existing integrations that already use the ‘user_token` field. All other customers should use the `user_id` instead. For more details, see [New User APIs](plaid.com/docs/api/users/user-apis).

Returns:

  • (String)


46
47
48
# File 'lib/the_plaid_api/models/cra_check_report_base_report_get_request.rb', line 46

def user_token
  @user_token
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/the_plaid_api/models/cra_check_report_base_report_get_request.rb', line 104

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  user_id = hash.key?('user_id') ? hash['user_id'] : SKIP
  third_party_user_token =
    hash.key?('third_party_user_token') ? hash['third_party_user_token'] : SKIP
  item_ids = hash.key?('item_ids') ? hash['item_ids'] : SKIP
  user_token = hash.key?('user_token') ? hash['user_token'] : SKIP
  user_tier = hash.key?('user_tier') ? hash['user_tier'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CraCheckReportBaseReportGetRequest.new(client_id: client_id,
                                         secret: secret,
                                         user_id: user_id,
                                         third_party_user_token: third_party_user_token,
                                         item_ids: item_ids,
                                         user_token: user_token,
                                         user_tier: user_tier,
                                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/the_plaid_api/models/cra_check_report_base_report_get_request.rb', line 53

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['user_id'] = 'user_id'
  @_hash['third_party_user_token'] = 'third_party_user_token'
  @_hash['item_ids'] = 'item_ids'
  @_hash['user_token'] = 'user_token'
  @_hash['user_tier'] = 'user_tier'
  @_hash
end

.nullablesObject

An array for nullable fields



79
80
81
82
83
84
# File 'lib/the_plaid_api/models/cra_check_report_base_report_get_request.rb', line 79

def self.nullables
  %w[
    item_ids
    user_tier
  ]
end

.optionalsObject

An array for optional fields



66
67
68
69
70
71
72
73
74
75
76
# File 'lib/the_plaid_api/models/cra_check_report_base_report_get_request.rb', line 66

def self.optionals
  %w[
    client_id
    secret
    user_id
    third_party_user_token
    item_ids
    user_token
    user_tier
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



145
146
147
148
149
150
151
# File 'lib/the_plaid_api/models/cra_check_report_base_report_get_request.rb', line 145

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, user_id:"\
  " #{@user_id.inspect}, third_party_user_token: #{@third_party_user_token.inspect}, item_ids:"\
  " #{@item_ids.inspect}, user_token: #{@user_token.inspect}, user_tier:"\
  " #{@user_tier.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



136
137
138
139
140
141
142
# File 'lib/the_plaid_api/models/cra_check_report_base_report_get_request.rb', line 136

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, user_id: #{@user_id},"\
  " third_party_user_token: #{@third_party_user_token}, item_ids: #{@item_ids}, user_token:"\
  " #{@user_token}, user_tier: #{@user_tier}, additional_properties:"\
  " #{@additional_properties}>"
end