Class: ThePlaidApi::CraCheckReportCashflowInsightsGetOptions

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/cra_check_report_cashflow_insights_get_options.rb

Overview

Defines configuration options to generate Cashflow Insights

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(attributes_version: SKIP, additional_properties: nil) ⇒ CraCheckReportCashflowInsightsGetOptions

Returns a new instance of CraCheckReportCashflowInsightsGetOptions.



37
38
39
40
41
42
43
# File 'lib/the_plaid_api/models/cra_check_report_cashflow_insights_get_options.rb', line 37

def initialize(attributes_version: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @attributes_version = attributes_version unless attributes_version == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#attributes_versionCashflowAttributesVersion

The version of cashflow attributes. Required if using Cash Flow Insights.



14
15
16
# File 'lib/the_plaid_api/models/cra_check_report_cashflow_insights_get_options.rb', line 14

def attributes_version
  @attributes_version
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/the_plaid_api/models/cra_check_report_cashflow_insights_get_options.rb', line 46

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  attributes_version =
    hash.key?('attributes_version') ? hash['attributes_version'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CraCheckReportCashflowInsightsGetOptions.new(attributes_version: attributes_version,
                                               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/the_plaid_api/models/cra_check_report_cashflow_insights_get_options.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['attributes_version'] = 'attributes_version'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
34
35
# File 'lib/the_plaid_api/models/cra_check_report_cashflow_insights_get_options.rb', line 31

def self.nullables
  %w[
    attributes_version
  ]
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/the_plaid_api/models/cra_check_report_cashflow_insights_get_options.rb', line 24

def self.optionals
  %w[
    attributes_version
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



73
74
75
76
77
# File 'lib/the_plaid_api/models/cra_check_report_cashflow_insights_get_options.rb', line 73

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} attributes_version: #{@attributes_version.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



66
67
68
69
70
# File 'lib/the_plaid_api/models/cra_check_report_cashflow_insights_get_options.rb', line 66

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} attributes_version: #{@attributes_version}, additional_properties:"\
  " #{@additional_properties}>"
end