Class: ThePlaidApi::CraCheckReportFailedWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/cra_check_report_failed_webhook.rb

Overview

Fired when a Check Report has failed to generate. To get more details, call ‘/user/items/get` and check for non-null `error` objects on the associated Items in the response. These `error` objects will contain more details on why the Item is in an error state and how to resolve it. After resolving the errors, you can try to re-generate the report.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, user_id:, environment:, item_ids: SKIP, additional_properties: nil) ⇒ CraCheckReportFailedWebhook

Returns a new instance of CraCheckReportFailedWebhook.



62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/the_plaid_api/models/cra_check_report_failed_webhook.rb', line 62

def initialize(webhook_type:, webhook_code:, user_id:, environment:,
               item_ids: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @user_id = user_id
  @item_ids = item_ids unless item_ids == SKIP
  @environment = environment
  @additional_properties = additional_properties
end

Instance Attribute Details

#environmentWebhookEnvironmentValues

The Plaid environment the webhook was sent from



35
36
37
# File 'lib/the_plaid_api/models/cra_check_report_failed_webhook.rb', line 35

def environment
  @environment
end

#item_idsArray[String]

A list of ‘item_ids` included in the Check Report. Access to this field is in closed beta.

Returns:

  • (Array[String])


31
32
33
# File 'lib/the_plaid_api/models/cra_check_report_failed_webhook.rb', line 31

def item_ids
  @item_ids
end

#user_idString

The ‘user_id` corresponding to the user the webhook has fired for.

Returns:

  • (String)


26
27
28
# File 'lib/the_plaid_api/models/cra_check_report_failed_webhook.rb', line 26

def user_id
  @user_id
end

#webhook_codeString

‘CHECK_REPORT_FAILED`

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/cra_check_report_failed_webhook.rb', line 22

def webhook_code
  @webhook_code
end

#webhook_typeString

‘CHECK_REPORT`

Returns:

  • (String)


18
19
20
# File 'lib/the_plaid_api/models/cra_check_report_failed_webhook.rb', line 18

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/the_plaid_api/models/cra_check_report_failed_webhook.rb', line 76

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  user_id = hash.key?('user_id') ? hash['user_id'] : nil
  environment = hash.key?('environment') ? hash['environment'] : nil
  item_ids = hash.key?('item_ids') ? hash['item_ids'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CraCheckReportFailedWebhook.new(webhook_type: webhook_type,
                                  webhook_code: webhook_code,
                                  user_id: user_id,
                                  environment: environment,
                                  item_ids: item_ids,
                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



38
39
40
41
42
43
44
45
46
# File 'lib/the_plaid_api/models/cra_check_report_failed_webhook.rb', line 38

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['user_id'] = 'user_id'
  @_hash['item_ids'] = 'item_ids'
  @_hash['environment'] = 'environment'
  @_hash
end

.nullablesObject

An array for nullable fields



56
57
58
59
60
# File 'lib/the_plaid_api/models/cra_check_report_failed_webhook.rb', line 56

def self.nullables
  %w[
    item_ids
  ]
end

.optionalsObject

An array for optional fields



49
50
51
52
53
# File 'lib/the_plaid_api/models/cra_check_report_failed_webhook.rb', line 49

def self.optionals
  %w[
    item_ids
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



111
112
113
114
115
116
# File 'lib/the_plaid_api/models/cra_check_report_failed_webhook.rb', line 111

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, user_id: #{@user_id.inspect}, item_ids: #{@item_ids.inspect},"\
  " environment: #{@environment.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



103
104
105
106
107
108
# File 'lib/the_plaid_api/models/cra_check_report_failed_webhook.rb', line 103

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, user_id:"\
  " #{@user_id}, item_ids: #{@item_ids}, environment: #{@environment}, additional_properties:"\
  " #{@additional_properties}>"
end