Class: ThePlaidApi::CraCheckReportFreddieMacGetResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/cra_check_report_freddie_mac_get_response.rb

Overview

CraCheckReportFreddieMacGetResponse defines the response schema for ‘/cra/check_report/freddie_mac/get`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(deal:, request_id:, schema_version:, additional_properties: nil) ⇒ CraCheckReportFreddieMacGetResponse

Returns a new instance of CraCheckReportFreddieMacGetResponse.



46
47
48
49
50
51
52
53
54
55
# File 'lib/the_plaid_api/models/cra_check_report_freddie_mac_get_response.rb', line 46

def initialize(deal:, request_id:, schema_version:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @deal = deal
  @request_id = request_id
  @schema_version = schema_version
  @additional_properties = additional_properties
end

Instance Attribute Details

#dealCraCheckReportFreddieMacVerificationOfAssetsDeal

An object representing a Base Report with Freddie Mac schema.



15
16
17
# File 'lib/the_plaid_api/models/cra_check_report_freddie_mac_get_response.rb', line 15

def deal
  @deal
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/cra_check_report_freddie_mac_get_response.rb', line 21

def request_id
  @request_id
end

#schema_versionFloat

The Verification Of Assets (VOA) schema version.

Returns:

  • (Float)


25
26
27
# File 'lib/the_plaid_api/models/cra_check_report_freddie_mac_get_response.rb', line 25

def schema_version
  @schema_version
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/the_plaid_api/models/cra_check_report_freddie_mac_get_response.rb', line 58

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  deal = CraCheckReportFreddieMacVerificationOfAssetsDeal.from_hash(hash['DEAL']) if
    hash['DEAL']
  request_id = hash.key?('request_id') ? hash['request_id'] : nil
  schema_version = hash.key?('SchemaVersion') ? hash['SchemaVersion'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CraCheckReportFreddieMacGetResponse.new(deal: deal,
                                          request_id: request_id,
                                          schema_version: schema_version,
                                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



28
29
30
31
32
33
34
# File 'lib/the_plaid_api/models/cra_check_report_freddie_mac_get_response.rb', line 28

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['deal'] = 'DEAL'
  @_hash['request_id'] = 'request_id'
  @_hash['schema_version'] = 'SchemaVersion'
  @_hash
end

.nullablesObject

An array for nullable fields



42
43
44
# File 'lib/the_plaid_api/models/cra_check_report_freddie_mac_get_response.rb', line 42

def self.nullables
  []
end

.optionalsObject

An array for optional fields



37
38
39
# File 'lib/the_plaid_api/models/cra_check_report_freddie_mac_get_response.rb', line 37

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/the_plaid_api/models/cra_check_report_freddie_mac_get_response.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} deal: #{@deal.inspect}, request_id: #{@request_id.inspect}, schema_version:"\
  " #{@schema_version.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/the_plaid_api/models/cra_check_report_freddie_mac_get_response.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} deal: #{@deal}, request_id: #{@request_id}, schema_version:"\
  " #{@schema_version}, additional_properties: #{@additional_properties}>"
end