Class: ThePlaidApi::CraCheckReportHomeLendingReportOptions

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/cra_check_report_home_lending_report_options.rb

Overview

Options for configuring Home Lending Report (Verification Report) generation.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(reports_requested:, employment_refresh_options: SKIP, additional_properties: nil) ⇒ CraCheckReportHomeLendingReportOptions

Returns a new instance of CraCheckReportHomeLendingReportOptions.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/the_plaid_api/models/cra_check_report_home_lending_report_options.rb', line 43

def initialize(reports_requested:, employment_refresh_options: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @reports_requested = reports_requested
  unless employment_refresh_options == SKIP
    @employment_refresh_options =
      employment_refresh_options
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#employment_refresh_optionsCraCheckReportVerificationGetEmploymentRefreshOptions

Defines configuration options for the Employment Refresh Report.



19
20
21
# File 'lib/the_plaid_api/models/cra_check_report_home_lending_report_options.rb', line 19

def employment_refresh_options
  @employment_refresh_options
end

#reports_requestedArray[CraCheckReportVerificationGetReportType]

Specifies which types of home lending reports to generate.



15
16
17
# File 'lib/the_plaid_api/models/cra_check_report_home_lending_report_options.rb', line 15

def reports_requested
  @reports_requested
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/the_plaid_api/models/cra_check_report_home_lending_report_options.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  reports_requested =
    hash.key?('reports_requested') ? hash['reports_requested'] : nil
  if hash['employment_refresh_options']
    employment_refresh_options = CraCheckReportVerificationGetEmploymentRefreshOptions.from_hash(hash['employment_refresh_options'])
  end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CraCheckReportHomeLendingReportOptions.new(reports_requested: reports_requested,
                                             employment_refresh_options: employment_refresh_options,
                                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/the_plaid_api/models/cra_check_report_home_lending_report_options.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['reports_requested'] = 'reports_requested'
  @_hash['employment_refresh_options'] = 'employment_refresh_options'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
40
41
# File 'lib/the_plaid_api/models/cra_check_report_home_lending_report_options.rb', line 37

def self.nullables
  %w[
    employment_refresh_options
  ]
end

.optionalsObject

An array for optional fields



30
31
32
33
34
# File 'lib/the_plaid_api/models/cra_check_report_home_lending_report_options.rb', line 30

def self.optionals
  %w[
    employment_refresh_options
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



88
89
90
91
92
93
# File 'lib/the_plaid_api/models/cra_check_report_home_lending_report_options.rb', line 88

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} reports_requested: #{@reports_requested.inspect},"\
  " employment_refresh_options: #{@employment_refresh_options.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



81
82
83
84
85
# File 'lib/the_plaid_api/models/cra_check_report_home_lending_report_options.rb', line 81

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} reports_requested: #{@reports_requested}, employment_refresh_options:"\
  " #{@employment_refresh_options}, additional_properties: #{@additional_properties}>"
end