Class: ThePlaidApi::CraCheckReportLendScoreGetResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/cra_check_report_lend_score_get_response.rb

Overview

CraCheckReportLendScoreGetResponse defines the response schema for ‘/cra/check_report/lend_score/get`.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(report:, request_id:, warnings: SKIP, additional_properties: nil) ⇒ CraCheckReportLendScoreGetResponse

Returns a new instance of CraCheckReportLendScoreGetResponse.



50
51
52
53
54
55
56
57
58
59
# File 'lib/the_plaid_api/models/cra_check_report_lend_score_get_response.rb', line 50

def initialize(report:, request_id:, warnings: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @report = report
  @request_id = request_id
  @warnings = warnings unless warnings == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#reportCraLendScoreReport

Contains data for the CRA LendScore Report.

Returns:



15
16
17
# File 'lib/the_plaid_api/models/cra_check_report_lend_score_get_response.rb', line 15

def report
  @report
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/cra_check_report_lend_score_get_response.rb', line 21

def request_id
  @request_id
end

#warningsArray[CraReportWarning]

If the LendScore generation was successful but a subset of data could not be retrieved, this array will contain information about the errors causing information to be missing

Returns:



27
28
29
# File 'lib/the_plaid_api/models/cra_check_report_lend_score_get_response.rb', line 27

def warnings
  @warnings
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/the_plaid_api/models/cra_check_report_lend_score_get_response.rb', line 62

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  report = CraLendScoreReport.from_hash(hash['report']) if hash['report']
  request_id = hash.key?('request_id') ? hash['request_id'] : nil
  # Parameter is an array, so we need to iterate through it
  warnings = nil
  unless hash['warnings'].nil?
    warnings = []
    hash['warnings'].each do |structure|
      warnings << (CraReportWarning.from_hash(structure) if structure)
    end
  end

  warnings = SKIP unless hash.key?('warnings')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CraCheckReportLendScoreGetResponse.new(report: report,
                                         request_id: request_id,
                                         warnings: warnings,
                                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



30
31
32
33
34
35
36
# File 'lib/the_plaid_api/models/cra_check_report_lend_score_get_response.rb', line 30

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['report'] = 'report'
  @_hash['request_id'] = 'request_id'
  @_hash['warnings'] = 'warnings'
  @_hash
end

.nullablesObject

An array for nullable fields



46
47
48
# File 'lib/the_plaid_api/models/cra_check_report_lend_score_get_response.rb', line 46

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
# File 'lib/the_plaid_api/models/cra_check_report_lend_score_get_response.rb', line 39

def self.optionals
  %w[
    warnings
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



101
102
103
104
105
# File 'lib/the_plaid_api/models/cra_check_report_lend_score_get_response.rb', line 101

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} report: #{@report.inspect}, request_id: #{@request_id.inspect}, warnings:"\
  " #{@warnings.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



94
95
96
97
98
# File 'lib/the_plaid_api/models/cra_check_report_lend_score_get_response.rb', line 94

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} report: #{@report}, request_id: #{@request_id}, warnings: #{@warnings},"\
  " additional_properties: #{@additional_properties}>"
end