Class: ThePlaidApi::CraCheckReportVerificationGetResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CraCheckReportVerificationGetResponse
- Defined in:
- lib/the_plaid_api/models/cra_check_report_verification_get_response.rb
Overview
CraCheckReportVerificationGetResponse defines the response schema for ‘/cra/check_report/verification/get`.
Instance Attribute Summary collapse
-
#report ⇒ CraVerificationReport
Contains data for the CRA Home Lending Report.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
-
#warnings ⇒ Array[CraReportWarning]
If the home lending report generation was successful but a subset of data could not be retrieved, this array will contain information about the errors causing information to be missing.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(report:, request_id:, warnings:, additional_properties: nil) ⇒ CraCheckReportVerificationGetResponse
constructor
A new instance of CraCheckReportVerificationGetResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(report:, request_id:, warnings:, additional_properties: nil) ⇒ CraCheckReportVerificationGetResponse
Returns a new instance of CraCheckReportVerificationGetResponse.
48 49 50 51 52 53 54 55 56 |
# File 'lib/the_plaid_api/models/cra_check_report_verification_get_response.rb', line 48 def initialize(report:, request_id:, warnings:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @report = report @request_id = request_id @warnings = warnings @additional_properties = additional_properties end |
Instance Attribute Details
#report ⇒ CraVerificationReport
Contains data for the CRA Home Lending Report.
15 16 17 |
# File 'lib/the_plaid_api/models/cra_check_report_verification_get_response.rb', line 15 def report @report end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
21 22 23 |
# File 'lib/the_plaid_api/models/cra_check_report_verification_get_response.rb', line 21 def request_id @request_id end |
#warnings ⇒ Array[CraReportWarning]
If the home lending report generation was successful but a subset of data could not be retrieved, this array will contain information about the errors causing information to be missing.
27 28 29 |
# File 'lib/the_plaid_api/models/cra_check_report_verification_get_response.rb', line 27 def warnings @warnings end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/the_plaid_api/models/cra_check_report_verification_get_response.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. report = CraVerificationReport.from_hash(hash['report']) if hash['report'] request_id = hash.key?('request_id') ? hash['request_id'] : nil # Parameter is an array, so we need to iterate through it warnings = nil unless hash['warnings'].nil? warnings = [] hash['warnings'].each do |structure| warnings << (CraReportWarning.from_hash(structure) if structure) end end warnings = nil unless hash.key?('warnings') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CraCheckReportVerificationGetResponse.new(report: report, request_id: request_id, warnings: warnings, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
30 31 32 33 34 35 36 |
# File 'lib/the_plaid_api/models/cra_check_report_verification_get_response.rb', line 30 def self.names @_hash = {} if @_hash.nil? @_hash['report'] = 'report' @_hash['request_id'] = 'request_id' @_hash['warnings'] = 'warnings' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/the_plaid_api/models/cra_check_report_verification_get_response.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/the_plaid_api/models/cra_check_report_verification_get_response.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 |
# File 'lib/the_plaid_api/models/cra_check_report_verification_get_response.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} report: #{@report.inspect}, request_id: #{@request_id.inspect}, warnings:"\ " #{@warnings.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/the_plaid_api/models/cra_check_report_verification_get_response.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} report: #{@report}, request_id: #{@request_id}, warnings: #{@warnings},"\ " additional_properties: #{@additional_properties}>" end |