Class: ThePlaidApi::CraCheckReportVerificationPdfGetRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/cra_check_report_verification_pdf_get_request.rb

Overview

CraCheckReportVerificationPdfGetRequest defines the request schema for ‘/cra/check_report/verification/pdf/get`.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(report_requested:, client_id: SKIP, secret: SKIP, user_id: SKIP, third_party_user_token: SKIP, user_token: SKIP, additional_properties: nil) ⇒ CraCheckReportVerificationPdfGetRequest

Returns a new instance of CraCheckReportVerificationPdfGetRequest.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/the_plaid_api/models/cra_check_report_verification_pdf_get_request.rb', line 75

def initialize(report_requested:, client_id: SKIP, secret: SKIP,
               user_id: SKIP, third_party_user_token: SKIP,
               user_token: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @user_id = user_id unless user_id == SKIP
  @third_party_user_token = third_party_user_token unless third_party_user_token == SKIP
  @report_requested = report_requested
  @user_token = user_token unless user_token == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/cra_check_report_verification_pdf_get_request.rb', line 17

def client_id
  @client_id
end

#report_requestedCraCheckReportVerificationPdfReportType

The type of verification PDF report to fetch.



37
38
39
# File 'lib/the_plaid_api/models/cra_check_report_verification_pdf_get_request.rb', line 37

def report_requested
  @report_requested
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/cra_check_report_verification_pdf_get_request.rb', line 22

def secret
  @secret
end

#third_party_user_tokenString

The third-party user token associated with the requested User data.

Returns:

  • (String)


33
34
35
# File 'lib/the_plaid_api/models/cra_check_report_verification_pdf_get_request.rb', line 33

def third_party_user_token
  @third_party_user_token
end

#user_idString

A unique user identifier, created by ‘/user/create`. Integrations that began using `/user/create` after December 10, 2025 use this field to identify a user instead of the `user_token`. For more details, see [new user APIs](plaid.com/docs/api/users/user-apis).

Returns:

  • (String)


29
30
31
# File 'lib/the_plaid_api/models/cra_check_report_verification_pdf_get_request.rb', line 29

def user_id
  @user_id
end

#user_tokenString

The user token associated with the User data is being requested for. This field is used only by customers with pre-existing integrations that already use the ‘user_token` field. All other customers should use the `user_id` instead. For more details, see [New User APIs](plaid.com/docs/api/users/user-apis).

Returns:

  • (String)


45
46
47
# File 'lib/the_plaid_api/models/cra_check_report_verification_pdf_get_request.rb', line 45

def user_token
  @user_token
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/the_plaid_api/models/cra_check_report_verification_pdf_get_request.rb', line 91

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  report_requested =
    hash.key?('report_requested') ? hash['report_requested'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  user_id = hash.key?('user_id') ? hash['user_id'] : SKIP
  third_party_user_token =
    hash.key?('third_party_user_token') ? hash['third_party_user_token'] : SKIP
  user_token = hash.key?('user_token') ? hash['user_token'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CraCheckReportVerificationPdfGetRequest.new(report_requested: report_requested,
                                              client_id: client_id,
                                              secret: secret,
                                              user_id: user_id,
                                              third_party_user_token: third_party_user_token,
                                              user_token: user_token,
                                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



48
49
50
51
52
53
54
55
56
57
# File 'lib/the_plaid_api/models/cra_check_report_verification_pdf_get_request.rb', line 48

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['user_id'] = 'user_id'
  @_hash['third_party_user_token'] = 'third_party_user_token'
  @_hash['report_requested'] = 'report_requested'
  @_hash['user_token'] = 'user_token'
  @_hash
end

.nullablesObject

An array for nullable fields



71
72
73
# File 'lib/the_plaid_api/models/cra_check_report_verification_pdf_get_request.rb', line 71

def self.nullables
  []
end

.optionalsObject

An array for optional fields



60
61
62
63
64
65
66
67
68
# File 'lib/the_plaid_api/models/cra_check_report_verification_pdf_get_request.rb', line 60

def self.optionals
  %w[
    client_id
    secret
    user_id
    third_party_user_token
    user_token
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



131
132
133
134
135
136
137
# File 'lib/the_plaid_api/models/cra_check_report_verification_pdf_get_request.rb', line 131

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, user_id:"\
  " #{@user_id.inspect}, third_party_user_token: #{@third_party_user_token.inspect},"\
  " report_requested: #{@report_requested.inspect}, user_token: #{@user_token.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



122
123
124
125
126
127
128
# File 'lib/the_plaid_api/models/cra_check_report_verification_pdf_get_request.rb', line 122

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, user_id: #{@user_id},"\
  " third_party_user_token: #{@third_party_user_token}, report_requested:"\
  " #{@report_requested}, user_token: #{@user_token}, additional_properties:"\
  " #{@additional_properties}>"
end