Class: ThePlaidApi::CraIncomeInsightsUserSummary
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CraIncomeInsightsUserSummary
- Defined in:
- lib/the_plaid_api/models/cra_income_insights_user_summary.rb
Overview
Aggregated summary of all income streams for this user.
Instance Attribute Summary collapse
-
#income_metrics ⇒ Array[CraIncomeMetrics]
List of a user’s aggregated income metrics for each currency.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(income_metrics:, additional_properties: nil) ⇒ CraIncomeInsightsUserSummary
constructor
A new instance of CraIncomeInsightsUserSummary.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(income_metrics:, additional_properties: nil) ⇒ CraIncomeInsightsUserSummary
Returns a new instance of CraIncomeInsightsUserSummary.
33 34 35 36 37 38 39 |
# File 'lib/the_plaid_api/models/cra_income_insights_user_summary.rb', line 33 def initialize(income_metrics:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @income_metrics = income_metrics @additional_properties = additional_properties end |
Instance Attribute Details
#income_metrics ⇒ Array[CraIncomeMetrics]
List of a user’s aggregated income metrics for each currency.
14 15 16 |
# File 'lib/the_plaid_api/models/cra_income_insights_user_summary.rb', line 14 def income_metrics @income_metrics end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/the_plaid_api/models/cra_income_insights_user_summary.rb', line 42 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it income_metrics = nil unless hash['income_metrics'].nil? income_metrics = [] hash['income_metrics'].each do |structure| income_metrics << (CraIncomeMetrics.from_hash(structure) if structure) end end income_metrics = nil unless hash.key?('income_metrics') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CraIncomeInsightsUserSummary.new(income_metrics: income_metrics, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/the_plaid_api/models/cra_income_insights_user_summary.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['income_metrics'] = 'income_metrics' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/the_plaid_api/models/cra_income_insights_user_summary.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/the_plaid_api/models/cra_income_insights_user_summary.rb', line 24 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
77 78 79 80 81 |
# File 'lib/the_plaid_api/models/cra_income_insights_user_summary.rb', line 77 def inspect class_name = self.class.name.split('::').last "<#{class_name} income_metrics: #{@income_metrics.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 74 |
# File 'lib/the_plaid_api/models/cra_income_insights_user_summary.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} income_metrics: #{@income_metrics}, additional_properties:"\ " #{@additional_properties}>" end |