Class: ThePlaidApi::CraLoanStatusHistoryUpdate

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/cra_loan_status_history_update.rb

Overview

Contains the status and date of an update to the loan.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(status:, date:, additional_properties: nil) ⇒ CraLoanStatusHistoryUpdate

Returns a new instance of CraLoanStatusHistoryUpdate.



39
40
41
42
43
44
45
46
# File 'lib/the_plaid_api/models/cra_loan_status_history_update.rb', line 39

def initialize(status:, date:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @status = status
  @date = date
  @additional_properties = additional_properties
end

Instance Attribute Details

#dateDate

The effective date for the status of the loan. The date should be in ISO 8601 format (YYYY-MM-DD).

Returns:

  • (Date)


19
20
21
# File 'lib/the_plaid_api/models/cra_loan_status_history_update.rb', line 19

def date
  @date
end

#statusCraLoanStatus

The status of the loan.

Returns:



14
15
16
# File 'lib/the_plaid_api/models/cra_loan_status_history_update.rb', line 14

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/the_plaid_api/models/cra_loan_status_history_update.rb', line 49

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  status = hash.key?('status') ? hash['status'] : nil
  date = hash.key?('date') ? hash['date'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CraLoanStatusHistoryUpdate.new(status: status,
                                 date: date,
                                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/the_plaid_api/models/cra_loan_status_history_update.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['status'] = 'status'
  @_hash['date'] = 'date'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
# File 'lib/the_plaid_api/models/cra_loan_status_history_update.rb', line 35

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
# File 'lib/the_plaid_api/models/cra_loan_status_history_update.rb', line 30

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



77
78
79
80
81
# File 'lib/the_plaid_api/models/cra_loan_status_history_update.rb', line 77

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status.inspect}, date: #{@date.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



70
71
72
73
74
# File 'lib/the_plaid_api/models/cra_loan_status_history_update.rb', line 70

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status}, date: #{@date}, additional_properties:"\
  " #{@additional_properties}>"
end