Class: ThePlaidApi::CraMonitoringInsightsSubscribeResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/cra_monitoring_insights_subscribe_response.rb

Overview

CraMonitoringInsightsSubscribeResponse defines the response schema for ‘cra/monitoring_insights/subscribe`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(request_id:, subscription_id:, additional_properties: nil) ⇒ CraMonitoringInsightsSubscribeResponse

Returns a new instance of CraMonitoringInsightsSubscribeResponse.



41
42
43
44
45
46
47
48
# File 'lib/the_plaid_api/models/cra_monitoring_insights_subscribe_response.rb', line 41

def initialize(request_id:, subscription_id:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @request_id = request_id
  @subscription_id = subscription_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/cra_monitoring_insights_subscribe_response.rb', line 17

def request_id
  @request_id
end

#subscription_idString

A unique identifier for the subscription.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/cra_monitoring_insights_subscribe_response.rb', line 21

def subscription_id
  @subscription_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/the_plaid_api/models/cra_monitoring_insights_subscribe_response.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  request_id = hash.key?('request_id') ? hash['request_id'] : nil
  subscription_id =
    hash.key?('subscription_id') ? hash['subscription_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CraMonitoringInsightsSubscribeResponse.new(request_id: request_id,
                                             subscription_id: subscription_id,
                                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
29
# File 'lib/the_plaid_api/models/cra_monitoring_insights_subscribe_response.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['request_id'] = 'request_id'
  @_hash['subscription_id'] = 'subscription_id'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/the_plaid_api/models/cra_monitoring_insights_subscribe_response.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



32
33
34
# File 'lib/the_plaid_api/models/cra_monitoring_insights_subscribe_response.rb', line 32

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/the_plaid_api/models/cra_monitoring_insights_subscribe_response.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} request_id: #{@request_id.inspect}, subscription_id:"\
  " #{@subscription_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/the_plaid_api/models/cra_monitoring_insights_subscribe_response.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} request_id: #{@request_id}, subscription_id: #{@subscription_id},"\
  " additional_properties: #{@additional_properties}>"
end