Class: ThePlaidApi::CraMonthlyIncomeValues
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CraMonthlyIncomeValues
- Defined in:
- lib/the_plaid_api/models/cra_monthly_income_values.rb
Overview
Modeled estimate of the monthly income.
Instance Attribute Summary collapse
-
#gross_income ⇒ Float
Gross Income modeled from trends of observed transactions.
-
#net_income ⇒ Float
Net Income estimated from observed transactions.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(gross_income:, net_income:, additional_properties: nil) ⇒ CraMonthlyIncomeValues
constructor
A new instance of CraMonthlyIncomeValues.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(gross_income:, net_income:, additional_properties: nil) ⇒ CraMonthlyIncomeValues
Returns a new instance of CraMonthlyIncomeValues.
38 39 40 41 42 43 44 45 |
# File 'lib/the_plaid_api/models/cra_monthly_income_values.rb', line 38 def initialize(gross_income:, net_income:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @gross_income = gross_income @net_income = net_income @additional_properties = additional_properties end |
Instance Attribute Details
#gross_income ⇒ Float
Gross Income modeled from trends of observed transactions.
14 15 16 |
# File 'lib/the_plaid_api/models/cra_monthly_income_values.rb', line 14 def gross_income @gross_income end |
#net_income ⇒ Float
Net Income estimated from observed transactions.
18 19 20 |
# File 'lib/the_plaid_api/models/cra_monthly_income_values.rb', line 18 def net_income @net_income end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/the_plaid_api/models/cra_monthly_income_values.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. gross_income = hash.key?('gross_income') ? hash['gross_income'] : nil net_income = hash.key?('net_income') ? hash['net_income'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CraMonthlyIncomeValues.new(gross_income: gross_income, net_income: net_income, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/the_plaid_api/models/cra_monthly_income_values.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['gross_income'] = 'gross_income' @_hash['net_income'] = 'net_income' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/the_plaid_api/models/cra_monthly_income_values.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/the_plaid_api/models/cra_monthly_income_values.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/the_plaid_api/models/cra_monthly_income_values.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} gross_income: #{@gross_income.inspect}, net_income: #{@net_income.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/the_plaid_api/models/cra_monthly_income_values.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} gross_income: #{@gross_income}, net_income: #{@net_income},"\ " additional_properties: #{@additional_properties}>" end |