Class: ThePlaidApi::CraPartnerInsightsFicoInput
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CraPartnerInsightsFicoInput
- Defined in:
- lib/the_plaid_api/models/cra_partner_insights_fico_input.rb
Overview
Configurations for FICO products used in the Partner Insights flow.
Instance Attribute Summary collapse
-
#fico_lender_id ⇒ String
ID provided by FICO that uniquely identifies the lender.
-
#lender_application_id ⇒ String
Client-generated identifier that uniquely identifies the FICO Application ID across FICO systems.
-
#ultrafico_score_requests ⇒ Array[CraPartnerInsightsUltraFicoScoreRequest]
A list of UltraFICO scoring requests.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(fico_lender_id:, lender_application_id:, ultrafico_score_requests:, additional_properties: nil) ⇒ CraPartnerInsightsFicoInput
constructor
A new instance of CraPartnerInsightsFicoInput.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(fico_lender_id:, lender_application_id:, ultrafico_score_requests:, additional_properties: nil) ⇒ CraPartnerInsightsFicoInput
Returns a new instance of CraPartnerInsightsFicoInput.
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/the_plaid_api/models/cra_partner_insights_fico_input.rb', line 46 def initialize(fico_lender_id:, lender_application_id:, ultrafico_score_requests:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @fico_lender_id = fico_lender_id @lender_application_id = lender_application_id @ultrafico_score_requests = ultrafico_score_requests @additional_properties = additional_properties end |
Instance Attribute Details
#fico_lender_id ⇒ String
ID provided by FICO that uniquely identifies the lender. Required for UltraFICO score generation. Sometimes referred to as Lender Org ID.
15 16 17 |
# File 'lib/the_plaid_api/models/cra_partner_insights_fico_input.rb', line 15 def fico_lender_id @fico_lender_id end |
#lender_application_id ⇒ String
Client-generated identifier that uniquely identifies the FICO Application ID across FICO systems.
20 21 22 |
# File 'lib/the_plaid_api/models/cra_partner_insights_fico_input.rb', line 20 def lender_application_id @lender_application_id end |
#ultrafico_score_requests ⇒ Array[CraPartnerInsightsUltraFicoScoreRequest]
A list of UltraFICO scoring requests. Each request contains all configuration required to generate an UltraFICO score.
25 26 27 |
# File 'lib/the_plaid_api/models/cra_partner_insights_fico_input.rb', line 25 def ultrafico_score_requests @ultrafico_score_requests end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/the_plaid_api/models/cra_partner_insights_fico_input.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. fico_lender_id = hash.key?('fico_lender_id') ? hash['fico_lender_id'] : nil lender_application_id = hash.key?('lender_application_id') ? hash['lender_application_id'] : nil # Parameter is an array, so we need to iterate through it ultrafico_score_requests = nil unless hash['ultrafico_score_requests'].nil? ultrafico_score_requests = [] hash['ultrafico_score_requests'].each do |structure| ultrafico_score_requests << (CraPartnerInsightsUltraFicoScoreRequest.from_hash(structure) if structure) end end ultrafico_score_requests = nil unless hash.key?('ultrafico_score_requests') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CraPartnerInsightsFicoInput.new(fico_lender_id: fico_lender_id, lender_application_id: lender_application_id, ultrafico_score_requests: ultrafico_score_requests, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
28 29 30 31 32 33 34 |
# File 'lib/the_plaid_api/models/cra_partner_insights_fico_input.rb', line 28 def self.names @_hash = {} if @_hash.nil? @_hash['fico_lender_id'] = 'fico_lender_id' @_hash['lender_application_id'] = 'lender_application_id' @_hash['ultrafico_score_requests'] = 'ultrafico_score_requests' @_hash end |
.nullables ⇒ Object
An array for nullable fields
42 43 44 |
# File 'lib/the_plaid_api/models/cra_partner_insights_fico_input.rb', line 42 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
37 38 39 |
# File 'lib/the_plaid_api/models/cra_partner_insights_fico_input.rb', line 37 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
100 101 102 103 104 105 |
# File 'lib/the_plaid_api/models/cra_partner_insights_fico_input.rb', line 100 def inspect class_name = self.class.name.split('::').last "<#{class_name} fico_lender_id: #{@fico_lender_id.inspect}, lender_application_id:"\ " #{@lender_application_id.inspect}, ultrafico_score_requests:"\ " #{@ultrafico_score_requests.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 97 |
# File 'lib/the_plaid_api/models/cra_partner_insights_fico_input.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} fico_lender_id: #{@fico_lender_id}, lender_application_id:"\ " #{@lender_application_id}, ultrafico_score_requests: #{@ultrafico_score_requests},"\ " additional_properties: #{@additional_properties}>" end |