Class: ThePlaidApi::CraPartnerInsightsGetResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CraPartnerInsightsGetResponse
- Defined in:
- lib/the_plaid_api/models/cra_partner_insights_get_response.rb
Overview
CraPartnerInsightsGetResponse defines the response schema for ‘/cra/partner_insights/get`.
Instance Attribute Summary collapse
-
#report ⇒ Array[CraPartnerInsights]
TODO: Write general description for this method.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(request_id:, report: SKIP, additional_properties: nil) ⇒ CraPartnerInsightsGetResponse
constructor
A new instance of CraPartnerInsightsGetResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(request_id:, report: SKIP, additional_properties: nil) ⇒ CraPartnerInsightsGetResponse
Returns a new instance of CraPartnerInsightsGetResponse.
43 44 45 46 47 48 49 50 |
# File 'lib/the_plaid_api/models/cra_partner_insights_get_response.rb', line 43 def initialize(request_id:, report: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @report = report unless report == SKIP @request_id = request_id @additional_properties = additional_properties end |
Instance Attribute Details
#report ⇒ Array[CraPartnerInsights]
TODO: Write general description for this method
15 16 17 |
# File 'lib/the_plaid_api/models/cra_partner_insights_get_response.rb', line 15 def report @report end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
21 22 23 |
# File 'lib/the_plaid_api/models/cra_partner_insights_get_response.rb', line 21 def request_id @request_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/the_plaid_api/models/cra_partner_insights_get_response.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. request_id = hash.key?('request_id') ? hash['request_id'] : nil # Parameter is an array, so we need to iterate through it report = nil unless hash['report'].nil? report = [] hash['report'].each do |structure| report << (CraPartnerInsights.from_hash(structure) if structure) end end report = SKIP unless hash.key?('report') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CraPartnerInsightsGetResponse.new(request_id: request_id, report: report, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/the_plaid_api/models/cra_partner_insights_get_response.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['report'] = 'report' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/the_plaid_api/models/cra_partner_insights_get_response.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 35 36 |
# File 'lib/the_plaid_api/models/cra_partner_insights_get_response.rb', line 32 def self.optionals %w[ report ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
90 91 92 93 94 |
# File 'lib/the_plaid_api/models/cra_partner_insights_get_response.rb', line 90 def inspect class_name = self.class.name.split('::').last "<#{class_name} report: #{@report.inspect}, request_id: #{@request_id.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 87 |
# File 'lib/the_plaid_api/models/cra_partner_insights_get_response.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} report: #{@report}, request_id: #{@request_id}, additional_properties:"\ " #{@additional_properties}>" end |