Class: ThePlaidApi::Credit1099Filer

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/credit1099_filer.rb

Overview

An object representing a filer used by 1099-K tax documents.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(address: SKIP, name: SKIP, tin: SKIP, type: SKIP, additional_properties: nil) ⇒ Credit1099Filer

Returns a new instance of Credit1099Filer.



58
59
60
61
62
63
64
65
66
67
68
# File 'lib/the_plaid_api/models/credit1099_filer.rb', line 58

def initialize(address: SKIP, name: SKIP, tin: SKIP, type: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @address = address unless address == SKIP
  @name = name unless name == SKIP
  @tin = tin unless tin == SKIP
  @type = type unless type == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#addressCreditPayStubAddress

Address on the pay stub.



14
15
16
# File 'lib/the_plaid_api/models/credit1099_filer.rb', line 14

def address
  @address
end

#nameString

Name of filer.

Returns:

  • (String)


18
19
20
# File 'lib/the_plaid_api/models/credit1099_filer.rb', line 18

def name
  @name
end

#tinString

Tax identification number of filer.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/credit1099_filer.rb', line 22

def tin
  @tin
end

#typeString

One of the following values will be provided: Payment Settlement Entity (PSE), Electronic Payment Facilitator (EPF), Other Third Party

Returns:

  • (String)


27
28
29
# File 'lib/the_plaid_api/models/credit1099_filer.rb', line 27

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/the_plaid_api/models/credit1099_filer.rb', line 71

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  address = CreditPayStubAddress.from_hash(hash['address']) if hash['address']
  name = hash.key?('name') ? hash['name'] : SKIP
  tin = hash.key?('tin') ? hash['tin'] : SKIP
  type = hash.key?('type') ? hash['type'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Credit1099Filer.new(address: address,
                      name: name,
                      tin: tin,
                      type: type,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



30
31
32
33
34
35
36
37
# File 'lib/the_plaid_api/models/credit1099_filer.rb', line 30

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['address'] = 'address'
  @_hash['name'] = 'name'
  @_hash['tin'] = 'tin'
  @_hash['type'] = 'type'
  @_hash
end

.nullablesObject

An array for nullable fields



50
51
52
53
54
55
56
# File 'lib/the_plaid_api/models/credit1099_filer.rb', line 50

def self.nullables
  %w[
    name
    tin
    type
  ]
end

.optionalsObject

An array for optional fields



40
41
42
43
44
45
46
47
# File 'lib/the_plaid_api/models/credit1099_filer.rb', line 40

def self.optionals
  %w[
    address
    name
    tin
    type
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



103
104
105
106
107
# File 'lib/the_plaid_api/models/credit1099_filer.rb', line 103

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} address: #{@address.inspect}, name: #{@name.inspect}, tin: #{@tin.inspect},"\
  " type: #{@type.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



96
97
98
99
100
# File 'lib/the_plaid_api/models/credit1099_filer.rb', line 96

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} address: #{@address}, name: #{@name}, tin: #{@tin}, type: #{@type},"\
  " additional_properties: #{@additional_properties}>"
end