Class: ThePlaidApi::Credit1099Payer
- Defined in:
- lib/the_plaid_api/models/credit1099_payer.rb
Overview
An object representing a payer used by 1099-MISC tax documents.
Instance Attribute Summary collapse
-
#address ⇒ CreditPayStubAddress
Address on the pay stub.
-
#name ⇒ String
Name of payer.
-
#telephone_number ⇒ String
Telephone number of payer.
-
#tin ⇒ String
Tax identification number of payer.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(address: SKIP, name: SKIP, tin: SKIP, telephone_number: SKIP, additional_properties: nil) ⇒ Credit1099Payer
constructor
A new instance of Credit1099Payer.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(address: SKIP, name: SKIP, tin: SKIP, telephone_number: SKIP, additional_properties: nil) ⇒ Credit1099Payer
Returns a new instance of Credit1099Payer.
57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/the_plaid_api/models/credit1099_payer.rb', line 57 def initialize(address: SKIP, name: SKIP, tin: SKIP, telephone_number: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @address = address unless address == SKIP @name = name unless name == SKIP @tin = tin unless tin == SKIP @telephone_number = telephone_number unless telephone_number == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#address ⇒ CreditPayStubAddress
Address on the pay stub.
14 15 16 |
# File 'lib/the_plaid_api/models/credit1099_payer.rb', line 14 def address @address end |
#name ⇒ String
Name of payer.
18 19 20 |
# File 'lib/the_plaid_api/models/credit1099_payer.rb', line 18 def name @name end |
#telephone_number ⇒ String
Telephone number of payer.
26 27 28 |
# File 'lib/the_plaid_api/models/credit1099_payer.rb', line 26 def telephone_number @telephone_number end |
#tin ⇒ String
Tax identification number of payer.
22 23 24 |
# File 'lib/the_plaid_api/models/credit1099_payer.rb', line 22 def tin @tin end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/the_plaid_api/models/credit1099_payer.rb', line 70 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. address = CreditPayStubAddress.from_hash(hash['address']) if hash['address'] name = hash.key?('name') ? hash['name'] : SKIP tin = hash.key?('tin') ? hash['tin'] : SKIP telephone_number = hash.key?('telephone_number') ? hash['telephone_number'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Credit1099Payer.new(address: address, name: name, tin: tin, telephone_number: telephone_number, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/the_plaid_api/models/credit1099_payer.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['address'] = 'address' @_hash['name'] = 'name' @_hash['tin'] = 'tin' @_hash['telephone_number'] = 'telephone_number' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 52 53 54 55 |
# File 'lib/the_plaid_api/models/credit1099_payer.rb', line 49 def self.nullables %w[ name tin telephone_number ] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/the_plaid_api/models/credit1099_payer.rb', line 39 def self.optionals %w[ address name tin telephone_number ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
103 104 105 106 107 108 |
# File 'lib/the_plaid_api/models/credit1099_payer.rb', line 103 def inspect class_name = self.class.name.split('::').last "<#{class_name} address: #{@address.inspect}, name: #{@name.inspect}, tin: #{@tin.inspect},"\ " telephone_number: #{@telephone_number.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
96 97 98 99 100 |
# File 'lib/the_plaid_api/models/credit1099_payer.rb', line 96 def to_s class_name = self.class.name.split('::').last "<#{class_name} address: #{@address}, name: #{@name}, tin: #{@tin}, telephone_number:"\ " #{@telephone_number}, additional_properties: #{@additional_properties}>" end |