Class: ThePlaidApi::CreditAuditCopyTokenCreateResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CreditAuditCopyTokenCreateResponse
- Defined in:
- lib/the_plaid_api/models/credit_audit_copy_token_create_response.rb
Overview
CreditAuditCopyTokenCreateResponse defines the response schema for ‘/credit/audit_copy_token/get`
Instance Attribute Summary collapse
-
#audit_copy_token ⇒ String
A token that can be shared with a third party auditor, which allows them to fetch the Asset Reports attached to the token.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(audit_copy_token:, request_id:, additional_properties: nil) ⇒ CreditAuditCopyTokenCreateResponse
constructor
A new instance of CreditAuditCopyTokenCreateResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(audit_copy_token:, request_id:, additional_properties: nil) ⇒ CreditAuditCopyTokenCreateResponse
Returns a new instance of CreditAuditCopyTokenCreateResponse.
43 44 45 46 47 48 49 50 |
# File 'lib/the_plaid_api/models/credit_audit_copy_token_create_response.rb', line 43 def initialize(audit_copy_token:, request_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @audit_copy_token = audit_copy_token @request_id = request_id @additional_properties = additional_properties end |
Instance Attribute Details
#audit_copy_token ⇒ String
A token that can be shared with a third party auditor, which allows them to fetch the Asset Reports attached to the token. This token should be stored securely.
17 18 19 |
# File 'lib/the_plaid_api/models/credit_audit_copy_token_create_response.rb', line 17 def audit_copy_token @audit_copy_token end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
23 24 25 |
# File 'lib/the_plaid_api/models/credit_audit_copy_token_create_response.rb', line 23 def request_id @request_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/the_plaid_api/models/credit_audit_copy_token_create_response.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. audit_copy_token = hash.key?('audit_copy_token') ? hash['audit_copy_token'] : nil request_id = hash.key?('request_id') ? hash['request_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreditAuditCopyTokenCreateResponse.new(audit_copy_token: audit_copy_token, request_id: request_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 |
# File 'lib/the_plaid_api/models/credit_audit_copy_token_create_response.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['audit_copy_token'] = 'audit_copy_token' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/the_plaid_api/models/credit_audit_copy_token_create_response.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/the_plaid_api/models/credit_audit_copy_token_create_response.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/the_plaid_api/models/credit_audit_copy_token_create_response.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} audit_copy_token: #{@audit_copy_token.inspect}, request_id:"\ " #{@request_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/the_plaid_api/models/credit_audit_copy_token_create_response.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} audit_copy_token: #{@audit_copy_token}, request_id: #{@request_id},"\ " additional_properties: #{@additional_properties}>" end |