Class: ThePlaidApi::CreditAuditCopyTokenUpdateRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CreditAuditCopyTokenUpdateRequest
- Defined in:
- lib/the_plaid_api/models/credit_audit_copy_token_update_request.rb
Overview
CreditAuditCopyTokenUpdateRequest defines the request schema for ‘/credit/audit_copy_token/update`
Instance Attribute Summary collapse
-
#audit_copy_token ⇒ String
The ‘audit_copy_token` you would like to update.
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#report_tokens ⇒ Array[String]
Array of tokens which the specified Audit Copy Token will be updated with.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(audit_copy_token:, report_tokens:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ CreditAuditCopyTokenUpdateRequest
constructor
A new instance of CreditAuditCopyTokenUpdateRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(audit_copy_token:, report_tokens:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ CreditAuditCopyTokenUpdateRequest
Returns a new instance of CreditAuditCopyTokenUpdateRequest.
57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/the_plaid_api/models/credit_audit_copy_token_update_request.rb', line 57 def initialize(audit_copy_token:, report_tokens:, client_id: SKIP, secret: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @audit_copy_token = audit_copy_token @report_tokens = report_tokens @additional_properties = additional_properties end |
Instance Attribute Details
#audit_copy_token ⇒ String
The ‘audit_copy_token` you would like to update.
26 27 28 |
# File 'lib/the_plaid_api/models/credit_audit_copy_token_update_request.rb', line 26 def audit_copy_token @audit_copy_token end |
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/credit_audit_copy_token_update_request.rb', line 17 def client_id @client_id end |
#report_tokens ⇒ Array[String]
Array of tokens which the specified Audit Copy Token will be updated with. The types of token supported are asset report token and employment report token. There can be at most 1 of each token type in the array.
32 33 34 |
# File 'lib/the_plaid_api/models/credit_audit_copy_token_update_request.rb', line 32 def report_tokens @report_tokens end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/the_plaid_api/models/credit_audit_copy_token_update_request.rb', line 22 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/the_plaid_api/models/credit_audit_copy_token_update_request.rb', line 70 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. audit_copy_token = hash.key?('audit_copy_token') ? hash['audit_copy_token'] : nil report_tokens = hash.key?('report_tokens') ? hash['report_tokens'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreditAuditCopyTokenUpdateRequest.new(audit_copy_token: audit_copy_token, report_tokens: report_tokens, client_id: client_id, secret: secret, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
35 36 37 38 39 40 41 42 |
# File 'lib/the_plaid_api/models/credit_audit_copy_token_update_request.rb', line 35 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['audit_copy_token'] = 'audit_copy_token' @_hash['report_tokens'] = 'report_tokens' @_hash end |
.nullables ⇒ Object
An array for nullable fields
53 54 55 |
# File 'lib/the_plaid_api/models/credit_audit_copy_token_update_request.rb', line 53 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
45 46 47 48 49 50 |
# File 'lib/the_plaid_api/models/credit_audit_copy_token_update_request.rb', line 45 def self.optionals %w[ client_id secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
104 105 106 107 108 109 |
# File 'lib/the_plaid_api/models/credit_audit_copy_token_update_request.rb', line 104 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\ " audit_copy_token: #{@audit_copy_token.inspect}, report_tokens: #{@report_tokens.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
96 97 98 99 100 101 |
# File 'lib/the_plaid_api/models/credit_audit_copy_token_update_request.rb', line 96 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, audit_copy_token:"\ " #{@audit_copy_token}, report_tokens: #{@report_tokens}, additional_properties:"\ " #{@additional_properties}>" end |