Class: ThePlaidApi::CreditBankIncomeGetRequestOptions

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/credit_bank_income_get_request_options.rb

Overview

An optional object for ‘/credit/bank_income/get` request options.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(count: 1, additional_properties: nil) ⇒ CreditBankIncomeGetRequestOptions

Returns a new instance of CreditBankIncomeGetRequestOptions.



37
38
39
40
41
42
43
# File 'lib/the_plaid_api/models/credit_bank_income_get_request_options.rb', line 37

def initialize(count: 1, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @count = count unless count == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#countInteger

How many Bank Income Reports should be fetched. Multiple reports may be available if the report has been re-created or refreshed. If more than one report is available, the most recent reports will be returned first.

Returns:

  • (Integer)


16
17
18
# File 'lib/the_plaid_api/models/credit_bank_income_get_request_options.rb', line 16

def count
  @count
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/the_plaid_api/models/credit_bank_income_get_request_options.rb', line 46

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  count = hash['count'] ||= 1

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreditBankIncomeGetRequestOptions.new(count: count,
                                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



19
20
21
22
23
# File 'lib/the_plaid_api/models/credit_bank_income_get_request_options.rb', line 19

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['count'] = 'count'
  @_hash
end

.nullablesObject

An array for nullable fields



33
34
35
# File 'lib/the_plaid_api/models/credit_bank_income_get_request_options.rb', line 33

def self.nullables
  []
end

.optionalsObject

An array for optional fields



26
27
28
29
30
# File 'lib/the_plaid_api/models/credit_bank_income_get_request_options.rb', line 26

def self.optionals
  %w[
    count
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



71
72
73
74
75
# File 'lib/the_plaid_api/models/credit_bank_income_get_request_options.rb', line 71

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} count: #{@count.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



65
66
67
68
# File 'lib/the_plaid_api/models/credit_bank_income_get_request_options.rb', line 65

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} count: #{@count}, additional_properties: #{@additional_properties}>"
end