Class: ThePlaidApi::CreditBankIncomeGetResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/credit_bank_income_get_response.rb

Overview

CreditBankIncomeGetResponse defines the response schema for ‘/credit/bank_income/get`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(request_id:, bank_income: SKIP, additional_properties: nil) ⇒ CreditBankIncomeGetResponse

Returns a new instance of CreditBankIncomeGetResponse.



43
44
45
46
47
48
49
50
# File 'lib/the_plaid_api/models/credit_bank_income_get_response.rb', line 43

def initialize(request_id:, bank_income: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @bank_income = bank_income unless bank_income == SKIP
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#bank_incomeArray[CreditBankIncome]

TODO: Write general description for this method

Returns:



15
16
17
# File 'lib/the_plaid_api/models/credit_bank_income_get_response.rb', line 15

def bank_income
  @bank_income
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/credit_bank_income_get_response.rb', line 21

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/the_plaid_api/models/credit_bank_income_get_response.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  request_id = hash.key?('request_id') ? hash['request_id'] : nil
  # Parameter is an array, so we need to iterate through it
  bank_income = nil
  unless hash['bank_income'].nil?
    bank_income = []
    hash['bank_income'].each do |structure|
      bank_income << (CreditBankIncome.from_hash(structure) if structure)
    end
  end

  bank_income = SKIP unless hash.key?('bank_income')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreditBankIncomeGetResponse.new(request_id: request_id,
                                  bank_income: bank_income,
                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
29
# File 'lib/the_plaid_api/models/credit_bank_income_get_response.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['bank_income'] = 'bank_income'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/the_plaid_api/models/credit_bank_income_get_response.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



32
33
34
35
36
# File 'lib/the_plaid_api/models/credit_bank_income_get_response.rb', line 32

def self.optionals
  %w[
    bank_income
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
# File 'lib/the_plaid_api/models/credit_bank_income_get_response.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} bank_income: #{@bank_income.inspect}, request_id: #{@request_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
# File 'lib/the_plaid_api/models/credit_bank_income_get_response.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} bank_income: #{@bank_income}, request_id: #{@request_id},"\
  " additional_properties: #{@additional_properties}>"
end