Class: ThePlaidApi::CreditBankIncomeRefreshRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/credit_bank_income_refresh_request.rb

Overview

CreditBankIncomeRefreshRequest defines the request schema for ‘/credit/bank_income/refresh`.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(user_token:, client_id: SKIP, secret: SKIP, user_id: SKIP, options: SKIP, additional_properties: nil) ⇒ CreditBankIncomeRefreshRequest

Returns a new instance of CreditBankIncomeRefreshRequest.



70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/the_plaid_api/models/credit_bank_income_refresh_request.rb', line 70

def initialize(user_token:, client_id: SKIP, secret: SKIP, user_id: SKIP,
               options: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @user_token = user_token
  @user_id = user_id unless user_id == SKIP
  @options = options unless options == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/credit_bank_income_refresh_request.rb', line 17

def client_id
  @client_id
end

#optionsCreditBankIncomeRefreshRequestOptions

An optional object for ‘/credit/bank_income/refresh` request options.



42
43
44
# File 'lib/the_plaid_api/models/credit_bank_income_refresh_request.rb', line 42

def options
  @options
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/credit_bank_income_refresh_request.rb', line 22

def secret
  @secret
end

#user_idString

The user token associated with the User data is being requested for. This field is used only by customers with pre-existing integrations that already use the ‘user_token` field. All other customers should use the `user_id` instead. For more details, see [New User APIs](plaid.com/docs/api/users/user-apis).

Returns:

  • (String)


38
39
40
# File 'lib/the_plaid_api/models/credit_bank_income_refresh_request.rb', line 38

def user_id
  @user_id
end

#user_tokenString

The user token associated with the User data is being requested for. This field is used only by customers with pre-existing integrations that already use the ‘user_token` field. All other customers should use the `user_id` instead. For more details, see [New User APIs](plaid.com/docs/api/users/user-apis).

Returns:

  • (String)


30
31
32
# File 'lib/the_plaid_api/models/credit_bank_income_refresh_request.rb', line 30

def user_token
  @user_token
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/the_plaid_api/models/credit_bank_income_refresh_request.rb', line 84

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  user_token = hash.key?('user_token') ? hash['user_token'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  user_id = hash.key?('user_id') ? hash['user_id'] : SKIP
  options = CreditBankIncomeRefreshRequestOptions.from_hash(hash['options']) if
    hash['options']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreditBankIncomeRefreshRequest.new(user_token: user_token,
                                     client_id: client_id,
                                     secret: secret,
                                     user_id: user_id,
                                     options: options,
                                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



45
46
47
48
49
50
51
52
53
# File 'lib/the_plaid_api/models/credit_bank_income_refresh_request.rb', line 45

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['user_token'] = 'user_token'
  @_hash['user_id'] = 'user_id'
  @_hash['options'] = 'options'
  @_hash
end

.nullablesObject

An array for nullable fields



66
67
68
# File 'lib/the_plaid_api/models/credit_bank_income_refresh_request.rb', line 66

def self.nullables
  []
end

.optionalsObject

An array for optional fields



56
57
58
59
60
61
62
63
# File 'lib/the_plaid_api/models/credit_bank_income_refresh_request.rb', line 56

def self.optionals
  %w[
    client_id
    secret
    user_id
    options
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



120
121
122
123
124
125
# File 'lib/the_plaid_api/models/credit_bank_income_refresh_request.rb', line 120

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, user_token:"\
  " #{@user_token.inspect}, user_id: #{@user_id.inspect}, options: #{@options.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



112
113
114
115
116
117
# File 'lib/the_plaid_api/models/credit_bank_income_refresh_request.rb', line 112

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, user_token: #{@user_token},"\
  " user_id: #{@user_id}, options: #{@options}, additional_properties:"\
  " #{@additional_properties}>"
end