Class: ThePlaidApi::CreditBankStatementUploadAccountOwner

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/credit_bank_statement_upload_account_owner.rb

Overview

An object containing data about the owner of the bank account for the uploaded bank statement.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name:, address:, additional_properties: nil) ⇒ CreditBankStatementUploadAccountOwner

Returns a new instance of CreditBankStatementUploadAccountOwner.



41
42
43
44
45
46
47
48
# File 'lib/the_plaid_api/models/credit_bank_statement_upload_account_owner.rb', line 41

def initialize(name:, address:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @name = name
  @address = address
  @additional_properties = additional_properties
end

Instance Attribute Details

#addressCreditBankStatementUploadAccountOwnerAddress

Address on the uploaded bank statement



19
20
21
# File 'lib/the_plaid_api/models/credit_bank_statement_upload_account_owner.rb', line 19

def address
  @address
end

#nameString

The name of the account owner

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/credit_bank_statement_upload_account_owner.rb', line 15

def name
  @name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/the_plaid_api/models/credit_bank_statement_upload_account_owner.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : nil
  address = CreditBankStatementUploadAccountOwnerAddress.from_hash(hash['address']) if
    hash['address']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreditBankStatementUploadAccountOwner.new(name: name,
                                            address: address,
                                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/the_plaid_api/models/credit_bank_statement_upload_account_owner.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash['address'] = 'address'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
38
39
# File 'lib/the_plaid_api/models/credit_bank_statement_upload_account_owner.rb', line 35

def self.nullables
  %w[
    name
  ]
end

.optionalsObject

An array for optional fields



30
31
32
# File 'lib/the_plaid_api/models/credit_bank_statement_upload_account_owner.rb', line 30

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/the_plaid_api/models/credit_bank_statement_upload_account_owner.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, address: #{@address.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/the_plaid_api/models/credit_bank_statement_upload_account_owner.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, address: #{@address}, additional_properties:"\
  " #{@additional_properties}>"
end