Class: ThePlaidApi::CreditBankStatementsUploadsGetRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CreditBankStatementsUploadsGetRequest
- Defined in:
- lib/the_plaid_api/models/credit_bank_statements_uploads_get_request.rb
Overview
CreditBankStatementsUploadsGetRequest defines the request schema for ‘/credit/bank_statements/uploads/get`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#options ⇒ CreditBankStatementsUploadsGetRequestOptions
An optional object for ‘/credit/bank_statements/uploads/get` request options.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#user_token ⇒ String
The user token associated with the User data is being requested for.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(user_token:, client_id: SKIP, secret: SKIP, options: SKIP, additional_properties: nil) ⇒ CreditBankStatementsUploadsGetRequest
constructor
A new instance of CreditBankStatementsUploadsGetRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(user_token:, client_id: SKIP, secret: SKIP, options: SKIP, additional_properties: nil) ⇒ CreditBankStatementsUploadsGetRequest
Returns a new instance of CreditBankStatementsUploadsGetRequest.
61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/the_plaid_api/models/credit_bank_statements_uploads_get_request.rb', line 61 def initialize(user_token:, client_id: SKIP, secret: SKIP, options: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @user_token = user_token @options = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/credit_bank_statements_uploads_get_request.rb', line 17 def client_id @client_id end |
#options ⇒ CreditBankStatementsUploadsGetRequestOptions
An optional object for ‘/credit/bank_statements/uploads/get` request options.
35 36 37 |
# File 'lib/the_plaid_api/models/credit_bank_statements_uploads_get_request.rb', line 35 def @options end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/the_plaid_api/models/credit_bank_statements_uploads_get_request.rb', line 22 def secret @secret end |
#user_token ⇒ String
The user token associated with the User data is being requested for. This field is used only by customers with pre-existing integrations that already use the ‘user_token` field. All other customers should use the `user_id` instead. For more details, see [New User APIs](plaid.com/docs/api/users/user-apis).
30 31 32 |
# File 'lib/the_plaid_api/models/credit_bank_statements_uploads_get_request.rb', line 30 def user_token @user_token end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/the_plaid_api/models/credit_bank_statements_uploads_get_request.rb', line 74 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. user_token = hash.key?('user_token') ? hash['user_token'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP = CreditBankStatementsUploadsGetRequestOptions.from_hash(hash['options']) if hash['options'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreditBankStatementsUploadsGetRequest.new(user_token: user_token, client_id: client_id, secret: secret, options: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
38 39 40 41 42 43 44 45 |
# File 'lib/the_plaid_api/models/credit_bank_statements_uploads_get_request.rb', line 38 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['user_token'] = 'user_token' @_hash['options'] = 'options' @_hash end |
.nullables ⇒ Object
An array for nullable fields
57 58 59 |
# File 'lib/the_plaid_api/models/credit_bank_statements_uploads_get_request.rb', line 57 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
48 49 50 51 52 53 54 |
# File 'lib/the_plaid_api/models/credit_bank_statements_uploads_get_request.rb', line 48 def self.optionals %w[ client_id secret options ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
107 108 109 110 111 112 |
# File 'lib/the_plaid_api/models/credit_bank_statements_uploads_get_request.rb', line 107 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, user_token:"\ " #{@user_token.inspect}, options: #{@options.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
100 101 102 103 104 |
# File 'lib/the_plaid_api/models/credit_bank_statements_uploads_get_request.rb', line 100 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, user_token: #{@user_token},"\ " options: #{@options}, additional_properties: #{@additional_properties}>" end |