Class: ThePlaidApi::CreditFreddieMacLoan

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/credit_freddie_mac_loan.rb

Overview

Information specific to a mortgage loan agreement between one or more borrowers and a mortgage lender.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(loan_identifiers:, loan_role_type:, additional_properties: nil) ⇒ CreditFreddieMacLoan

Returns a new instance of CreditFreddieMacLoan.



39
40
41
42
43
44
45
46
47
# File 'lib/the_plaid_api/models/credit_freddie_mac_loan.rb', line 39

def initialize(loan_identifiers:, loan_role_type:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @loan_identifiers = loan_identifiers
  @loan_role_type = loan_role_type
  @additional_properties = additional_properties
end

Instance Attribute Details

#loan_identifiersCreditFreddieMacLoanIdentifiers

Collection of current and previous identifiers for this loan.



15
16
17
# File 'lib/the_plaid_api/models/credit_freddie_mac_loan.rb', line 15

def loan_identifiers
  @loan_identifiers
end

#loan_role_typeString

Type of loan. The value can only be “SubjectLoan”

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/credit_freddie_mac_loan.rb', line 19

def loan_role_type
  @loan_role_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/the_plaid_api/models/credit_freddie_mac_loan.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  loan_identifiers = CreditFreddieMacLoanIdentifiers.from_hash(hash['LOAN_IDENTIFIERS']) if
    hash['LOAN_IDENTIFIERS']
  loan_role_type = hash.key?('LoanRoleType') ? hash['LoanRoleType'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreditFreddieMacLoan.new(loan_identifiers: loan_identifiers,
                           loan_role_type: loan_role_type,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/the_plaid_api/models/credit_freddie_mac_loan.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['loan_identifiers'] = 'LOAN_IDENTIFIERS'
  @_hash['loan_role_type'] = 'LoanRoleType'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
# File 'lib/the_plaid_api/models/credit_freddie_mac_loan.rb', line 35

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
# File 'lib/the_plaid_api/models/credit_freddie_mac_loan.rb', line 30

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/the_plaid_api/models/credit_freddie_mac_loan.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} loan_identifiers: #{@loan_identifiers.inspect}, loan_role_type:"\
  " #{@loan_role_type.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/the_plaid_api/models/credit_freddie_mac_loan.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} loan_identifiers: #{@loan_identifiers}, loan_role_type: #{@loan_role_type},"\
  " additional_properties: #{@additional_properties}>"
end