Class: ThePlaidApi::CreditFreddieMacReportingInformation

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/credit_freddie_mac_reporting_information.rb

Overview

Information about an report identifier and a report name.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(reporting_information_identifier:, report_date_time: SKIP, report_identifier_type: SKIP, reporting_information_parent_identifier: SKIP, additional_properties: nil) ⇒ CreditFreddieMacReportingInformation

Returns a new instance of CreditFreddieMacReportingInformation.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/the_plaid_api/models/credit_freddie_mac_reporting_information.rb', line 58

def initialize(reporting_information_identifier:, report_date_time: SKIP,
               report_identifier_type: SKIP,
               reporting_information_parent_identifier: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @report_date_time = report_date_time unless report_date_time == SKIP
  @report_identifier_type = report_identifier_type unless report_identifier_type == SKIP
  unless reporting_information_parent_identifier == SKIP
    @reporting_information_parent_identifier =
      reporting_information_parent_identifier
  end
  @reporting_information_identifier = reporting_information_identifier
  @additional_properties = additional_properties
end

Instance Attribute Details

#report_date_timeString

Documentation not found in the MISMO model viewer and not provided by Freddie Mac.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/credit_freddie_mac_reporting_information.rb', line 15

def report_date_time
  @report_date_time
end

#report_identifier_typeString

Documentation not found in the MISMO model viewer and not provided by Freddie Mac. The value can only be “ReportID”

Returns:

  • (String)


20
21
22
# File 'lib/the_plaid_api/models/credit_freddie_mac_reporting_information.rb', line 20

def report_identifier_type
  @report_identifier_type
end

#reporting_information_identifierString

Documentation not found in the MISMO model viewer and not provided by Freddie Mac.

Returns:

  • (String)


30
31
32
# File 'lib/the_plaid_api/models/credit_freddie_mac_reporting_information.rb', line 30

def reporting_information_identifier
  @reporting_information_identifier
end

#reporting_information_parent_identifierString

Documentation not found in the MISMO model viewer and not provided by Freddie Mac.

Returns:

  • (String)


25
26
27
# File 'lib/the_plaid_api/models/credit_freddie_mac_reporting_information.rb', line 25

def reporting_information_parent_identifier
  @reporting_information_parent_identifier
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/the_plaid_api/models/credit_freddie_mac_reporting_information.rb', line 76

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  reporting_information_identifier =
    hash.key?('ReportingInformationIdentifier') ? hash['ReportingInformationIdentifier'] : nil
  report_date_time =
    hash.key?('ReportDateTime') ? hash['ReportDateTime'] : SKIP
  report_identifier_type =
    hash.key?('ReportIdentifierType') ? hash['ReportIdentifierType'] : SKIP
  reporting_information_parent_identifier =
    hash.key?('ReportingInformationParentIdentifier') ? hash['ReportingInformationParentIdentifier'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreditFreddieMacReportingInformation.new(reporting_information_identifier: reporting_information_identifier,
                                           report_date_time: report_date_time,
                                           report_identifier_type: report_identifier_type,
                                           reporting_information_parent_identifier: reporting_information_parent_identifier,
                                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
42
# File 'lib/the_plaid_api/models/credit_freddie_mac_reporting_information.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['report_date_time'] = 'ReportDateTime'
  @_hash['report_identifier_type'] = 'ReportIdentifierType'
  @_hash['reporting_information_parent_identifier'] =
    'ReportingInformationParentIdentifier'
  @_hash['reporting_information_identifier'] =
    'ReportingInformationIdentifier'
  @_hash
end

.nullablesObject

An array for nullable fields



54
55
56
# File 'lib/the_plaid_api/models/credit_freddie_mac_reporting_information.rb', line 54

def self.nullables
  []
end

.optionalsObject

An array for optional fields



45
46
47
48
49
50
51
# File 'lib/the_plaid_api/models/credit_freddie_mac_reporting_information.rb', line 45

def self.optionals
  %w[
    report_date_time
    report_identifier_type
    reporting_information_parent_identifier
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



114
115
116
117
118
119
120
121
# File 'lib/the_plaid_api/models/credit_freddie_mac_reporting_information.rb', line 114

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} report_date_time: #{@report_date_time.inspect}, report_identifier_type:"\
  " #{@report_identifier_type.inspect}, reporting_information_parent_identifier:"\
  " #{@reporting_information_parent_identifier.inspect}, reporting_information_identifier:"\
  " #{@reporting_information_identifier.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



105
106
107
108
109
110
111
# File 'lib/the_plaid_api/models/credit_freddie_mac_reporting_information.rb', line 105

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} report_date_time: #{@report_date_time}, report_identifier_type:"\
  " #{@report_identifier_type}, reporting_information_parent_identifier:"\
  " #{@reporting_information_parent_identifier}, reporting_information_identifier:"\
  " #{@reporting_information_identifier}, additional_properties: #{@additional_properties}>"
end