Class: ThePlaidApi::CreditFreddieMacReportsGetRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CreditFreddieMacReportsGetRequest
- Defined in:
- lib/the_plaid_api/models/credit_freddie_mac_reports_get_request.rb
Overview
CreditFreddieMacReportsGetRequest defines the request schema for ‘credit/asset_report/freddie_mac/get`
Instance Attribute Summary collapse
-
#audit_copy_token ⇒ String
A token that can be shared with a third party auditor to allow them to obtain access to the Asset Report.
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(audit_copy_token:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ CreditFreddieMacReportsGetRequest
constructor
A new instance of CreditFreddieMacReportsGetRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(audit_copy_token:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ CreditFreddieMacReportsGetRequest
Returns a new instance of CreditFreddieMacReportsGetRequest.
51 52 53 54 55 56 57 58 59 60 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_reports_get_request.rb', line 51 def initialize(audit_copy_token:, client_id: SKIP, secret: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @audit_copy_token = audit_copy_token @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#audit_copy_token ⇒ String
A token that can be shared with a third party auditor to allow them to obtain access to the Asset Report. This token should be stored securely.
16 17 18 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_reports_get_request.rb', line 16 def audit_copy_token @audit_copy_token end |
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
22 23 24 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_reports_get_request.rb', line 22 def client_id @client_id end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
27 28 29 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_reports_get_request.rb', line 27 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_reports_get_request.rb', line 63 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. audit_copy_token = hash.key?('audit_copy_token') ? hash['audit_copy_token'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreditFreddieMacReportsGetRequest.new(audit_copy_token: audit_copy_token, client_id: client_id, secret: secret, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
30 31 32 33 34 35 36 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_reports_get_request.rb', line 30 def self.names @_hash = {} if @_hash.nil? @_hash['audit_copy_token'] = 'audit_copy_token' @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash end |
.nullables ⇒ Object
An array for nullable fields
47 48 49 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_reports_get_request.rb', line 47 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_reports_get_request.rb', line 39 def self.optionals %w[ client_id secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
94 95 96 97 98 99 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_reports_get_request.rb', line 94 def inspect class_name = self.class.name.split('::').last "<#{class_name} audit_copy_token: #{@audit_copy_token.inspect}, client_id:"\ " #{@client_id.inspect}, secret: #{@secret.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
87 88 89 90 91 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_reports_get_request.rb', line 87 def to_s class_name = self.class.name.split('::').last "<#{class_name} audit_copy_token: #{@audit_copy_token}, client_id: #{@client_id}, secret:"\ " #{@secret}, additional_properties: #{@additional_properties}>" end |