Class: ThePlaidApi::CreditPayStubEarnings
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CreditPayStubEarnings
- Defined in:
- lib/the_plaid_api/models/credit_pay_stub_earnings.rb
Overview
An object representing both a breakdown of earnings on a pay stub and the total earnings.
Instance Attribute Summary collapse
-
#breakdown ⇒ Array[PayStubEarningsBreakdown]
TODO: Write general description for this method.
-
#total ⇒ PayStubEarningsTotal
An object representing both the current pay period and year to date amount for an earning category.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(breakdown:, total:, additional_properties: nil) ⇒ CreditPayStubEarnings
constructor
A new instance of CreditPayStubEarnings.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(breakdown:, total:, additional_properties: nil) ⇒ CreditPayStubEarnings
Returns a new instance of CreditPayStubEarnings.
40 41 42 43 44 45 46 47 |
# File 'lib/the_plaid_api/models/credit_pay_stub_earnings.rb', line 40 def initialize(breakdown:, total:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @breakdown = breakdown @total = total @additional_properties = additional_properties end |
Instance Attribute Details
#breakdown ⇒ Array[PayStubEarningsBreakdown]
TODO: Write general description for this method
15 16 17 |
# File 'lib/the_plaid_api/models/credit_pay_stub_earnings.rb', line 15 def breakdown @breakdown end |
#total ⇒ PayStubEarningsTotal
An object representing both the current pay period and year to date amount for an earning category.
20 21 22 |
# File 'lib/the_plaid_api/models/credit_pay_stub_earnings.rb', line 20 def total @total end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/the_plaid_api/models/credit_pay_stub_earnings.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it breakdown = nil unless hash['breakdown'].nil? breakdown = [] hash['breakdown'].each do |structure| breakdown << (PayStubEarningsBreakdown.from_hash(structure) if structure) end end breakdown = nil unless hash.key?('breakdown') total = PayStubEarningsTotal.from_hash(hash['total']) if hash['total'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreditPayStubEarnings.new(breakdown: breakdown, total: total, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/the_plaid_api/models/credit_pay_stub_earnings.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['breakdown'] = 'breakdown' @_hash['total'] = 'total' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/the_plaid_api/models/credit_pay_stub_earnings.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 |
# File 'lib/the_plaid_api/models/credit_pay_stub_earnings.rb', line 31 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
87 88 89 90 91 |
# File 'lib/the_plaid_api/models/credit_pay_stub_earnings.rb', line 87 def inspect class_name = self.class.name.split('::').last "<#{class_name} breakdown: #{@breakdown.inspect}, total: #{@total.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
80 81 82 83 84 |
# File 'lib/the_plaid_api/models/credit_pay_stub_earnings.rb', line 80 def to_s class_name = self.class.name.split('::').last "<#{class_name} breakdown: #{@breakdown}, total: #{@total}, additional_properties:"\ " #{@additional_properties}>" end |