Class: ThePlaidApi::CreditPayrollIncomePrecheckResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/credit_payroll_income_precheck_response.rb

Overview

Defines the response schema for ‘/credit/payroll_income/precheck`.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(request_id:, confidence:, additional_properties: nil) ⇒ CreditPayrollIncomePrecheckResponse

Returns a new instance of CreditPayrollIncomePrecheckResponse.



48
49
50
51
52
53
54
55
# File 'lib/the_plaid_api/models/credit_payroll_income_precheck_response.rb', line 48

def initialize(request_id:, confidence:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @request_id = request_id
  @confidence = confidence
  @additional_properties = additional_properties
end

Instance Attribute Details

#confidenceIncomeVerificationPrecheckConfidence

The confidence that Plaid can support the user in the digital income verification flow instead of requiring a manual paystub upload. One of the following: ‘“HIGH”`: It is very likely that this user can use the digital income verification flow. “`LOW`”: It is unlikely that this user can use the digital income verification flow. `“UNKNOWN”`: It was not possible to determine if the user is supportable with the information passed.



28
29
30
# File 'lib/the_plaid_api/models/credit_payroll_income_precheck_response.rb', line 28

def confidence
  @confidence
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/credit_payroll_income_precheck_response.rb', line 16

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/the_plaid_api/models/credit_payroll_income_precheck_response.rb', line 58

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  request_id = hash.key?('request_id') ? hash['request_id'] : nil
  confidence = hash.key?('confidence') ? hash['confidence'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreditPayrollIncomePrecheckResponse.new(request_id: request_id,
                                          confidence: confidence,
                                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



31
32
33
34
35
36
# File 'lib/the_plaid_api/models/credit_payroll_income_precheck_response.rb', line 31

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['request_id'] = 'request_id'
  @_hash['confidence'] = 'confidence'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/the_plaid_api/models/credit_payroll_income_precheck_response.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
# File 'lib/the_plaid_api/models/credit_payroll_income_precheck_response.rb', line 39

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



86
87
88
89
90
# File 'lib/the_plaid_api/models/credit_payroll_income_precheck_response.rb', line 86

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} request_id: #{@request_id.inspect}, confidence: #{@confidence.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



79
80
81
82
83
# File 'lib/the_plaid_api/models/credit_payroll_income_precheck_response.rb', line 79

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} request_id: #{@request_id}, confidence: #{@confidence},"\
  " additional_properties: #{@additional_properties}>"
end