Class: ThePlaidApi::CreditPayrollIncomeRefreshRequestOptions
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CreditPayrollIncomeRefreshRequestOptions
- Defined in:
- lib/the_plaid_api/models/credit_payroll_income_refresh_request_options.rb
Overview
An optional object for ‘/credit/payroll_income/refresh` request options.
Instance Attribute Summary collapse
-
#item_ids ⇒ Array[String]
An array of ‘item_id`s to be refreshed.
-
#webhook ⇒ String
The URL where Plaid will send the payroll income refresh webhook.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(item_ids: SKIP, webhook: SKIP, additional_properties: nil) ⇒ CreditPayrollIncomeRefreshRequestOptions
constructor
A new instance of CreditPayrollIncomeRefreshRequestOptions.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(item_ids: SKIP, webhook: SKIP, additional_properties: nil) ⇒ CreditPayrollIncomeRefreshRequestOptions
Returns a new instance of CreditPayrollIncomeRefreshRequestOptions.
43 44 45 46 47 48 49 50 |
# File 'lib/the_plaid_api/models/credit_payroll_income_refresh_request_options.rb', line 43 def initialize(item_ids: SKIP, webhook: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @item_ids = item_ids unless item_ids == SKIP @webhook = webhook unless webhook == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#item_ids ⇒ Array[String]
An array of ‘item_id`s to be refreshed. Each `item_id` should uniquely identify a payroll income item. If this field is not provided, all `item_id`s associated with the `user_token` will be refreshed.
16 17 18 |
# File 'lib/the_plaid_api/models/credit_payroll_income_refresh_request_options.rb', line 16 def item_ids @item_ids end |
#webhook ⇒ String
The URL where Plaid will send the payroll income refresh webhook.
20 21 22 |
# File 'lib/the_plaid_api/models/credit_payroll_income_refresh_request_options.rb', line 20 def webhook @webhook end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/the_plaid_api/models/credit_payroll_income_refresh_request_options.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. item_ids = hash.key?('item_ids') ? hash['item_ids'] : SKIP webhook = hash.key?('webhook') ? hash['webhook'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreditPayrollIncomeRefreshRequestOptions.new(item_ids: item_ids, webhook: webhook, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/the_plaid_api/models/credit_payroll_income_refresh_request_options.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['item_ids'] = 'item_ids' @_hash['webhook'] = 'webhook' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/the_plaid_api/models/credit_payroll_income_refresh_request_options.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/the_plaid_api/models/credit_payroll_income_refresh_request_options.rb', line 31 def self.optionals %w[ item_ids webhook ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/the_plaid_api/models/credit_payroll_income_refresh_request_options.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} item_ids: #{@item_ids.inspect}, webhook: #{@webhook.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/the_plaid_api/models/credit_payroll_income_refresh_request_options.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} item_ids: #{@item_ids}, webhook: #{@webhook}, additional_properties:"\ " #{@additional_properties}>" end |