Class: ThePlaidApi::CreditPayrollIncomeRefreshResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CreditPayrollIncomeRefreshResponse
- Defined in:
- lib/the_plaid_api/models/credit_payroll_income_refresh_response.rb
Overview
CreditPayrollIncomeRefreshResponse defines the response schema for ‘/credit/payroll_income/refresh`
Instance Attribute Summary collapse
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
-
#verification_refresh_status ⇒ String
The verification refresh status.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(request_id:, verification_refresh_status:, additional_properties: nil) ⇒ CreditPayrollIncomeRefreshResponse
constructor
A new instance of CreditPayrollIncomeRefreshResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(request_id:, verification_refresh_status:, additional_properties: nil) ⇒ CreditPayrollIncomeRefreshResponse
Returns a new instance of CreditPayrollIncomeRefreshResponse.
45 46 47 48 49 50 51 52 53 |
# File 'lib/the_plaid_api/models/credit_payroll_income_refresh_response.rb', line 45 def initialize(request_id:, verification_refresh_status:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @request_id = request_id @verification_refresh_status = verification_refresh_status @additional_properties = additional_properties end |
Instance Attribute Details
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
17 18 19 |
# File 'lib/the_plaid_api/models/credit_payroll_income_refresh_response.rb', line 17 def request_id @request_id end |
#verification_refresh_status ⇒ String
The verification refresh status. One of the following: ‘“USER_PRESENCE_REQUIRED”` User presence is required to refresh an income verification. `“SUCCESSFUL”` The income verification refresh was successful. `“NOT_FOUND”` No new data was found after the income verification refresh.
25 26 27 |
# File 'lib/the_plaid_api/models/credit_payroll_income_refresh_response.rb', line 25 def verification_refresh_status @verification_refresh_status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/the_plaid_api/models/credit_payroll_income_refresh_response.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. request_id = hash.key?('request_id') ? hash['request_id'] : nil verification_refresh_status = hash.key?('verification_refresh_status') ? hash['verification_refresh_status'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreditPayrollIncomeRefreshResponse.new(request_id: request_id, verification_refresh_status: verification_refresh_status, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
28 29 30 31 32 33 |
# File 'lib/the_plaid_api/models/credit_payroll_income_refresh_response.rb', line 28 def self.names @_hash = {} if @_hash.nil? @_hash['request_id'] = 'request_id' @_hash['verification_refresh_status'] = 'verification_refresh_status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/the_plaid_api/models/credit_payroll_income_refresh_response.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
36 37 38 |
# File 'lib/the_plaid_api/models/credit_payroll_income_refresh_response.rb', line 36 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 90 |
# File 'lib/the_plaid_api/models/credit_payroll_income_refresh_response.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} request_id: #{@request_id.inspect}, verification_refresh_status:"\ " #{@verification_refresh_status.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/the_plaid_api/models/credit_payroll_income_refresh_response.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} request_id: #{@request_id}, verification_refresh_status:"\ " #{@verification_refresh_status}, additional_properties: #{@additional_properties}>" end |