Class: ThePlaidApi::CreditRelayCreateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/credit_relay_create_request.rb

Overview

CreditRelayCreateRequest defines the request schema for ‘/credit/relay/create`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(report_tokens:, secondary_client_id:, client_id: SKIP, secret: SKIP, webhook: SKIP, additional_properties: nil) ⇒ CreditRelayCreateRequest

Returns a new instance of CreditRelayCreateRequest.



66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/the_plaid_api/models/credit_relay_create_request.rb', line 66

def initialize(report_tokens:, secondary_client_id:, client_id: SKIP,
               secret: SKIP, webhook: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @report_tokens = report_tokens
  @secondary_client_id = secondary_client_id
  @webhook = webhook unless webhook == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/credit_relay_create_request.rb', line 17

def client_id
  @client_id
end

#report_tokensArray[String]

List of report token strings, with at most one token of each report type. Currently only Asset Report token is supported.

Returns:

  • (Array[String])


27
28
29
# File 'lib/the_plaid_api/models/credit_relay_create_request.rb', line 27

def report_tokens
  @report_tokens
end

#secondary_client_idString

The ‘secondary_client_id` is the client id of the third party with whom you would like to share the relay token.

Returns:

  • (String)


32
33
34
# File 'lib/the_plaid_api/models/credit_relay_create_request.rb', line 32

def secondary_client_id
  @secondary_client_id
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/credit_relay_create_request.rb', line 22

def secret
  @secret
end

#webhookString

URL to which Plaid will send webhooks when the Secondary Client successfully retrieves an Asset Report by calling ‘/credit/relay/get`.

Returns:

  • (String)


37
38
39
# File 'lib/the_plaid_api/models/credit_relay_create_request.rb', line 37

def webhook
  @webhook
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/the_plaid_api/models/credit_relay_create_request.rb', line 80

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  report_tokens = hash.key?('report_tokens') ? hash['report_tokens'] : nil
  secondary_client_id =
    hash.key?('secondary_client_id') ? hash['secondary_client_id'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  webhook = hash.key?('webhook') ? hash['webhook'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreditRelayCreateRequest.new(report_tokens: report_tokens,
                               secondary_client_id: secondary_client_id,
                               client_id: client_id,
                               secret: secret,
                               webhook: webhook,
                               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



40
41
42
43
44
45
46
47
48
# File 'lib/the_plaid_api/models/credit_relay_create_request.rb', line 40

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['report_tokens'] = 'report_tokens'
  @_hash['secondary_client_id'] = 'secondary_client_id'
  @_hash['webhook'] = 'webhook'
  @_hash
end

.nullablesObject

An array for nullable fields



60
61
62
63
64
# File 'lib/the_plaid_api/models/credit_relay_create_request.rb', line 60

def self.nullables
  %w[
    webhook
  ]
end

.optionalsObject

An array for optional fields



51
52
53
54
55
56
57
# File 'lib/the_plaid_api/models/credit_relay_create_request.rb', line 51

def self.optionals
  %w[
    client_id
    secret
    webhook
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



116
117
118
119
120
121
122
# File 'lib/the_plaid_api/models/credit_relay_create_request.rb', line 116

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\
  " report_tokens: #{@report_tokens.inspect}, secondary_client_id:"\
  " #{@secondary_client_id.inspect}, webhook: #{@webhook.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



108
109
110
111
112
113
# File 'lib/the_plaid_api/models/credit_relay_create_request.rb', line 108

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, report_tokens:"\
  " #{@report_tokens}, secondary_client_id: #{@secondary_client_id}, webhook: #{@webhook},"\
  " additional_properties: #{@additional_properties}>"
end