Class: ThePlaidApi::CreditRelayPdfGetRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CreditRelayPdfGetRequest
- Defined in:
- lib/the_plaid_api/models/credit_relay_pdf_get_request.rb
Overview
CreditRelayPDFGetRequest defines the request schema for ‘/credit/relay/pdf/get`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#relay_token ⇒ String
The ‘relay_token` granting access to the report you would like to get.
-
#report_type ⇒ String
readonly
The report type.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(relay_token:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ CreditRelayPdfGetRequest
constructor
A new instance of CreditRelayPdfGetRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(relay_token:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ CreditRelayPdfGetRequest
Returns a new instance of CreditRelayPdfGetRequest.
56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/the_plaid_api/models/credit_relay_pdf_get_request.rb', line 56 def initialize(relay_token:, client_id: SKIP, secret: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @relay_token = relay_token @report_type = 'asset' @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/credit_relay_pdf_get_request.rb', line 17 def client_id @client_id end |
#relay_token ⇒ String
The ‘relay_token` granting access to the report you would like to get.
26 27 28 |
# File 'lib/the_plaid_api/models/credit_relay_pdf_get_request.rb', line 26 def relay_token @relay_token end |
#report_type ⇒ String (readonly)
The report type. It can be ‘asset`. Income report types are not yet supported.
31 32 33 |
# File 'lib/the_plaid_api/models/credit_relay_pdf_get_request.rb', line 31 def report_type @report_type end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/the_plaid_api/models/credit_relay_pdf_get_request.rb', line 22 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/the_plaid_api/models/credit_relay_pdf_get_request.rb', line 69 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. relay_token = hash.key?('relay_token') ? hash['relay_token'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreditRelayPdfGetRequest.new(relay_token: relay_token, client_id: client_id, secret: secret, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
34 35 36 37 38 39 40 41 |
# File 'lib/the_plaid_api/models/credit_relay_pdf_get_request.rb', line 34 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['relay_token'] = 'relay_token' @_hash['report_type'] = 'report_type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
52 53 54 |
# File 'lib/the_plaid_api/models/credit_relay_pdf_get_request.rb', line 52 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 47 48 49 |
# File 'lib/the_plaid_api/models/credit_relay_pdf_get_request.rb', line 44 def self.optionals %w[ client_id secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 104 |
# File 'lib/the_plaid_api/models/credit_relay_pdf_get_request.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, relay_token:"\ " #{@relay_token.inspect}, report_type: #{@report_type.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 |
# File 'lib/the_plaid_api/models/credit_relay_pdf_get_request.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, relay_token: #{@relay_token},"\ " report_type: #{@report_type}, additional_properties: #{@additional_properties}>" end |