Class: ThePlaidApi::CreditRelayRefreshRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/credit_relay_refresh_request.rb

Overview

CreditRelayRefreshRequest defines the request schema for ‘/credit/relay/refresh`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(relay_token:, client_id: SKIP, secret: SKIP, webhook: SKIP, additional_properties: nil) ⇒ CreditRelayRefreshRequest

Returns a new instance of CreditRelayRefreshRequest.



65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/the_plaid_api/models/credit_relay_refresh_request.rb', line 65

def initialize(relay_token:, client_id: SKIP, secret: SKIP, webhook: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @relay_token = relay_token
  @report_type = 'asset'
  @webhook = webhook unless webhook == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/credit_relay_refresh_request.rb', line 17

def client_id
  @client_id
end

#relay_tokenString

The ‘relay_token` granting access to the report you would like to refresh.

Returns:

  • (String)


26
27
28
# File 'lib/the_plaid_api/models/credit_relay_refresh_request.rb', line 26

def relay_token
  @relay_token
end

#report_typeString (readonly)

The report type. It can be ‘asset`. Income report types are not yet supported.

Returns:

  • (String)


31
32
33
# File 'lib/the_plaid_api/models/credit_relay_refresh_request.rb', line 31

def report_type
  @report_type
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/credit_relay_refresh_request.rb', line 22

def secret
  @secret
end

#webhookString

The URL registered to receive webhooks when the report of a relay token has been refreshed.

Returns:

  • (String)


36
37
38
# File 'lib/the_plaid_api/models/credit_relay_refresh_request.rb', line 36

def webhook
  @webhook
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/the_plaid_api/models/credit_relay_refresh_request.rb', line 79

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  relay_token = hash.key?('relay_token') ? hash['relay_token'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  webhook = hash.key?('webhook') ? hash['webhook'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreditRelayRefreshRequest.new(relay_token: relay_token,
                                client_id: client_id,
                                secret: secret,
                                webhook: webhook,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



39
40
41
42
43
44
45
46
47
# File 'lib/the_plaid_api/models/credit_relay_refresh_request.rb', line 39

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['relay_token'] = 'relay_token'
  @_hash['report_type'] = 'report_type'
  @_hash['webhook'] = 'webhook'
  @_hash
end

.nullablesObject

An array for nullable fields



59
60
61
62
63
# File 'lib/the_plaid_api/models/credit_relay_refresh_request.rb', line 59

def self.nullables
  %w[
    webhook
  ]
end

.optionalsObject

An array for optional fields



50
51
52
53
54
55
56
# File 'lib/the_plaid_api/models/credit_relay_refresh_request.rb', line 50

def self.optionals
  %w[
    client_id
    secret
    webhook
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



112
113
114
115
116
117
# File 'lib/the_plaid_api/models/credit_relay_refresh_request.rb', line 112

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, relay_token:"\
  " #{@relay_token.inspect}, report_type: #{@report_type.inspect}, webhook:"\
  " #{@webhook.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



104
105
106
107
108
109
# File 'lib/the_plaid_api/models/credit_relay_refresh_request.rb', line 104

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, relay_token: #{@relay_token},"\
  " report_type: #{@report_type}, webhook: #{@webhook}, additional_properties:"\
  " #{@additional_properties}>"
end