Class: ThePlaidApi::CreditRelayRefreshResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/credit_relay_refresh_response.rb

Overview

CreditRelayRefreshResponse defines the response schema for ‘/credit/relay/refresh`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(relay_token:, request_id:, asset_report_id: SKIP, additional_properties: nil) ⇒ CreditRelayRefreshResponse

Returns a new instance of CreditRelayRefreshResponse.



49
50
51
52
53
54
55
56
57
58
# File 'lib/the_plaid_api/models/credit_relay_refresh_response.rb', line 49

def initialize(relay_token:, request_id:, asset_report_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @relay_token = relay_token
  @asset_report_id = asset_report_id unless asset_report_id == SKIP
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#asset_report_idString

A unique ID identifying an Asset Report. Like all Plaid identifiers, this ID is case sensitive.

Returns:

  • (String)


20
21
22
# File 'lib/the_plaid_api/models/credit_relay_refresh_response.rb', line 20

def asset_report_id
  @asset_report_id
end

#relay_tokenString

TODO: Write general description for this method

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/credit_relay_refresh_response.rb', line 15

def relay_token
  @relay_token
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


26
27
28
# File 'lib/the_plaid_api/models/credit_relay_refresh_response.rb', line 26

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/the_plaid_api/models/credit_relay_refresh_response.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  relay_token = hash.key?('relay_token') ? hash['relay_token'] : nil
  request_id = hash.key?('request_id') ? hash['request_id'] : nil
  asset_report_id =
    hash.key?('asset_report_id') ? hash['asset_report_id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreditRelayRefreshResponse.new(relay_token: relay_token,
                                 request_id: request_id,
                                 asset_report_id: asset_report_id,
                                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
# File 'lib/the_plaid_api/models/credit_relay_refresh_response.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['relay_token'] = 'relay_token'
  @_hash['asset_report_id'] = 'asset_report_id'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



45
46
47
# File 'lib/the_plaid_api/models/credit_relay_refresh_response.rb', line 45

def self.nullables
  []
end

.optionalsObject

An array for optional fields



38
39
40
41
42
# File 'lib/the_plaid_api/models/credit_relay_refresh_response.rb', line 38

def self.optionals
  %w[
    asset_report_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



92
93
94
95
96
97
# File 'lib/the_plaid_api/models/credit_relay_refresh_response.rb', line 92

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} relay_token: #{@relay_token.inspect}, asset_report_id:"\
  " #{@asset_report_id.inspect}, request_id: #{@request_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



85
86
87
88
89
# File 'lib/the_plaid_api/models/credit_relay_refresh_response.rb', line 85

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} relay_token: #{@relay_token}, asset_report_id: #{@asset_report_id},"\
  " request_id: #{@request_id}, additional_properties: #{@additional_properties}>"
end