Class: ThePlaidApi::CreditRelayRemoveResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/credit_relay_remove_response.rb

Overview

CreditRelayRemoveResponse defines the response schema for ‘/credit/relay/remove`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(removed:, request_id:, additional_properties: nil) ⇒ CreditRelayRemoveResponse

Returns a new instance of CreditRelayRemoveResponse.



41
42
43
44
45
46
47
48
# File 'lib/the_plaid_api/models/credit_relay_remove_response.rb', line 41

def initialize(removed:, request_id:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @removed = removed
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#removedTrueClass | FalseClass

‘true` if the relay token was successfully removed.

Returns:

  • (TrueClass | FalseClass)


15
16
17
# File 'lib/the_plaid_api/models/credit_relay_remove_response.rb', line 15

def removed
  @removed
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/credit_relay_remove_response.rb', line 21

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/the_plaid_api/models/credit_relay_remove_response.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  removed = hash.key?('removed') ? hash['removed'] : nil
  request_id = hash.key?('request_id') ? hash['request_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreditRelayRemoveResponse.new(removed: removed,
                                request_id: request_id,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
29
# File 'lib/the_plaid_api/models/credit_relay_remove_response.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['removed'] = 'removed'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/the_plaid_api/models/credit_relay_remove_response.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



32
33
34
# File 'lib/the_plaid_api/models/credit_relay_remove_response.rb', line 32

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/the_plaid_api/models/credit_relay_remove_response.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} removed: #{@removed.inspect}, request_id: #{@request_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/the_plaid_api/models/credit_relay_remove_response.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} removed: #{@removed}, request_id: #{@request_id}, additional_properties:"\
  " #{@additional_properties}>"
end