Class: ThePlaidApi::CreditSessionDocumentIncomeResult

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/credit_session_document_income_result.rb

Overview

The details of a document income verification in Link

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(num_paystubs_uploaded:, num_w2s_uploaded:, num_bank_statements_uploaded:, num_1099s_uploaded:, additional_properties: nil) ⇒ CreditSessionDocumentIncomeResult

Returns a new instance of CreditSessionDocumentIncomeResult.



48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/the_plaid_api/models/credit_session_document_income_result.rb', line 48

def initialize(num_paystubs_uploaded:, num_w2s_uploaded:,
               num_bank_statements_uploaded:, num_1099s_uploaded:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @num_paystubs_uploaded = num_paystubs_uploaded
  @num_w2s_uploaded = num_w2s_uploaded
  @num_bank_statements_uploaded = num_bank_statements_uploaded
  @num_1099s_uploaded = num_1099s_uploaded
  @additional_properties = additional_properties
end

Instance Attribute Details

#num_1099s_uploadedInteger

The number of 1099s uploaded by the user

Returns:

  • (Integer)


26
27
28
# File 'lib/the_plaid_api/models/credit_session_document_income_result.rb', line 26

def num_1099s_uploaded
  @num_1099s_uploaded
end

#num_bank_statements_uploadedInteger

The number of bank statements uploaded by the user.

Returns:

  • (Integer)


22
23
24
# File 'lib/the_plaid_api/models/credit_session_document_income_result.rb', line 22

def num_bank_statements_uploaded
  @num_bank_statements_uploaded
end

#num_paystubs_uploadedInteger

The number of paystubs uploaded by the user.

Returns:

  • (Integer)


14
15
16
# File 'lib/the_plaid_api/models/credit_session_document_income_result.rb', line 14

def num_paystubs_uploaded
  @num_paystubs_uploaded
end

#num_w2s_uploadedInteger

The number of w2s uploaded by the user.

Returns:

  • (Integer)


18
19
20
# File 'lib/the_plaid_api/models/credit_session_document_income_result.rb', line 18

def num_w2s_uploaded
  @num_w2s_uploaded
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/the_plaid_api/models/credit_session_document_income_result.rb', line 62

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  num_paystubs_uploaded =
    hash.key?('num_paystubs_uploaded') ? hash['num_paystubs_uploaded'] : nil
  num_w2s_uploaded =
    hash.key?('num_w2s_uploaded') ? hash['num_w2s_uploaded'] : nil
  num_bank_statements_uploaded =
    hash.key?('num_bank_statements_uploaded') ? hash['num_bank_statements_uploaded'] : nil
  num_1099s_uploaded =
    hash.key?('num_1099s_uploaded') ? hash['num_1099s_uploaded'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreditSessionDocumentIncomeResult.new(num_paystubs_uploaded: num_paystubs_uploaded,
                                        num_w2s_uploaded: num_w2s_uploaded,
                                        num_bank_statements_uploaded: num_bank_statements_uploaded,
                                        num_1099s_uploaded: num_1099s_uploaded,
                                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/the_plaid_api/models/credit_session_document_income_result.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['num_paystubs_uploaded'] = 'num_paystubs_uploaded'
  @_hash['num_w2s_uploaded'] = 'num_w2s_uploaded'
  @_hash['num_bank_statements_uploaded'] = 'num_bank_statements_uploaded'
  @_hash['num_1099s_uploaded'] = 'num_1099s_uploaded'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/the_plaid_api/models/credit_session_document_income_result.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
# File 'lib/the_plaid_api/models/credit_session_document_income_result.rb', line 39

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



100
101
102
103
104
105
106
# File 'lib/the_plaid_api/models/credit_session_document_income_result.rb', line 100

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} num_paystubs_uploaded: #{@num_paystubs_uploaded.inspect}, num_w2s_uploaded:"\
  " #{@num_w2s_uploaded.inspect}, num_bank_statements_uploaded:"\
  " #{@num_bank_statements_uploaded.inspect}, num_1099s_uploaded:"\
  " #{@num_1099s_uploaded.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
96
97
# File 'lib/the_plaid_api/models/credit_session_document_income_result.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} num_paystubs_uploaded: #{@num_paystubs_uploaded}, num_w2s_uploaded:"\
  " #{@num_w2s_uploaded}, num_bank_statements_uploaded: #{@num_bank_statements_uploaded},"\
  " num_1099s_uploaded: #{@num_1099s_uploaded}, additional_properties:"\
  " #{@additional_properties}>"
end