Class: ThePlaidApi::CreditSessionsGetResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/credit_sessions_get_response.rb

Overview

CreditSessionsGetResponse defines the response schema for ‘/credit/sessions/get`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(request_id:, sessions: SKIP, additional_properties: nil) ⇒ CreditSessionsGetResponse

Returns a new instance of CreditSessionsGetResponse.



44
45
46
47
48
49
50
51
# File 'lib/the_plaid_api/models/credit_sessions_get_response.rb', line 44

def initialize(request_id:, sessions: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @sessions = sessions unless sessions == SKIP
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/credit_sessions_get_response.rb', line 22

def request_id
  @request_id
end

#sessionsArray[CreditSession]

A list of Link sessions for the user. Sessions will be sorted in reverse chronological order.

Returns:



16
17
18
# File 'lib/the_plaid_api/models/credit_sessions_get_response.rb', line 16

def sessions
  @sessions
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/the_plaid_api/models/credit_sessions_get_response.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  request_id = hash.key?('request_id') ? hash['request_id'] : nil
  # Parameter is an array, so we need to iterate through it
  sessions = nil
  unless hash['sessions'].nil?
    sessions = []
    hash['sessions'].each do |structure|
      sessions << (CreditSession.from_hash(structure) if structure)
    end
  end

  sessions = SKIP unless hash.key?('sessions')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreditSessionsGetResponse.new(request_id: request_id,
                                sessions: sessions,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
# File 'lib/the_plaid_api/models/credit_sessions_get_response.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['sessions'] = 'sessions'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/the_plaid_api/models/credit_sessions_get_response.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



33
34
35
36
37
# File 'lib/the_plaid_api/models/credit_sessions_get_response.rb', line 33

def self.optionals
  %w[
    sessions
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



91
92
93
94
95
# File 'lib/the_plaid_api/models/credit_sessions_get_response.rb', line 91

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} sessions: #{@sessions.inspect}, request_id: #{@request_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
# File 'lib/the_plaid_api/models/credit_sessions_get_response.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} sessions: #{@sessions}, request_id: #{@request_id}, additional_properties:"\
  " #{@additional_properties}>"
end