Class: ThePlaidApi::DefaultUpdateWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/default_update_webhook.rb

Overview

Fired when new transaction data is available for an Item. Plaid will typically check for new transaction data several times a day. This webhook is intended for use with ‘/transactions/get`; if you are using the newer `/transactions/sync` endpoint, this webhook will still be fired to maintain backwards compatibility, but it is recommended to listen for and respond to the `SYNC_UPDATES_AVAILABLE` webhook instead.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, new_transactions:, item_id:, environment:, error: SKIP, additional_properties: nil) ⇒ DefaultUpdateWebhook

Returns a new instance of DefaultUpdateWebhook.



76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/the_plaid_api/models/default_update_webhook.rb', line 76

def initialize(webhook_type:, webhook_code:, new_transactions:, item_id:,
               environment:, error: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @error = error unless error == SKIP
  @new_transactions = new_transactions
  @item_id = item_id
  @environment = environment
  @additional_properties = additional_properties
end

Instance Attribute Details

#environmentWebhookEnvironmentValues

The Plaid environment the webhook was sent from



48
49
50
# File 'lib/the_plaid_api/models/default_update_webhook.rb', line 48

def environment
  @environment
end

#errorError

Errors are identified by ‘error_code` and categorized by `error_type`. Use these in preference to HTTP status codes to identify and handle specific errors. HTTP status codes are set and provide the broadest categorization of errors: 4xx codes are for developer- or user-related errors, and 5xx codes are for Plaid-related errors, and the status will be 2xx in non-error cases. An Item with a non-`null` error object will only be part of an API response when calling `/item/get` to view Item status. Otherwise, error fields will be `null` if no error has occurred; if an error has occurred, an error code will be returned instead.

Returns:



35
36
37
# File 'lib/the_plaid_api/models/default_update_webhook.rb', line 35

def error
  @error
end

#item_idString

The ‘item_id` of the Item the webhook relates to.

Returns:

  • (String)


44
45
46
# File 'lib/the_plaid_api/models/default_update_webhook.rb', line 44

def item_id
  @item_id
end

#new_transactionsFloat

The number of new transactions detected since the last time this webhook was fired.

Returns:

  • (Float)


40
41
42
# File 'lib/the_plaid_api/models/default_update_webhook.rb', line 40

def new_transactions
  @new_transactions
end

#webhook_codeString

‘DEFAULT_UPDATE`

Returns:

  • (String)


23
24
25
# File 'lib/the_plaid_api/models/default_update_webhook.rb', line 23

def webhook_code
  @webhook_code
end

#webhook_typeString

‘TRANSACTIONS`

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/default_update_webhook.rb', line 19

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/the_plaid_api/models/default_update_webhook.rb', line 91

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  new_transactions =
    hash.key?('new_transactions') ? hash['new_transactions'] : nil
  item_id = hash.key?('item_id') ? hash['item_id'] : nil
  environment = hash.key?('environment') ? hash['environment'] : nil
  error = Error.from_hash(hash['error']) if hash['error']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DefaultUpdateWebhook.new(webhook_type: webhook_type,
                           webhook_code: webhook_code,
                           new_transactions: new_transactions,
                           item_id: item_id,
                           environment: environment,
                           error: error,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



51
52
53
54
55
56
57
58
59
60
# File 'lib/the_plaid_api/models/default_update_webhook.rb', line 51

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['error'] = 'error'
  @_hash['new_transactions'] = 'new_transactions'
  @_hash['item_id'] = 'item_id'
  @_hash['environment'] = 'environment'
  @_hash
end

.nullablesObject

An array for nullable fields



70
71
72
73
74
# File 'lib/the_plaid_api/models/default_update_webhook.rb', line 70

def self.nullables
  %w[
    error
  ]
end

.optionalsObject

An array for optional fields



63
64
65
66
67
# File 'lib/the_plaid_api/models/default_update_webhook.rb', line 63

def self.optionals
  %w[
    error
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



129
130
131
132
133
134
135
# File 'lib/the_plaid_api/models/default_update_webhook.rb', line 129

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, error: #{@error.inspect}, new_transactions:"\
  " #{@new_transactions.inspect}, item_id: #{@item_id.inspect}, environment:"\
  " #{@environment.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



121
122
123
124
125
126
# File 'lib/the_plaid_api/models/default_update_webhook.rb', line 121

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, error:"\
  " #{@error}, new_transactions: #{@new_transactions}, item_id: #{@item_id}, environment:"\
  " #{@environment}, additional_properties: #{@additional_properties}>"
end