Class: ThePlaidApi::EmailAddressMatchScore

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/email_address_match_score.rb

Overview

Score found by matching email provided by the API with the email on the account at the financial institution. 100 is a perfect match and 0 is a no match. If the account contains multiple owners, the maximum match score is filled.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(score: SKIP, additional_properties: nil) ⇒ EmailAddressMatchScore

Returns a new instance of EmailAddressMatchScore.



44
45
46
47
48
49
50
# File 'lib/the_plaid_api/models/email_address_match_score.rb', line 44

def initialize(score: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @score = score unless score == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#scoreInteger

Match score for normalized email. 100 is a perfect match, 99-70 is a partial match (matching the same email with different ‘+’ extensions), anything below 70 is considered a mismatch. Typically, the match threshold should be set to a score of 70 or higher. If the email is missing from either the API or financial institution, this is null.

Returns:

  • (Integer)


21
22
23
# File 'lib/the_plaid_api/models/email_address_match_score.rb', line 21

def score
  @score
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/the_plaid_api/models/email_address_match_score.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  score = hash.key?('score') ? hash['score'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  EmailAddressMatchScore.new(score: score,
                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
# File 'lib/the_plaid_api/models/email_address_match_score.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['score'] = 'score'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
41
42
# File 'lib/the_plaid_api/models/email_address_match_score.rb', line 38

def self.nullables
  %w[
    score
  ]
end

.optionalsObject

An array for optional fields



31
32
33
34
35
# File 'lib/the_plaid_api/models/email_address_match_score.rb', line 31

def self.optionals
  %w[
    score
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
82
# File 'lib/the_plaid_api/models/email_address_match_score.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} score: #{@score.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
# File 'lib/the_plaid_api/models/email_address_match_score.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} score: #{@score}, additional_properties: #{@additional_properties}>"
end