Class: ThePlaidApi::Employer1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/employer1.rb

Overview

Information about the employer on the paystub

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name:, address: SKIP, additional_properties: nil) ⇒ Employer1

Returns a new instance of Employer1.



42
43
44
45
46
47
48
49
# File 'lib/the_plaid_api/models/employer1.rb', line 42

def initialize(name:, address: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @address = address unless address == SKIP
  @name = name
  @additional_properties = additional_properties
end

Instance Attribute Details

#addressAddress2

Address on the paystub

Returns:



14
15
16
# File 'lib/the_plaid_api/models/employer1.rb', line 14

def address
  @address
end

#nameString

The name of the employer on the paystub.

Returns:

  • (String)


18
19
20
# File 'lib/the_plaid_api/models/employer1.rb', line 18

def name
  @name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/the_plaid_api/models/employer1.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : nil
  address = Address2.from_hash(hash['address']) if hash['address']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Employer1.new(name: name,
                address: address,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/the_plaid_api/models/employer1.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['address'] = 'address'
  @_hash['name'] = 'name'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
39
40
# File 'lib/the_plaid_api/models/employer1.rb', line 36

def self.nullables
  %w[
    name
  ]
end

.optionalsObject

An array for optional fields



29
30
31
32
33
# File 'lib/the_plaid_api/models/employer1.rb', line 29

def self.optionals
  %w[
    address
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/the_plaid_api/models/employer1.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} address: #{@address.inspect}, name: #{@name.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/the_plaid_api/models/employer1.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} address: #{@address}, name: #{@name}, additional_properties:"\
  " #{@additional_properties}>"
end