Class: ThePlaidApi::EmployerVerification

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/employer_verification.rb

Overview

An object containing employer data.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name: SKIP, additional_properties: nil) ⇒ EmployerVerification

Returns a new instance of EmployerVerification.



37
38
39
40
41
42
43
# File 'lib/the_plaid_api/models/employer_verification.rb', line 37

def initialize(name: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @name = name unless name == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#nameString

Name of employer.

Returns:

  • (String)


14
15
16
# File 'lib/the_plaid_api/models/employer_verification.rb', line 14

def name
  @name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/the_plaid_api/models/employer_verification.rb', line 46

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  EmployerVerification.new(name: name,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/the_plaid_api/models/employer_verification.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
34
35
# File 'lib/the_plaid_api/models/employer_verification.rb', line 31

def self.nullables
  %w[
    name
  ]
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/the_plaid_api/models/employer_verification.rb', line 24

def self.optionals
  %w[
    name
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



71
72
73
74
# File 'lib/the_plaid_api/models/employer_verification.rb', line 71

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



65
66
67
68
# File 'lib/the_plaid_api/models/employer_verification.rb', line 65

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, additional_properties: #{@additional_properties}>"
end