Class: ThePlaidApi::EmployersSearchResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/employers_search_response.rb

Overview

EmployersSearchResponse defines the response schema for ‘/employers/search`.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(employers:, request_id:, additional_properties: nil) ⇒ EmployersSearchResponse

Returns a new instance of EmployersSearchResponse.



40
41
42
43
44
45
46
47
# File 'lib/the_plaid_api/models/employers_search_response.rb', line 40

def initialize(employers:, request_id:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @employers = employers
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#employersArray[Employer]

A list of employers matching the search criteria.

Returns:



14
15
16
# File 'lib/the_plaid_api/models/employers_search_response.rb', line 14

def employers
  @employers
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


20
21
22
# File 'lib/the_plaid_api/models/employers_search_response.rb', line 20

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/the_plaid_api/models/employers_search_response.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  employers = nil
  unless hash['employers'].nil?
    employers = []
    hash['employers'].each do |structure|
      employers << (Employer.from_hash(structure) if structure)
    end
  end

  employers = nil unless hash.key?('employers')
  request_id = hash.key?('request_id') ? hash['request_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  EmployersSearchResponse.new(employers: employers,
                              request_id: request_id,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/the_plaid_api/models/employers_search_response.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['employers'] = 'employers'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
# File 'lib/the_plaid_api/models/employers_search_response.rb', line 36

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
# File 'lib/the_plaid_api/models/employers_search_response.rb', line 31

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



87
88
89
90
91
# File 'lib/the_plaid_api/models/employers_search_response.rb', line 87

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} employers: #{@employers.inspect}, request_id: #{@request_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



80
81
82
83
84
# File 'lib/the_plaid_api/models/employers_search_response.rb', line 80

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} employers: #{@employers}, request_id: #{@request_id},"\
  " additional_properties: #{@additional_properties}>"
end