Class: ThePlaidApi::EmploymentDetails

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/employment_details.rb

Overview

An object representing employment details found on a paystub.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(annual_salary: SKIP, hire_date: SKIP, additional_properties: nil) ⇒ EmploymentDetails

Returns a new instance of EmploymentDetails.



43
44
45
46
47
48
49
50
51
# File 'lib/the_plaid_api/models/employment_details.rb', line 43

def initialize(annual_salary: SKIP, hire_date: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @annual_salary = annual_salary unless annual_salary == SKIP
  @hire_date = hire_date unless hire_date == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#annual_salaryPay

An object representing a monetary amount.

Returns:



14
15
16
# File 'lib/the_plaid_api/models/employment_details.rb', line 14

def annual_salary
  @annual_salary
end

#hire_dateDate

Date on which the employee was hired, in the YYYY-MM-DD format.

Returns:

  • (Date)


18
19
20
# File 'lib/the_plaid_api/models/employment_details.rb', line 18

def hire_date
  @hire_date
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/the_plaid_api/models/employment_details.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  annual_salary = Pay.from_hash(hash['annual_salary']) if hash['annual_salary']
  hire_date = hash.key?('hire_date') ? hash['hire_date'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  EmploymentDetails.new(annual_salary: annual_salary,
                        hire_date: hire_date,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/the_plaid_api/models/employment_details.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['annual_salary'] = 'annual_salary'
  @_hash['hire_date'] = 'hire_date'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
40
41
# File 'lib/the_plaid_api/models/employment_details.rb', line 37

def self.nullables
  %w[
    hire_date
  ]
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/the_plaid_api/models/employment_details.rb', line 29

def self.optionals
  %w[
    annual_salary
    hire_date
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



82
83
84
85
86
# File 'lib/the_plaid_api/models/employment_details.rb', line 82

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} annual_salary: #{@annual_salary.inspect}, hire_date: #{@hire_date.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



75
76
77
78
79
# File 'lib/the_plaid_api/models/employment_details.rb', line 75

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} annual_salary: #{@annual_salary}, hire_date: #{@hire_date},"\
  " additional_properties: #{@additional_properties}>"
end