Class: ThePlaidApi::EntityScreeningHitEmails

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/entity_screening_hit_emails.rb

Overview

Email address information for the associated entity watchlist hit

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(email_address:, additional_properties: nil) ⇒ EntityScreeningHitEmails

Returns a new instance of EntityScreeningHitEmails.



35
36
37
38
39
40
41
# File 'lib/the_plaid_api/models/entity_screening_hit_emails.rb', line 35

def initialize(email_address:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @email_address = email_address
  @additional_properties = additional_properties
end

Instance Attribute Details

#email_addressString

A valid email address. Must not have leading or trailing spaces and address must be RFC compliant. For more information, see [RFC 3696](datatracker.ietf.org/doc/html/rfc3696).

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/entity_screening_hit_emails.rb', line 16

def email_address
  @email_address
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/the_plaid_api/models/entity_screening_hit_emails.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  email_address = hash.key?('email_address') ? hash['email_address'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  EntityScreeningHitEmails.new(email_address: email_address,
                               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



19
20
21
22
23
# File 'lib/the_plaid_api/models/entity_screening_hit_emails.rb', line 19

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['email_address'] = 'email_address'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/the_plaid_api/models/entity_screening_hit_emails.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



26
27
28
# File 'lib/the_plaid_api/models/entity_screening_hit_emails.rb', line 26

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



70
71
72
73
74
# File 'lib/the_plaid_api/models/entity_screening_hit_emails.rb', line 70

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} email_address: #{@email_address.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



63
64
65
66
67
# File 'lib/the_plaid_api/models/entity_screening_hit_emails.rb', line 63

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} email_address: #{@email_address}, additional_properties:"\
  " #{@additional_properties}>"
end