Class: ThePlaidApi::ExternalPaymentRefundDetails

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/external_payment_refund_details.rb

Overview

Details about external payment refund

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name:, iban:, bacs:, additional_properties: nil) ⇒ ExternalPaymentRefundDetails

Returns a new instance of ExternalPaymentRefundDetails.



48
49
50
51
52
53
54
55
56
# File 'lib/the_plaid_api/models/external_payment_refund_details.rb', line 48

def initialize(name:, iban:, bacs:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @name = name
  @iban = iban
  @bacs = bacs
  @additional_properties = additional_properties
end

Instance Attribute Details

#bacsRecipientBacsNullable

An object containing a BACS account number and sort code. If an IBAN is not provided or if this recipient needs to accept domestic GBP-denominated payments, BACS data is required.



24
25
26
# File 'lib/the_plaid_api/models/external_payment_refund_details.rb', line 24

def bacs
  @bacs
end

#ibanString

The International Bank Account Number (IBAN) for the account.

Returns:

  • (String)


18
19
20
# File 'lib/the_plaid_api/models/external_payment_refund_details.rb', line 18

def iban
  @iban
end

#nameString

The name of the account holder.

Returns:

  • (String)


14
15
16
# File 'lib/the_plaid_api/models/external_payment_refund_details.rb', line 14

def name
  @name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/the_plaid_api/models/external_payment_refund_details.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : nil
  iban = hash.key?('iban') ? hash['iban'] : nil
  bacs = RecipientBacsNullable.from_hash(hash['bacs']) if hash['bacs']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ExternalPaymentRefundDetails.new(name: name,
                                   iban: iban,
                                   bacs: bacs,
                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
# File 'lib/the_plaid_api/models/external_payment_refund_details.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash['iban'] = 'iban'
  @_hash['bacs'] = 'bacs'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
44
45
46
# File 'lib/the_plaid_api/models/external_payment_refund_details.rb', line 41

def self.nullables
  %w[
    iban
    bacs
  ]
end

.optionalsObject

An array for optional fields



36
37
38
# File 'lib/the_plaid_api/models/external_payment_refund_details.rb', line 36

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/the_plaid_api/models/external_payment_refund_details.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, iban: #{@iban.inspect}, bacs: #{@bacs.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/the_plaid_api/models/external_payment_refund_details.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, iban: #{@iban}, bacs: #{@bacs}, additional_properties:"\
  " #{@additional_properties}>"
end