Class: ThePlaidApi::FallbackAuthMicrodepositAutoVerifiedWebhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::FallbackAuthMicrodepositAutoVerifiedWebhook
- Defined in:
- lib/the_plaid_api/models/fallback_auth_microdeposit_auto_verified_webhook.rb
Overview
Fires when an account is automatically verified using micro-deposits
Instance Attribute Summary collapse
-
#account_id ⇒ String
The external account ID associated with the micro-deposit.
-
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from.
-
#error ⇒ String
The error code associated with the webhook.
-
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error.
-
#webhook_code ⇒ String
‘AUTOMATICALLY_VERIFIED`.
-
#webhook_type ⇒ String
‘AUTH`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, account_id:, item_id:, environment:, error: SKIP, additional_properties: nil) ⇒ FallbackAuthMicrodepositAutoVerifiedWebhook
constructor
A new instance of FallbackAuthMicrodepositAutoVerifiedWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, account_id:, item_id:, environment:, error: SKIP, additional_properties: nil) ⇒ FallbackAuthMicrodepositAutoVerifiedWebhook
Returns a new instance of FallbackAuthMicrodepositAutoVerifiedWebhook.
62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/the_plaid_api/models/fallback_auth_microdeposit_auto_verified_webhook.rb', line 62 def initialize(webhook_type:, webhook_code:, account_id:, item_id:, environment:, error: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @error = error unless error == SKIP @account_id = account_id @item_id = item_id @environment = environment @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
The external account ID associated with the micro-deposit
26 27 28 |
# File 'lib/the_plaid_api/models/fallback_auth_microdeposit_auto_verified_webhook.rb', line 26 def account_id @account_id end |
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from
34 35 36 |
# File 'lib/the_plaid_api/models/fallback_auth_microdeposit_auto_verified_webhook.rb', line 34 def environment @environment end |
#error ⇒ String
The error code associated with the webhook.
22 23 24 |
# File 'lib/the_plaid_api/models/fallback_auth_microdeposit_auto_verified_webhook.rb', line 22 def error @error end |
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error
30 31 32 |
# File 'lib/the_plaid_api/models/fallback_auth_microdeposit_auto_verified_webhook.rb', line 30 def item_id @item_id end |
#webhook_code ⇒ String
‘AUTOMATICALLY_VERIFIED`
18 19 20 |
# File 'lib/the_plaid_api/models/fallback_auth_microdeposit_auto_verified_webhook.rb', line 18 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘AUTH`
14 15 16 |
# File 'lib/the_plaid_api/models/fallback_auth_microdeposit_auto_verified_webhook.rb', line 14 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/the_plaid_api/models/fallback_auth_microdeposit_auto_verified_webhook.rb', line 77 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil account_id = hash.key?('account_id') ? hash['account_id'] : nil item_id = hash.key?('item_id') ? hash['item_id'] : nil environment = hash.key?('environment') ? hash['environment'] : nil error = hash.key?('error') ? hash['error'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. FallbackAuthMicrodepositAutoVerifiedWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, account_id: account_id, item_id: item_id, environment: environment, error: error, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/the_plaid_api/models/fallback_auth_microdeposit_auto_verified_webhook.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['error'] = 'error' @_hash['account_id'] = 'account_id' @_hash['item_id'] = 'item_id' @_hash['environment'] = 'environment' @_hash end |
.nullables ⇒ Object
An array for nullable fields
56 57 58 59 60 |
# File 'lib/the_plaid_api/models/fallback_auth_microdeposit_auto_verified_webhook.rb', line 56 def self.nullables %w[ error ] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 52 53 |
# File 'lib/the_plaid_api/models/fallback_auth_microdeposit_auto_verified_webhook.rb', line 49 def self.optionals %w[ error ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
114 115 116 117 118 119 120 |
# File 'lib/the_plaid_api/models/fallback_auth_microdeposit_auto_verified_webhook.rb', line 114 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, error: #{@error.inspect}, account_id: #{@account_id.inspect},"\ " item_id: #{@item_id.inspect}, environment: #{@environment.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
106 107 108 109 110 111 |
# File 'lib/the_plaid_api/models/fallback_auth_microdeposit_auto_verified_webhook.rb', line 106 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, error:"\ " #{@error}, account_id: #{@account_id}, item_id: #{@item_id}, environment: #{@environment},"\ " additional_properties: #{@additional_properties}>" end |