Class: ThePlaidApi::FiAttributeEntity
- Defined in:
- lib/the_plaid_api/models/fi_attribute_entity.rb
Overview
Financial Institution provider-specific attribute
Instance Attribute Summary collapse
-
#name ⇒ String
Name of attribute.
-
#value ⇒ String
Value of attribute.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name:, value:) ⇒ FiAttributeEntity
constructor
A new instance of FiAttributeEntity.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name:, value:) ⇒ FiAttributeEntity
Returns a new instance of FiAttributeEntity.
38 39 40 41 |
# File 'lib/the_plaid_api/models/fi_attribute_entity.rb', line 38 def initialize(name:, value:) @name = name @value = value end |
Instance Attribute Details
#name ⇒ String
Name of attribute
14 15 16 |
# File 'lib/the_plaid_api/models/fi_attribute_entity.rb', line 14 def name @name end |
#value ⇒ String
Value of attribute
18 19 20 |
# File 'lib/the_plaid_api/models/fi_attribute_entity.rb', line 18 def value @value end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/the_plaid_api/models/fi_attribute_entity.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : nil value = hash.key?('value') ? hash['value'] : nil # Create object from extracted values. FiAttributeEntity.new(name: name, value: value) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/the_plaid_api/models/fi_attribute_entity.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['value'] = 'value' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/the_plaid_api/models/fi_attribute_entity.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/the_plaid_api/models/fi_attribute_entity.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
63 64 65 66 |
# File 'lib/the_plaid_api/models/fi_attribute_entity.rb', line 63 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, value: #{@value.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
57 58 59 60 |
# File 'lib/the_plaid_api/models/fi_attribute_entity.rb', line 57 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, value: #{@value}>" end |