Class: ThePlaidApi::ForwardedJsonResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/forwarded_json_response.rb

Overview

An arbitrary JSON payload sent to or received from the Plaid server. Internal use only.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(request_id:, additional_properties: nil) ⇒ ForwardedJsonResponse

Returns a new instance of ForwardedJsonResponse.



36
37
38
39
40
41
42
# File 'lib/the_plaid_api/models/forwarded_json_response.rb', line 36

def initialize(request_id:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/forwarded_json_response.rb', line 17

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/the_plaid_api/models/forwarded_json_response.rb', line 45

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  request_id = hash.key?('request_id') ? hash['request_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ForwardedJsonResponse.new(request_id: request_id,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



20
21
22
23
24
# File 'lib/the_plaid_api/models/forwarded_json_response.rb', line 20

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



32
33
34
# File 'lib/the_plaid_api/models/forwarded_json_response.rb', line 32

def self.nullables
  []
end

.optionalsObject

An array for optional fields



27
28
29
# File 'lib/the_plaid_api/models/forwarded_json_response.rb', line 27

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



71
72
73
74
75
# File 'lib/the_plaid_api/models/forwarded_json_response.rb', line 71

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} request_id: #{@request_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



64
65
66
67
68
# File 'lib/the_plaid_api/models/forwarded_json_response.rb', line 64

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} request_id: #{@request_id}, additional_properties:"\
  " #{@additional_properties}>"
end