Class: ThePlaidApi::HistoricalAnnualIncome

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/historical_annual_income.rb

Overview

An object representing the historical annual income amount.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(current_amount:, baseline_amount: SKIP, additional_properties: nil) ⇒ HistoricalAnnualIncome

Returns a new instance of HistoricalAnnualIncome.



42
43
44
45
46
47
48
49
50
# File 'lib/the_plaid_api/models/historical_annual_income.rb', line 42

def initialize(current_amount:, baseline_amount: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @baseline_amount = baseline_amount unless baseline_amount == SKIP
  @current_amount = current_amount
  @additional_properties = additional_properties
end

Instance Attribute Details

#baseline_amountFloat

The historical annual income at the time of subscription

Returns:

  • (Float)


14
15
16
# File 'lib/the_plaid_api/models/historical_annual_income.rb', line 14

def baseline_amount
  @baseline_amount
end

#current_amountFloat

The current historical annual income

Returns:

  • (Float)


18
19
20
# File 'lib/the_plaid_api/models/historical_annual_income.rb', line 18

def current_amount
  @current_amount
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/the_plaid_api/models/historical_annual_income.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  current_amount =
    hash.key?('current_amount') ? hash['current_amount'] : nil
  baseline_amount =
    hash.key?('baseline_amount') ? hash['baseline_amount'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  HistoricalAnnualIncome.new(current_amount: current_amount,
                             baseline_amount: baseline_amount,
                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/the_plaid_api/models/historical_annual_income.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['baseline_amount'] = 'baseline_amount'
  @_hash['current_amount'] = 'current_amount'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
39
40
# File 'lib/the_plaid_api/models/historical_annual_income.rb', line 36

def self.nullables
  %w[
    baseline_amount
  ]
end

.optionalsObject

An array for optional fields



29
30
31
32
33
# File 'lib/the_plaid_api/models/historical_annual_income.rb', line 29

def self.optionals
  %w[
    baseline_amount
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



83
84
85
86
87
# File 'lib/the_plaid_api/models/historical_annual_income.rb', line 83

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} baseline_amount: #{@baseline_amount.inspect}, current_amount:"\
  " #{@current_amount.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



76
77
78
79
80
# File 'lib/the_plaid_api/models/historical_annual_income.rb', line 76

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} baseline_amount: #{@baseline_amount}, current_amount: #{@current_amount},"\
  " additional_properties: #{@additional_properties}>"
end