Class: ThePlaidApi::IdentityDefaultUpdateWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/identity_default_update_webhook.rb

Overview

Fired when a change to identity data has been detected on an Item. Items are checked for identity updates every 30-90 days. We recommend that upon receiving this webhook you make another call to ‘/identity/get` to fetch the user’s latest identity data.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, item_id:, account_ids_with_updated_identity:, error:, environment:, additional_properties: nil) ⇒ IdentityDefaultUpdateWebhook

Returns a new instance of IdentityDefaultUpdateWebhook.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/the_plaid_api/models/identity_default_update_webhook.rb', line 74

def initialize(webhook_type:, webhook_code:, item_id:,
               account_ids_with_updated_identity:, error:, environment:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @item_id = item_id
  @account_ids_with_updated_identity = 
  @error = error
  @environment = environment
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_ids_with_updated_identityHash[String, Object]

An object with keys of ‘account_id`’s that are mapped to their respective identity attributes that changed. Example: ‘{ “XMBvvyMGQ1UoLbKByoMqH3nXMj84ALSdE5B58”: [“PHONES”] }`

Returns:

  • (Hash[String, Object])


31
32
33
# File 'lib/the_plaid_api/models/identity_default_update_webhook.rb', line 31

def 
  @account_ids_with_updated_identity
end

#environmentWebhookEnvironmentValues

The Plaid environment the webhook was sent from



47
48
49
# File 'lib/the_plaid_api/models/identity_default_update_webhook.rb', line 47

def environment
  @environment
end

#errorError

Errors are identified by ‘error_code` and categorized by `error_type`. Use these in preference to HTTP status codes to identify and handle specific errors. HTTP status codes are set and provide the broadest categorization of errors: 4xx codes are for developer- or user-related errors, and 5xx codes are for Plaid-related errors, and the status will be 2xx in non-error cases. An Item with a non-`null` error object will only be part of an API response when calling `/item/get` to view Item status. Otherwise, error fields will be `null` if no error has occurred; if an error has occurred, an error code will be returned instead.

Returns:



43
44
45
# File 'lib/the_plaid_api/models/identity_default_update_webhook.rb', line 43

def error
  @error
end

#item_idString

The ‘item_id` of the Item associated with this webhook, warning, or error

Returns:

  • (String)


25
26
27
# File 'lib/the_plaid_api/models/identity_default_update_webhook.rb', line 25

def item_id
  @item_id
end

#webhook_codeString

‘DEFAULT_UPDATE`

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/identity_default_update_webhook.rb', line 21

def webhook_code
  @webhook_code
end

#webhook_typeString

‘IDENTITY`

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/identity_default_update_webhook.rb', line 17

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/the_plaid_api/models/identity_default_update_webhook.rb', line 90

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  item_id = hash.key?('item_id') ? hash['item_id'] : nil
   =
    hash.key?('account_ids_with_updated_identity') ? hash['account_ids_with_updated_identity'] : nil
  error = Error.from_hash(hash['error']) if hash['error']
  environment = hash.key?('environment') ? hash['environment'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  IdentityDefaultUpdateWebhook.new(webhook_type: webhook_type,
                                   webhook_code: webhook_code,
                                   item_id: item_id,
                                   account_ids_with_updated_identity: ,
                                   error: error,
                                   environment: environment,
                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



50
51
52
53
54
55
56
57
58
59
60
# File 'lib/the_plaid_api/models/identity_default_update_webhook.rb', line 50

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['item_id'] = 'item_id'
  @_hash['account_ids_with_updated_identity'] =
    'account_ids_with_updated_identity'
  @_hash['error'] = 'error'
  @_hash['environment'] = 'environment'
  @_hash
end

.nullablesObject

An array for nullable fields



68
69
70
71
72
# File 'lib/the_plaid_api/models/identity_default_update_webhook.rb', line 68

def self.nullables
  %w[
    error
  ]
end

.optionalsObject

An array for optional fields



63
64
65
# File 'lib/the_plaid_api/models/identity_default_update_webhook.rb', line 63

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



129
130
131
132
133
134
135
# File 'lib/the_plaid_api/models/identity_default_update_webhook.rb', line 129

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, item_id: #{@item_id.inspect}, account_ids_with_updated_identity:"\
  " #{@account_ids_with_updated_identity.inspect}, error: #{@error.inspect}, environment:"\
  " #{@environment.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



120
121
122
123
124
125
126
# File 'lib/the_plaid_api/models/identity_default_update_webhook.rb', line 120

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, item_id:"\
  " #{@item_id}, account_ids_with_updated_identity: #{@account_ids_with_updated_identity},"\
  " error: #{@error}, environment: #{@environment}, additional_properties:"\
  " #{@additional_properties}>"
end