Class: ThePlaidApi::IdentityDocumentUpload

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/identity_document_upload.rb

Overview

Document object with metadata of the uploaded document

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(document_id: SKIP, metadata: SKIP, risk_insights: SKIP, additional_properties: nil) ⇒ IdentityDocumentUpload

Returns a new instance of IdentityDocumentUpload.



48
49
50
51
52
53
54
55
56
57
# File 'lib/the_plaid_api/models/identity_document_upload.rb', line 48

def initialize(document_id: SKIP, metadata: SKIP, risk_insights: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @document_id = document_id unless document_id == SKIP
  @metadata =  unless  == SKIP
  @risk_insights = risk_insights unless risk_insights == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#document_idString

A UUID identifying the document.

Returns:

  • (String)


14
15
16
# File 'lib/the_plaid_api/models/identity_document_upload.rb', line 14

def document_id
  @document_id
end

#metadataIdentityDocumentUploadMetadata

Metadata pertaining to the document.



18
19
20
# File 'lib/the_plaid_api/models/identity_document_upload.rb', line 18

def 
  @metadata
end

#risk_insightsIdentityDocumentUploadRiskInsights

Object representing fraud risk data of the uploaded document. Only provided when using Identity Document Upload with Fraud Risk enabled.



23
24
25
# File 'lib/the_plaid_api/models/identity_document_upload.rb', line 23

def risk_insights
  @risk_insights
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/the_plaid_api/models/identity_document_upload.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  document_id = hash.key?('document_id') ? hash['document_id'] : SKIP
   = IdentityDocumentUploadMetadata.from_hash(hash['metadata']) if hash['metadata']
  risk_insights = IdentityDocumentUploadRiskInsights.from_hash(hash['risk_insights']) if
    hash['risk_insights']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  IdentityDocumentUpload.new(document_id: document_id,
                             metadata: ,
                             risk_insights: risk_insights,
                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/the_plaid_api/models/identity_document_upload.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['document_id'] = 'document_id'
  @_hash['metadata'] = 'metadata'
  @_hash['risk_insights'] = 'risk_insights'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/the_plaid_api/models/identity_document_upload.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
41
# File 'lib/the_plaid_api/models/identity_document_upload.rb', line 35

def self.optionals
  %w[
    document_id
    metadata
    risk_insights
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



91
92
93
94
95
96
# File 'lib/the_plaid_api/models/identity_document_upload.rb', line 91

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} document_id: #{@document_id.inspect}, metadata: #{@metadata.inspect},"\
  " risk_insights: #{@risk_insights.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
# File 'lib/the_plaid_api/models/identity_document_upload.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} document_id: #{@document_id}, metadata: #{@metadata}, risk_insights:"\
  " #{@risk_insights}, additional_properties: #{@additional_properties}>"
end