Class: ThePlaidApi::IdentityDocumentsUploadsGetResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/identity_documents_uploads_get_response.rb

Overview

IdentityDocumentsUploadsGetResponse defines the response schema for ‘/identity/documents/uploads/get`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(accounts:, item:, request_id:, additional_properties: nil) ⇒ IdentityDocumentsUploadsGetResponse

Returns a new instance of IdentityDocumentsUploadsGetResponse.



46
47
48
49
50
51
52
53
54
# File 'lib/the_plaid_api/models/identity_documents_uploads_get_response.rb', line 46

def initialize(accounts:, item:, request_id:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @accounts = accounts
  @item = item
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#accountsArray[AccountIdentityDocumentUpload]

The accounts for which Identity data has been requested

Returns:



15
16
17
# File 'lib/the_plaid_api/models/identity_documents_uploads_get_response.rb', line 15

def accounts
  @accounts
end

#itemItem

Metadata about the Item.

Returns:



19
20
21
# File 'lib/the_plaid_api/models/identity_documents_uploads_get_response.rb', line 19

def item
  @item
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


25
26
27
# File 'lib/the_plaid_api/models/identity_documents_uploads_get_response.rb', line 25

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/the_plaid_api/models/identity_documents_uploads_get_response.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  accounts = nil
  unless hash['accounts'].nil?
    accounts = []
    hash['accounts'].each do |structure|
      accounts << (AccountIdentityDocumentUpload.from_hash(structure) if structure)
    end
  end

  accounts = nil unless hash.key?('accounts')
  item = Item.from_hash(hash['item']) if hash['item']
  request_id = hash.key?('request_id') ? hash['request_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  IdentityDocumentsUploadsGetResponse.new(accounts: accounts,
                                          item: item,
                                          request_id: request_id,
                                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



28
29
30
31
32
33
34
# File 'lib/the_plaid_api/models/identity_documents_uploads_get_response.rb', line 28

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['accounts'] = 'accounts'
  @_hash['item'] = 'item'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



42
43
44
# File 'lib/the_plaid_api/models/identity_documents_uploads_get_response.rb', line 42

def self.nullables
  []
end

.optionalsObject

An array for optional fields



37
38
39
# File 'lib/the_plaid_api/models/identity_documents_uploads_get_response.rb', line 37

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



96
97
98
99
100
# File 'lib/the_plaid_api/models/identity_documents_uploads_get_response.rb', line 96

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} accounts: #{@accounts.inspect}, item: #{@item.inspect}, request_id:"\
  " #{@request_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



89
90
91
92
93
# File 'lib/the_plaid_api/models/identity_documents_uploads_get_response.rb', line 89

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} accounts: #{@accounts}, item: #{@item}, request_id: #{@request_id},"\
  " additional_properties: #{@additional_properties}>"
end