Class: ThePlaidApi::IdentityMatchRequestOptions
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::IdentityMatchRequestOptions
- Defined in:
- lib/the_plaid_api/models/identity_match_request_options.rb
Overview
An optional object to filter /identity/match results
Instance Attribute Summary collapse
-
#account_ids ⇒ Array[String]
An array of ‘account_ids` to perform fuzzy match.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_ids: SKIP, additional_properties: nil) ⇒ IdentityMatchRequestOptions
constructor
A new instance of IdentityMatchRequestOptions.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_ids: SKIP, additional_properties: nil) ⇒ IdentityMatchRequestOptions
Returns a new instance of IdentityMatchRequestOptions.
35 36 37 38 39 40 41 |
# File 'lib/the_plaid_api/models/identity_match_request_options.rb', line 35 def initialize(account_ids: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_ids = account_ids unless account_ids == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_ids ⇒ Array[String]
An array of ‘account_ids` to perform fuzzy match
14 15 16 |
# File 'lib/the_plaid_api/models/identity_match_request_options.rb', line 14 def account_ids @account_ids end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/the_plaid_api/models/identity_match_request_options.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_ids = hash.key?('account_ids') ? hash['account_ids'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. IdentityMatchRequestOptions.new(account_ids: account_ids, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/the_plaid_api/models/identity_match_request_options.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['account_ids'] = 'account_ids' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/the_plaid_api/models/identity_match_request_options.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/the_plaid_api/models/identity_match_request_options.rb', line 24 def self.optionals %w[ account_ids ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
70 71 72 73 74 |
# File 'lib/the_plaid_api/models/identity_match_request_options.rb', line 70 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_ids: #{@account_ids.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
63 64 65 66 67 |
# File 'lib/the_plaid_api/models/identity_match_request_options.rb', line 63 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_ids: #{@account_ids}, additional_properties:"\ " #{@additional_properties}>" end |