Class: ThePlaidApi::IdentityMatchResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/identity_match_response.rb

Overview

IdentityMatchResponse defines the response schema for ‘/identity/match`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(accounts:, item:, request_id:, additional_properties: nil) ⇒ IdentityMatchResponse

Returns a new instance of IdentityMatchResponse.



45
46
47
48
49
50
51
52
53
# File 'lib/the_plaid_api/models/identity_match_response.rb', line 45

def initialize(accounts:, item:, request_id:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @accounts = accounts
  @item = item
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#accountsArray[AccountIdentityMatchScore]

The accounts for which Identity match has been requested

Returns:



14
15
16
# File 'lib/the_plaid_api/models/identity_match_response.rb', line 14

def accounts
  @accounts
end

#itemItem

Metadata about the Item.

Returns:



18
19
20
# File 'lib/the_plaid_api/models/identity_match_response.rb', line 18

def item
  @item
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


24
25
26
# File 'lib/the_plaid_api/models/identity_match_response.rb', line 24

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/the_plaid_api/models/identity_match_response.rb', line 56

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  accounts = nil
  unless hash['accounts'].nil?
    accounts = []
    hash['accounts'].each do |structure|
      accounts << (AccountIdentityMatchScore.from_hash(structure) if structure)
    end
  end

  accounts = nil unless hash.key?('accounts')
  item = Item.from_hash(hash['item']) if hash['item']
  request_id = hash.key?('request_id') ? hash['request_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  IdentityMatchResponse.new(accounts: accounts,
                            item: item,
                            request_id: request_id,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
# File 'lib/the_plaid_api/models/identity_match_response.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['accounts'] = 'accounts'
  @_hash['item'] = 'item'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
# File 'lib/the_plaid_api/models/identity_match_response.rb', line 41

def self.nullables
  []
end

.optionalsObject

An array for optional fields



36
37
38
# File 'lib/the_plaid_api/models/identity_match_response.rb', line 36

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



95
96
97
98
99
# File 'lib/the_plaid_api/models/identity_match_response.rb', line 95

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} accounts: #{@accounts.inspect}, item: #{@item.inspect}, request_id:"\
  " #{@request_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



88
89
90
91
92
# File 'lib/the_plaid_api/models/identity_match_response.rb', line 88

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} accounts: #{@accounts}, item: #{@item}, request_id: #{@request_id},"\
  " additional_properties: #{@additional_properties}>"
end