Class: ThePlaidApi::IdentityVerificationAutofillCreateResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/identity_verification_autofill_create_response.rb

Overview

Autofill represents unverified customer information. This needs to be confirmed by the customer before using.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(status:, user:, request_id:, additional_properties: nil) ⇒ IdentityVerificationAutofillCreateResponse

Returns a new instance of IdentityVerificationAutofillCreateResponse.



49
50
51
52
53
54
55
56
57
# File 'lib/the_plaid_api/models/identity_verification_autofill_create_response.rb', line 49

def initialize(status:, user:, request_id:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @status = status
  @user = user
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


26
27
28
# File 'lib/the_plaid_api/models/identity_verification_autofill_create_response.rb', line 26

def request_id
  @request_id
end

#statusIdentityVerificationAutofillStatus

A status enum indicating whether autofill succeeded or failed.



15
16
17
# File 'lib/the_plaid_api/models/identity_verification_autofill_create_response.rb', line 15

def status
  @status
end

#userIdentityVerificationAutofillUserData

User information that was autofilled. All this information should be confirmed by the user before using.



20
21
22
# File 'lib/the_plaid_api/models/identity_verification_autofill_create_response.rb', line 20

def user
  @user
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/the_plaid_api/models/identity_verification_autofill_create_response.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  status = hash.key?('status') ? hash['status'] : nil
  user = IdentityVerificationAutofillUserData.from_hash(hash['user']) if hash['user']
  request_id = hash.key?('request_id') ? hash['request_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  IdentityVerificationAutofillCreateResponse.new(status: status,
                                                 user: user,
                                                 request_id: request_id,
                                                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
# File 'lib/the_plaid_api/models/identity_verification_autofill_create_response.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['status'] = 'status'
  @_hash['user'] = 'user'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
46
47
# File 'lib/the_plaid_api/models/identity_verification_autofill_create_response.rb', line 43

def self.nullables
  %w[
    user
  ]
end

.optionalsObject

An array for optional fields



38
39
40
# File 'lib/the_plaid_api/models/identity_verification_autofill_create_response.rb', line 38

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
# File 'lib/the_plaid_api/models/identity_verification_autofill_create_response.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status.inspect}, user: #{@user.inspect}, request_id:"\
  " #{@request_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
# File 'lib/the_plaid_api/models/identity_verification_autofill_create_response.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status}, user: #{@user}, request_id: #{@request_id},"\
  " additional_properties: #{@additional_properties}>"
end