Class: ThePlaidApi::IdentityVerificationRequestUserName

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/identity_verification_request_user_name.rb

Overview

You can use this field to pre-populate the user’s legal name; if it is provided here, they will not be prompted to enter their name in the identity verification attempt.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(given_name:, family_name:, additional_properties: nil) ⇒ IdentityVerificationRequestUserName

Returns a new instance of IdentityVerificationRequestUserName.



42
43
44
45
46
47
48
49
# File 'lib/the_plaid_api/models/identity_verification_request_user_name.rb', line 42

def initialize(given_name:, family_name:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @given_name = given_name
  @family_name = family_name
  @additional_properties = additional_properties
end

Instance Attribute Details

#family_nameString

A string with at least one non-whitespace character, with a max length of 100 characters.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/identity_verification_request_user_name.rb', line 22

def family_name
  @family_name
end

#given_nameString

A string with at least one non-whitespace character, with a max length of 100 characters.

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/identity_verification_request_user_name.rb', line 17

def given_name
  @given_name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/the_plaid_api/models/identity_verification_request_user_name.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  given_name = hash.key?('given_name') ? hash['given_name'] : nil
  family_name = hash.key?('family_name') ? hash['family_name'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  IdentityVerificationRequestUserName.new(given_name: given_name,
                                          family_name: family_name,
                                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
# File 'lib/the_plaid_api/models/identity_verification_request_user_name.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['given_name'] = 'given_name'
  @_hash['family_name'] = 'family_name'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/the_plaid_api/models/identity_verification_request_user_name.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



33
34
35
# File 'lib/the_plaid_api/models/identity_verification_request_user_name.rb', line 33

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/the_plaid_api/models/identity_verification_request_user_name.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} given_name: #{@given_name.inspect}, family_name: #{@family_name.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/the_plaid_api/models/identity_verification_request_user_name.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} given_name: #{@given_name}, family_name: #{@family_name},"\
  " additional_properties: #{@additional_properties}>"
end