Class: ThePlaidApi::IdentityVerificationResponseUserName
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::IdentityVerificationResponseUserName
- Defined in:
- lib/the_plaid_api/models/identity_verification_response_user_name.rb
Overview
The full name provided by the user. If the user has not submitted their name, this field will be null. Otherwise, both fields are guaranteed to be filled.
Instance Attribute Summary collapse
-
#family_name ⇒ String
A string with at least one non-whitespace character, with a max length of 100 characters.
-
#given_name ⇒ String
A string with at least one non-whitespace character, with a max length of 100 characters.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(given_name:, family_name:, additional_properties: nil) ⇒ IdentityVerificationResponseUserName
constructor
A new instance of IdentityVerificationResponseUserName.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(given_name:, family_name:, additional_properties: nil) ⇒ IdentityVerificationResponseUserName
Returns a new instance of IdentityVerificationResponseUserName.
42 43 44 45 46 47 48 49 |
# File 'lib/the_plaid_api/models/identity_verification_response_user_name.rb', line 42 def initialize(given_name:, family_name:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @given_name = given_name @family_name = family_name @additional_properties = additional_properties end |
Instance Attribute Details
#family_name ⇒ String
A string with at least one non-whitespace character, with a max length of 100 characters.
22 23 24 |
# File 'lib/the_plaid_api/models/identity_verification_response_user_name.rb', line 22 def family_name @family_name end |
#given_name ⇒ String
A string with at least one non-whitespace character, with a max length of 100 characters.
17 18 19 |
# File 'lib/the_plaid_api/models/identity_verification_response_user_name.rb', line 17 def given_name @given_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/the_plaid_api/models/identity_verification_response_user_name.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. given_name = hash.key?('given_name') ? hash['given_name'] : nil family_name = hash.key?('family_name') ? hash['family_name'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. IdentityVerificationResponseUserName.new(given_name: given_name, family_name: family_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 |
# File 'lib/the_plaid_api/models/identity_verification_response_user_name.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['given_name'] = 'given_name' @_hash['family_name'] = 'family_name' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/the_plaid_api/models/identity_verification_response_user_name.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
33 34 35 |
# File 'lib/the_plaid_api/models/identity_verification_response_user_name.rb', line 33 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
80 81 82 83 84 |
# File 'lib/the_plaid_api/models/identity_verification_response_user_name.rb', line 80 def inspect class_name = self.class.name.split('::').last "<#{class_name} given_name: #{@given_name.inspect}, family_name: #{@family_name.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 77 |
# File 'lib/the_plaid_api/models/identity_verification_response_user_name.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} given_name: #{@given_name}, family_name: #{@family_name},"\ " additional_properties: #{@additional_properties}>" end |