Class: ThePlaidApi::IdentityVerificationRetryRequestStepsObject

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/identity_verification_retry_request_steps_object.rb

Overview

Instructions for the ‘custom` retry strategy specifying which steps should be required or skipped. Note: This field must be provided when the retry strategy is `custom` and must be omitted otherwise. Custom retries override settings in your Plaid Template. For example, if your Plaid Template has `verify_sms` disabled, a custom retry with `verify_sms` enabled will still require the step. The `selfie_check` step is currently not supported on the sandbox server. Sandbox requests will silently disable the `selfie_check` step when provided.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(verify_sms:, kyc_check:, documentary_verification:, selfie_check:, additional_properties: nil) ⇒ IdentityVerificationRetryRequestStepsObject

Returns a new instance of IdentityVerificationRetryRequestStepsObject.



62
63
64
65
66
67
68
69
70
71
72
# File 'lib/the_plaid_api/models/identity_verification_retry_request_steps_object.rb', line 62

def initialize(verify_sms:, kyc_check:, documentary_verification:,
               selfie_check:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @verify_sms = verify_sms
  @kyc_check = kyc_check
  @documentary_verification = documentary_verification
  @selfie_check = selfie_check
  @additional_properties = additional_properties
end

Instance Attribute Details

#documentary_verificationTrueClass | FalseClass

A boolean field specifying whether the new session should require or skip the ‘documentary_verification` step.

Returns:

  • (TrueClass | FalseClass)


32
33
34
# File 'lib/the_plaid_api/models/identity_verification_retry_request_steps_object.rb', line 32

def documentary_verification
  @documentary_verification
end

#kyc_checkTrueClass | FalseClass

A boolean field specifying whether the new session should require or skip the ‘kyc_check` (Data Source Verification) step.

Returns:

  • (TrueClass | FalseClass)


27
28
29
# File 'lib/the_plaid_api/models/identity_verification_retry_request_steps_object.rb', line 27

def kyc_check
  @kyc_check
end

#selfie_checkTrueClass | FalseClass

A boolean field specifying whether the new session should require or skip the ‘selfie_check` step. If a previous session has already passed the `selfie_check` step, the new selfie check will be a Selfie Reauthentication check, in which the selfie is tested for liveness and for consistency with the previous selfie.

Returns:

  • (TrueClass | FalseClass)


40
41
42
# File 'lib/the_plaid_api/models/identity_verification_retry_request_steps_object.rb', line 40

def selfie_check
  @selfie_check
end

#verify_smsTrueClass | FalseClass

A boolean field specifying whether the new session should require or skip the ‘verify_sms` step.

Returns:

  • (TrueClass | FalseClass)


22
23
24
# File 'lib/the_plaid_api/models/identity_verification_retry_request_steps_object.rb', line 22

def verify_sms
  @verify_sms
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/the_plaid_api/models/identity_verification_retry_request_steps_object.rb', line 75

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  verify_sms = hash.key?('verify_sms') ? hash['verify_sms'] : nil
  kyc_check = hash.key?('kyc_check') ? hash['kyc_check'] : nil
  documentary_verification =
    hash.key?('documentary_verification') ? hash['documentary_verification'] : nil
  selfie_check = hash.key?('selfie_check') ? hash['selfie_check'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  IdentityVerificationRetryRequestStepsObject.new(verify_sms: verify_sms,
                                                  kyc_check: kyc_check,
                                                  documentary_verification: documentary_verification,
                                                  selfie_check: selfie_check,
                                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



43
44
45
46
47
48
49
50
# File 'lib/the_plaid_api/models/identity_verification_retry_request_steps_object.rb', line 43

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['verify_sms'] = 'verify_sms'
  @_hash['kyc_check'] = 'kyc_check'
  @_hash['documentary_verification'] = 'documentary_verification'
  @_hash['selfie_check'] = 'selfie_check'
  @_hash
end

.nullablesObject

An array for nullable fields



58
59
60
# File 'lib/the_plaid_api/models/identity_verification_retry_request_steps_object.rb', line 58

def self.nullables
  []
end

.optionalsObject

An array for optional fields



53
54
55
# File 'lib/the_plaid_api/models/identity_verification_retry_request_steps_object.rb', line 53

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



109
110
111
112
113
114
# File 'lib/the_plaid_api/models/identity_verification_retry_request_steps_object.rb', line 109

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} verify_sms: #{@verify_sms.inspect}, kyc_check: #{@kyc_check.inspect},"\
  " documentary_verification: #{@documentary_verification.inspect}, selfie_check:"\
  " #{@selfie_check.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



101
102
103
104
105
106
# File 'lib/the_plaid_api/models/identity_verification_retry_request_steps_object.rb', line 101

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} verify_sms: #{@verify_sms}, kyc_check: #{@kyc_check},"\
  " documentary_verification: #{@documentary_verification}, selfie_check: #{@selfie_check},"\
  " additional_properties: #{@additional_properties}>"
end