Class: ThePlaidApi::IdentityVerificationTemplateReference
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::IdentityVerificationTemplateReference
- Defined in:
- lib/the_plaid_api/models/identity_verification_template_reference.rb
Overview
The resource ID and version number of the template configuring the behavior of a given Identity Verification.
Instance Attribute Summary collapse
-
#id ⇒ String
ID of the associated Identity Verification template.
-
#version ⇒ Integer
Version of the associated Identity Verification template.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id:, version:, additional_properties: nil) ⇒ IdentityVerificationTemplateReference
constructor
A new instance of IdentityVerificationTemplateReference.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id:, version:, additional_properties: nil) ⇒ IdentityVerificationTemplateReference
Returns a new instance of IdentityVerificationTemplateReference.
40 41 42 43 44 45 46 47 |
# File 'lib/the_plaid_api/models/identity_verification_template_reference.rb', line 40 def initialize(id:, version:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id @version = version @additional_properties = additional_properties end |
Instance Attribute Details
#id ⇒ String
ID of the associated Identity Verification template. Like all Plaid identifiers, this is case-sensitive.
16 17 18 |
# File 'lib/the_plaid_api/models/identity_verification_template_reference.rb', line 16 def id @id end |
#version ⇒ Integer
Version of the associated Identity Verification template.
20 21 22 |
# File 'lib/the_plaid_api/models/identity_verification_template_reference.rb', line 20 def version @version end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/the_plaid_api/models/identity_verification_template_reference.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil version = hash.key?('version') ? hash['version'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. IdentityVerificationTemplateReference.new(id: id, version: version, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/the_plaid_api/models/identity_verification_template_reference.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['version'] = 'version' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/the_plaid_api/models/identity_verification_template_reference.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 |
# File 'lib/the_plaid_api/models/identity_verification_template_reference.rb', line 31 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/the_plaid_api/models/identity_verification_template_reference.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, version: #{@version.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/the_plaid_api/models/identity_verification_template_reference.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, version: #{@version}, additional_properties:"\ " #{@additional_properties}>" end |