Class: ThePlaidApi::IdvProtectEvent

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/idv_protect_event.rb

Overview

Information about a Protect event including Trust Index score and fraud attributes.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(event_id:, timestamp:, trust_index:, fraud_attributes:, additional_properties: nil) ⇒ IdvProtectEvent

Returns a new instance of IdvProtectEvent.



55
56
57
58
59
60
61
62
63
64
65
# File 'lib/the_plaid_api/models/idv_protect_event.rb', line 55

def initialize(event_id:, timestamp:, trust_index:, fraud_attributes:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @event_id = event_id
  @timestamp = timestamp
  @trust_index = trust_index
  @fraud_attributes = fraud_attributes
  @additional_properties = additional_properties
end

Instance Attribute Details

#event_idString

The event ID.

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/idv_protect_event.rb', line 16

def event_id
  @event_id
end

#fraud_attributesObject

Event fraud attributes as an arbitrary set of key-value pairs.

Returns:

  • (Object)


30
31
32
# File 'lib/the_plaid_api/models/idv_protect_event.rb', line 30

def fraud_attributes
  @fraud_attributes
end

#timestampDateTime

The timestamp of the event, in [ISO 8601](wikipedia.org/wiki/ISO_8601) format, e.g. ā€˜ā€œ2017-09-14T14:42:19.350Zā€`

Returns:

  • (DateTime)


22
23
24
# File 'lib/the_plaid_api/models/idv_protect_event.rb', line 22

def timestamp
  @timestamp
end

#trust_indexTrustIndex

Represents a calculated Trust Index Score.

Returns:



26
27
28
# File 'lib/the_plaid_api/models/idv_protect_event.rb', line 26

def trust_index
  @trust_index
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/the_plaid_api/models/idv_protect_event.rb', line 68

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  event_id = hash.key?('event_id') ? hash['event_id'] : nil
  timestamp = if hash.key?('timestamp')
                (DateTimeHelper.from_rfc3339(hash['timestamp']) if hash['timestamp'])
              end
  trust_index = TrustIndex.from_hash(hash['trust_index']) if hash['trust_index']
  fraud_attributes =
    hash.key?('fraud_attributes') ? hash['fraud_attributes'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  IdvProtectEvent.new(event_id: event_id,
                      timestamp: timestamp,
                      trust_index: trust_index,
                      fraud_attributes: fraud_attributes,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
# File 'lib/the_plaid_api/models/idv_protect_event.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['event_id'] = 'event_id'
  @_hash['timestamp'] = 'timestamp'
  @_hash['trust_index'] = 'trust_index'
  @_hash['fraud_attributes'] = 'fraud_attributes'
  @_hash
end

.nullablesObject

An array for nullable fields



48
49
50
51
52
53
# File 'lib/the_plaid_api/models/idv_protect_event.rb', line 48

def self.nullables
  %w[
    trust_index
    fraud_attributes
  ]
end

.optionalsObject

An array for optional fields



43
44
45
# File 'lib/the_plaid_api/models/idv_protect_event.rb', line 43

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



108
109
110
111
112
113
# File 'lib/the_plaid_api/models/idv_protect_event.rb', line 108

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} event_id: #{@event_id.inspect}, timestamp: #{@timestamp.inspect},"\
  " trust_index: #{@trust_index.inspect}, fraud_attributes: #{@fraud_attributes.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_custom_timestampObject



95
96
97
# File 'lib/the_plaid_api/models/idv_protect_event.rb', line 95

def to_custom_timestamp
  DateTimeHelper.to_rfc3339(timestamp)
end

#to_sObject

Provides a human-readable string representation of the object.



100
101
102
103
104
105
# File 'lib/the_plaid_api/models/idv_protect_event.rb', line 100

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} event_id: #{@event_id}, timestamp: #{@timestamp}, trust_index:"\
  " #{@trust_index}, fraud_attributes: #{@fraud_attributes}, additional_properties:"\
  " #{@additional_properties}>"
end