Class: ThePlaidApi::ImageQualityDetails
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ImageQualityDetails
- Defined in:
- lib/the_plaid_api/models/image_quality_details.rb
Overview
Details about the image quality of the document.
Instance Attribute Summary collapse
-
#blur_check ⇒ ImageQualityOutcome
The outcome of the image quality check.
-
#dimensions_check ⇒ ImageQualityOutcome
The outcome of the image quality check.
-
#glare_check ⇒ ImageQualityOutcome
The outcome of the image quality check.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(glare_check:, dimensions_check:, blur_check:, additional_properties: nil) ⇒ ImageQualityDetails
constructor
A new instance of ImageQualityDetails.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(glare_check:, dimensions_check:, blur_check:, additional_properties: nil) ⇒ ImageQualityDetails
Returns a new instance of ImageQualityDetails.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/the_plaid_api/models/image_quality_details.rb', line 43 def initialize(glare_check:, dimensions_check:, blur_check:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @glare_check = glare_check @dimensions_check = dimensions_check @blur_check = blur_check @additional_properties = additional_properties end |
Instance Attribute Details
#blur_check ⇒ ImageQualityOutcome
The outcome of the image quality check.
22 23 24 |
# File 'lib/the_plaid_api/models/image_quality_details.rb', line 22 def blur_check @blur_check end |
#dimensions_check ⇒ ImageQualityOutcome
The outcome of the image quality check.
18 19 20 |
# File 'lib/the_plaid_api/models/image_quality_details.rb', line 18 def dimensions_check @dimensions_check end |
#glare_check ⇒ ImageQualityOutcome
The outcome of the image quality check.
14 15 16 |
# File 'lib/the_plaid_api/models/image_quality_details.rb', line 14 def glare_check @glare_check end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/the_plaid_api/models/image_quality_details.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. glare_check = hash.key?('glare_check') ? hash['glare_check'] : nil dimensions_check = hash.key?('dimensions_check') ? hash['dimensions_check'] : nil blur_check = hash.key?('blur_check') ? hash['blur_check'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ImageQualityDetails.new(glare_check: glare_check, dimensions_check: dimensions_check, blur_check: blur_check, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/the_plaid_api/models/image_quality_details.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['glare_check'] = 'glare_check' @_hash['dimensions_check'] = 'dimensions_check' @_hash['blur_check'] = 'blur_check' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/the_plaid_api/models/image_quality_details.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/the_plaid_api/models/image_quality_details.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 91 |
# File 'lib/the_plaid_api/models/image_quality_details.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} glare_check: #{@glare_check.inspect}, dimensions_check:"\ " #{@dimensions_check.inspect}, blur_check: #{@blur_check.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/the_plaid_api/models/image_quality_details.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} glare_check: #{@glare_check}, dimensions_check: #{@dimensions_check},"\ " blur_check: #{@blur_check}, additional_properties: #{@additional_properties}>" end |