Class: ThePlaidApi::IncomeVerificationCreateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/income_verification_create_request.rb

Overview

IncomeVerificationCreateRequest defines the request schema for ‘/income/verification/create`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook:, client_id: SKIP, secret: SKIP, precheck_id: SKIP, options: SKIP, additional_properties: nil) ⇒ IncomeVerificationCreateRequest

Returns a new instance of IncomeVerificationCreateRequest.



64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/the_plaid_api/models/income_verification_create_request.rb', line 64

def initialize(webhook:, client_id: SKIP, secret: SKIP, precheck_id: SKIP,
               options: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @webhook = webhook
  @precheck_id = precheck_id unless precheck_id == SKIP
  @options = options unless options == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/income_verification_create_request.rb', line 17

def client_id
  @client_id
end

#optionsIncomeVerificationCreateRequestOptions

Optional arguments for ‘/income/verification/create`



36
37
38
# File 'lib/the_plaid_api/models/income_verification_create_request.rb', line 36

def options
  @options
end

#precheck_idString

The ID of a precheck created with ‘/income/verification/precheck`. Will be used to improve conversion of the income verification flow.

Returns:

  • (String)


32
33
34
# File 'lib/the_plaid_api/models/income_verification_create_request.rb', line 32

def precheck_id
  @precheck_id
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/income_verification_create_request.rb', line 22

def secret
  @secret
end

#webhookString

The URL endpoint to which Plaid should send webhooks related to the progress of the income verification process.

Returns:

  • (String)


27
28
29
# File 'lib/the_plaid_api/models/income_verification_create_request.rb', line 27

def webhook
  @webhook
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/the_plaid_api/models/income_verification_create_request.rb', line 78

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook = hash.key?('webhook') ? hash['webhook'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  precheck_id = hash.key?('precheck_id') ? hash['precheck_id'] : SKIP
  options = IncomeVerificationCreateRequestOptions.from_hash(hash['options']) if
    hash['options']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  IncomeVerificationCreateRequest.new(webhook: webhook,
                                      client_id: client_id,
                                      secret: secret,
                                      precheck_id: precheck_id,
                                      options: options,
                                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



39
40
41
42
43
44
45
46
47
# File 'lib/the_plaid_api/models/income_verification_create_request.rb', line 39

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['webhook'] = 'webhook'
  @_hash['precheck_id'] = 'precheck_id'
  @_hash['options'] = 'options'
  @_hash
end

.nullablesObject

An array for nullable fields



60
61
62
# File 'lib/the_plaid_api/models/income_verification_create_request.rb', line 60

def self.nullables
  []
end

.optionalsObject

An array for optional fields



50
51
52
53
54
55
56
57
# File 'lib/the_plaid_api/models/income_verification_create_request.rb', line 50

def self.optionals
  %w[
    client_id
    secret
    precheck_id
    options
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



114
115
116
117
118
119
# File 'lib/the_plaid_api/models/income_verification_create_request.rb', line 114

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, webhook:"\
  " #{@webhook.inspect}, precheck_id: #{@precheck_id.inspect}, options: #{@options.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



106
107
108
109
110
111
# File 'lib/the_plaid_api/models/income_verification_create_request.rb', line 106

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, webhook: #{@webhook},"\
  " precheck_id: #{@precheck_id}, options: #{@options}, additional_properties:"\
  " #{@additional_properties}>"
end