Class: ThePlaidApi::IncomeVerificationPrecheckResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/income_verification_precheck_response.rb

Overview

IncomeVerificationPrecheckResponse defines the response schema for ‘/income/verification/precheck`.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(precheck_id:, request_id:, confidence:, additional_properties: nil) ⇒ IncomeVerificationPrecheckResponse

Returns a new instance of IncomeVerificationPrecheckResponse.



55
56
57
58
59
60
61
62
63
64
# File 'lib/the_plaid_api/models/income_verification_precheck_response.rb', line 55

def initialize(precheck_id:, request_id:, confidence:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @precheck_id = precheck_id
  @request_id = request_id
  @confidence = confidence
  @additional_properties = additional_properties
end

Instance Attribute Details

#confidenceIncomeVerificationPrecheckConfidence

The confidence that Plaid can support the user in the digital income verification flow instead of requiring a manual paystub upload. One of the following: ‘“HIGH”`: It is very likely that this user can use the digital income verification flow. “`LOW`”: It is unlikely that this user can use the digital income verification flow. `“UNKNOWN”`: It was not possible to determine if the user is supportable with the information passed.



34
35
36
# File 'lib/the_plaid_api/models/income_verification_precheck_response.rb', line 34

def confidence
  @confidence
end

#precheck_idString

ID of the precheck. Provide this value when calling ‘/link/token/create` in order to optimize Link conversion.

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/income_verification_precheck_response.rb', line 16

def precheck_id
  @precheck_id
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/income_verification_precheck_response.rb', line 22

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/the_plaid_api/models/income_verification_precheck_response.rb', line 67

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  precheck_id = hash.key?('precheck_id') ? hash['precheck_id'] : nil
  request_id = hash.key?('request_id') ? hash['request_id'] : nil
  confidence = hash.key?('confidence') ? hash['confidence'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  IncomeVerificationPrecheckResponse.new(precheck_id: precheck_id,
                                         request_id: request_id,
                                         confidence: confidence,
                                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
# File 'lib/the_plaid_api/models/income_verification_precheck_response.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['precheck_id'] = 'precheck_id'
  @_hash['request_id'] = 'request_id'
  @_hash['confidence'] = 'confidence'
  @_hash
end

.nullablesObject

An array for nullable fields



51
52
53
# File 'lib/the_plaid_api/models/income_verification_precheck_response.rb', line 51

def self.nullables
  []
end

.optionalsObject

An array for optional fields



46
47
48
# File 'lib/the_plaid_api/models/income_verification_precheck_response.rb', line 46

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



97
98
99
100
101
# File 'lib/the_plaid_api/models/income_verification_precheck_response.rb', line 97

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} precheck_id: #{@precheck_id.inspect}, request_id: #{@request_id.inspect},"\
  " confidence: #{@confidence.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



90
91
92
93
94
# File 'lib/the_plaid_api/models/income_verification_precheck_response.rb', line 90

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} precheck_id: #{@precheck_id}, request_id: #{@request_id}, confidence:"\
  " #{@confidence}, additional_properties: #{@additional_properties}>"
end