Class: ThePlaidApi::IncomeVerificationRiskSignalsStatusWebhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::IncomeVerificationRiskSignalsStatusWebhook
- Defined in:
- lib/the_plaid_api/models/income_verification_risk_signals_status_webhook.rb
Overview
Fired when risk signals have been processed for documents uploaded via Document Income. It will typically take a minute or two for this webhook to fire after the end user has uploaded their documents in the Document Income flow. Once this webhook has fired, ‘/credit/payroll_income/risk_signals/get` may then be called to determine whether the documents were successfully processed and to retrieve risk data.
Instance Attribute Summary collapse
-
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from.
-
#item_id ⇒ String
The Item ID associated with the verification.
-
#risk_signals_status ⇒ String
‘RISK_SIGNALS_PROCESSING_COMPLETE`: The income verification fraud detection processing has completed.
-
#user_id ⇒ String
The Plaid ‘user_id` of the User associated with this webhook, warning, or error.
-
#webhook_code ⇒ String
‘INCOME_VERIFICATION_RISK_SIGNALS`.
-
#webhook_type ⇒ String
‘“INCOME”`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, item_id:, environment:, user_id: SKIP, risk_signals_status: SKIP, additional_properties: nil) ⇒ IncomeVerificationRiskSignalsStatusWebhook
constructor
A new instance of IncomeVerificationRiskSignalsStatusWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, item_id:, environment:, user_id: SKIP, risk_signals_status: SKIP, additional_properties: nil) ⇒ IncomeVerificationRiskSignalsStatusWebhook
Returns a new instance of IncomeVerificationRiskSignalsStatusWebhook.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/the_plaid_api/models/income_verification_risk_signals_status_webhook.rb', line 71 def initialize(webhook_type:, webhook_code:, item_id:, environment:, user_id: SKIP, risk_signals_status: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @item_id = item_id @user_id = user_id unless user_id == SKIP @risk_signals_status = risk_signals_status unless risk_signals_status == SKIP @environment = environment @additional_properties = additional_properties end |
Instance Attribute Details
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from
44 45 46 |
# File 'lib/the_plaid_api/models/income_verification_risk_signals_status_webhook.rb', line 44 def environment @environment end |
#item_id ⇒ String
The Item ID associated with the verification.
27 28 29 |
# File 'lib/the_plaid_api/models/income_verification_risk_signals_status_webhook.rb', line 27 def item_id @item_id end |
#risk_signals_status ⇒ String
‘RISK_SIGNALS_PROCESSING_COMPLETE`: The income verification fraud detection processing has completed. If the user uploaded multiple documents, this webhook will fire when all documents have finished processing. Call the `/credit/payroll_income/risk_signals/get` endpoint to get all risk signal data.
40 41 42 |
# File 'lib/the_plaid_api/models/income_verification_risk_signals_status_webhook.rb', line 40 def risk_signals_status @risk_signals_status end |
#user_id ⇒ String
The Plaid ‘user_id` of the User associated with this webhook, warning, or error.
32 33 34 |
# File 'lib/the_plaid_api/models/income_verification_risk_signals_status_webhook.rb', line 32 def user_id @user_id end |
#webhook_code ⇒ String
‘INCOME_VERIFICATION_RISK_SIGNALS`
23 24 25 |
# File 'lib/the_plaid_api/models/income_verification_risk_signals_status_webhook.rb', line 23 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘“INCOME”`
19 20 21 |
# File 'lib/the_plaid_api/models/income_verification_risk_signals_status_webhook.rb', line 19 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/the_plaid_api/models/income_verification_risk_signals_status_webhook.rb', line 87 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil item_id = hash.key?('item_id') ? hash['item_id'] : nil environment = hash.key?('environment') ? hash['environment'] : nil user_id = hash.key?('user_id') ? hash['user_id'] : SKIP risk_signals_status = hash.key?('risk_signals_status') ? hash['risk_signals_status'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. IncomeVerificationRiskSignalsStatusWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, item_id: item_id, environment: environment, user_id: user_id, risk_signals_status: risk_signals_status, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/the_plaid_api/models/income_verification_risk_signals_status_webhook.rb', line 47 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['item_id'] = 'item_id' @_hash['user_id'] = 'user_id' @_hash['risk_signals_status'] = 'risk_signals_status' @_hash['environment'] = 'environment' @_hash end |
.nullables ⇒ Object
An array for nullable fields
67 68 69 |
# File 'lib/the_plaid_api/models/income_verification_risk_signals_status_webhook.rb', line 67 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
59 60 61 62 63 64 |
# File 'lib/the_plaid_api/models/income_verification_risk_signals_status_webhook.rb', line 59 def self.optionals %w[ user_id risk_signals_status ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
125 126 127 128 129 130 131 |
# File 'lib/the_plaid_api/models/income_verification_risk_signals_status_webhook.rb', line 125 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, item_id: #{@item_id.inspect}, user_id: #{@user_id.inspect},"\ " risk_signals_status: #{@risk_signals_status.inspect}, environment:"\ " #{@environment.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
117 118 119 120 121 122 |
# File 'lib/the_plaid_api/models/income_verification_risk_signals_status_webhook.rb', line 117 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, item_id:"\ " #{@item_id}, user_id: #{@user_id}, risk_signals_status: #{@risk_signals_status},"\ " environment: #{@environment}, additional_properties: #{@additional_properties}>" end |