Class: ThePlaidApi::InitialUpdateWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/initial_update_webhook.rb

Overview

Fired when an Item’s initial transaction pull is completed. Once this webhook has been fired, transaction data for the most recent 30 days can be fetched for the Item. This webhook will also be fired if account selections for the Item are updated, with ‘new_transactions` set to the number of net new transactions pulled after the account selection update. This webhook is intended for use with `/transactions/get`; if you are using the newer `/transactions/sync` endpoint, this webhook will still be fired to maintain backwards compatibility, but it is recommended to listen for and respond to the `SYNC_UPDATES_AVAILABLE` webhook instead.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, new_transactions:, item_id:, environment:, error: SKIP, additional_properties: nil) ⇒ InitialUpdateWebhook

Returns a new instance of InitialUpdateWebhook.



70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/the_plaid_api/models/initial_update_webhook.rb', line 70

def initialize(webhook_type:, webhook_code:, new_transactions:, item_id:,
               environment:, error: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @error = error unless error == SKIP
  @new_transactions = new_transactions
  @item_id = item_id
  @environment = environment
  @additional_properties = additional_properties
end

Instance Attribute Details

#environmentWebhookEnvironmentValues

The Plaid environment the webhook was sent from



42
43
44
# File 'lib/the_plaid_api/models/initial_update_webhook.rb', line 42

def environment
  @environment
end

#errorString

The error code associated with the webhook.

Returns:

  • (String)


30
31
32
# File 'lib/the_plaid_api/models/initial_update_webhook.rb', line 30

def error
  @error
end

#item_idString

The ‘item_id` of the Item associated with this webhook, warning, or error

Returns:

  • (String)


38
39
40
# File 'lib/the_plaid_api/models/initial_update_webhook.rb', line 38

def item_id
  @item_id
end

#new_transactionsFloat

The number of new transactions available.

Returns:

  • (Float)


34
35
36
# File 'lib/the_plaid_api/models/initial_update_webhook.rb', line 34

def new_transactions
  @new_transactions
end

#webhook_codeString

‘INITIAL_UPDATE`

Returns:

  • (String)


26
27
28
# File 'lib/the_plaid_api/models/initial_update_webhook.rb', line 26

def webhook_code
  @webhook_code
end

#webhook_typeString

‘TRANSACTIONS`

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/initial_update_webhook.rb', line 22

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/the_plaid_api/models/initial_update_webhook.rb', line 85

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  new_transactions =
    hash.key?('new_transactions') ? hash['new_transactions'] : nil
  item_id = hash.key?('item_id') ? hash['item_id'] : nil
  environment = hash.key?('environment') ? hash['environment'] : nil
  error = hash.key?('error') ? hash['error'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  InitialUpdateWebhook.new(webhook_type: webhook_type,
                           webhook_code: webhook_code,
                           new_transactions: new_transactions,
                           item_id: item_id,
                           environment: environment,
                           error: error,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



45
46
47
48
49
50
51
52
53
54
# File 'lib/the_plaid_api/models/initial_update_webhook.rb', line 45

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['error'] = 'error'
  @_hash['new_transactions'] = 'new_transactions'
  @_hash['item_id'] = 'item_id'
  @_hash['environment'] = 'environment'
  @_hash
end

.nullablesObject

An array for nullable fields



64
65
66
67
68
# File 'lib/the_plaid_api/models/initial_update_webhook.rb', line 64

def self.nullables
  %w[
    error
  ]
end

.optionalsObject

An array for optional fields



57
58
59
60
61
# File 'lib/the_plaid_api/models/initial_update_webhook.rb', line 57

def self.optionals
  %w[
    error
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



123
124
125
126
127
128
129
# File 'lib/the_plaid_api/models/initial_update_webhook.rb', line 123

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, error: #{@error.inspect}, new_transactions:"\
  " #{@new_transactions.inspect}, item_id: #{@item_id.inspect}, environment:"\
  " #{@environment.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



115
116
117
118
119
120
# File 'lib/the_plaid_api/models/initial_update_webhook.rb', line 115

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, error:"\
  " #{@error}, new_transactions: #{@new_transactions}, item_id: #{@item_id}, environment:"\
  " #{@environment}, additional_properties: #{@additional_properties}>"
end