Class: ThePlaidApi::InitiatorFiAttribute

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/initiator_fi_attribute.rb

Overview

Initiator Fi Attribute

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name: SKIP, value: SKIP, additional_properties: nil) ⇒ InitiatorFiAttribute

Returns a new instance of InitiatorFiAttribute.



41
42
43
44
45
46
47
48
# File 'lib/the_plaid_api/models/initiator_fi_attribute.rb', line 41

def initialize(name: SKIP, value: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @name = name unless name == SKIP
  @value = value unless value == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#nameString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/the_plaid_api/models/initiator_fi_attribute.rb', line 14

def name
  @name
end

#valuePartyType

Identifies the type of a party

Returns:



18
19
20
# File 'lib/the_plaid_api/models/initiator_fi_attribute.rb', line 18

def value
  @value
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/the_plaid_api/models/initiator_fi_attribute.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : SKIP
  value = hash.key?('value') ? hash['value'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  InitiatorFiAttribute.new(name: name,
                           value: value,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/the_plaid_api/models/initiator_fi_attribute.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash['value'] = 'value'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/the_plaid_api/models/initiator_fi_attribute.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/the_plaid_api/models/initiator_fi_attribute.rb', line 29

def self.optionals
  %w[
    name
    value
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/the_plaid_api/models/initiator_fi_attribute.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, value: #{@value.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/the_plaid_api/models/initiator_fi_attribute.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, value: #{@value}, additional_properties:"\
  " #{@additional_properties}>"
end