Class: ThePlaidApi::InstitutionStatusAlertWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/institution_status_alert_webhook.rb

Overview

Fired when institution status meets the conditions configured in the developer dashboard.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, institution_id:, institution_overall_success_rate:, environment:, additional_properties: nil) ⇒ InstitutionStatusAlertWebhook

Returns a new instance of InstitutionStatusAlertWebhook.



56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/the_plaid_api/models/institution_status_alert_webhook.rb', line 56

def initialize(webhook_type:, webhook_code:, institution_id:,
               institution_overall_success_rate:, environment:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @institution_id = institution_id
  @institution_overall_success_rate = institution_overall_success_rate
  @environment = environment
  @additional_properties = additional_properties
end

Instance Attribute Details

#environmentWebhookEnvironmentValues

The Plaid environment the webhook was sent from



32
33
34
# File 'lib/the_plaid_api/models/institution_status_alert_webhook.rb', line 32

def environment
  @environment
end

#institution_idString

The ID of the associated institution.

Returns:

  • (String)


23
24
25
# File 'lib/the_plaid_api/models/institution_status_alert_webhook.rb', line 23

def institution_id
  @institution_id
end

#institution_overall_success_rateFloat

The global success rate of the institution, calculated based on item add health.

Returns:

  • (Float)


28
29
30
# File 'lib/the_plaid_api/models/institution_status_alert_webhook.rb', line 28

def institution_overall_success_rate
  @institution_overall_success_rate
end

#webhook_codeString

‘INSTITUTION_STATUS_ALERT_TRIGGERED`

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/institution_status_alert_webhook.rb', line 19

def webhook_code
  @webhook_code
end

#webhook_typeString

‘DASHBOARD_CONFIGURED_ALERT`

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/institution_status_alert_webhook.rb', line 15

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/the_plaid_api/models/institution_status_alert_webhook.rb', line 71

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  institution_id =
    hash.key?('institution_id') ? hash['institution_id'] : nil
  institution_overall_success_rate =
    hash.key?('institution_overall_success_rate') ? hash['institution_overall_success_rate'] : nil
  environment = hash.key?('environment') ? hash['environment'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  InstitutionStatusAlertWebhook.new(webhook_type: webhook_type,
                                    webhook_code: webhook_code,
                                    institution_id: institution_id,
                                    institution_overall_success_rate: institution_overall_success_rate,
                                    environment: environment,
                                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



35
36
37
38
39
40
41
42
43
44
# File 'lib/the_plaid_api/models/institution_status_alert_webhook.rb', line 35

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['institution_id'] = 'institution_id'
  @_hash['institution_overall_success_rate'] =
    'institution_overall_success_rate'
  @_hash['environment'] = 'environment'
  @_hash
end

.nullablesObject

An array for nullable fields



52
53
54
# File 'lib/the_plaid_api/models/institution_status_alert_webhook.rb', line 52

def self.nullables
  []
end

.optionalsObject

An array for optional fields



47
48
49
# File 'lib/the_plaid_api/models/institution_status_alert_webhook.rb', line 47

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



109
110
111
112
113
114
115
# File 'lib/the_plaid_api/models/institution_status_alert_webhook.rb', line 109

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, institution_id: #{@institution_id.inspect},"\
  " institution_overall_success_rate: #{@institution_overall_success_rate.inspect},"\
  " environment: #{@environment.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



100
101
102
103
104
105
106
# File 'lib/the_plaid_api/models/institution_status_alert_webhook.rb', line 100

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code},"\
  " institution_id: #{@institution_id}, institution_overall_success_rate:"\
  " #{@institution_overall_success_rate}, environment: #{@environment}, additional_properties:"\
  " #{@additional_properties}>"
end