Class: ThePlaidApi::InstitutionSupportedNetworks

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/institution_supported_networks.rb

Overview

Contains the RTP and RfP network and types supported by the linked Item’s institution.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(rtp:, rfp:, additional_properties: nil) ⇒ InstitutionSupportedNetworks

Returns a new instance of InstitutionSupportedNetworks.



39
40
41
42
43
44
45
46
# File 'lib/the_plaid_api/models/institution_supported_networks.rb', line 39

def initialize(rtp:, rfp:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @rtp = rtp
  @rfp = rfp
  @additional_properties = additional_properties
end

Instance Attribute Details

#rfpTransferCapabilitiesGetRfP

Contains the supported service types in RfP



19
20
21
# File 'lib/the_plaid_api/models/institution_supported_networks.rb', line 19

def rfp
  @rfp
end

#rtpTransferCapabilitiesGetRtp

Contains the supported service types in RTP



15
16
17
# File 'lib/the_plaid_api/models/institution_supported_networks.rb', line 15

def rtp
  @rtp
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/the_plaid_api/models/institution_supported_networks.rb', line 49

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  rtp = TransferCapabilitiesGetRtp.from_hash(hash['rtp']) if hash['rtp']
  rfp = TransferCapabilitiesGetRfP.from_hash(hash['rfp']) if hash['rfp']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  InstitutionSupportedNetworks.new(rtp: rtp,
                                   rfp: rfp,
                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/the_plaid_api/models/institution_supported_networks.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['rtp'] = 'rtp'
  @_hash['rfp'] = 'rfp'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
# File 'lib/the_plaid_api/models/institution_supported_networks.rb', line 35

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
# File 'lib/the_plaid_api/models/institution_supported_networks.rb', line 30

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



77
78
79
80
81
# File 'lib/the_plaid_api/models/institution_supported_networks.rb', line 77

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} rtp: #{@rtp.inspect}, rfp: #{@rfp.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



70
71
72
73
74
# File 'lib/the_plaid_api/models/institution_supported_networks.rb', line 70

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} rtp: #{@rtp}, rfp: #{@rfp}, additional_properties:"\
  " #{@additional_properties}>"
end