Class: ThePlaidApi::InstitutionsGetRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::InstitutionsGetRequest
- Defined in:
- lib/the_plaid_api/models/institutions_get_request.rb
Overview
InstitutionsGetRequest defines the request schema for ‘/institutions/get`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#count ⇒ Integer
The total number of Institutions to return.
-
#country_codes ⇒ Array[CountryCode]
Specify which country or countries to include institutions from, using the ISO-3166-1 alpha-2 country code standard.
-
#offset ⇒ Integer
The number of Institutions to skip.
-
#options ⇒ InstitutionsGetRequestOptions
An optional object to filter ‘/institutions/get` results.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(count:, offset:, country_codes:, client_id: SKIP, secret: SKIP, options: SKIP, additional_properties: nil) ⇒ InstitutionsGetRequest
constructor
A new instance of InstitutionsGetRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(count:, offset:, country_codes:, client_id: SKIP, secret: SKIP, options: SKIP, additional_properties: nil) ⇒ InstitutionsGetRequest
Returns a new instance of InstitutionsGetRequest.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/the_plaid_api/models/institutions_get_request.rb', line 69 def initialize(count:, offset:, country_codes:, client_id: SKIP, secret: SKIP, options: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @count = count @offset = offset @country_codes = country_codes @options = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/the_plaid_api/models/institutions_get_request.rb', line 16 def client_id @client_id end |
#count ⇒ Integer
The total number of Institutions to return.
25 26 27 |
# File 'lib/the_plaid_api/models/institutions_get_request.rb', line 25 def count @count end |
#country_codes ⇒ Array[CountryCode]
Specify which country or countries to include institutions from, using the ISO-3166-1 alpha-2 country code standard. In API versions 2019-05-29 and earlier, the ‘country_codes` parameter is an optional parameter within the `options` object and will default to `[US]` if it is not supplied.
37 38 39 |
# File 'lib/the_plaid_api/models/institutions_get_request.rb', line 37 def country_codes @country_codes end |
#offset ⇒ Integer
The number of Institutions to skip.
29 30 31 |
# File 'lib/the_plaid_api/models/institutions_get_request.rb', line 29 def offset @offset end |
#options ⇒ InstitutionsGetRequestOptions
An optional object to filter ‘/institutions/get` results.
41 42 43 |
# File 'lib/the_plaid_api/models/institutions_get_request.rb', line 41 def @options end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
21 22 23 |
# File 'lib/the_plaid_api/models/institutions_get_request.rb', line 21 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/the_plaid_api/models/institutions_get_request.rb', line 84 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. count = hash.key?('count') ? hash['count'] : nil offset = hash.key?('offset') ? hash['offset'] : nil country_codes = hash.key?('country_codes') ? hash['country_codes'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP = InstitutionsGetRequestOptions.from_hash(hash['options']) if hash['options'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InstitutionsGetRequest.new(count: count, offset: offset, country_codes: country_codes, client_id: client_id, secret: secret, options: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
44 45 46 47 48 49 50 51 52 53 |
# File 'lib/the_plaid_api/models/institutions_get_request.rb', line 44 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['count'] = 'count' @_hash['offset'] = 'offset' @_hash['country_codes'] = 'country_codes' @_hash['options'] = 'options' @_hash end |
.nullables ⇒ Object
An array for nullable fields
65 66 67 |
# File 'lib/the_plaid_api/models/institutions_get_request.rb', line 65 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
56 57 58 59 60 61 62 |
# File 'lib/the_plaid_api/models/institutions_get_request.rb', line 56 def self.optionals %w[ client_id secret options ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
121 122 123 124 125 126 |
# File 'lib/the_plaid_api/models/institutions_get_request.rb', line 121 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, count:"\ " #{@count.inspect}, offset: #{@offset.inspect}, country_codes: #{@country_codes.inspect},"\ " options: #{@options.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
113 114 115 116 117 118 |
# File 'lib/the_plaid_api/models/institutions_get_request.rb', line 113 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, count: #{@count}, offset:"\ " #{@offset}, country_codes: #{@country_codes}, options: #{@options}, additional_properties:"\ " #{@additional_properties}>" end |