Class: ThePlaidApi::InstitutionsSearchResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/institutions_search_response.rb

Overview

InstitutionsSearchResponse defines the response schema for ‘/institutions/search`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(institutions:, request_id:, additional_properties: nil) ⇒ InstitutionsSearchResponse

Returns a new instance of InstitutionsSearchResponse.



41
42
43
44
45
46
47
48
# File 'lib/the_plaid_api/models/institutions_search_response.rb', line 41

def initialize(institutions:, request_id:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @institutions = institutions
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#institutionsArray[Institution]

An array of institutions matching the search criteria

Returns:



15
16
17
# File 'lib/the_plaid_api/models/institutions_search_response.rb', line 15

def institutions
  @institutions
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/institutions_search_response.rb', line 21

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/the_plaid_api/models/institutions_search_response.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  institutions = nil
  unless hash['institutions'].nil?
    institutions = []
    hash['institutions'].each do |structure|
      institutions << (Institution.from_hash(structure) if structure)
    end
  end

  institutions = nil unless hash.key?('institutions')
  request_id = hash.key?('request_id') ? hash['request_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  InstitutionsSearchResponse.new(institutions: institutions,
                                 request_id: request_id,
                                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
29
# File 'lib/the_plaid_api/models/institutions_search_response.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['institutions'] = 'institutions'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/the_plaid_api/models/institutions_search_response.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



32
33
34
# File 'lib/the_plaid_api/models/institutions_search_response.rb', line 32

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



88
89
90
91
92
# File 'lib/the_plaid_api/models/institutions_search_response.rb', line 88

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} institutions: #{@institutions.inspect}, request_id: #{@request_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



81
82
83
84
85
# File 'lib/the_plaid_api/models/institutions_search_response.rb', line 81

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} institutions: #{@institutions}, request_id: #{@request_id},"\
  " additional_properties: #{@additional_properties}>"
end