Class: ThePlaidApi::InvestmentsAuth401KFeeDetails

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/investments_auth401_k_fee_details.rb

Overview

Object containing information on account fee transactions for the 401k account.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_fee_count_12m:, account_fee_amount_12m:, additional_properties: nil) ⇒ InvestmentsAuth401KFeeDetails

Returns a new instance of InvestmentsAuth401KFeeDetails.



40
41
42
43
44
45
46
47
48
# File 'lib/the_plaid_api/models/investments_auth401_k_fee_details.rb', line 40

def initialize(account_fee_count_12m:, account_fee_amount_12m:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_fee_count_12m = 
  @account_fee_amount_12m = 
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_fee_amount_12mFloat

Sum of account fee transactions on this account, for the past 12 months.

Returns:

  • (Float)


20
21
22
# File 'lib/the_plaid_api/models/investments_auth401_k_fee_details.rb', line 20

def 
  @account_fee_amount_12m
end

#account_fee_count_12mInteger

Number of account fee transactions on this account, for the past 12 months.

Returns:

  • (Integer)


16
17
18
# File 'lib/the_plaid_api/models/investments_auth401_k_fee_details.rb', line 16

def 
  @account_fee_count_12m
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/the_plaid_api/models/investments_auth401_k_fee_details.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   =
    hash.key?('account_fee_count_12m') ? hash['account_fee_count_12m'] : nil
   =
    hash.key?('account_fee_amount_12m') ? hash['account_fee_amount_12m'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  InvestmentsAuth401KFeeDetails.new(account_fee_count_12m: ,
                                    account_fee_amount_12m: ,
                                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/the_plaid_api/models/investments_auth401_k_fee_details.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_fee_count_12m'] = 'account_fee_count_12m'
  @_hash['account_fee_amount_12m'] = 'account_fee_amount_12m'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
# File 'lib/the_plaid_api/models/investments_auth401_k_fee_details.rb', line 36

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
# File 'lib/the_plaid_api/models/investments_auth401_k_fee_details.rb', line 31

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



81
82
83
84
85
86
# File 'lib/the_plaid_api/models/investments_auth401_k_fee_details.rb', line 81

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_fee_count_12m: #{@account_fee_count_12m.inspect},"\
  " account_fee_amount_12m: #{@account_fee_amount_12m.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



74
75
76
77
78
# File 'lib/the_plaid_api/models/investments_auth401_k_fee_details.rb', line 74

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_fee_count_12m: #{@account_fee_count_12m}, account_fee_amount_12m:"\
  " #{@account_fee_amount_12m}, additional_properties: #{@additional_properties}>"
end