Class: ThePlaidApi::InvestmentsHistoricalUpdateWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/investments_historical_update_webhook.rb

Overview

Fired after an asynchronous extraction on an investments account.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, item_id:, new_investments_transactions:, cancelled_investments_transactions:, environment:, user_id: SKIP, error: SKIP, additional_properties: nil) ⇒ InvestmentsHistoricalUpdateWebhook

Returns a new instance of InvestmentsHistoricalUpdateWebhook.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/the_plaid_api/models/investments_historical_update_webhook.rb', line 85

def initialize(webhook_type:, webhook_code:, item_id:,
               new_investments_transactions:,
               cancelled_investments_transactions:, environment:,
               user_id: SKIP, error: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @item_id = item_id
  @user_id = user_id unless user_id == SKIP
  @error = error unless error == SKIP
  @new_investments_transactions = new_investments_transactions
  @cancelled_investments_transactions = cancelled_investments_transactions
  @environment = environment
  @additional_properties = additional_properties
end

Instance Attribute Details

#cancelled_investments_transactionsFloat

The number of canceled transactions reported since the last time this webhook was fired.

Returns:

  • (Float)


49
50
51
# File 'lib/the_plaid_api/models/investments_historical_update_webhook.rb', line 49

def cancelled_investments_transactions
  @cancelled_investments_transactions
end

#environmentWebhookEnvironmentValues

The Plaid environment the webhook was sent from



53
54
55
# File 'lib/the_plaid_api/models/investments_historical_update_webhook.rb', line 53

def environment
  @environment
end

#errorError

Errors are identified by ‘error_code` and categorized by `error_type`. Use these in preference to HTTP status codes to identify and handle specific errors. HTTP status codes are set and provide the broadest categorization of errors: 4xx codes are for developer- or user-related errors, and 5xx codes are for Plaid-related errors, and the status will be 2xx in non-error cases. An Item with a non-`null` error object will only be part of an API response when calling `/item/get` to view Item status. Otherwise, error fields will be `null` if no error has occurred; if an error has occurred, an error code will be returned instead.

Returns:



39
40
41
# File 'lib/the_plaid_api/models/investments_historical_update_webhook.rb', line 39

def error
  @error
end

#item_idString

The ‘item_id` of the Item associated with this webhook, warning, or error

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/investments_historical_update_webhook.rb', line 22

def item_id
  @item_id
end

#new_investments_transactionsFloat

The number of new transactions reported since the last time this webhook was fired.

Returns:

  • (Float)


44
45
46
# File 'lib/the_plaid_api/models/investments_historical_update_webhook.rb', line 44

def new_investments_transactions
  @new_investments_transactions
end

#user_idString

The Plaid ‘user_id` of the User associated with this webhook, warning, or error.

Returns:

  • (String)


27
28
29
# File 'lib/the_plaid_api/models/investments_historical_update_webhook.rb', line 27

def user_id
  @user_id
end

#webhook_codeString

‘HISTORICAL_UPDATE`

Returns:

  • (String)


18
19
20
# File 'lib/the_plaid_api/models/investments_historical_update_webhook.rb', line 18

def webhook_code
  @webhook_code
end

#webhook_typeString

‘INVESTMENTS_TRANSACTIONS`

Returns:

  • (String)


14
15
16
# File 'lib/the_plaid_api/models/investments_historical_update_webhook.rb', line 14

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/the_plaid_api/models/investments_historical_update_webhook.rb', line 104

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  item_id = hash.key?('item_id') ? hash['item_id'] : nil
  new_investments_transactions =
    hash.key?('new_investments_transactions') ? hash['new_investments_transactions'] : nil
  cancelled_investments_transactions =
    hash.key?('cancelled_investments_transactions') ? hash['cancelled_investments_transactions'] : nil
  environment = hash.key?('environment') ? hash['environment'] : nil
  user_id = hash.key?('user_id') ? hash['user_id'] : SKIP
  error = Error.from_hash(hash['error']) if hash['error']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  InvestmentsHistoricalUpdateWebhook.new(webhook_type: webhook_type,
                                         webhook_code: webhook_code,
                                         item_id: item_id,
                                         new_investments_transactions: new_investments_transactions,
                                         cancelled_investments_transactions: cancelled_investments_transactions,
                                         environment: environment,
                                         user_id: user_id,
                                         error: error,
                                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/the_plaid_api/models/investments_historical_update_webhook.rb', line 56

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['item_id'] = 'item_id'
  @_hash['user_id'] = 'user_id'
  @_hash['error'] = 'error'
  @_hash['new_investments_transactions'] = 'new_investments_transactions'
  @_hash['cancelled_investments_transactions'] =
    'cancelled_investments_transactions'
  @_hash['environment'] = 'environment'
  @_hash
end

.nullablesObject

An array for nullable fields



79
80
81
82
83
# File 'lib/the_plaid_api/models/investments_historical_update_webhook.rb', line 79

def self.nullables
  %w[
    error
  ]
end

.optionalsObject

An array for optional fields



71
72
73
74
75
76
# File 'lib/the_plaid_api/models/investments_historical_update_webhook.rb', line 71

def self.optionals
  %w[
    user_id
    error
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



149
150
151
152
153
154
155
156
157
# File 'lib/the_plaid_api/models/investments_historical_update_webhook.rb', line 149

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, item_id: #{@item_id.inspect}, user_id: #{@user_id.inspect},"\
  " error: #{@error.inspect}, new_investments_transactions:"\
  " #{@new_investments_transactions.inspect}, cancelled_investments_transactions:"\
  " #{@cancelled_investments_transactions.inspect}, environment: #{@environment.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



139
140
141
142
143
144
145
146
# File 'lib/the_plaid_api/models/investments_historical_update_webhook.rb', line 139

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, item_id:"\
  " #{@item_id}, user_id: #{@user_id}, error: #{@error}, new_investments_transactions:"\
  " #{@new_investments_transactions}, cancelled_investments_transactions:"\
  " #{@cancelled_investments_transactions}, environment: #{@environment},"\
  " additional_properties: #{@additional_properties}>"
end