Class: ThePlaidApi::IssuesSearchRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::IssuesSearchRequest
- Defined in:
- lib/the_plaid_api/models/issues_search_request.rb
Overview
IssuesSearchRequest defines the request schema for ‘/issues/search`.
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#item_id ⇒ String
A unique identifier for the Plaid Item.
-
#link_session_id ⇒ String
A unique identifier for the Link session.
-
#link_session_request_id ⇒ String
The ‘request_id` for the Link session that might have had an institution connection issue.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_id: SKIP, secret: SKIP, item_id: SKIP, link_session_id: SKIP, link_session_request_id: SKIP, additional_properties: nil) ⇒ IssuesSearchRequest
constructor
A new instance of IssuesSearchRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_id: SKIP, secret: SKIP, item_id: SKIP, link_session_id: SKIP, link_session_request_id: SKIP, additional_properties: nil) ⇒ IssuesSearchRequest
Returns a new instance of IssuesSearchRequest.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/the_plaid_api/models/issues_search_request.rb', line 63 def initialize(client_id: SKIP, secret: SKIP, item_id: SKIP, link_session_id: SKIP, link_session_request_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @item_id = item_id unless item_id == SKIP @link_session_id = link_session_id unless link_session_id == SKIP @link_session_request_id = link_session_request_id unless link_session_request_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/the_plaid_api/models/issues_search_request.rb', line 16 def client_id @client_id end |
#item_id ⇒ String
A unique identifier for the Plaid Item.
25 26 27 |
# File 'lib/the_plaid_api/models/issues_search_request.rb', line 25 def item_id @item_id end |
#link_session_id ⇒ String
A unique identifier for the Link session.
29 30 31 |
# File 'lib/the_plaid_api/models/issues_search_request.rb', line 29 def link_session_id @link_session_id end |
#link_session_request_id ⇒ String
The ‘request_id` for the Link session that might have had an institution connection issue.
34 35 36 |
# File 'lib/the_plaid_api/models/issues_search_request.rb', line 34 def link_session_request_id @link_session_request_id end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
21 22 23 |
# File 'lib/the_plaid_api/models/issues_search_request.rb', line 21 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/the_plaid_api/models/issues_search_request.rb', line 78 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP item_id = hash.key?('item_id') ? hash['item_id'] : SKIP link_session_id = hash.key?('link_session_id') ? hash['link_session_id'] : SKIP link_session_request_id = hash.key?('link_session_request_id') ? hash['link_session_request_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. IssuesSearchRequest.new(client_id: client_id, secret: secret, item_id: item_id, link_session_id: link_session_id, link_session_request_id: link_session_request_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 |
# File 'lib/the_plaid_api/models/issues_search_request.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['item_id'] = 'item_id' @_hash['link_session_id'] = 'link_session_id' @_hash['link_session_request_id'] = 'link_session_request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
59 60 61 |
# File 'lib/the_plaid_api/models/issues_search_request.rb', line 59 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
48 49 50 51 52 53 54 55 56 |
# File 'lib/the_plaid_api/models/issues_search_request.rb', line 48 def self.optionals %w[ client_id secret item_id link_session_id link_session_request_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
115 116 117 118 119 120 121 |
# File 'lib/the_plaid_api/models/issues_search_request.rb', line 115 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, item_id:"\ " #{@item_id.inspect}, link_session_id: #{@link_session_id.inspect},"\ " link_session_request_id: #{@link_session_request_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
107 108 109 110 111 112 |
# File 'lib/the_plaid_api/models/issues_search_request.rb', line 107 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, item_id: #{@item_id},"\ " link_session_id: #{@link_session_id}, link_session_request_id:"\ " #{@link_session_request_id}, additional_properties: #{@additional_properties}>" end |