Class: ThePlaidApi::IssuesSearchResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/issues_search_response.rb

Overview

IssuesSearchResponse defines the response schema for ‘/issues/search`.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(issues: SKIP, request_id: SKIP, additional_properties: nil) ⇒ IssuesSearchResponse

Returns a new instance of IssuesSearchResponse.



45
46
47
48
49
50
51
52
# File 'lib/the_plaid_api/models/issues_search_response.rb', line 45

def initialize(issues: SKIP, request_id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @issues = issues unless issues == SKIP
  @request_id = request_id unless request_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#issuesArray[Issue]

A list of issues affecting the Item, session, or request passed in, conforming to the Issues data model. An empty list indicates that no matching issues were found.

Returns:



16
17
18
# File 'lib/the_plaid_api/models/issues_search_response.rb', line 16

def issues
  @issues
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/issues_search_response.rb', line 22

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/the_plaid_api/models/issues_search_response.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  issues = nil
  unless hash['issues'].nil?
    issues = []
    hash['issues'].each do |structure|
      issues << (Issue.from_hash(structure) if structure)
    end
  end

  issues = SKIP unless hash.key?('issues')
  request_id = hash.key?('request_id') ? hash['request_id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  IssuesSearchResponse.new(issues: issues,
                           request_id: request_id,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
# File 'lib/the_plaid_api/models/issues_search_response.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['issues'] = 'issues'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
# File 'lib/the_plaid_api/models/issues_search_response.rb', line 41

def self.nullables
  []
end

.optionalsObject

An array for optional fields



33
34
35
36
37
38
# File 'lib/the_plaid_api/models/issues_search_response.rb', line 33

def self.optionals
  %w[
    issues
    request_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



92
93
94
95
96
# File 'lib/the_plaid_api/models/issues_search_response.rb', line 92

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} issues: #{@issues.inspect}, request_id: #{@request_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



85
86
87
88
89
# File 'lib/the_plaid_api/models/issues_search_response.rb', line 85

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} issues: #{@issues}, request_id: #{@request_id}, additional_properties:"\
  " #{@additional_properties}>"
end