Class: ThePlaidApi::ItemApplicationListUserAuth
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ItemApplicationListUserAuth
- Defined in:
- lib/the_plaid_api/models/item_application_list_user_auth.rb
Overview
User authentication parameters, for clients making a request without an ‘access_token`. This is only allowed for select clients and will not be supported in the future. Most clients should call /item/import to obtain an access token before making a request.
Instance Attribute Summary collapse
-
#fi_username_hash ⇒ String
Account username hashed by FI.
-
#user_id ⇒ String
Account username.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(user_id: SKIP, fi_username_hash: SKIP, additional_properties: nil) ⇒ ItemApplicationListUserAuth
constructor
A new instance of ItemApplicationListUserAuth.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(user_id: SKIP, fi_username_hash: SKIP, additional_properties: nil) ⇒ ItemApplicationListUserAuth
Returns a new instance of ItemApplicationListUserAuth.
47 48 49 50 51 52 53 54 55 |
# File 'lib/the_plaid_api/models/item_application_list_user_auth.rb', line 47 def initialize(user_id: SKIP, fi_username_hash: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @user_id = user_id unless user_id == SKIP @fi_username_hash = fi_username_hash unless fi_username_hash == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#fi_username_hash ⇒ String
Account username hashed by FI.
21 22 23 |
# File 'lib/the_plaid_api/models/item_application_list_user_auth.rb', line 21 def fi_username_hash @fi_username_hash end |
#user_id ⇒ String
Account username.
17 18 19 |
# File 'lib/the_plaid_api/models/item_application_list_user_auth.rb', line 17 def user_id @user_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/the_plaid_api/models/item_application_list_user_auth.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. user_id = hash.key?('user_id') ? hash['user_id'] : SKIP fi_username_hash = hash.key?('fi_username_hash') ? hash['fi_username_hash'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ItemApplicationListUserAuth.new(user_id: user_id, fi_username_hash: fi_username_hash, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/the_plaid_api/models/item_application_list_user_auth.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['user_id'] = 'user_id' @_hash['fi_username_hash'] = 'fi_username_hash' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 43 44 45 |
# File 'lib/the_plaid_api/models/item_application_list_user_auth.rb', line 40 def self.nullables %w[ user_id fi_username_hash ] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 35 36 37 |
# File 'lib/the_plaid_api/models/item_application_list_user_auth.rb', line 32 def self.optionals %w[ user_id fi_username_hash ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
87 88 89 90 91 |
# File 'lib/the_plaid_api/models/item_application_list_user_auth.rb', line 87 def inspect class_name = self.class.name.split('::').last "<#{class_name} user_id: #{@user_id.inspect}, fi_username_hash:"\ " #{@fi_username_hash.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
80 81 82 83 84 |
# File 'lib/the_plaid_api/models/item_application_list_user_auth.rb', line 80 def to_s class_name = self.class.name.split('::').last "<#{class_name} user_id: #{@user_id}, fi_username_hash: #{@fi_username_hash},"\ " additional_properties: #{@additional_properties}>" end |