Class: ThePlaidApi::ItemApplicationScopesUpdateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/item_application_scopes_update_request.rb

Overview

ItemApplicationScopesUpdateRequest defines the request schema for ‘/item/application/scopes/update`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(access_token:, application_id:, scopes:, context:, client_id: SKIP, secret: SKIP, state: SKIP, additional_properties: nil) ⇒ ItemApplicationScopesUpdateRequest

Returns a new instance of ItemApplicationScopesUpdateRequest.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/the_plaid_api/models/item_application_scopes_update_request.rb', line 78

def initialize(access_token:, application_id:, scopes:, context:,
               client_id: SKIP, secret: SKIP, state: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @access_token = access_token
  @application_id = application_id
  @scopes = scopes
  @state = state unless state == SKIP
  @context = context
  @additional_properties = additional_properties
end

Instance Attribute Details

#access_tokenString

The access token associated with the Item data is being requested for.

Returns:

  • (String)


26
27
28
# File 'lib/the_plaid_api/models/item_application_scopes_update_request.rb', line 26

def access_token
  @access_token
end

#application_idString

This field will map to the application ID that is returned from /item/application/list, or provided to the institution in an oauth redirect.

Returns:

  • (String)


32
33
34
# File 'lib/the_plaid_api/models/item_application_scopes_update_request.rb', line 32

def application_id
  @application_id
end

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/item_application_scopes_update_request.rb', line 17

def client_id
  @client_id
end

#contextScopesContext

An indicator for when scopes are being updated. When scopes are updated via enrollment (i.e. OAuth), the partner must send ‘ENROLLMENT`. When scopes are updated in a post-enrollment view, the partner must send `PORTAL`.

Returns:



49
50
51
# File 'lib/the_plaid_api/models/item_application_scopes_update_request.rb', line 49

def context
  @context
end

#scopesScopes

The scopes object

Returns:



36
37
38
# File 'lib/the_plaid_api/models/item_application_scopes_update_request.rb', line 36

def scopes
  @scopes
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/item_application_scopes_update_request.rb', line 22

def secret
  @secret
end

#stateString

When scopes are updated during enrollment, this field must be populated with the state sent to the partner in the OAuth Login URI. This field is required when the context is ‘ENROLLMENT`.

Returns:

  • (String)


42
43
44
# File 'lib/the_plaid_api/models/item_application_scopes_update_request.rb', line 42

def state
  @state
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/the_plaid_api/models/item_application_scopes_update_request.rb', line 95

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  access_token = hash.key?('access_token') ? hash['access_token'] : nil
  application_id =
    hash.key?('application_id') ? hash['application_id'] : nil
  scopes = Scopes.from_hash(hash['scopes']) if hash['scopes']
  context = hash.key?('context') ? hash['context'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  state = hash.key?('state') ? hash['state'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ItemApplicationScopesUpdateRequest.new(access_token: access_token,
                                         application_id: application_id,
                                         scopes: scopes,
                                         context: context,
                                         client_id: client_id,
                                         secret: secret,
                                         state: state,
                                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



52
53
54
55
56
57
58
59
60
61
62
# File 'lib/the_plaid_api/models/item_application_scopes_update_request.rb', line 52

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['access_token'] = 'access_token'
  @_hash['application_id'] = 'application_id'
  @_hash['scopes'] = 'scopes'
  @_hash['state'] = 'state'
  @_hash['context'] = 'context'
  @_hash
end

.nullablesObject

An array for nullable fields



74
75
76
# File 'lib/the_plaid_api/models/item_application_scopes_update_request.rb', line 74

def self.nullables
  []
end

.optionalsObject

An array for optional fields



65
66
67
68
69
70
71
# File 'lib/the_plaid_api/models/item_application_scopes_update_request.rb', line 65

def self.optionals
  %w[
    client_id
    secret
    state
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



135
136
137
138
139
140
141
# File 'lib/the_plaid_api/models/item_application_scopes_update_request.rb', line 135

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, access_token:"\
  " #{@access_token.inspect}, application_id: #{@application_id.inspect}, scopes:"\
  " #{@scopes.inspect}, state: #{@state.inspect}, context: #{@context.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



127
128
129
130
131
132
# File 'lib/the_plaid_api/models/item_application_scopes_update_request.rb', line 127

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, access_token:"\
  " #{@access_token}, application_id: #{@application_id}, scopes: #{@scopes}, state:"\
  " #{@state}, context: #{@context}, additional_properties: #{@additional_properties}>"
end