Class: ThePlaidApi::ItemGetResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/item_get_response.rb

Overview

ItemGetResponse defines the response schema for ‘/item/get` and `/item/webhook/update`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(item:, request_id:, status: SKIP, additional_properties: nil) ⇒ ItemGetResponse

Returns a new instance of ItemGetResponse.



51
52
53
54
55
56
57
58
59
# File 'lib/the_plaid_api/models/item_get_response.rb', line 51

def initialize(item:, request_id:, status: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @item = item
  @status = status unless status == SKIP
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#itemItemWithConsentFields

Metadata about the Item



15
16
17
# File 'lib/the_plaid_api/models/item_get_response.rb', line 15

def item
  @item
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


26
27
28
# File 'lib/the_plaid_api/models/item_get_response.rb', line 26

def request_id
  @request_id
end

#statusItemStatusNullable

Information about the last successful and failed transactions update for the Item.

Returns:



20
21
22
# File 'lib/the_plaid_api/models/item_get_response.rb', line 20

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/the_plaid_api/models/item_get_response.rb', line 62

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  item = ItemWithConsentFields.from_hash(hash['item']) if hash['item']
  request_id = hash.key?('request_id') ? hash['request_id'] : nil
  status = ItemStatusNullable.from_hash(hash['status']) if hash['status']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ItemGetResponse.new(item: item,
                      request_id: request_id,
                      status: status,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
# File 'lib/the_plaid_api/models/item_get_response.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['item'] = 'item'
  @_hash['status'] = 'status'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



45
46
47
48
49
# File 'lib/the_plaid_api/models/item_get_response.rb', line 45

def self.nullables
  %w[
    status
  ]
end

.optionalsObject

An array for optional fields



38
39
40
41
42
# File 'lib/the_plaid_api/models/item_get_response.rb', line 38

def self.optionals
  %w[
    status
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



92
93
94
95
96
# File 'lib/the_plaid_api/models/item_get_response.rb', line 92

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} item: #{@item.inspect}, status: #{@status.inspect}, request_id:"\
  " #{@request_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



85
86
87
88
89
# File 'lib/the_plaid_api/models/item_get_response.rb', line 85

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} item: #{@item}, status: #{@status}, request_id: #{@request_id},"\
  " additional_properties: #{@additional_properties}>"
end