Class: ThePlaidApi::ItemImportRequest
- Defined in:
- lib/the_plaid_api/models/item_import_request.rb
Overview
ItemImportRequest defines the request schema for ‘/item/import`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#institution_id ⇒ String
The Plaid Institution ID associated with the Item.
-
#options ⇒ ItemImportRequestOptions
An optional object to configure ‘/item/import` request.
-
#products ⇒ Array[Products]
Array of product strings.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#user_auth ⇒ ItemImportRequestUserAuth
Object of user ID and auth token pair, permitting Plaid to aggregate a user’s accounts.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(products:, user_auth:, client_id: SKIP, secret: SKIP, institution_id: SKIP, options: SKIP, additional_properties: nil) ⇒ ItemImportRequest
constructor
A new instance of ItemImportRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(products:, user_auth:, client_id: SKIP, secret: SKIP, institution_id: SKIP, options: SKIP, additional_properties: nil) ⇒ ItemImportRequest
Returns a new instance of ItemImportRequest.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/the_plaid_api/models/item_import_request.rb', line 67 def initialize(products:, user_auth:, client_id: SKIP, secret: SKIP, institution_id: SKIP, options: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @institution_id = institution_id unless institution_id == SKIP @products = products @user_auth = user_auth @options = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/the_plaid_api/models/item_import_request.rb', line 16 def client_id @client_id end |
#institution_id ⇒ String
The Plaid Institution ID associated with the Item.
25 26 27 |
# File 'lib/the_plaid_api/models/item_import_request.rb', line 25 def institution_id @institution_id end |
#options ⇒ ItemImportRequestOptions
An optional object to configure ‘/item/import` request.
38 39 40 |
# File 'lib/the_plaid_api/models/item_import_request.rb', line 38 def @options end |
#products ⇒ Array[Products]
Array of product strings
29 30 31 |
# File 'lib/the_plaid_api/models/item_import_request.rb', line 29 def products @products end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
21 22 23 |
# File 'lib/the_plaid_api/models/item_import_request.rb', line 21 def secret @secret end |
#user_auth ⇒ ItemImportRequestUserAuth
Object of user ID and auth token pair, permitting Plaid to aggregate a user’s accounts
34 35 36 |
# File 'lib/the_plaid_api/models/item_import_request.rb', line 34 def user_auth @user_auth end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/the_plaid_api/models/item_import_request.rb', line 83 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. products = hash.key?('products') ? hash['products'] : nil user_auth = ItemImportRequestUserAuth.from_hash(hash['user_auth']) if hash['user_auth'] client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP institution_id = hash.key?('institution_id') ? hash['institution_id'] : SKIP = ItemImportRequestOptions.from_hash(hash['options']) if hash['options'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ItemImportRequest.new(products: products, user_auth: user_auth, client_id: client_id, secret: secret, institution_id: institution_id, options: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
41 42 43 44 45 46 47 48 49 50 |
# File 'lib/the_plaid_api/models/item_import_request.rb', line 41 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['institution_id'] = 'institution_id' @_hash['products'] = 'products' @_hash['user_auth'] = 'user_auth' @_hash['options'] = 'options' @_hash end |
.nullables ⇒ Object
An array for nullable fields
63 64 65 |
# File 'lib/the_plaid_api/models/item_import_request.rb', line 63 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
53 54 55 56 57 58 59 60 |
# File 'lib/the_plaid_api/models/item_import_request.rb', line 53 def self.optionals %w[ client_id secret institution_id options ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
121 122 123 124 125 126 127 |
# File 'lib/the_plaid_api/models/item_import_request.rb', line 121 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\ " institution_id: #{@institution_id.inspect}, products: #{@products.inspect}, user_auth:"\ " #{@user_auth.inspect}, options: #{@options.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
113 114 115 116 117 118 |
# File 'lib/the_plaid_api/models/item_import_request.rb', line 113 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, institution_id:"\ " #{@institution_id}, products: #{@products}, user_auth: #{@user_auth}, options:"\ " #{@options}, additional_properties: #{@additional_properties}>" end |