Class: ThePlaidApi::ItemImportResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/item_import_response.rb

Overview

ItemImportResponse defines the response schema for ‘/item/import`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(access_token:, request_id:, additional_properties: nil) ⇒ ItemImportResponse

Returns a new instance of ItemImportResponse.



40
41
42
43
44
45
46
47
# File 'lib/the_plaid_api/models/item_import_response.rb', line 40

def initialize(access_token:, request_id:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @access_token = access_token
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#access_tokenString

The access token associated with the Item data is being requested for.

Returns:

  • (String)


14
15
16
# File 'lib/the_plaid_api/models/item_import_response.rb', line 14

def access_token
  @access_token
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


20
21
22
# File 'lib/the_plaid_api/models/item_import_response.rb', line 20

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/the_plaid_api/models/item_import_response.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  access_token = hash.key?('access_token') ? hash['access_token'] : nil
  request_id = hash.key?('request_id') ? hash['request_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ItemImportResponse.new(access_token: access_token,
                         request_id: request_id,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/the_plaid_api/models/item_import_response.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['access_token'] = 'access_token'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
# File 'lib/the_plaid_api/models/item_import_response.rb', line 36

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
# File 'lib/the_plaid_api/models/item_import_response.rb', line 31

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
82
# File 'lib/the_plaid_api/models/item_import_response.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} access_token: #{@access_token.inspect}, request_id: #{@request_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



71
72
73
74
75
# File 'lib/the_plaid_api/models/item_import_response.rb', line 71

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} access_token: #{@access_token}, request_id: #{@request_id},"\
  " additional_properties: #{@additional_properties}>"
end