Class: ThePlaidApi::ItemPublicTokenCreateResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/item_public_token_create_response.rb

Overview

ItemPublicTokenCreateResponse defines the response schema for ‘/item/public_token/create`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(public_token:, request_id:, expiration: SKIP, additional_properties: nil) ⇒ ItemPublicTokenCreateResponse

Returns a new instance of ItemPublicTokenCreateResponse.



51
52
53
54
55
56
57
58
59
60
# File 'lib/the_plaid_api/models/item_public_token_create_response.rb', line 51

def initialize(public_token:, request_id:, expiration: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @public_token = public_token
  @expiration = expiration unless expiration == SKIP
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#expirationDateTime

A ‘public_token` for the particular Item corresponding to the specified `access_token`

Returns:

  • (DateTime)


22
23
24
# File 'lib/the_plaid_api/models/item_public_token_create_response.rb', line 22

def expiration
  @expiration
end

#public_tokenString

A ‘public_token` for the particular Item corresponding to the specified `access_token`

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/item_public_token_create_response.rb', line 17

def public_token
  @public_token
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


28
29
30
# File 'lib/the_plaid_api/models/item_public_token_create_response.rb', line 28

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/the_plaid_api/models/item_public_token_create_response.rb', line 63

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  public_token = hash.key?('public_token') ? hash['public_token'] : nil
  request_id = hash.key?('request_id') ? hash['request_id'] : nil
  expiration = if hash.key?('expiration')
                 (DateTimeHelper.from_rfc3339(hash['expiration']) if hash['expiration'])
               else
                 SKIP
               end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ItemPublicTokenCreateResponse.new(public_token: public_token,
                                    request_id: request_id,
                                    expiration: expiration,
                                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



31
32
33
34
35
36
37
# File 'lib/the_plaid_api/models/item_public_token_create_response.rb', line 31

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['public_token'] = 'public_token'
  @_hash['expiration'] = 'expiration'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



47
48
49
# File 'lib/the_plaid_api/models/item_public_token_create_response.rb', line 47

def self.nullables
  []
end

.optionalsObject

An array for optional fields



40
41
42
43
44
# File 'lib/the_plaid_api/models/item_public_token_create_response.rb', line 40

def self.optionals
  %w[
    expiration
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



101
102
103
104
105
# File 'lib/the_plaid_api/models/item_public_token_create_response.rb', line 101

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} public_token: #{@public_token.inspect}, expiration: #{@expiration.inspect},"\
  " request_id: #{@request_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_custom_expirationObject



89
90
91
# File 'lib/the_plaid_api/models/item_public_token_create_response.rb', line 89

def to_custom_expiration
  DateTimeHelper.to_rfc3339(expiration)
end

#to_sObject

Provides a human-readable string representation of the object.



94
95
96
97
98
# File 'lib/the_plaid_api/models/item_public_token_create_response.rb', line 94

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} public_token: #{@public_token}, expiration: #{@expiration}, request_id:"\
  " #{@request_id}, additional_properties: #{@additional_properties}>"
end