Class: ThePlaidApi::ItemPublicTokenExchangeResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ItemPublicTokenExchangeResponse
- Defined in:
- lib/the_plaid_api/models/item_public_token_exchange_response.rb
Overview
ItemPublicTokenExchangeResponse defines the response schema for ‘/item/public_token/exchange`
Instance Attribute Summary collapse
-
#access_token ⇒ String
The access token associated with the Item data is being requested for.
-
#item_id ⇒ String
The ‘item_id` value of the Item associated with the returned `access_token`.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(access_token:, item_id:, request_id:, additional_properties: nil) ⇒ ItemPublicTokenExchangeResponse
constructor
A new instance of ItemPublicTokenExchangeResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(access_token:, item_id:, request_id:, additional_properties: nil) ⇒ ItemPublicTokenExchangeResponse
Returns a new instance of ItemPublicTokenExchangeResponse.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/the_plaid_api/models/item_public_token_exchange_response.rb', line 47 def initialize(access_token:, item_id:, request_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @access_token = access_token @item_id = item_id @request_id = request_id @additional_properties = additional_properties end |
Instance Attribute Details
#access_token ⇒ String
The access token associated with the Item data is being requested for.
15 16 17 |
# File 'lib/the_plaid_api/models/item_public_token_exchange_response.rb', line 15 def access_token @access_token end |
#item_id ⇒ String
The ‘item_id` value of the Item associated with the returned `access_token`
20 21 22 |
# File 'lib/the_plaid_api/models/item_public_token_exchange_response.rb', line 20 def item_id @item_id end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
26 27 28 |
# File 'lib/the_plaid_api/models/item_public_token_exchange_response.rb', line 26 def request_id @request_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/the_plaid_api/models/item_public_token_exchange_response.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. access_token = hash.key?('access_token') ? hash['access_token'] : nil item_id = hash.key?('item_id') ? hash['item_id'] : nil request_id = hash.key?('request_id') ? hash['request_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ItemPublicTokenExchangeResponse.new(access_token: access_token, item_id: item_id, request_id: request_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 |
# File 'lib/the_plaid_api/models/item_public_token_exchange_response.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['access_token'] = 'access_token' @_hash['item_id'] = 'item_id' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/the_plaid_api/models/item_public_token_exchange_response.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
38 39 40 |
# File 'lib/the_plaid_api/models/item_public_token_exchange_response.rb', line 38 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/the_plaid_api/models/item_public_token_exchange_response.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} access_token: #{@access_token.inspect}, item_id: #{@item_id.inspect},"\ " request_id: #{@request_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/the_plaid_api/models/item_public_token_exchange_response.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} access_token: #{@access_token}, item_id: #{@item_id}, request_id:"\ " #{@request_id}, additional_properties: #{@additional_properties}>" end |