Class: ThePlaidApi::ItemRemoveRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/item_remove_request.rb

Overview

ItemRemoveRequest defines the request schema for ‘/item/remove`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(access_token:, client_id: SKIP, secret: SKIP, reason_code: SKIP, reason_note: SKIP, additional_properties: nil) ⇒ ItemRemoveRequest

Returns a new instance of ItemRemoveRequest.



78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/the_plaid_api/models/item_remove_request.rb', line 78

def initialize(access_token:, client_id: SKIP, secret: SKIP,
               reason_code: SKIP, reason_note: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @access_token = access_token
  @reason_code = reason_code unless reason_code == SKIP
  @reason_note = reason_note unless reason_note == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#access_tokenString

The access token associated with the Item data is being requested for.

Returns:

  • (String)


25
26
27
# File 'lib/the_plaid_api/models/item_remove_request.rb', line 25

def access_token
  @access_token
end

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/item_remove_request.rb', line 16

def client_id
  @client_id
end

#reason_codeItemRemoveReasonCode

The reason for removing the item ‘FRAUD_FIRST_PARTY`: The end user who owns the connected bank account committed fraud `FRAUD_FALSE_IDENTITY`: The end user created the connection using false identity information or stolen credentials `FRAUD_ABUSE`: The end user is abusing the client’s service or platform through their connected account ‘FRAUD_OTHER`: Other fraud-related reasons involving the end user not covered by the specific fraud categories `CONNECTION_IS_NON_FUNCTIONAL`: The connection to the end user’s financial institution is broken and cannot be restored ‘OTHER`: Any other reason for removing the connection not covered by the above categories



41
42
43
# File 'lib/the_plaid_api/models/item_remove_request.rb', line 41

def reason_code
  @reason_code
end

#reason_noteString

Additional context or details about the reason for removing the item. Personally identifiable information, such as an email address or phone number, should not be included in the ‘reason_note`.

Returns:

  • (String)


47
48
49
# File 'lib/the_plaid_api/models/item_remove_request.rb', line 47

def reason_note
  @reason_note
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/item_remove_request.rb', line 21

def secret
  @secret
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/the_plaid_api/models/item_remove_request.rb', line 93

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  access_token = hash.key?('access_token') ? hash['access_token'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  reason_code = hash.key?('reason_code') ? hash['reason_code'] : SKIP
  reason_note = hash.key?('reason_note') ? hash['reason_note'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ItemRemoveRequest.new(access_token: access_token,
                        client_id: client_id,
                        secret: secret,
                        reason_code: reason_code,
                        reason_note: reason_note,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



50
51
52
53
54
55
56
57
58
# File 'lib/the_plaid_api/models/item_remove_request.rb', line 50

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['access_token'] = 'access_token'
  @_hash['reason_code'] = 'reason_code'
  @_hash['reason_note'] = 'reason_note'
  @_hash
end

.nullablesObject

An array for nullable fields



71
72
73
74
75
76
# File 'lib/the_plaid_api/models/item_remove_request.rb', line 71

def self.nullables
  %w[
    reason_code
    reason_note
  ]
end

.optionalsObject

An array for optional fields



61
62
63
64
65
66
67
68
# File 'lib/the_plaid_api/models/item_remove_request.rb', line 61

def self.optionals
  %w[
    client_id
    secret
    reason_code
    reason_note
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



128
129
130
131
132
133
# File 'lib/the_plaid_api/models/item_remove_request.rb', line 128

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, access_token:"\
  " #{@access_token.inspect}, reason_code: #{@reason_code.inspect}, reason_note:"\
  " #{@reason_note.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



120
121
122
123
124
125
# File 'lib/the_plaid_api/models/item_remove_request.rb', line 120

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, access_token:"\
  " #{@access_token}, reason_code: #{@reason_code}, reason_note: #{@reason_note},"\
  " additional_properties: #{@additional_properties}>"
end