Class: ThePlaidApi::ItemStatus

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/item_status.rb

Overview

An object with information about the status of the Item.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(investments: SKIP, transactions: SKIP, last_webhook: SKIP, additional_properties: nil) ⇒ ItemStatus

Returns a new instance of ItemStatus.



53
54
55
56
57
58
59
60
61
62
# File 'lib/the_plaid_api/models/item_status.rb', line 53

def initialize(investments: SKIP, transactions: SKIP, last_webhook: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @investments = investments unless investments == SKIP
  @transactions = transactions unless transactions == SKIP
  @last_webhook = last_webhook unless last_webhook == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#investmentsItemStatusInvestments

Information about the last successful and failed investments update for the Item.



15
16
17
# File 'lib/the_plaid_api/models/item_status.rb', line 15

def investments
  @investments
end

#last_webhookItemStatusLastWebhook

Information about the last webhook fired for the Item.



24
25
26
# File 'lib/the_plaid_api/models/item_status.rb', line 24

def last_webhook
  @last_webhook
end

#transactionsItemStatusTransactions

Information about the last successful and failed transactions update for the Item.



20
21
22
# File 'lib/the_plaid_api/models/item_status.rb', line 20

def transactions
  @transactions
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/the_plaid_api/models/item_status.rb', line 65

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  investments = ItemStatusInvestments.from_hash(hash['investments']) if hash['investments']
  transactions = ItemStatusTransactions.from_hash(hash['transactions']) if
    hash['transactions']
  last_webhook = ItemStatusLastWebhook.from_hash(hash['last_webhook']) if hash['last_webhook']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ItemStatus.new(investments: investments,
                 transactions: transactions,
                 last_webhook: last_webhook,
                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
# File 'lib/the_plaid_api/models/item_status.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['investments'] = 'investments'
  @_hash['transactions'] = 'transactions'
  @_hash['last_webhook'] = 'last_webhook'
  @_hash
end

.nullablesObject

An array for nullable fields



45
46
47
48
49
50
51
# File 'lib/the_plaid_api/models/item_status.rb', line 45

def self.nullables
  %w[
    investments
    transactions
    last_webhook
  ]
end

.optionalsObject

An array for optional fields



36
37
38
39
40
41
42
# File 'lib/the_plaid_api/models/item_status.rb', line 36

def self.optionals
  %w[
    investments
    transactions
    last_webhook
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



96
97
98
99
100
101
# File 'lib/the_plaid_api/models/item_status.rb', line 96

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} investments: #{@investments.inspect}, transactions:"\
  " #{@transactions.inspect}, last_webhook: #{@last_webhook.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



89
90
91
92
93
# File 'lib/the_plaid_api/models/item_status.rb', line 89

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} investments: #{@investments}, transactions: #{@transactions}, last_webhook:"\
  " #{@last_webhook}, additional_properties: #{@additional_properties}>"
end