Class: ThePlaidApi::ItemStatusLastWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/item_status_last_webhook.rb

Overview

Information about the last webhook fired for the Item.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(sent_at: SKIP, code_sent: SKIP, additional_properties: nil) ⇒ ItemStatusLastWebhook

Returns a new instance of ItemStatusLastWebhook.



45
46
47
48
49
50
51
52
# File 'lib/the_plaid_api/models/item_status_last_webhook.rb', line 45

def initialize(sent_at: SKIP, code_sent: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @sent_at = sent_at unless sent_at == SKIP
  @code_sent = code_sent unless code_sent == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#code_sentString

The last webhook code sent.

Returns:

  • (String)


20
21
22
# File 'lib/the_plaid_api/models/item_status_last_webhook.rb', line 20

def code_sent
  @code_sent
end

#sent_atDateTime

[ISO 8601](wikipedia.org/wiki/ISO_8601) timestamp of when the webhook was fired.

Returns:

  • (DateTime)


16
17
18
# File 'lib/the_plaid_api/models/item_status_last_webhook.rb', line 16

def sent_at
  @sent_at
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/the_plaid_api/models/item_status_last_webhook.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  sent_at = if hash.key?('sent_at')
              (DateTimeHelper.from_rfc3339(hash['sent_at']) if hash['sent_at'])
            else
              SKIP
            end
  code_sent = hash.key?('code_sent') ? hash['code_sent'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ItemStatusLastWebhook.new(sent_at: sent_at,
                            code_sent: code_sent,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/the_plaid_api/models/item_status_last_webhook.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['sent_at'] = 'sent_at'
  @_hash['code_sent'] = 'code_sent'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
42
43
# File 'lib/the_plaid_api/models/item_status_last_webhook.rb', line 39

def self.nullables
  %w[
    sent_at
  ]
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/the_plaid_api/models/item_status_last_webhook.rb', line 31

def self.optionals
  %w[
    sent_at
    code_sent
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



91
92
93
94
95
# File 'lib/the_plaid_api/models/item_status_last_webhook.rb', line 91

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} sent_at: #{@sent_at.inspect}, code_sent: #{@code_sent.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_custom_sent_atObject



79
80
81
# File 'lib/the_plaid_api/models/item_status_last_webhook.rb', line 79

def to_custom_sent_at
  DateTimeHelper.to_rfc3339(sent_at)
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
# File 'lib/the_plaid_api/models/item_status_last_webhook.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} sent_at: #{@sent_at}, code_sent: #{@code_sent}, additional_properties:"\
  " #{@additional_properties}>"
end