Class: ThePlaidApi::LatestScoredEvent

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/latest_scored_event.rb

Overview

The latest scored event for a user.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(event_id:, timestamp:, trust_index:, fraud_attributes:, event_type: SKIP, additional_properties: nil) ⇒ LatestScoredEvent

Returns a new instance of LatestScoredEvent.



61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/the_plaid_api/models/latest_scored_event.rb', line 61

def initialize(event_id:, timestamp:, trust_index:, fraud_attributes:,
               event_type: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @event_id = event_id
  @timestamp = timestamp
  @event_type = event_type unless event_type == SKIP
  @trust_index = trust_index
  @fraud_attributes = fraud_attributes
  @additional_properties = additional_properties
end

Instance Attribute Details

#event_idString

The event ID.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/latest_scored_event.rb', line 15

def event_id
  @event_id
end

#event_typeString

The type of event.

Returns:

  • (String)


25
26
27
# File 'lib/the_plaid_api/models/latest_scored_event.rb', line 25

def event_type
  @event_type
end

#fraud_attributesObject

Event fraud attributes as an arbitrary set of key-value pairs.

Returns:

  • (Object)


33
34
35
# File 'lib/the_plaid_api/models/latest_scored_event.rb', line 33

def fraud_attributes
  @fraud_attributes
end

#timestampDateTime

The timestamp of the event, in [ISO 8601](wikipedia.org/wiki/ISO_8601) format, e.g. ā€˜ā€œ2017-09-14T14:42:19.350Zā€`

Returns:

  • (DateTime)


21
22
23
# File 'lib/the_plaid_api/models/latest_scored_event.rb', line 21

def timestamp
  @timestamp
end

#trust_indexTrustIndex

Represents a calculated Trust Index Score.

Returns:



29
30
31
# File 'lib/the_plaid_api/models/latest_scored_event.rb', line 29

def trust_index
  @trust_index
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/the_plaid_api/models/latest_scored_event.rb', line 75

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  event_id = hash.key?('event_id') ? hash['event_id'] : nil
  timestamp = if hash.key?('timestamp')
                (DateTimeHelper.from_rfc3339(hash['timestamp']) if hash['timestamp'])
              end
  trust_index = TrustIndex.from_hash(hash['trust_index']) if hash['trust_index']
  fraud_attributes =
    hash.key?('fraud_attributes') ? hash['fraud_attributes'] : nil
  event_type = hash.key?('event_type') ? hash['event_type'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  LatestScoredEvent.new(event_id: event_id,
                        timestamp: timestamp,
                        trust_index: trust_index,
                        fraud_attributes: fraud_attributes,
                        event_type: event_type,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



36
37
38
39
40
41
42
43
44
# File 'lib/the_plaid_api/models/latest_scored_event.rb', line 36

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['event_id'] = 'event_id'
  @_hash['timestamp'] = 'timestamp'
  @_hash['event_type'] = 'event_type'
  @_hash['trust_index'] = 'trust_index'
  @_hash['fraud_attributes'] = 'fraud_attributes'
  @_hash
end

.nullablesObject

An array for nullable fields



54
55
56
57
58
59
# File 'lib/the_plaid_api/models/latest_scored_event.rb', line 54

def self.nullables
  %w[
    trust_index
    fraud_attributes
  ]
end

.optionalsObject

An array for optional fields



47
48
49
50
51
# File 'lib/the_plaid_api/models/latest_scored_event.rb', line 47

def self.optionals
  %w[
    event_type
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



117
118
119
120
121
122
123
# File 'lib/the_plaid_api/models/latest_scored_event.rb', line 117

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} event_id: #{@event_id.inspect}, timestamp: #{@timestamp.inspect},"\
  " event_type: #{@event_type.inspect}, trust_index: #{@trust_index.inspect},"\
  " fraud_attributes: #{@fraud_attributes.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_custom_timestampObject



104
105
106
# File 'lib/the_plaid_api/models/latest_scored_event.rb', line 104

def to_custom_timestamp
  DateTimeHelper.to_rfc3339(timestamp)
end

#to_sObject

Provides a human-readable string representation of the object.



109
110
111
112
113
114
# File 'lib/the_plaid_api/models/latest_scored_event.rb', line 109

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} event_id: #{@event_id}, timestamp: #{@timestamp}, event_type:"\
  " #{@event_type}, trust_index: #{@trust_index}, fraud_attributes: #{@fraud_attributes},"\
  " additional_properties: #{@additional_properties}>"
end