Class: ThePlaidApi::LiabilitiesDefaultUpdateWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/liabilities_default_update_webhook.rb

Overview

The webhook of type ‘LIABILITIES` and code `DEFAULT_UPDATE` will be fired when new or updated liabilities have been detected on a liabilities item.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, item_id:, error:, account_ids_with_new_liabilities:, account_ids_with_updated_liabilities:, environment:, user_id: SKIP, additional_properties: nil) ⇒ LiabilitiesDefaultUpdateWebhook

Returns a new instance of LiabilitiesDefaultUpdateWebhook.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/the_plaid_api/models/liabilities_default_update_webhook.rb', line 87

def initialize(webhook_type:, webhook_code:, item_id:, error:,
               account_ids_with_new_liabilities:,
               account_ids_with_updated_liabilities:, environment:,
               user_id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @item_id = item_id
  @user_id = user_id unless user_id == SKIP
  @error = error
  @account_ids_with_new_liabilities = 
  @account_ids_with_updated_liabilities = 
  @environment = environment
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_ids_with_new_liabilitiesArray[String]

An array of ‘account_id`’s for accounts that contain new liabilities.‘

Returns:

  • (Array[String])


44
45
46
# File 'lib/the_plaid_api/models/liabilities_default_update_webhook.rb', line 44

def 
  @account_ids_with_new_liabilities
end

#account_ids_with_updated_liabilitiesHash[String, Object]

An object with keys of ‘account_id`’s that are mapped to their respective liabilities fields that changed. Example: ‘{ “XMBvvyMGQ1UoLbKByoMqH3nXMj84ALSdE5B58”: [“past_amount_due”] }`

Returns:

  • (Hash[String, Object])


51
52
53
# File 'lib/the_plaid_api/models/liabilities_default_update_webhook.rb', line 51

def 
  @account_ids_with_updated_liabilities
end

#environmentWebhookEnvironmentValues

The Plaid environment the webhook was sent from



55
56
57
# File 'lib/the_plaid_api/models/liabilities_default_update_webhook.rb', line 55

def environment
  @environment
end

#errorError

Errors are identified by ‘error_code` and categorized by `error_type`. Use these in preference to HTTP status codes to identify and handle specific errors. HTTP status codes are set and provide the broadest categorization of errors: 4xx codes are for developer- or user-related errors, and 5xx codes are for Plaid-related errors, and the status will be 2xx in non-error cases. An Item with a non-`null` error object will only be part of an API response when calling `/item/get` to view Item status. Otherwise, error fields will be `null` if no error has occurred; if an error has occurred, an error code will be returned instead.

Returns:



40
41
42
# File 'lib/the_plaid_api/models/liabilities_default_update_webhook.rb', line 40

def error
  @error
end

#item_idString

The ‘item_id` of the Item associated with this webhook, warning, or error

Returns:

  • (String)


23
24
25
# File 'lib/the_plaid_api/models/liabilities_default_update_webhook.rb', line 23

def item_id
  @item_id
end

#user_idString

The Plaid ‘user_id` of the User associated with this webhook, warning, or error.

Returns:

  • (String)


28
29
30
# File 'lib/the_plaid_api/models/liabilities_default_update_webhook.rb', line 28

def user_id
  @user_id
end

#webhook_codeString

‘DEFAULT_UPDATE`

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/liabilities_default_update_webhook.rb', line 19

def webhook_code
  @webhook_code
end

#webhook_typeString

‘LIABILITIES`

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/liabilities_default_update_webhook.rb', line 15

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/the_plaid_api/models/liabilities_default_update_webhook.rb', line 106

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  item_id = hash.key?('item_id') ? hash['item_id'] : nil
  error = Error.from_hash(hash['error']) if hash['error']
   =
    hash.key?('account_ids_with_new_liabilities') ? hash['account_ids_with_new_liabilities'] : nil
   =
    hash.key?('account_ids_with_updated_liabilities') ? hash['account_ids_with_updated_liabilities'] : nil
  environment = hash.key?('environment') ? hash['environment'] : nil
  user_id = hash.key?('user_id') ? hash['user_id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  LiabilitiesDefaultUpdateWebhook.new(webhook_type: webhook_type,
                                      webhook_code: webhook_code,
                                      item_id: item_id,
                                      error: error,
                                      account_ids_with_new_liabilities: ,
                                      account_ids_with_updated_liabilities: ,
                                      environment: environment,
                                      user_id: user_id,
                                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/the_plaid_api/models/liabilities_default_update_webhook.rb', line 58

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['item_id'] = 'item_id'
  @_hash['user_id'] = 'user_id'
  @_hash['error'] = 'error'
  @_hash['account_ids_with_new_liabilities'] =
    'account_ids_with_new_liabilities'
  @_hash['account_ids_with_updated_liabilities'] =
    'account_ids_with_updated_liabilities'
  @_hash['environment'] = 'environment'
  @_hash
end

.nullablesObject

An array for nullable fields



81
82
83
84
85
# File 'lib/the_plaid_api/models/liabilities_default_update_webhook.rb', line 81

def self.nullables
  %w[
    error
  ]
end

.optionalsObject

An array for optional fields



74
75
76
77
78
# File 'lib/the_plaid_api/models/liabilities_default_update_webhook.rb', line 74

def self.optionals
  %w[
    user_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



151
152
153
154
155
156
157
158
159
# File 'lib/the_plaid_api/models/liabilities_default_update_webhook.rb', line 151

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, item_id: #{@item_id.inspect}, user_id: #{@user_id.inspect},"\
  " error: #{@error.inspect}, account_ids_with_new_liabilities:"\
  " #{@account_ids_with_new_liabilities.inspect}, account_ids_with_updated_liabilities:"\
  " #{@account_ids_with_updated_liabilities.inspect}, environment: #{@environment.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



141
142
143
144
145
146
147
148
# File 'lib/the_plaid_api/models/liabilities_default_update_webhook.rb', line 141

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, item_id:"\
  " #{@item_id}, user_id: #{@user_id}, error: #{@error}, account_ids_with_new_liabilities:"\
  " #{@account_ids_with_new_liabilities}, account_ids_with_updated_liabilities:"\
  " #{@account_ids_with_updated_liabilities}, environment: #{@environment},"\
  " additional_properties: #{@additional_properties}>"
end