Class: ThePlaidApi::LiabilitiesGetResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/liabilities_get_response.rb

Overview

LiabilitiesGetResponse defines the response schema for ‘/liabilities/get`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(accounts:, item:, liabilities:, request_id:, additional_properties: nil) ⇒ LiabilitiesGetResponse

Returns a new instance of LiabilitiesGetResponse.



50
51
52
53
54
55
56
57
58
59
60
# File 'lib/the_plaid_api/models/liabilities_get_response.rb', line 50

def initialize(accounts:, item:, liabilities:, request_id:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @accounts = accounts
  @item = item
  @liabilities = liabilities
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#accountsArray[Account]

An array of accounts associated with the Item

Returns:



14
15
16
# File 'lib/the_plaid_api/models/liabilities_get_response.rb', line 14

def accounts
  @accounts
end

#itemItem

Metadata about the Item.

Returns:



18
19
20
# File 'lib/the_plaid_api/models/liabilities_get_response.rb', line 18

def item
  @item
end

#liabilitiesLiabilitiesObject

An object containing liability accounts

Returns:



22
23
24
# File 'lib/the_plaid_api/models/liabilities_get_response.rb', line 22

def liabilities
  @liabilities
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


28
29
30
# File 'lib/the_plaid_api/models/liabilities_get_response.rb', line 28

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/the_plaid_api/models/liabilities_get_response.rb', line 63

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  accounts = nil
  unless hash['accounts'].nil?
    accounts = []
    hash['accounts'].each do |structure|
      accounts << (Account.from_hash(structure) if structure)
    end
  end

  accounts = nil unless hash.key?('accounts')
  item = Item.from_hash(hash['item']) if hash['item']
  liabilities = LiabilitiesObject.from_hash(hash['liabilities']) if hash['liabilities']
  request_id = hash.key?('request_id') ? hash['request_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  LiabilitiesGetResponse.new(accounts: accounts,
                             item: item,
                             liabilities: liabilities,
                             request_id: request_id,
                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



31
32
33
34
35
36
37
38
# File 'lib/the_plaid_api/models/liabilities_get_response.rb', line 31

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['accounts'] = 'accounts'
  @_hash['item'] = 'item'
  @_hash['liabilities'] = 'liabilities'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



46
47
48
# File 'lib/the_plaid_api/models/liabilities_get_response.rb', line 46

def self.nullables
  []
end

.optionalsObject

An array for optional fields



41
42
43
# File 'lib/the_plaid_api/models/liabilities_get_response.rb', line 41

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



104
105
106
107
108
109
# File 'lib/the_plaid_api/models/liabilities_get_response.rb', line 104

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} accounts: #{@accounts.inspect}, item: #{@item.inspect}, liabilities:"\
  " #{@liabilities.inspect}, request_id: #{@request_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



97
98
99
100
101
# File 'lib/the_plaid_api/models/liabilities_get_response.rb', line 97

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} accounts: #{@accounts}, item: #{@item}, liabilities: #{@liabilities},"\
  " request_id: #{@request_id}, additional_properties: #{@additional_properties}>"
end