Class: ThePlaidApi::LinkDeliveryCommunicationMethod

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/link_delivery_communication_method.rb

Overview

The communication method containing both the type and address to send the URL.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(method: SKIP, address: SKIP, additional_properties: nil) ⇒ LinkDeliveryCommunicationMethod

Returns a new instance of LinkDeliveryCommunicationMethod.



45
46
47
48
49
50
51
52
# File 'lib/the_plaid_api/models/link_delivery_communication_method.rb', line 45

def initialize(method: SKIP, address: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @method = method unless method == SKIP
  @address = address unless address == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#addressString

The phone number / email address that Hosted Link sessions are delivered to. Phone numbers must be in E.164 format.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/link_delivery_communication_method.rb', line 22

def address
  @address
end

#methodLinkDeliveryDeliveryMethod

The delivery method to be used to deliver the Hosted Link session URL. ‘SMS`: The URL will be delivered through SMS `EMAIL`: The URL will be delivered through email



17
18
19
# File 'lib/the_plaid_api/models/link_delivery_communication_method.rb', line 17

def method
  @method
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/the_plaid_api/models/link_delivery_communication_method.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  method = hash.key?('method') ? hash['method'] : SKIP
  address = hash.key?('address') ? hash['address'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  LinkDeliveryCommunicationMethod.new(method: method,
                                      address: address,
                                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
# File 'lib/the_plaid_api/models/link_delivery_communication_method.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['method'] = 'method'
  @_hash['address'] = 'address'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
# File 'lib/the_plaid_api/models/link_delivery_communication_method.rb', line 41

def self.nullables
  []
end

.optionalsObject

An array for optional fields



33
34
35
36
37
38
# File 'lib/the_plaid_api/models/link_delivery_communication_method.rb', line 33

def self.optionals
  %w[
    method
    address
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



83
84
85
86
87
# File 'lib/the_plaid_api/models/link_delivery_communication_method.rb', line 83

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} method: #{@method.inspect}, address: #{@address.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



76
77
78
79
80
# File 'lib/the_plaid_api/models/link_delivery_communication_method.rb', line 76

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} method: #{@method}, address: #{@address}, additional_properties:"\
  " #{@additional_properties}>"
end