Class: ThePlaidApi::LinkDeliveryGetRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::LinkDeliveryGetRequest
- Defined in:
- lib/the_plaid_api/models/link_delivery_get_request.rb
Overview
LinkDeliveryGetRequest defines the request schema for ‘/link_delivery/get`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#link_delivery_session_id ⇒ String
The ID for the Hosted Link session from a previous invocation of ‘/link_delivery/create`.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(link_delivery_session_id:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ LinkDeliveryGetRequest
constructor
A new instance of LinkDeliveryGetRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(link_delivery_session_id:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ LinkDeliveryGetRequest
Returns a new instance of LinkDeliveryGetRequest.
50 51 52 53 54 55 56 57 58 59 |
# File 'lib/the_plaid_api/models/link_delivery_get_request.rb', line 50 def initialize(link_delivery_session_id:, client_id: SKIP, secret: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @link_delivery_session_id = link_delivery_session_id @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/the_plaid_api/models/link_delivery_get_request.rb', line 16 def client_id @client_id end |
#link_delivery_session_id ⇒ String
The ID for the Hosted Link session from a previous invocation of ‘/link_delivery/create`.
26 27 28 |
# File 'lib/the_plaid_api/models/link_delivery_get_request.rb', line 26 def link_delivery_session_id @link_delivery_session_id end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
21 22 23 |
# File 'lib/the_plaid_api/models/link_delivery_get_request.rb', line 21 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/the_plaid_api/models/link_delivery_get_request.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. link_delivery_session_id = hash.key?('link_delivery_session_id') ? hash['link_delivery_session_id'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LinkDeliveryGetRequest.new(link_delivery_session_id: link_delivery_session_id, client_id: client_id, secret: secret, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 |
# File 'lib/the_plaid_api/models/link_delivery_get_request.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['link_delivery_session_id'] = 'link_delivery_session_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
46 47 48 |
# File 'lib/the_plaid_api/models/link_delivery_get_request.rb', line 46 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
38 39 40 41 42 43 |
# File 'lib/the_plaid_api/models/link_delivery_get_request.rb', line 38 def self.optionals %w[ client_id secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 98 |
# File 'lib/the_plaid_api/models/link_delivery_get_request.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\ " link_delivery_session_id: #{@link_delivery_session_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 |
# File 'lib/the_plaid_api/models/link_delivery_get_request.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, link_delivery_session_id:"\ " #{@link_delivery_session_id}, additional_properties: #{@additional_properties}>" end |