Class: ThePlaidApi::LinkSessionExitMetadata
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::LinkSessionExitMetadata
- Defined in:
- lib/the_plaid_api/models/link_session_exit_metadata.rb
Overview
Displayed if a user exits Link without successfully linking an Item.
Instance Attribute Summary collapse
-
#institution ⇒ LinkSessionExitMetadataInstitution
An institution object.
-
#link_session_id ⇒ String
A unique identifier associated with a user’s actions and events through the Link flow.
-
#request_id ⇒ String
The request ID for the last request made by Link.
-
#status ⇒ Status2
The point at which the user exited the Link flow.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(institution: SKIP, status: SKIP, link_session_id: SKIP, request_id: SKIP, additional_properties: nil) ⇒ LinkSessionExitMetadata
constructor
A new instance of LinkSessionExitMetadata.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(institution: SKIP, status: SKIP, link_session_id: SKIP, request_id: SKIP, additional_properties: nil) ⇒ LinkSessionExitMetadata
Returns a new instance of LinkSessionExitMetadata.
60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/the_plaid_api/models/link_session_exit_metadata.rb', line 60 def initialize(institution: SKIP, status: SKIP, link_session_id: SKIP, request_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @institution = institution unless institution == SKIP @status = status unless status == SKIP @link_session_id = link_session_id unless link_session_id == SKIP @request_id = request_id unless request_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#institution ⇒ LinkSessionExitMetadataInstitution
An institution object. If the Item was created via Same-Day or Instant micro-deposit verification, will be ‘null`.
15 16 17 |
# File 'lib/the_plaid_api/models/link_session_exit_metadata.rb', line 15 def institution @institution end |
#link_session_id ⇒ String
A unique identifier associated with a user’s actions and events through the Link flow. Include this identifier when opening a support ticket for faster turnaround.
26 27 28 |
# File 'lib/the_plaid_api/models/link_session_exit_metadata.rb', line 26 def link_session_id @link_session_id end |
#request_id ⇒ String
The request ID for the last request made by Link. This can be shared with Plaid Support to expedite investigation.
31 32 33 |
# File 'lib/the_plaid_api/models/link_session_exit_metadata.rb', line 31 def request_id @request_id end |
#status ⇒ Status2
The point at which the user exited the Link flow. One of the following values.
20 21 22 |
# File 'lib/the_plaid_api/models/link_session_exit_metadata.rb', line 20 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/the_plaid_api/models/link_session_exit_metadata.rb', line 73 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. institution = LinkSessionExitMetadataInstitution.from_hash(hash['institution']) if hash['institution'] status = Status2.from_hash(hash['status']) if hash['status'] link_session_id = hash.key?('link_session_id') ? hash['link_session_id'] : SKIP request_id = hash.key?('request_id') ? hash['request_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LinkSessionExitMetadata.new(institution: institution, status: status, link_session_id: link_session_id, request_id: request_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
34 35 36 37 38 39 40 41 |
# File 'lib/the_plaid_api/models/link_session_exit_metadata.rb', line 34 def self.names @_hash = {} if @_hash.nil? @_hash['institution'] = 'institution' @_hash['status'] = 'status' @_hash['link_session_id'] = 'link_session_id' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 57 58 |
# File 'lib/the_plaid_api/models/link_session_exit_metadata.rb', line 54 def self.nullables %w[ institution ] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 47 48 49 50 51 |
# File 'lib/the_plaid_api/models/link_session_exit_metadata.rb', line 44 def self.optionals %w[ institution status link_session_id request_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
108 109 110 111 112 113 |
# File 'lib/the_plaid_api/models/link_session_exit_metadata.rb', line 108 def inspect class_name = self.class.name.split('::').last "<#{class_name} institution: #{@institution.inspect}, status: #{@status.inspect},"\ " link_session_id: #{@link_session_id.inspect}, request_id: #{@request_id.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
100 101 102 103 104 105 |
# File 'lib/the_plaid_api/models/link_session_exit_metadata.rb', line 100 def to_s class_name = self.class.name.split('::').last "<#{class_name} institution: #{@institution}, status: #{@status}, link_session_id:"\ " #{@link_session_id}, request_id: #{@request_id}, additional_properties:"\ " #{@additional_properties}>" end |