Class: ThePlaidApi::LinkTokenCashflowReport

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/link_token_cashflow_report.rb

Overview

Configuration parameters for the Cashflow Report product. Currently in closed beta.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(days_requested: 365, additional_properties: nil) ⇒ LinkTokenCashflowReport

Returns a new instance of LinkTokenCashflowReport.



37
38
39
40
41
42
43
# File 'lib/the_plaid_api/models/link_token_cashflow_report.rb', line 37

def initialize(days_requested: 365, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @days_requested = days_requested unless days_requested == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#days_requestedInteger

Number of days of transaction history to request in the Cashflow Report product.

Returns:

  • (Integer)


16
17
18
# File 'lib/the_plaid_api/models/link_token_cashflow_report.rb', line 16

def days_requested
  @days_requested
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/the_plaid_api/models/link_token_cashflow_report.rb', line 46

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  days_requested = hash['days_requested'] ||= 365

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  LinkTokenCashflowReport.new(days_requested: days_requested,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



19
20
21
22
23
# File 'lib/the_plaid_api/models/link_token_cashflow_report.rb', line 19

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['days_requested'] = 'days_requested'
  @_hash
end

.nullablesObject

An array for nullable fields



33
34
35
# File 'lib/the_plaid_api/models/link_token_cashflow_report.rb', line 33

def self.nullables
  []
end

.optionalsObject

An array for optional fields



26
27
28
29
30
# File 'lib/the_plaid_api/models/link_token_cashflow_report.rb', line 26

def self.optionals
  %w[
    days_requested
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



72
73
74
75
76
# File 'lib/the_plaid_api/models/link_token_cashflow_report.rb', line 72

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} days_requested: #{@days_requested.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



65
66
67
68
69
# File 'lib/the_plaid_api/models/link_token_cashflow_report.rb', line 65

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} days_requested: #{@days_requested}, additional_properties:"\
  " #{@additional_properties}>"
end