Class: ThePlaidApi::LinkTokenCreateCreditFilter
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::LinkTokenCreateCreditFilter
- Defined in:
- lib/the_plaid_api/models/link_token_create_credit_filter.rb
Overview
A filter to apply to ‘credit`-type accounts
Instance Attribute Summary collapse
-
#account_subtypes ⇒ Array[CreditAccountSubtype]
An array of account subtypes to display in Link.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_subtypes: SKIP, additional_properties: nil) ⇒ LinkTokenCreateCreditFilter
constructor
A new instance of LinkTokenCreateCreditFilter.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_subtypes: SKIP, additional_properties: nil) ⇒ LinkTokenCreateCreditFilter
Returns a new instance of LinkTokenCreateCreditFilter.
38 39 40 41 42 43 44 |
# File 'lib/the_plaid_api/models/link_token_create_credit_filter.rb', line 38 def initialize(account_subtypes: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_subtypes = account_subtypes unless account_subtypes == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_subtypes ⇒ Array[CreditAccountSubtype]
An array of account subtypes to display in Link. If not specified, all account subtypes will be shown. For a full list of valid types and subtypes, see the [Account schema](plaid.com/docs/api/accounts#account-type-schema).
17 18 19 |
# File 'lib/the_plaid_api/models/link_token_create_credit_filter.rb', line 17 def account_subtypes @account_subtypes end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/the_plaid_api/models/link_token_create_credit_filter.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_subtypes = hash.key?('account_subtypes') ? hash['account_subtypes'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LinkTokenCreateCreditFilter.new(account_subtypes: account_subtypes, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
20 21 22 23 24 |
# File 'lib/the_plaid_api/models/link_token_create_credit_filter.rb', line 20 def self.names @_hash = {} if @_hash.nil? @_hash['account_subtypes'] = 'account_subtypes' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/the_plaid_api/models/link_token_create_credit_filter.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
27 28 29 30 31 |
# File 'lib/the_plaid_api/models/link_token_create_credit_filter.rb', line 27 def self.optionals %w[ account_subtypes ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
74 75 76 77 78 |
# File 'lib/the_plaid_api/models/link_token_create_credit_filter.rb', line 74 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_subtypes: #{@account_subtypes.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 71 |
# File 'lib/the_plaid_api/models/link_token_create_credit_filter.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_subtypes: #{@account_subtypes}, additional_properties:"\ " #{@additional_properties}>" end |