Class: ThePlaidApi::LinkTokenCreateInstitutionData
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::LinkTokenCreateInstitutionData
- Defined in:
- lib/the_plaid_api/models/link_token_create_institution_data.rb
Overview
A map containing data used to highlight institutions in Link.
Instance Attribute Summary collapse
-
#routing_number ⇒ String
The routing number of the bank to highlight in Link.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(routing_number: SKIP, additional_properties: nil) ⇒ LinkTokenCreateInstitutionData
constructor
A new instance of LinkTokenCreateInstitutionData.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(routing_number: SKIP, additional_properties: nil) ⇒ LinkTokenCreateInstitutionData
Returns a new instance of LinkTokenCreateInstitutionData.
39 40 41 42 43 44 45 |
# File 'lib/the_plaid_api/models/link_token_create_institution_data.rb', line 39 def initialize(routing_number: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @routing_number = routing_number unless routing_number == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#routing_number ⇒ String
The routing number of the bank to highlight in Link. Note: in rare cases, a single routing number can be associated with multiple institutions, e.g. due to a brokerage using another institution to manage ACH on its sweep accounts. If this happens, the bank will not be highlighted in Link even if the routing number is provided.
18 19 20 |
# File 'lib/the_plaid_api/models/link_token_create_institution_data.rb', line 18 def routing_number @routing_number end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/the_plaid_api/models/link_token_create_institution_data.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. routing_number = hash.key?('routing_number') ? hash['routing_number'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LinkTokenCreateInstitutionData.new(routing_number: routing_number, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 |
# File 'lib/the_plaid_api/models/link_token_create_institution_data.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['routing_number'] = 'routing_number' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/the_plaid_api/models/link_token_create_institution_data.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
28 29 30 31 32 |
# File 'lib/the_plaid_api/models/link_token_create_institution_data.rb', line 28 def self.optionals %w[ routing_number ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/the_plaid_api/models/link_token_create_institution_data.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} routing_number: #{@routing_number.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
68 69 70 71 72 |
# File 'lib/the_plaid_api/models/link_token_create_institution_data.rb', line 68 def to_s class_name = self.class.name.split('::').last "<#{class_name} routing_number: #{@routing_number}, additional_properties:"\ " #{@additional_properties}>" end |