Class: ThePlaidApi::LinkTokenCreateRequestAccountSubtypes

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/link_token_create_request_account_subtypes.rb

Overview

By default, Link will only display account types that are compatible with all products supplied in the ‘products` parameter of `/link/token/create`. You can further limit the accounts shown in Link by using `account_filters` to specify the account subtypes to be shown in Link. Only the specified subtypes will be shown. This filtering applies to both the Account Select view (if enabled) and the Institution Select view. Institutions that do not support the selected subtypes will be omitted from Link. To indicate that all subtypes should be shown, use the value `“all”`. If the `account_filters` filter is used, any account type for which a filter is not specified will be entirely omitted from Link. For a full list of valid types and subtypes, see the [Account schema](plaid.com/docs/api/accounts#account-type-schema). For institutions using OAuth, the filter will not affect the list of institutions or accounts shown by the bank in the OAuth window.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(depository: SKIP, credit: SKIP, loan: SKIP, investment: SKIP, additional_properties: nil) ⇒ LinkTokenCreateRequestAccountSubtypes

Returns a new instance of LinkTokenCreateRequestAccountSubtypes.



67
68
69
70
71
72
73
74
75
76
77
# File 'lib/the_plaid_api/models/link_token_create_request_account_subtypes.rb', line 67

def initialize(depository: SKIP, credit: SKIP, loan: SKIP, investment: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @depository = depository unless depository == SKIP
  @credit = credit unless credit == SKIP
  @loan = loan unless loan == SKIP
  @investment = investment unless investment == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#creditLinkTokenCreateCreditFilter

A filter to apply to ‘credit`-type accounts



31
32
33
# File 'lib/the_plaid_api/models/link_token_create_request_account_subtypes.rb', line 31

def credit
  @credit
end

#depositoryLinkTokenCreateDepositoryFilter

A filter to apply to ‘depository`-type accounts



27
28
29
# File 'lib/the_plaid_api/models/link_token_create_request_account_subtypes.rb', line 27

def depository
  @depository
end

#investmentLinkTokenCreateInvestmentFilter

A filter to apply to ‘investment`-type accounts (or `brokerage`-type accounts for API versions 2018-05-22 and earlier).



40
41
42
# File 'lib/the_plaid_api/models/link_token_create_request_account_subtypes.rb', line 40

def investment
  @investment
end

#loanLinkTokenCreateLoanFilter

A filter to apply to ‘loan`-type accounts



35
36
37
# File 'lib/the_plaid_api/models/link_token_create_request_account_subtypes.rb', line 35

def loan
  @loan
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/the_plaid_api/models/link_token_create_request_account_subtypes.rb', line 80

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  depository = LinkTokenCreateDepositoryFilter.from_hash(hash['depository']) if
    hash['depository']
  credit = LinkTokenCreateCreditFilter.from_hash(hash['credit']) if hash['credit']
  loan = LinkTokenCreateLoanFilter.from_hash(hash['loan']) if hash['loan']
  investment = LinkTokenCreateInvestmentFilter.from_hash(hash['investment']) if
    hash['investment']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  LinkTokenCreateRequestAccountSubtypes.new(depository: depository,
                                            credit: credit,
                                            loan: loan,
                                            investment: investment,
                                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



43
44
45
46
47
48
49
50
# File 'lib/the_plaid_api/models/link_token_create_request_account_subtypes.rb', line 43

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['depository'] = 'depository'
  @_hash['credit'] = 'credit'
  @_hash['loan'] = 'loan'
  @_hash['investment'] = 'investment'
  @_hash
end

.nullablesObject

An array for nullable fields



63
64
65
# File 'lib/the_plaid_api/models/link_token_create_request_account_subtypes.rb', line 63

def self.nullables
  []
end

.optionalsObject

An array for optional fields



53
54
55
56
57
58
59
60
# File 'lib/the_plaid_api/models/link_token_create_request_account_subtypes.rb', line 53

def self.optionals
  %w[
    depository
    credit
    loan
    investment
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



114
115
116
117
118
119
# File 'lib/the_plaid_api/models/link_token_create_request_account_subtypes.rb', line 114

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} depository: #{@depository.inspect}, credit: #{@credit.inspect}, loan:"\
  " #{@loan.inspect}, investment: #{@investment.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



107
108
109
110
111
# File 'lib/the_plaid_api/models/link_token_create_request_account_subtypes.rb', line 107

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} depository: #{@depository}, credit: #{@credit}, loan: #{@loan}, investment:"\
  " #{@investment}, additional_properties: #{@additional_properties}>"
end