Class: ThePlaidApi::LinkTokenCreateRequestCraOptionsBaseReport
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::LinkTokenCreateRequestCraOptionsBaseReport
- Defined in:
- lib/the_plaid_api/models/link_token_create_request_cra_options_base_report.rb
Overview
Specifies options for initializing Link for use with the Base Report product, specifically the ‘client_report_id`.
Instance Attribute Summary collapse
-
#client_report_id ⇒ String
Client-generated identifier, which can be used by lenders to track loan applications.
-
#gse_options ⇒ LinkTokenCreateRequestCraOptionsBaseReportGseOptions
Specifies options for initializing Link to create reports that can be shared with GSEs for mortgage verification.
-
#home_lending_report_options ⇒ CraCheckReportHomeLendingReportOptions
Options for configuring Home Lending Report (Verification Report) generation.
-
#require_identity ⇒ TrueClass | FalseClass
Indicates that the report must include identity information.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_report_id: SKIP, gse_options: SKIP, require_identity: SKIP, home_lending_report_options: SKIP, additional_properties: nil) ⇒ LinkTokenCreateRequestCraOptionsBaseReport
constructor
A new instance of LinkTokenCreateRequestCraOptionsBaseReport.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_report_id: SKIP, gse_options: SKIP, require_identity: SKIP, home_lending_report_options: SKIP, additional_properties: nil) ⇒ LinkTokenCreateRequestCraOptionsBaseReport
Returns a new instance of LinkTokenCreateRequestCraOptionsBaseReport.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_base_report.rb', line 63 def initialize(client_report_id: SKIP, gse_options: SKIP, require_identity: SKIP, home_lending_report_options: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_report_id = client_report_id unless client_report_id == SKIP @gse_options = unless == SKIP @require_identity = require_identity unless require_identity == SKIP unless == SKIP @home_lending_report_options = end @additional_properties = additional_properties end |
Instance Attribute Details
#client_report_id ⇒ String
Client-generated identifier, which can be used by lenders to track loan applications.
16 17 18 |
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_base_report.rb', line 16 def client_report_id @client_report_id end |
#gse_options ⇒ LinkTokenCreateRequestCraOptionsBaseReportGseOptions
Specifies options for initializing Link to create reports that can be shared with GSEs for mortgage verification.
21 22 23 |
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_base_report.rb', line 21 def @gse_options end |
#home_lending_report_options ⇒ CraCheckReportHomeLendingReportOptions
Options for configuring Home Lending Report (Verification Report) generation.
31 32 33 |
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_base_report.rb', line 31 def @home_lending_report_options end |
#require_identity ⇒ TrueClass | FalseClass
Indicates that the report must include identity information. If identity information is not available, the report will fail.
26 27 28 |
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_base_report.rb', line 26 def require_identity @require_identity end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_base_report.rb', line 80 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_report_id = hash.key?('client_report_id') ? hash['client_report_id'] : SKIP if hash['gse_options'] = LinkTokenCreateRequestCraOptionsBaseReportGseOptions.from_hash(hash['gse_options']) end require_identity = hash.key?('require_identity') ? hash['require_identity'] : SKIP if hash['home_lending_report_options'] = CraCheckReportHomeLendingReportOptions.from_hash(hash['home_lending_report_options']) end # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LinkTokenCreateRequestCraOptionsBaseReport.new(client_report_id: client_report_id, gse_options: , require_identity: require_identity, home_lending_report_options: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
34 35 36 37 38 39 40 41 |
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_base_report.rb', line 34 def self.names @_hash = {} if @_hash.nil? @_hash['client_report_id'] = 'client_report_id' @_hash['gse_options'] = 'gse_options' @_hash['require_identity'] = 'require_identity' @_hash['home_lending_report_options'] = 'home_lending_report_options' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 57 58 59 60 61 |
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_base_report.rb', line 54 def self.nullables %w[ client_report_id gse_options require_identity home_lending_report_options ] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 47 48 49 50 51 |
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_base_report.rb', line 44 def self.optionals %w[ client_report_id gse_options require_identity home_lending_report_options ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
119 120 121 122 123 124 125 |
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_base_report.rb', line 119 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_report_id: #{@client_report_id.inspect}, gse_options:"\ " #{@gse_options.inspect}, require_identity: #{@require_identity.inspect},"\ " home_lending_report_options: #{@home_lending_report_options.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
111 112 113 114 115 116 |
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_base_report.rb', line 111 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_report_id: #{@client_report_id}, gse_options: #{@gse_options},"\ " require_identity: #{@require_identity}, home_lending_report_options:"\ " #{@home_lending_report_options}, additional_properties: #{@additional_properties}>" end |