Class: ThePlaidApi::LinkTokenCreateRequestCraOptionsBaseReportGseOptions

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/link_token_create_request_cra_options_base_report_gse_options.rb

Overview

Specifies options for initializing Link to create reports that can be shared with GSEs for mortgage verification.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(report_types:, additional_properties: nil) ⇒ LinkTokenCreateRequestCraOptionsBaseReportGseOptions

Returns a new instance of LinkTokenCreateRequestCraOptionsBaseReportGseOptions.



34
35
36
37
38
39
40
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_base_report_gse_options.rb', line 34

def initialize(report_types:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @report_types = report_types
  @additional_properties = additional_properties
end

Instance Attribute Details

#report_typesArray[GseReportType]

Specifies which types of reports should be made available to GSEs.

Returns:



15
16
17
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_base_report_gse_options.rb', line 15

def report_types
  @report_types
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_base_report_gse_options.rb', line 43

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  report_types = hash.key?('report_types') ? hash['report_types'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  LinkTokenCreateRequestCraOptionsBaseReportGseOptions.new(report_types: report_types,
                                                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_base_report_gse_options.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['report_types'] = 'report_types'
  @_hash
end

.nullablesObject

An array for nullable fields



30
31
32
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_base_report_gse_options.rb', line 30

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_base_report_gse_options.rb', line 25

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



69
70
71
72
73
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_base_report_gse_options.rb', line 69

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} report_types: #{@report_types.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



62
63
64
65
66
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_base_report_gse_options.rb', line 62

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} report_types: #{@report_types}, additional_properties:"\
  " #{@additional_properties}>"
end