Class: ThePlaidApi::LinkTokenCreateRequestCraOptionsLendScore

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/link_token_create_request_cra_options_lend_score.rb

Overview

Specifies options for initializing Link for use with the CRA LendScore product.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(lend_score_version: SKIP, additional_properties: nil) ⇒ LinkTokenCreateRequestCraOptionsLendScore

Returns a new instance of LinkTokenCreateRequestCraOptionsLendScore.



38
39
40
41
42
43
44
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_lend_score.rb', line 38

def initialize(lend_score_version: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @lend_score_version = lend_score_version unless lend_score_version == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#lend_score_versionPlaidLendScoreVersion

The version of the LendScore to use. Required if using LendScore.



15
16
17
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_lend_score.rb', line 15

def lend_score_version
  @lend_score_version
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_lend_score.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  lend_score_version =
    hash.key?('lend_score_version') ? hash['lend_score_version'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  LinkTokenCreateRequestCraOptionsLendScore.new(lend_score_version: lend_score_version,
                                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_lend_score.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['lend_score_version'] = 'lend_score_version'
  @_hash
end

.nullablesObject

An array for nullable fields



32
33
34
35
36
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_lend_score.rb', line 32

def self.nullables
  %w[
    lend_score_version
  ]
end

.optionalsObject

An array for optional fields



25
26
27
28
29
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_lend_score.rb', line 25

def self.optionals
  %w[
    lend_score_version
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



74
75
76
77
78
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_lend_score.rb', line 74

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} lend_score_version: #{@lend_score_version.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



67
68
69
70
71
# File 'lib/the_plaid_api/models/link_token_create_request_cra_options_lend_score.rb', line 67

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} lend_score_version: #{@lend_score_version}, additional_properties:"\
  " #{@additional_properties}>"
end