Class: ThePlaidApi::LinkTokenCreateRequestEmployment

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/link_token_create_request_employment.rb

Overview

Specifies options for initializing Link for use with the Employment product. This field is required if ‘employment` is included in the `products` array.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(employment_source_types: SKIP, bank_employment: SKIP, additional_properties: nil) ⇒ LinkTokenCreateRequestEmployment

Returns a new instance of LinkTokenCreateRequestEmployment.



46
47
48
49
50
51
52
53
54
# File 'lib/the_plaid_api/models/link_token_create_request_employment.rb', line 46

def initialize(employment_source_types: SKIP, bank_employment: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @employment_source_types = employment_source_types unless employment_source_types == SKIP
  @bank_employment = bank_employment unless bank_employment == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#bank_employmentLinkTokenCreateRequestEmploymentBankIncome

Specifies options for initializing Link for use with Bank Employment. This field is required if ‘employment` is included in the `products` array and `bank` is specified in `employment_source_types`.



23
24
25
# File 'lib/the_plaid_api/models/link_token_create_request_employment.rb', line 23

def bank_employment
  @bank_employment
end

#employment_source_typesArray[EmploymentSourceType]

The types of source employment data that users will be permitted to share. Options include ‘bank` and `payroll`. Currently you can only specify one of these options.

Returns:



17
18
19
# File 'lib/the_plaid_api/models/link_token_create_request_employment.rb', line 17

def employment_source_types
  @employment_source_types
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/the_plaid_api/models/link_token_create_request_employment.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  employment_source_types =
    hash.key?('employment_source_types') ? hash['employment_source_types'] : SKIP
  if hash['bank_employment']
    bank_employment = LinkTokenCreateRequestEmploymentBankIncome.from_hash(hash['bank_employment'])
  end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  LinkTokenCreateRequestEmployment.new(employment_source_types: employment_source_types,
                                       bank_employment: bank_employment,
                                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
# File 'lib/the_plaid_api/models/link_token_create_request_employment.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['employment_source_types'] = 'employment_source_types'
  @_hash['bank_employment'] = 'bank_employment'
  @_hash
end

.nullablesObject

An array for nullable fields



42
43
44
# File 'lib/the_plaid_api/models/link_token_create_request_employment.rb', line 42

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
# File 'lib/the_plaid_api/models/link_token_create_request_employment.rb', line 34

def self.optionals
  %w[
    employment_source_types
    bank_employment
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



88
89
90
91
92
93
# File 'lib/the_plaid_api/models/link_token_create_request_employment.rb', line 88

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} employment_source_types: #{@employment_source_types.inspect},"\
  " bank_employment: #{@bank_employment.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



81
82
83
84
85
# File 'lib/the_plaid_api/models/link_token_create_request_employment.rb', line 81

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} employment_source_types: #{@employment_source_types}, bank_employment:"\
  " #{@bank_employment}, additional_properties: #{@additional_properties}>"
end