Class: ThePlaidApi::LinkTokenCreateRequestIncomeVerificationPayrollIncome

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/link_token_create_request_income_verification_payroll_income.rb

Overview

Specifies options for initializing Link for use with Payroll Income (including Document Income). Further customization options for Document Income, such as customizing which document types may be uploaded, are also available via the [Link Customization pane](dashboard.plaid.com/link) in the Dashboard. (Requires Production enablement.)

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(flow_types: SKIP, is_update_mode: false, item_id_to_update: SKIP, parsing_config: SKIP, additional_properties: nil) ⇒ LinkTokenCreateRequestIncomeVerificationPayrollIncome

Returns a new instance of LinkTokenCreateRequestIncomeVerificationPayrollIncome.



68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/the_plaid_api/models/link_token_create_request_income_verification_payroll_income.rb', line 68

def initialize(flow_types: SKIP, is_update_mode: false,
               item_id_to_update: SKIP, parsing_config: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @flow_types = flow_types unless flow_types == SKIP
  @is_update_mode = is_update_mode unless is_update_mode == SKIP
  @item_id_to_update = item_id_to_update unless item_id_to_update == SKIP
  @parsing_config = parsing_config unless parsing_config == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#flow_typesArray[IncomeVerificationPayrollFlowType]

The types of payroll income verification to enable for the Link session. If none are specified, then users will see both document and digital payroll income.



21
22
23
# File 'lib/the_plaid_api/models/link_token_create_request_income_verification_payroll_income.rb', line 21

def flow_types
  @flow_types
end

#is_update_modeTrueClass | FalseClass

An identifier to indicate whether the income verification Link token will be used for update mode. This field is only relevant for participants in the Payroll Income Refresh beta.

Returns:

  • (TrueClass | FalseClass)


27
28
29
# File 'lib/the_plaid_api/models/link_token_create_request_income_verification_payroll_income.rb', line 27

def is_update_mode
  @is_update_mode
end

#item_id_to_updateString

Uniquely identify a payroll income Item to update with. This field is only relevant for participants in the Payroll Income Refresh beta.

Returns:

  • (String)


32
33
34
# File 'lib/the_plaid_api/models/link_token_create_request_income_verification_payroll_income.rb', line 32

def item_id_to_update
  @item_id_to_update
end

#parsing_configArray[IncomeVerificationDocParsingConfig]

The types of analysis to enable for document uploads. If this field is not provided, then docs will undergo OCR parsing only.



37
38
39
# File 'lib/the_plaid_api/models/link_token_create_request_income_verification_payroll_income.rb', line 37

def parsing_config
  @parsing_config
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/the_plaid_api/models/link_token_create_request_income_verification_payroll_income.rb', line 82

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  flow_types = hash.key?('flow_types') ? hash['flow_types'] : SKIP
  is_update_mode = hash['is_update_mode'] ||= false
  item_id_to_update =
    hash.key?('item_id_to_update') ? hash['item_id_to_update'] : SKIP
  parsing_config =
    hash.key?('parsing_config') ? hash['parsing_config'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  LinkTokenCreateRequestIncomeVerificationPayrollIncome.new(flow_types: flow_types,
                                                            is_update_mode: is_update_mode,
                                                            item_id_to_update: item_id_to_update,
                                                            parsing_config: parsing_config,
                                                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



40
41
42
43
44
45
46
47
# File 'lib/the_plaid_api/models/link_token_create_request_income_verification_payroll_income.rb', line 40

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['flow_types'] = 'flow_types'
  @_hash['is_update_mode'] = 'is_update_mode'
  @_hash['item_id_to_update'] = 'item_id_to_update'
  @_hash['parsing_config'] = 'parsing_config'
  @_hash
end

.nullablesObject

An array for nullable fields



60
61
62
63
64
65
66
# File 'lib/the_plaid_api/models/link_token_create_request_income_verification_payroll_income.rb', line 60

def self.nullables
  %w[
    flow_types
    item_id_to_update
    parsing_config
  ]
end

.optionalsObject

An array for optional fields



50
51
52
53
54
55
56
57
# File 'lib/the_plaid_api/models/link_token_create_request_income_verification_payroll_income.rb', line 50

def self.optionals
  %w[
    flow_types
    is_update_mode
    item_id_to_update
    parsing_config
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



117
118
119
120
121
122
123
# File 'lib/the_plaid_api/models/link_token_create_request_income_verification_payroll_income.rb', line 117

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} flow_types: #{@flow_types.inspect}, is_update_mode:"\
  " #{@is_update_mode.inspect}, item_id_to_update: #{@item_id_to_update.inspect},"\
  " parsing_config: #{@parsing_config.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



109
110
111
112
113
114
# File 'lib/the_plaid_api/models/link_token_create_request_income_verification_payroll_income.rb', line 109

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} flow_types: #{@flow_types}, is_update_mode: #{@is_update_mode},"\
  " item_id_to_update: #{@item_id_to_update}, parsing_config: #{@parsing_config},"\
  " additional_properties: #{@additional_properties}>"
end