Class: ThePlaidApi::LinkTokenCreateRequestPaymentInitiation

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/link_token_create_request_payment_initiation.rb

Overview

Specifies options for initializing Link for use with the Payment Initiation (Europe) product. This field is required if ‘payment_initiation` is included in the `products` array. Either `payment_id` or `consent_id` must be provided.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(payment_id: SKIP, consent_id: SKIP, additional_properties: nil) ⇒ LinkTokenCreateRequestPaymentInitiation

Returns a new instance of LinkTokenCreateRequestPaymentInitiation.



46
47
48
49
50
51
52
53
54
# File 'lib/the_plaid_api/models/link_token_create_request_payment_initiation.rb', line 46

def initialize(payment_id: SKIP, consent_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @payment_id = payment_id unless payment_id == SKIP
  @consent_id = consent_id unless consent_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

The ‘consent_id` provided by the `/payment_initiation/consent/create` endpoint.

Returns:

  • (String)


23
24
25
# File 'lib/the_plaid_api/models/link_token_create_request_payment_initiation.rb', line 23

def consent_id
  @consent_id
end

#payment_idString

The ‘payment_id` provided by the `/payment_initiation/payment/create` endpoint.

Returns:

  • (String)


18
19
20
# File 'lib/the_plaid_api/models/link_token_create_request_payment_initiation.rb', line 18

def payment_id
  @payment_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/the_plaid_api/models/link_token_create_request_payment_initiation.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  payment_id = hash.key?('payment_id') ? hash['payment_id'] : SKIP
  consent_id = hash.key?('consent_id') ? hash['consent_id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  LinkTokenCreateRequestPaymentInitiation.new(payment_id: payment_id,
                                              consent_id: consent_id,
                                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
# File 'lib/the_plaid_api/models/link_token_create_request_payment_initiation.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['payment_id'] = 'payment_id'
  @_hash['consent_id'] = 'consent_id'
  @_hash
end

.nullablesObject

An array for nullable fields



42
43
44
# File 'lib/the_plaid_api/models/link_token_create_request_payment_initiation.rb', line 42

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
# File 'lib/the_plaid_api/models/link_token_create_request_payment_initiation.rb', line 34

def self.optionals
  %w[
    payment_id
    consent_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



85
86
87
88
89
# File 'lib/the_plaid_api/models/link_token_create_request_payment_initiation.rb', line 85

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} payment_id: #{@payment_id.inspect}, consent_id: #{@consent_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



78
79
80
81
82
# File 'lib/the_plaid_api/models/link_token_create_request_payment_initiation.rb', line 78

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} payment_id: #{@payment_id}, consent_id: #{@consent_id},"\
  " additional_properties: #{@additional_properties}>"
end