Class: ThePlaidApi::LinkTokenCreateRequestStatements

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/link_token_create_request_statements.rb

Overview

Specifies options for initializing Link for use with the Statements product. This field is required for the statements product.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(start_date:, end_date:, additional_properties: nil) ⇒ LinkTokenCreateRequestStatements

Returns a new instance of LinkTokenCreateRequestStatements.



43
44
45
46
47
48
49
50
# File 'lib/the_plaid_api/models/link_token_create_request_statements.rb', line 43

def initialize(start_date:, end_date:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @start_date = start_date
  @end_date = end_date
  @additional_properties = additional_properties
end

Instance Attribute Details

#end_dateDate

The end date for statements, in [ISO 8601](wikipedia.org/wiki/ISO_8601) “YYYY-MM-DD” format, e.g. “2020-10-30”. You can request up to two years of data.

Returns:

  • (Date)


23
24
25
# File 'lib/the_plaid_api/models/link_token_create_request_statements.rb', line 23

def end_date
  @end_date
end

#start_dateDate

The start date for statements, in [ISO 8601](wikipedia.org/wiki/ISO_8601) “YYYY-MM-DD” format, e.g. “2020-10-30”.

Returns:

  • (Date)


17
18
19
# File 'lib/the_plaid_api/models/link_token_create_request_statements.rb', line 17

def start_date
  @start_date
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/the_plaid_api/models/link_token_create_request_statements.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  start_date = hash.key?('start_date') ? hash['start_date'] : nil
  end_date = hash.key?('end_date') ? hash['end_date'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  LinkTokenCreateRequestStatements.new(start_date: start_date,
                                       end_date: end_date,
                                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
# File 'lib/the_plaid_api/models/link_token_create_request_statements.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['start_date'] = 'start_date'
  @_hash['end_date'] = 'end_date'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/the_plaid_api/models/link_token_create_request_statements.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/the_plaid_api/models/link_token_create_request_statements.rb', line 34

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



81
82
83
84
85
# File 'lib/the_plaid_api/models/link_token_create_request_statements.rb', line 81

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} start_date: #{@start_date.inspect}, end_date: #{@end_date.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



74
75
76
77
78
# File 'lib/the_plaid_api/models/link_token_create_request_statements.rb', line 74

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} start_date: #{@start_date}, end_date: #{@end_date}, additional_properties:"\
  " #{@additional_properties}>"
end