Class: ThePlaidApi::LinkTokenEuConfig

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/link_token_eu_config.rb

Overview

Configuration parameters for EU flows

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(headless: SKIP, additional_properties: nil) ⇒ LinkTokenEuConfig

Returns a new instance of LinkTokenEuConfig.



35
36
37
38
39
40
41
# File 'lib/the_plaid_api/models/link_token_eu_config.rb', line 35

def initialize(headless: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @headless = headless unless headless == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#headlessTrueClass | FalseClass

If ‘true`, open Link without an initial UI. Defaults to `false`.

Returns:

  • (TrueClass | FalseClass)


14
15
16
# File 'lib/the_plaid_api/models/link_token_eu_config.rb', line 14

def headless
  @headless
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/the_plaid_api/models/link_token_eu_config.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  headless = hash.key?('headless') ? hash['headless'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  LinkTokenEuConfig.new(headless: headless,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/the_plaid_api/models/link_token_eu_config.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['headless'] = 'headless'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/the_plaid_api/models/link_token_eu_config.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/the_plaid_api/models/link_token_eu_config.rb', line 24

def self.optionals
  %w[
    headless
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



69
70
71
72
73
# File 'lib/the_plaid_api/models/link_token_eu_config.rb', line 69

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} headless: #{@headless.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



63
64
65
66
# File 'lib/the_plaid_api/models/link_token_eu_config.rb', line 63

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} headless: #{@headless}, additional_properties: #{@additional_properties}>"
end