Class: ThePlaidApi::LinkTokenInvestments

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/link_token_investments.rb

Overview

Configuration parameters for the Investments product

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(allow_unverified_crypto_wallets: SKIP, allow_manual_entry: SKIP, additional_properties: nil) ⇒ LinkTokenInvestments

Returns a new instance of LinkTokenInvestments.



44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/the_plaid_api/models/link_token_investments.rb', line 44

def initialize(allow_unverified_crypto_wallets: SKIP,
               allow_manual_entry: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  unless allow_unverified_crypto_wallets == SKIP
    @allow_unverified_crypto_wallets =
      allow_unverified_crypto_wallets
  end
  @allow_manual_entry = allow_manual_entry unless allow_manual_entry == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#allow_manual_entryTrueClass | FalseClass

If ‘true`, allow users to manually enter Investments account and holdings information. Defaults to `false`.

Returns:

  • (TrueClass | FalseClass)


20
21
22
# File 'lib/the_plaid_api/models/link_token_investments.rb', line 20

def allow_manual_entry
  @allow_manual_entry
end

#allow_unverified_crypto_walletsTrueClass | FalseClass

If ‘true`, allow self-custody crypto wallets to be added without requiring signature verification. Defaults to `false`.

Returns:

  • (TrueClass | FalseClass)


15
16
17
# File 'lib/the_plaid_api/models/link_token_investments.rb', line 15

def allow_unverified_crypto_wallets
  @allow_unverified_crypto_wallets
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/the_plaid_api/models/link_token_investments.rb', line 58

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  allow_unverified_crypto_wallets =
    hash.key?('allow_unverified_crypto_wallets') ? hash['allow_unverified_crypto_wallets'] : SKIP
  allow_manual_entry =
    hash.key?('allow_manual_entry') ? hash['allow_manual_entry'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  LinkTokenInvestments.new(allow_unverified_crypto_wallets: allow_unverified_crypto_wallets,
                           allow_manual_entry: allow_manual_entry,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
29
# File 'lib/the_plaid_api/models/link_token_investments.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['allow_unverified_crypto_wallets'] =
    'allow_unverified_crypto_wallets'
  @_hash['allow_manual_entry'] = 'allow_manual_entry'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/the_plaid_api/models/link_token_investments.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



32
33
34
35
36
37
# File 'lib/the_plaid_api/models/link_token_investments.rb', line 32

def self.optionals
  %w[
    allow_unverified_crypto_wallets
    allow_manual_entry
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
94
# File 'lib/the_plaid_api/models/link_token_investments.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} allow_unverified_crypto_wallets:"\
  " #{@allow_unverified_crypto_wallets.inspect}, allow_manual_entry:"\
  " #{@allow_manual_entry.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



81
82
83
84
85
86
# File 'lib/the_plaid_api/models/link_token_investments.rb', line 81

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} allow_unverified_crypto_wallets: #{@allow_unverified_crypto_wallets},"\
  " allow_manual_entry: #{@allow_manual_entry}, additional_properties:"\
  " #{@additional_properties}>"
end