Class: ThePlaidApi::LoanIdentifier

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/loan_identifier.rb

Overview

The information used to identify this loan by various parties to the transaction or other organizations.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(loan_identifier:, loan_identifier_type:, additional_properties: nil) ⇒ LoanIdentifier

Returns a new instance of LoanIdentifier.



43
44
45
46
47
48
49
50
51
# File 'lib/the_plaid_api/models/loan_identifier.rb', line 43

def initialize(loan_identifier:, loan_identifier_type:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @loan_identifier = loan_identifier
  @loan_identifier_type = loan_identifier_type
  @additional_properties = additional_properties
end

Instance Attribute Details

#loan_identifierString

The value of the identifier for the specified type.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/loan_identifier.rb', line 15

def loan_identifier
  @loan_identifier
end

#loan_identifier_typeLoanIdentifierType

A value from a MISMO prescribed list that specifies the type of loan identifier.

Returns:



20
21
22
# File 'lib/the_plaid_api/models/loan_identifier.rb', line 20

def loan_identifier_type
  @loan_identifier_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/the_plaid_api/models/loan_identifier.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  loan_identifier =
    hash.key?('LoanIdentifier') ? hash['LoanIdentifier'] : nil
  loan_identifier_type =
    hash.key?('LoanIdentifierType') ? hash['LoanIdentifierType'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  LoanIdentifier.new(loan_identifier: loan_identifier,
                     loan_identifier_type: loan_identifier_type,
                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/the_plaid_api/models/loan_identifier.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['loan_identifier'] = 'LoanIdentifier'
  @_hash['loan_identifier_type'] = 'LoanIdentifierType'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
39
40
41
# File 'lib/the_plaid_api/models/loan_identifier.rb', line 36

def self.nullables
  %w[
    loan_identifier
    loan_identifier_type
  ]
end

.optionalsObject

An array for optional fields



31
32
33
# File 'lib/the_plaid_api/models/loan_identifier.rb', line 31

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



84
85
86
87
88
# File 'lib/the_plaid_api/models/loan_identifier.rb', line 84

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} loan_identifier: #{@loan_identifier.inspect}, loan_identifier_type:"\
  " #{@loan_identifier_type.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



77
78
79
80
81
# File 'lib/the_plaid_api/models/loan_identifier.rb', line 77

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} loan_identifier: #{@loan_identifier}, loan_identifier_type:"\
  " #{@loan_identifier_type}, additional_properties: #{@additional_properties}>"
end