Class: ThePlaidApi::LoanPaymentsCounts

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/loan_payments_counts.rb

Overview

Details regarding the number of loan payments

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(current_count:, baseline_count: SKIP, additional_properties: nil) ⇒ LoanPaymentsCounts

Returns a new instance of LoanPaymentsCounts.



43
44
45
46
47
48
49
50
51
# File 'lib/the_plaid_api/models/loan_payments_counts.rb', line 43

def initialize(current_count:, baseline_count: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @baseline_count = baseline_count unless baseline_count == SKIP
  @current_count = current_count
  @additional_properties = additional_properties
end

Instance Attribute Details

#baseline_countFloat

The number of loan payments made in the 30 days before the subscription date

Returns:

  • (Float)


15
16
17
# File 'lib/the_plaid_api/models/loan_payments_counts.rb', line 15

def baseline_count
  @baseline_count
end

#current_countFloat

The current number of loan payments made in the last 30 days

Returns:

  • (Float)


19
20
21
# File 'lib/the_plaid_api/models/loan_payments_counts.rb', line 19

def current_count
  @current_count
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/the_plaid_api/models/loan_payments_counts.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  current_count = hash.key?('current_count') ? hash['current_count'] : nil
  baseline_count =
    hash.key?('baseline_count') ? hash['baseline_count'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  LoanPaymentsCounts.new(current_count: current_count,
                         baseline_count: baseline_count,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/the_plaid_api/models/loan_payments_counts.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['baseline_count'] = 'baseline_count'
  @_hash['current_count'] = 'current_count'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
40
41
# File 'lib/the_plaid_api/models/loan_payments_counts.rb', line 37

def self.nullables
  %w[
    baseline_count
  ]
end

.optionalsObject

An array for optional fields



30
31
32
33
34
# File 'lib/the_plaid_api/models/loan_payments_counts.rb', line 30

def self.optionals
  %w[
    baseline_count
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



83
84
85
86
87
# File 'lib/the_plaid_api/models/loan_payments_counts.rb', line 83

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} baseline_count: #{@baseline_count.inspect}, current_count:"\
  " #{@current_count.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



76
77
78
79
80
# File 'lib/the_plaid_api/models/loan_payments_counts.rb', line 76

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} baseline_count: #{@baseline_count}, current_count: #{@current_count},"\
  " additional_properties: #{@additional_properties}>"
end