Class: ThePlaidApi::MatchSummary

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/match_summary.rb

Overview

Summary object reflecting the match result of the associated data

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(summary:, additional_properties: nil) ⇒ MatchSummary

Returns a new instance of MatchSummary.



44
45
46
47
48
49
50
# File 'lib/the_plaid_api/models/match_summary.rb', line 44

def initialize(summary:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @summary = summary
  @additional_properties = additional_properties
end

Instance Attribute Details

#summaryMatchSummaryCode1

An enum indicating the match type between data provided by user and data checked against an external data source. ‘match` indicates that the provided input data was a strong match against external data. `partial_match` indicates the data approximately matched against external data. For example, “Knope” vs. “Knope-Wyatt” for last name. `no_match` indicates that Plaid was able to perform a check against an external data source and it did not match the provided input data. `no_data` indicates that Plaid was unable to find external data to compare against the provided input data. `no_input` indicates that Plaid was unable to perform a check because no information was provided for this field by the end user.

Returns:



25
26
27
# File 'lib/the_plaid_api/models/match_summary.rb', line 25

def summary
  @summary
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/the_plaid_api/models/match_summary.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  summary = hash.key?('summary') ? hash['summary'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  MatchSummary.new(summary: summary,
                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



28
29
30
31
32
# File 'lib/the_plaid_api/models/match_summary.rb', line 28

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['summary'] = 'summary'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/the_plaid_api/models/match_summary.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
# File 'lib/the_plaid_api/models/match_summary.rb', line 35

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
82
# File 'lib/the_plaid_api/models/match_summary.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} summary: #{@summary.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
# File 'lib/the_plaid_api/models/match_summary.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} summary: #{@summary}, additional_properties: #{@additional_properties}>"
end