Class: ThePlaidApi::Meta
- Defined in:
- lib/the_plaid_api/models/meta.rb
Overview
Allows specifying the metadata of the test account
Instance Attribute Summary collapse
-
#limit ⇒ Float
The account’s limit.
-
#mask ⇒ String
The account’s mask.
-
#name ⇒ String
The account’s name.
-
#official_name ⇒ String
The account’s official name.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name:, official_name:, limit:, mask:, additional_properties: nil) ⇒ Meta
constructor
A new instance of Meta.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name:, official_name:, limit:, mask:, additional_properties: nil) ⇒ Meta
Returns a new instance of Meta.
50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/the_plaid_api/models/meta.rb', line 50 def initialize(name:, official_name:, limit:, mask:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name @official_name = official_name @limit = limit @mask = mask @additional_properties = additional_properties end |
Instance Attribute Details
#limit ⇒ Float
The account’s limit
22 23 24 |
# File 'lib/the_plaid_api/models/meta.rb', line 22 def limit @limit end |
#mask ⇒ String
The account’s mask. Should be an empty string or a string of 2-4 alphanumeric characters. This allows you to model a mask which does not match the account number (such as with a virtual account number).
28 29 30 |
# File 'lib/the_plaid_api/models/meta.rb', line 28 def mask @mask end |
#name ⇒ String
The account’s name
14 15 16 |
# File 'lib/the_plaid_api/models/meta.rb', line 14 def name @name end |
#official_name ⇒ String
The account’s official name
18 19 20 |
# File 'lib/the_plaid_api/models/meta.rb', line 18 def official_name @official_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/the_plaid_api/models/meta.rb', line 63 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : nil official_name = hash.key?('official_name') ? hash['official_name'] : nil limit = hash.key?('limit') ? hash['limit'] : nil mask = hash.key?('mask') ? hash['mask'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Meta.new(name: name, official_name: official_name, limit: limit, mask: mask, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
31 32 33 34 35 36 37 38 |
# File 'lib/the_plaid_api/models/meta.rb', line 31 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['official_name'] = 'official_name' @_hash['limit'] = 'limit' @_hash['mask'] = 'mask' @_hash end |
.nullables ⇒ Object
An array for nullable fields
46 47 48 |
# File 'lib/the_plaid_api/models/meta.rb', line 46 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
41 42 43 |
# File 'lib/the_plaid_api/models/meta.rb', line 41 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
95 96 97 98 99 100 |
# File 'lib/the_plaid_api/models/meta.rb', line 95 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, official_name: #{@official_name.inspect}, limit:"\ " #{@limit.inspect}, mask: #{@mask.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
88 89 90 91 92 |
# File 'lib/the_plaid_api/models/meta.rb', line 88 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, official_name: #{@official_name}, limit: #{@limit}, mask:"\ " #{@mask}, additional_properties: #{@additional_properties}>" end |