Class: ThePlaidApi::MonitoringConsumerReportPermissiblePurpose

Inherits:
Object
  • Object
show all
Defined in:
lib/the_plaid_api/models/monitoring_consumer_report_permissible_purpose.rb

Overview

Describes the reason you are generating a Consumer Report for this user. ‘ACCOUNT_REVIEW_CREDIT`: In connection with a consumer credit transaction for the review or collection of an account pursuant to FCRA Section 604(a)(3)(A). `WRITTEN_INSTRUCTION_OTHER`: In accordance with the written instructions of the consumer pursuant to FCRA Section 604(a)(2), such as when an individual agrees to act as a guarantor or assumes personal liability for a consumer, business, or commercial loan.

Constant Summary collapse

MONITORING_CONSUMER_REPORT_PERMISSIBLE_PURPOSE =
[
  # TODO: Write general description for ACCOUNT_REVIEW_CREDIT
  ACCOUNT_REVIEW_CREDIT = 'ACCOUNT_REVIEW_CREDIT'.freeze,

  # TODO: Write general description for WRITTEN_INSTRUCTION_OTHER
  WRITTEN_INSTRUCTION_OTHER = 'WRITTEN_INSTRUCTION_OTHER'.freeze
].freeze

Class Method Summary collapse

Class Method Details

.from_value(value, default_value = ACCOUNT_REVIEW_CREDIT) ⇒ Object



29
30
31
32
33
34
35
36
37
38
39
40
# File 'lib/the_plaid_api/models/monitoring_consumer_report_permissible_purpose.rb', line 29

def self.from_value(value, default_value = ACCOUNT_REVIEW_CREDIT)
  return default_value if value.nil?

  str = value.to_s.strip

  case str.downcase
  when 'account_review_credit' then ACCOUNT_REVIEW_CREDIT
  when 'written_instruction_other' then WRITTEN_INSTRUCTION_OTHER
  else
    default_value
  end
end

.validate(value) ⇒ Object



23
24
25
26
27
# File 'lib/the_plaid_api/models/monitoring_consumer_report_permissible_purpose.rb', line 23

def self.validate(value)
  return false if value.nil?

  MONITORING_CONSUMER_REPORT_PERMISSIBLE_PURPOSE.include?(value)
end