Class: ThePlaidApi::MonitoringInsights

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/monitoring_insights.rb

Overview

An object representing the Monitoring Insights for the given Item

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(income:, loans:, additional_properties: nil) ⇒ MonitoringInsights

Returns a new instance of MonitoringInsights.



38
39
40
41
42
43
44
45
# File 'lib/the_plaid_api/models/monitoring_insights.rb', line 38

def initialize(income:, loans:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @income = income
  @loans = loans
  @additional_properties = additional_properties
end

Instance Attribute Details

#incomeMonitoringIncomeInsights

An object representing the income subcategory of the report



14
15
16
# File 'lib/the_plaid_api/models/monitoring_insights.rb', line 14

def income
  @income
end

#loansMonitoringLoanInsights

An object representing the loan exposure subcategory of the report



18
19
20
# File 'lib/the_plaid_api/models/monitoring_insights.rb', line 18

def loans
  @loans
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/the_plaid_api/models/monitoring_insights.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  income = MonitoringIncomeInsights.from_hash(hash['income']) if hash['income']
  loans = MonitoringLoanInsights.from_hash(hash['loans']) if hash['loans']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  MonitoringInsights.new(income: income,
                         loans: loans,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/the_plaid_api/models/monitoring_insights.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['income'] = 'income'
  @_hash['loans'] = 'loans'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/the_plaid_api/models/monitoring_insights.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/the_plaid_api/models/monitoring_insights.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



76
77
78
79
80
# File 'lib/the_plaid_api/models/monitoring_insights.rb', line 76

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} income: #{@income.inspect}, loans: #{@loans.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



69
70
71
72
73
# File 'lib/the_plaid_api/models/monitoring_insights.rb', line 69

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} income: #{@income}, loans: #{@loans}, additional_properties:"\
  " #{@additional_properties}>"
end