Class: ThePlaidApi::MonitoringInsightsItemStatus

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/monitoring_insights_item_status.rb

Overview

An object with details of the Monitoring Insights Item’s status.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(status_code:, reason: SKIP, additional_properties: nil) ⇒ MonitoringInsightsItemStatus

Returns a new instance of MonitoringInsightsItemStatus.



44
45
46
47
48
49
50
51
# File 'lib/the_plaid_api/models/monitoring_insights_item_status.rb', line 44

def initialize(status_code:, reason: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @status_code = status_code
  @reason = reason unless reason == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#reasonString

A reason for why a Monitoring Insights Report is not available. This field will only be populated when the ‘status_code` is not `AVAILABLE`

Returns:

  • (String)


20
21
22
# File 'lib/the_plaid_api/models/monitoring_insights_item_status.rb', line 20

def reason
  @reason
end

#status_codeMonitoringItemStatusCode

Enum for the status of the Item’s insights



14
15
16
# File 'lib/the_plaid_api/models/monitoring_insights_item_status.rb', line 14

def status_code
  @status_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/the_plaid_api/models/monitoring_insights_item_status.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  status_code = hash.key?('status_code') ? hash['status_code'] : nil
  reason = hash.key?('reason') ? hash['reason'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  MonitoringInsightsItemStatus.new(status_code: status_code,
                                   reason: reason,
                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/the_plaid_api/models/monitoring_insights_item_status.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['status_code'] = 'status_code'
  @_hash['reason'] = 'reason'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
41
42
# File 'lib/the_plaid_api/models/monitoring_insights_item_status.rb', line 38

def self.nullables
  %w[
    reason
  ]
end

.optionalsObject

An array for optional fields



31
32
33
34
35
# File 'lib/the_plaid_api/models/monitoring_insights_item_status.rb', line 31

def self.optionals
  %w[
    reason
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



82
83
84
85
86
# File 'lib/the_plaid_api/models/monitoring_insights_item_status.rb', line 82

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} status_code: #{@status_code.inspect}, reason: #{@reason.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



75
76
77
78
79
# File 'lib/the_plaid_api/models/monitoring_insights_item_status.rb', line 75

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} status_code: #{@status_code}, reason: #{@reason}, additional_properties:"\
  " #{@additional_properties}>"
end