Class: ThePlaidApi::Name

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/name.rb

Overview

Parent container for name that allows for choice group between parsed and unparsed containers.Parent container for name that allows for choice group between parsed and unparsed containers.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(first_name:, last_name:, additional_properties: nil) ⇒ Name

Returns a new instance of Name.



40
41
42
43
44
45
46
47
# File 'lib/the_plaid_api/models/name.rb', line 40

def initialize(first_name:, last_name:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @first_name = first_name
  @last_name = last_name
  @additional_properties = additional_properties
end

Instance Attribute Details

#first_nameString

The first name of the individual represented by the parent object.

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/name.rb', line 16

def first_name
  @first_name
end

#last_nameString

The last name of the individual represented by the parent object.

Returns:

  • (String)


20
21
22
# File 'lib/the_plaid_api/models/name.rb', line 20

def last_name
  @last_name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/the_plaid_api/models/name.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  first_name = hash.key?('FirstName') ? hash['FirstName'] : nil
  last_name = hash.key?('LastName') ? hash['LastName'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Name.new(first_name: first_name,
           last_name: last_name,
           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/the_plaid_api/models/name.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['first_name'] = 'FirstName'
  @_hash['last_name'] = 'LastName'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
# File 'lib/the_plaid_api/models/name.rb', line 36

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
# File 'lib/the_plaid_api/models/name.rb', line 31

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
82
# File 'lib/the_plaid_api/models/name.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} first_name: #{@first_name.inspect}, last_name: #{@last_name.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



71
72
73
74
75
# File 'lib/the_plaid_api/models/name.rb', line 71

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} first_name: #{@first_name}, last_name: #{@last_name},"\
  " additional_properties: #{@additional_properties}>"
end