Class: ThePlaidApi::NetworkStatusGetUser

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/network_status_get_user.rb

Overview

An object specifying information about the end user for the network status check.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(phone_number:, additional_properties: nil) ⇒ NetworkStatusGetUser

Returns a new instance of NetworkStatusGetUser.



35
36
37
38
39
40
41
# File 'lib/the_plaid_api/models/network_status_get_user.rb', line 35

def initialize(phone_number:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @phone_number = phone_number
  @additional_properties = additional_properties
end

Instance Attribute Details

#phone_numberString

The user’s phone number in [E.164](en.wikipedia.org/wiki/E.164) format.

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/network_status_get_user.rb', line 16

def phone_number
  @phone_number
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/the_plaid_api/models/network_status_get_user.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  phone_number = hash.key?('phone_number') ? hash['phone_number'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  NetworkStatusGetUser.new(phone_number: phone_number,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



19
20
21
22
23
# File 'lib/the_plaid_api/models/network_status_get_user.rb', line 19

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['phone_number'] = 'phone_number'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/the_plaid_api/models/network_status_get_user.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



26
27
28
# File 'lib/the_plaid_api/models/network_status_get_user.rb', line 26

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



70
71
72
73
74
# File 'lib/the_plaid_api/models/network_status_get_user.rb', line 70

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} phone_number: #{@phone_number.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



63
64
65
66
67
# File 'lib/the_plaid_api/models/network_status_get_user.rb', line 63

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} phone_number: #{@phone_number}, additional_properties:"\
  " #{@additional_properties}>"
end