Class: ThePlaidApi::NumbersBacs

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/numbers_bacs.rb

Overview

Identifying information for transferring money to or from a UK bank account via BACS.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_id:, account:, sort_code:, additional_properties: nil) ⇒ NumbersBacs

Returns a new instance of NumbersBacs.



44
45
46
47
48
49
50
51
52
53
# File 'lib/the_plaid_api/models/numbers_bacs.rb', line 44

def initialize(account_id:, account:, sort_code:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_id = 
  @account = 
  @sort_code = sort_code
  @additional_properties = additional_properties
end

Instance Attribute Details

#accountString

The BACS account number for the account

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/numbers_bacs.rb', line 19

def 
  @account
end

#account_idString

The Plaid account ID associated with the account numbers

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/numbers_bacs.rb', line 15

def 
  @account_id
end

#sort_codeString

The BACS sort code for the account

Returns:

  • (String)


23
24
25
# File 'lib/the_plaid_api/models/numbers_bacs.rb', line 23

def sort_code
  @sort_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/the_plaid_api/models/numbers_bacs.rb', line 56

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('account_id') ? hash['account_id'] : nil
   = hash.key?('account') ? hash['account'] : nil
  sort_code = hash.key?('sort_code') ? hash['sort_code'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  NumbersBacs.new(account_id: ,
                  account: ,
                  sort_code: sort_code,
                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/the_plaid_api/models/numbers_bacs.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_id'] = 'account_id'
  @_hash['account'] = 'account'
  @_hash['sort_code'] = 'sort_code'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/the_plaid_api/models/numbers_bacs.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
# File 'lib/the_plaid_api/models/numbers_bacs.rb', line 35

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



86
87
88
89
90
# File 'lib/the_plaid_api/models/numbers_bacs.rb', line 86

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_id: #{@account_id.inspect}, account: #{@account.inspect},"\
  " sort_code: #{@sort_code.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



79
80
81
82
83
# File 'lib/the_plaid_api/models/numbers_bacs.rb', line 79

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_id: #{@account_id}, account: #{@account}, sort_code: #{@sort_code},"\
  " additional_properties: #{@additional_properties}>"
end