Class: ThePlaidApi::NumbersEftNullable

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/numbers_eft_nullable.rb

Overview

Identifying information for transferring money to or from a Canadian bank account via EFT.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_id:, account:, institution:, branch:, additional_properties: nil) ⇒ NumbersEftNullable

Returns a new instance of NumbersEftNullable.



49
50
51
52
53
54
55
56
57
58
59
# File 'lib/the_plaid_api/models/numbers_eft_nullable.rb', line 49

def initialize(account_id:, account:, institution:, branch:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_id = 
  @account = 
  @institution = institution
  @branch = branch
  @additional_properties = additional_properties
end

Instance Attribute Details

#accountString

The EFT account number for the account

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/numbers_eft_nullable.rb', line 19

def 
  @account
end

#account_idString

The Plaid account ID associated with the account numbers

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/numbers_eft_nullable.rb', line 15

def 
  @account_id
end

#branchString

The EFT branch number for the account

Returns:

  • (String)


27
28
29
# File 'lib/the_plaid_api/models/numbers_eft_nullable.rb', line 27

def branch
  @branch
end

#institutionString

The EFT institution number for the account

Returns:

  • (String)


23
24
25
# File 'lib/the_plaid_api/models/numbers_eft_nullable.rb', line 23

def institution
  @institution
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/the_plaid_api/models/numbers_eft_nullable.rb', line 62

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('account_id') ? hash['account_id'] : nil
   = hash.key?('account') ? hash['account'] : nil
  institution = hash.key?('institution') ? hash['institution'] : nil
  branch = hash.key?('branch') ? hash['branch'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  NumbersEftNullable.new(account_id: ,
                         account: ,
                         institution: institution,
                         branch: branch,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



30
31
32
33
34
35
36
37
# File 'lib/the_plaid_api/models/numbers_eft_nullable.rb', line 30

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_id'] = 'account_id'
  @_hash['account'] = 'account'
  @_hash['institution'] = 'institution'
  @_hash['branch'] = 'branch'
  @_hash
end

.nullablesObject

An array for nullable fields



45
46
47
# File 'lib/the_plaid_api/models/numbers_eft_nullable.rb', line 45

def self.nullables
  []
end

.optionalsObject

An array for optional fields



40
41
42
# File 'lib/the_plaid_api/models/numbers_eft_nullable.rb', line 40

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



94
95
96
97
98
99
# File 'lib/the_plaid_api/models/numbers_eft_nullable.rb', line 94

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_id: #{@account_id.inspect}, account: #{@account.inspect},"\
  " institution: #{@institution.inspect}, branch: #{@branch.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



87
88
89
90
91
# File 'lib/the_plaid_api/models/numbers_eft_nullable.rb', line 87

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_id: #{@account_id}, account: #{@account}, institution:"\
  " #{@institution}, branch: #{@branch}, additional_properties: #{@additional_properties}>"
end