Class: ThePlaidApi::NumbersInternational
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::NumbersInternational
- Defined in:
- lib/the_plaid_api/models/numbers_international.rb
Overview
Identifying information for transferring money to or from an international bank account via wire transfer.
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Plaid account ID associated with the account numbers.
-
#bic ⇒ String
The Bank Identifier Code (BIC) for the account.
-
#iban ⇒ String
The International Bank Account Number (IBAN) for the account.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_id:, iban:, bic:, additional_properties: nil) ⇒ NumbersInternational
constructor
A new instance of NumbersInternational.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_id:, iban:, bic:, additional_properties: nil) ⇒ NumbersInternational
Returns a new instance of NumbersInternational.
44 45 46 47 48 49 50 51 52 |
# File 'lib/the_plaid_api/models/numbers_international.rb', line 44 def initialize(account_id:, iban:, bic:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_id = account_id @iban = iban @bic = bic @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
The Plaid account ID associated with the account numbers
15 16 17 |
# File 'lib/the_plaid_api/models/numbers_international.rb', line 15 def account_id @account_id end |
#bic ⇒ String
The Bank Identifier Code (BIC) for the account
23 24 25 |
# File 'lib/the_plaid_api/models/numbers_international.rb', line 23 def bic @bic end |
#iban ⇒ String
The International Bank Account Number (IBAN) for the account
19 20 21 |
# File 'lib/the_plaid_api/models/numbers_international.rb', line 19 def iban @iban end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/the_plaid_api/models/numbers_international.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_id = hash.key?('account_id') ? hash['account_id'] : nil iban = hash.key?('iban') ? hash['iban'] : nil bic = hash.key?('bic') ? hash['bic'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. NumbersInternational.new(account_id: account_id, iban: iban, bic: bic, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/the_plaid_api/models/numbers_international.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['account_id'] = 'account_id' @_hash['iban'] = 'iban' @_hash['bic'] = 'bic' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/the_plaid_api/models/numbers_international.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/the_plaid_api/models/numbers_international.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 |
# File 'lib/the_plaid_api/models/numbers_international.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_id: #{@account_id.inspect}, iban: #{@iban.inspect}, bic:"\ " #{@bic.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/the_plaid_api/models/numbers_international.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_id: #{@account_id}, iban: #{@iban}, bic: #{@bic},"\ " additional_properties: #{@additional_properties}>" end |