Class: ThePlaidApi::NumbersRetirement401K

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/numbers_retirement401_k.rb

Overview

Identifying information for transferring holdings from a 401k account to another 401k account or IRA via the manual 401k rollover process.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_id:, plan: SKIP, account: SKIP, additional_properties: nil) ⇒ NumbersRetirement401K

Returns a new instance of NumbersRetirement401K.



47
48
49
50
51
52
53
54
55
56
# File 'lib/the_plaid_api/models/numbers_retirement401_k.rb', line 47

def initialize(account_id:, plan: SKIP, account: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_id = 
  @plan = plan unless plan == SKIP
  @account =  unless  == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#accountString

The full account number for the account

Returns:

  • (String)


23
24
25
# File 'lib/the_plaid_api/models/numbers_retirement401_k.rb', line 23

def 
  @account
end

#account_idString

The Plaid account ID associated with the account numbers

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/numbers_retirement401_k.rb', line 15

def 
  @account_id
end

#planString

The plan number for the employer’s 401k retirement plan

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/numbers_retirement401_k.rb', line 19

def plan
  @plan
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/the_plaid_api/models/numbers_retirement401_k.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('account_id') ? hash['account_id'] : nil
  plan = hash.key?('plan') ? hash['plan'] : SKIP
   = hash.key?('account') ? hash['account'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  NumbersRetirement401K.new(account_id: ,
                            plan: plan,
                            account: ,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/the_plaid_api/models/numbers_retirement401_k.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_id'] = 'account_id'
  @_hash['plan'] = 'plan'
  @_hash['account'] = 'account'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/the_plaid_api/models/numbers_retirement401_k.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
# File 'lib/the_plaid_api/models/numbers_retirement401_k.rb', line 35

def self.optionals
  %w[
    plan
    account
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/the_plaid_api/models/numbers_retirement401_k.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_id: #{@account_id.inspect}, plan: #{@plan.inspect}, account:"\
  " #{@account.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/the_plaid_api/models/numbers_retirement401_k.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_id: #{@account_id}, plan: #{@plan}, account: #{@account},"\
  " additional_properties: #{@additional_properties}>"
end