Class: ThePlaidApi::OauthIntrospectRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::OauthIntrospectRequest
- Defined in:
- lib/the_plaid_api/models/oauth_introspect_request.rb
Overview
OAuth token introspect request.
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#client_secret ⇒ String
Your Plaid API ‘secret`.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#token ⇒ String
An OAuth token of any type (‘refresh_token`, `access_token`, etc).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(token:, client_id: SKIP, client_secret: SKIP, secret: SKIP, additional_properties: nil) ⇒ OauthIntrospectRequest
constructor
A new instance of OauthIntrospectRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(token:, client_id: SKIP, client_secret: SKIP, secret: SKIP, additional_properties: nil) ⇒ OauthIntrospectRequest
Returns a new instance of OauthIntrospectRequest.
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/the_plaid_api/models/oauth_introspect_request.rb', line 58 def initialize(token:, client_id: SKIP, client_secret: SKIP, secret: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @token = token @client_id = client_id unless client_id == SKIP @client_secret = client_secret unless client_secret == SKIP @secret = secret unless secret == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
20 21 22 |
# File 'lib/the_plaid_api/models/oauth_introspect_request.rb', line 20 def client_id @client_id end |
#client_secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body as either `secret` or `client_secret`.
26 27 28 |
# File 'lib/the_plaid_api/models/oauth_introspect_request.rb', line 26 def client_secret @client_secret end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body as either `secret` or `client_secret`.
32 33 34 |
# File 'lib/the_plaid_api/models/oauth_introspect_request.rb', line 32 def secret @secret end |
#token ⇒ String
An OAuth token of any type (‘refresh_token`, `access_token`, etc)
14 15 16 |
# File 'lib/the_plaid_api/models/oauth_introspect_request.rb', line 14 def token @token end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/the_plaid_api/models/oauth_introspect_request.rb', line 71 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. token = hash.key?('token') ? hash['token'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP client_secret = hash.key?('client_secret') ? hash['client_secret'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. OauthIntrospectRequest.new(token: token, client_id: client_id, client_secret: client_secret, secret: secret, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
35 36 37 38 39 40 41 42 |
# File 'lib/the_plaid_api/models/oauth_introspect_request.rb', line 35 def self.names @_hash = {} if @_hash.nil? @_hash['token'] = 'token' @_hash['client_id'] = 'client_id' @_hash['client_secret'] = 'client_secret' @_hash['secret'] = 'secret' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 |
# File 'lib/the_plaid_api/models/oauth_introspect_request.rb', line 54 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
45 46 47 48 49 50 51 |
# File 'lib/the_plaid_api/models/oauth_introspect_request.rb', line 45 def self.optionals %w[ client_id client_secret secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
103 104 105 106 107 108 |
# File 'lib/the_plaid_api/models/oauth_introspect_request.rb', line 103 def inspect class_name = self.class.name.split('::').last "<#{class_name} token: #{@token.inspect}, client_id: #{@client_id.inspect}, client_secret:"\ " #{@client_secret.inspect}, secret: #{@secret.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
96 97 98 99 100 |
# File 'lib/the_plaid_api/models/oauth_introspect_request.rb', line 96 def to_s class_name = self.class.name.split('::').last "<#{class_name} token: #{@token}, client_id: #{@client_id}, client_secret:"\ " #{@client_secret}, secret: #{@secret}, additional_properties: #{@additional_properties}>" end |