Class: ThePlaidApi::OauthTokenResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/oauth_token_response.rb

Overview

OAuth token grant success response

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(access_token:, refresh_token:, token_type:, expires_in:, request_id:, additional_properties: nil) ⇒ OauthTokenResponse

Returns a new instance of OauthTokenResponse.



55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/the_plaid_api/models/oauth_token_response.rb', line 55

def initialize(access_token:, refresh_token:, token_type:, expires_in:,
               request_id:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @access_token = access_token
  @refresh_token = refresh_token
  @token_type = token_type
  @expires_in = expires_in
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#access_tokenString

Access token for OAuth

Returns:

  • (String)


14
15
16
# File 'lib/the_plaid_api/models/oauth_token_response.rb', line 14

def access_token
  @access_token
end

#expires_inInteger

Time remaining in seconds before expiration

Returns:

  • (Integer)


26
27
28
# File 'lib/the_plaid_api/models/oauth_token_response.rb', line 26

def expires_in
  @expires_in
end

#refresh_tokenString

Refresh token for OAuth

Returns:

  • (String)


18
19
20
# File 'lib/the_plaid_api/models/oauth_token_response.rb', line 18

def refresh_token
  @refresh_token
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


32
33
34
# File 'lib/the_plaid_api/models/oauth_token_response.rb', line 32

def request_id
  @request_id
end

#token_typeString

Type of token the access token is. Currently it is always Bearer

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/oauth_token_response.rb', line 22

def token_type
  @token_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/the_plaid_api/models/oauth_token_response.rb', line 69

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  access_token = hash.key?('access_token') ? hash['access_token'] : nil
  refresh_token = hash.key?('refresh_token') ? hash['refresh_token'] : nil
  token_type = hash.key?('token_type') ? hash['token_type'] : nil
  expires_in = hash.key?('expires_in') ? hash['expires_in'] : nil
  request_id = hash.key?('request_id') ? hash['request_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  OauthTokenResponse.new(access_token: access_token,
                         refresh_token: refresh_token,
                         token_type: token_type,
                         expires_in: expires_in,
                         request_id: request_id,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



35
36
37
38
39
40
41
42
43
# File 'lib/the_plaid_api/models/oauth_token_response.rb', line 35

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['access_token'] = 'access_token'
  @_hash['refresh_token'] = 'refresh_token'
  @_hash['token_type'] = 'token_type'
  @_hash['expires_in'] = 'expires_in'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



51
52
53
# File 'lib/the_plaid_api/models/oauth_token_response.rb', line 51

def self.nullables
  []
end

.optionalsObject

An array for optional fields



46
47
48
# File 'lib/the_plaid_api/models/oauth_token_response.rb', line 46

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



104
105
106
107
108
109
110
# File 'lib/the_plaid_api/models/oauth_token_response.rb', line 104

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} access_token: #{@access_token.inspect}, refresh_token:"\
  " #{@refresh_token.inspect}, token_type: #{@token_type.inspect}, expires_in:"\
  " #{@expires_in.inspect}, request_id: #{@request_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



96
97
98
99
100
101
# File 'lib/the_plaid_api/models/oauth_token_response.rb', line 96

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} access_token: #{@access_token}, refresh_token: #{@refresh_token},"\
  " token_type: #{@token_type}, expires_in: #{@expires_in}, request_id: #{@request_id},"\
  " additional_properties: #{@additional_properties}>"
end