Class: ThePlaidApi::OtherFilter

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/other_filter.rb

Overview

A filter to apply to ‘other`-type accounts

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_subtypes:, additional_properties: nil) ⇒ OtherFilter

Returns a new instance of OtherFilter.



36
37
38
39
40
41
42
# File 'lib/the_plaid_api/models/other_filter.rb', line 36

def initialize(account_subtypes:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account_subtypes = 
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_subtypesArray[OtherAccountSubtype]

An array of account subtypes to display in Link. If not specified, all account subtypes will be shown. For a full list of valid types and subtypes, see the [Account schema](plaid.com/docs/api/accounts#account-type-schema).

Returns:



17
18
19
# File 'lib/the_plaid_api/models/other_filter.rb', line 17

def 
  @account_subtypes
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/the_plaid_api/models/other_filter.rb', line 45

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   =
    hash.key?('account_subtypes') ? hash['account_subtypes'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  OtherFilter.new(account_subtypes: ,
                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



20
21
22
23
24
# File 'lib/the_plaid_api/models/other_filter.rb', line 20

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_subtypes'] = 'account_subtypes'
  @_hash
end

.nullablesObject

An array for nullable fields



32
33
34
# File 'lib/the_plaid_api/models/other_filter.rb', line 32

def self.nullables
  []
end

.optionalsObject

An array for optional fields



27
28
29
# File 'lib/the_plaid_api/models/other_filter.rb', line 27

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



72
73
74
75
76
# File 'lib/the_plaid_api/models/other_filter.rb', line 72

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_subtypes: #{@account_subtypes.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



65
66
67
68
69
# File 'lib/the_plaid_api/models/other_filter.rb', line 65

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_subtypes: #{@account_subtypes}, additional_properties:"\
  " #{@additional_properties}>"
end