Class: ThePlaidApi::PartnerCustomerCreateResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::PartnerCustomerCreateResponse
- Defined in:
- lib/the_plaid_api/models/partner_customer_create_response.rb
Overview
Response schema for ‘/partner/customer/create`.
Instance Attribute Summary collapse
-
#end_customer ⇒ PartnerEndCustomerWithSecrets
The details for the newly created end customer, including secrets for non-Production environments.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(end_customer: SKIP, request_id: SKIP, additional_properties: nil) ⇒ PartnerCustomerCreateResponse
constructor
A new instance of PartnerCustomerCreateResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(end_customer: SKIP, request_id: SKIP, additional_properties: nil) ⇒ PartnerCustomerCreateResponse
Returns a new instance of PartnerCustomerCreateResponse.
44 45 46 47 48 49 50 51 52 |
# File 'lib/the_plaid_api/models/partner_customer_create_response.rb', line 44 def initialize(end_customer: SKIP, request_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @end_customer = end_customer unless end_customer == SKIP @request_id = request_id unless request_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#end_customer ⇒ PartnerEndCustomerWithSecrets
The details for the newly created end customer, including secrets for non-Production environments.
15 16 17 |
# File 'lib/the_plaid_api/models/partner_customer_create_response.rb', line 15 def end_customer @end_customer end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
21 22 23 |
# File 'lib/the_plaid_api/models/partner_customer_create_response.rb', line 21 def request_id @request_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/the_plaid_api/models/partner_customer_create_response.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. end_customer = PartnerEndCustomerWithSecrets.from_hash(hash['end_customer']) if hash['end_customer'] request_id = hash.key?('request_id') ? hash['request_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PartnerCustomerCreateResponse.new(end_customer: end_customer, request_id: request_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/the_plaid_api/models/partner_customer_create_response.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['end_customer'] = 'end_customer' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/the_plaid_api/models/partner_customer_create_response.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 35 36 37 |
# File 'lib/the_plaid_api/models/partner_customer_create_response.rb', line 32 def self.optionals %w[ end_customer request_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/the_plaid_api/models/partner_customer_create_response.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} end_customer: #{@end_customer.inspect}, request_id: #{@request_id.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 81 |
# File 'lib/the_plaid_api/models/partner_customer_create_response.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} end_customer: #{@end_customer}, request_id: #{@request_id},"\ " additional_properties: #{@additional_properties}>" end |