Class: ThePlaidApi::PartnerCustomerOauthInstitutionsGetResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/partner_customer_oauth_institutions_get_response.rb

Overview

Response schema for ‘/partner/customer/oauth_institutions/get`.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(flowdown_status: SKIP, questionnaire_status: SKIP, institutions: SKIP, request_id: SKIP, additional_properties: nil) ⇒ PartnerCustomerOauthInstitutionsGetResponse

Returns a new instance of PartnerCustomerOauthInstitutionsGetResponse.



57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/the_plaid_api/models/partner_customer_oauth_institutions_get_response.rb', line 57

def initialize(flowdown_status: SKIP, questionnaire_status: SKIP,
               institutions: SKIP, request_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @flowdown_status = flowdown_status unless flowdown_status == SKIP
  @questionnaire_status = questionnaire_status unless questionnaire_status == SKIP
  @institutions = institutions unless institutions == SKIP
  @request_id = request_id unless request_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#flowdown_statusPartnerEndCustomerFlowdownStatus

The status of the addendum to the Plaid MSA (“flowdown”) for the end customer.



15
16
17
# File 'lib/the_plaid_api/models/partner_customer_oauth_institutions_get_response.rb', line 15

def flowdown_status
  @flowdown_status
end

#institutionsArray[PartnerEndCustomerOauthInstitution]

The OAuth institutions with which the end customer’s application is being registered.



24
25
26
# File 'lib/the_plaid_api/models/partner_customer_oauth_institutions_get_response.rb', line 24

def institutions
  @institutions
end

#questionnaire_statusPartnerEndCustomerQuestionnaireStatus

The status of the end customer’s security questionnaire.



19
20
21
# File 'lib/the_plaid_api/models/partner_customer_oauth_institutions_get_response.rb', line 19

def questionnaire_status
  @questionnaire_status
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


30
31
32
# File 'lib/the_plaid_api/models/partner_customer_oauth_institutions_get_response.rb', line 30

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/the_plaid_api/models/partner_customer_oauth_institutions_get_response.rb', line 71

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  flowdown_status =
    hash.key?('flowdown_status') ? hash['flowdown_status'] : SKIP
  questionnaire_status =
    hash.key?('questionnaire_status') ? hash['questionnaire_status'] : SKIP
  # Parameter is an array, so we need to iterate through it
  institutions = nil
  unless hash['institutions'].nil?
    institutions = []
    hash['institutions'].each do |structure|
      institutions << (PartnerEndCustomerOauthInstitution.from_hash(structure) if structure)
    end
  end

  institutions = SKIP unless hash.key?('institutions')
  request_id = hash.key?('request_id') ? hash['request_id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PartnerCustomerOauthInstitutionsGetResponse.new(flowdown_status: flowdown_status,
                                                  questionnaire_status: questionnaire_status,
                                                  institutions: institutions,
                                                  request_id: request_id,
                                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
# File 'lib/the_plaid_api/models/partner_customer_oauth_institutions_get_response.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['flowdown_status'] = 'flowdown_status'
  @_hash['questionnaire_status'] = 'questionnaire_status'
  @_hash['institutions'] = 'institutions'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



53
54
55
# File 'lib/the_plaid_api/models/partner_customer_oauth_institutions_get_response.rb', line 53

def self.nullables
  []
end

.optionalsObject

An array for optional fields



43
44
45
46
47
48
49
50
# File 'lib/the_plaid_api/models/partner_customer_oauth_institutions_get_response.rb', line 43

def self.optionals
  %w[
    flowdown_status
    questionnaire_status
    institutions
    request_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



115
116
117
118
119
120
# File 'lib/the_plaid_api/models/partner_customer_oauth_institutions_get_response.rb', line 115

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} flowdown_status: #{@flowdown_status.inspect}, questionnaire_status:"\
  " #{@questionnaire_status.inspect}, institutions: #{@institutions.inspect}, request_id:"\
  " #{@request_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



107
108
109
110
111
112
# File 'lib/the_plaid_api/models/partner_customer_oauth_institutions_get_response.rb', line 107

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} flowdown_status: #{@flowdown_status}, questionnaire_status:"\
  " #{@questionnaire_status}, institutions: #{@institutions}, request_id: #{@request_id},"\
  " additional_properties: #{@additional_properties}>"
end