Class: ThePlaidApi::PartnerEndCustomerAddress

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/partner_end_customer_address.rb

Overview

The end customer’s address.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(city: SKIP, street: SKIP, region: SKIP, postal_code: SKIP, country_code: SKIP, additional_properties: nil) ⇒ PartnerEndCustomerAddress

Returns a new instance of PartnerEndCustomerAddress.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/the_plaid_api/models/partner_end_customer_address.rb', line 59

def initialize(city: SKIP, street: SKIP, region: SKIP, postal_code: SKIP,
               country_code: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @city = city unless city == SKIP
  @street = street unless street == SKIP
  @region = region unless region == SKIP
  @postal_code = postal_code unless postal_code == SKIP
  @country_code = country_code unless country_code == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#cityString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/the_plaid_api/models/partner_end_customer_address.rb', line 14

def city
  @city
end

#country_codeString

ISO-3166-1 alpha-2 country code standard.

Returns:

  • (String)


30
31
32
# File 'lib/the_plaid_api/models/partner_end_customer_address.rb', line 30

def country_code
  @country_code
end

#postal_codeString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/the_plaid_api/models/partner_end_customer_address.rb', line 26

def postal_code
  @postal_code
end

#regionString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/partner_end_customer_address.rb', line 22

def region
  @region
end

#streetString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/the_plaid_api/models/partner_end_customer_address.rb', line 18

def street
  @street
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/the_plaid_api/models/partner_end_customer_address.rb', line 73

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  city = hash.key?('city') ? hash['city'] : SKIP
  street = hash.key?('street') ? hash['street'] : SKIP
  region = hash.key?('region') ? hash['region'] : SKIP
  postal_code = hash.key?('postal_code') ? hash['postal_code'] : SKIP
  country_code = hash.key?('country_code') ? hash['country_code'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PartnerEndCustomerAddress.new(city: city,
                                street: street,
                                region: region,
                                postal_code: postal_code,
                                country_code: country_code,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
# File 'lib/the_plaid_api/models/partner_end_customer_address.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['city'] = 'city'
  @_hash['street'] = 'street'
  @_hash['region'] = 'region'
  @_hash['postal_code'] = 'postal_code'
  @_hash['country_code'] = 'country_code'
  @_hash
end

.nullablesObject

An array for nullable fields



55
56
57
# File 'lib/the_plaid_api/models/partner_end_customer_address.rb', line 55

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
47
48
49
50
51
52
# File 'lib/the_plaid_api/models/partner_end_customer_address.rb', line 44

def self.optionals
  %w[
    city
    street
    region
    postal_code
    country_code
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



108
109
110
111
112
113
# File 'lib/the_plaid_api/models/partner_end_customer_address.rb', line 108

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} city: #{@city.inspect}, street: #{@street.inspect}, region:"\
  " #{@region.inspect}, postal_code: #{@postal_code.inspect}, country_code:"\
  " #{@country_code.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



100
101
102
103
104
105
# File 'lib/the_plaid_api/models/partner_end_customer_address.rb', line 100

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} city: #{@city}, street: #{@street}, region: #{@region}, postal_code:"\
  " #{@postal_code}, country_code: #{@country_code}, additional_properties:"\
  " #{@additional_properties}>"
end