Class: ThePlaidApi::PartnerEndCustomerAssetsUnderManagement

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/partner_end_customer_assets_under_management.rb

Overview

Assets under management for the given end customer. Required for end customers with monthly service commitments.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(amount:, iso_currency_code:, additional_properties: nil) ⇒ PartnerEndCustomerAssetsUnderManagement

Returns a new instance of PartnerEndCustomerAssetsUnderManagement.



39
40
41
42
43
44
45
46
# File 'lib/the_plaid_api/models/partner_end_customer_assets_under_management.rb', line 39

def initialize(amount:, iso_currency_code:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @amount = amount
  @iso_currency_code = iso_currency_code
  @additional_properties = additional_properties
end

Instance Attribute Details

#amountFloat

TODO: Write general description for this method

Returns:

  • (Float)


15
16
17
# File 'lib/the_plaid_api/models/partner_end_customer_assets_under_management.rb', line 15

def amount
  @amount
end

#iso_currency_codeString

TODO: Write general description for this method

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/partner_end_customer_assets_under_management.rb', line 19

def iso_currency_code
  @iso_currency_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/the_plaid_api/models/partner_end_customer_assets_under_management.rb', line 49

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  amount = hash.key?('amount') ? hash['amount'] : nil
  iso_currency_code =
    hash.key?('iso_currency_code') ? hash['iso_currency_code'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PartnerEndCustomerAssetsUnderManagement.new(amount: amount,
                                              iso_currency_code: iso_currency_code,
                                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/the_plaid_api/models/partner_end_customer_assets_under_management.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['amount'] = 'amount'
  @_hash['iso_currency_code'] = 'iso_currency_code'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
# File 'lib/the_plaid_api/models/partner_end_customer_assets_under_management.rb', line 35

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
# File 'lib/the_plaid_api/models/partner_end_customer_assets_under_management.rb', line 30

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
82
# File 'lib/the_plaid_api/models/partner_end_customer_assets_under_management.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} amount: #{@amount.inspect}, iso_currency_code:"\
  " #{@iso_currency_code.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



71
72
73
74
75
# File 'lib/the_plaid_api/models/partner_end_customer_assets_under_management.rb', line 71

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} amount: #{@amount}, iso_currency_code: #{@iso_currency_code},"\
  " additional_properties: #{@additional_properties}>"
end