Class: ThePlaidApi::PartnerEndCustomerCraUseCases

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/partner_end_customer_cra_use_cases.rb

Overview

The list of use cases associated with a given permissible purpose.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(use_cases: SKIP, additional_properties: nil) ⇒ PartnerEndCustomerCraUseCases

Returns a new instance of PartnerEndCustomerCraUseCases.



35
36
37
38
39
40
41
# File 'lib/the_plaid_api/models/partner_end_customer_cra_use_cases.rb', line 35

def initialize(use_cases: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @use_cases = use_cases unless use_cases == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#use_casesArray[PartnerEndCustomerCraUseCase]

List of use cases for the given permissible purpose.

Returns:



14
15
16
# File 'lib/the_plaid_api/models/partner_end_customer_cra_use_cases.rb', line 14

def use_cases
  @use_cases
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/the_plaid_api/models/partner_end_customer_cra_use_cases.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  use_cases = hash.key?('use_cases') ? hash['use_cases'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PartnerEndCustomerCraUseCases.new(use_cases: use_cases,
                                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/the_plaid_api/models/partner_end_customer_cra_use_cases.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['use_cases'] = 'use_cases'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/the_plaid_api/models/partner_end_customer_cra_use_cases.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/the_plaid_api/models/partner_end_customer_cra_use_cases.rb', line 24

def self.optionals
  %w[
    use_cases
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



70
71
72
73
74
# File 'lib/the_plaid_api/models/partner_end_customer_cra_use_cases.rb', line 70

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} use_cases: #{@use_cases.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



63
64
65
66
67
# File 'lib/the_plaid_api/models/partner_end_customer_cra_use_cases.rb', line 63

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} use_cases: #{@use_cases}, additional_properties:"\
  " #{@additional_properties}>"
end