Class: ThePlaidApi::PartnerEndCustomerOauthInstitutionEnvironments

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/partner_end_customer_oauth_institution_environments.rb

Overview

Registration statuses by environment.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(development: SKIP, production: SKIP, additional_properties: nil) ⇒ PartnerEndCustomerOauthInstitutionEnvironments

Returns a new instance of PartnerEndCustomerOauthInstitutionEnvironments.



41
42
43
44
45
46
47
48
49
# File 'lib/the_plaid_api/models/partner_end_customer_oauth_institution_environments.rb', line 41

def initialize(development: SKIP, production: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @development = development unless development == SKIP
  @production = production unless production == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#developmentPartnerEndCustomerOauthInstitutionApplicationStatus

The registration status for the end customer’s application.



14
15
16
# File 'lib/the_plaid_api/models/partner_end_customer_oauth_institution_environments.rb', line 14

def development
  @development
end

#productionPartnerEndCustomerOauthInstitutionApplicationStatus

The registration status for the end customer’s application.



18
19
20
# File 'lib/the_plaid_api/models/partner_end_customer_oauth_institution_environments.rb', line 18

def production
  @production
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/the_plaid_api/models/partner_end_customer_oauth_institution_environments.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  development = hash.key?('development') ? hash['development'] : SKIP
  production = hash.key?('production') ? hash['production'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PartnerEndCustomerOauthInstitutionEnvironments.new(development: development,
                                                     production: production,
                                                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/the_plaid_api/models/partner_end_customer_oauth_institution_environments.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['development'] = 'development'
  @_hash['production'] = 'production'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/the_plaid_api/models/partner_end_customer_oauth_institution_environments.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/the_plaid_api/models/partner_end_customer_oauth_institution_environments.rb', line 29

def self.optionals
  %w[
    development
    production
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/the_plaid_api/models/partner_end_customer_oauth_institution_environments.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} development: #{@development.inspect}, production: #{@production.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/the_plaid_api/models/partner_end_customer_oauth_institution_environments.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} development: #{@development}, production: #{@production},"\
  " additional_properties: #{@additional_properties}>"
end