Class: ThePlaidApi::PartnerEndCustomerSecrets

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/partner_end_customer_secrets.rb

Overview

The secrets for the newly created end customer.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(sandbox: SKIP, development: SKIP, production: SKIP, additional_properties: nil) ⇒ PartnerEndCustomerSecrets

Returns a new instance of PartnerEndCustomerSecrets.



50
51
52
53
54
55
56
57
58
59
# File 'lib/the_plaid_api/models/partner_end_customer_secrets.rb', line 50

def initialize(sandbox: SKIP, development: SKIP, production: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @sandbox = sandbox unless sandbox == SKIP
  @development = development unless development == SKIP
  @production = production unless production == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#developmentString

The end customer’s secret key for the Development environment. The Development environment has been removed.

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/partner_end_customer_secrets.rb', line 19

def development
  @development
end

#productionString

The end customer’s secret key for the Production environment. The end customer will be provided with a limited number of credits to test in the Production environment before full enablement.

Returns:

  • (String)


25
26
27
# File 'lib/the_plaid_api/models/partner_end_customer_secrets.rb', line 25

def production
  @production
end

#sandboxString

The end customer’s secret key for the Sandbox environment.

Returns:

  • (String)


14
15
16
# File 'lib/the_plaid_api/models/partner_end_customer_secrets.rb', line 14

def sandbox
  @sandbox
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/the_plaid_api/models/partner_end_customer_secrets.rb', line 62

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  sandbox = hash.key?('sandbox') ? hash['sandbox'] : SKIP
  development = hash.key?('development') ? hash['development'] : SKIP
  production = hash.key?('production') ? hash['production'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PartnerEndCustomerSecrets.new(sandbox: sandbox,
                                development: development,
                                production: production,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



28
29
30
31
32
33
34
# File 'lib/the_plaid_api/models/partner_end_customer_secrets.rb', line 28

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['sandbox'] = 'sandbox'
  @_hash['development'] = 'development'
  @_hash['production'] = 'production'
  @_hash
end

.nullablesObject

An array for nullable fields



46
47
48
# File 'lib/the_plaid_api/models/partner_end_customer_secrets.rb', line 46

def self.nullables
  []
end

.optionalsObject

An array for optional fields



37
38
39
40
41
42
43
# File 'lib/the_plaid_api/models/partner_end_customer_secrets.rb', line 37

def self.optionals
  %w[
    sandbox
    development
    production
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



92
93
94
95
96
# File 'lib/the_plaid_api/models/partner_end_customer_secrets.rb', line 92

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} sandbox: #{@sandbox.inspect}, development: #{@development.inspect},"\
  " production: #{@production.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



85
86
87
88
89
# File 'lib/the_plaid_api/models/partner_end_customer_secrets.rb', line 85

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} sandbox: #{@sandbox}, development: #{@development}, production:"\
  " #{@production}, additional_properties: #{@additional_properties}>"
end