Class: ThePlaidApi::Pay
- Defined in:
- lib/the_plaid_api/models/pay.rb
Overview
An object representing a monetary amount.
Instance Attribute Summary collapse
-
#amount ⇒ Float
A numerical amount of a specific currency.
-
#currency ⇒ String
Currency code, e.g.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(amount: SKIP, currency: SKIP, additional_properties: nil) ⇒ Pay
constructor
A new instance of Pay.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(amount: SKIP, currency: SKIP, additional_properties: nil) ⇒ Pay
Returns a new instance of Pay.
44 45 46 47 48 49 50 51 |
# File 'lib/the_plaid_api/models/pay.rb', line 44 def initialize(amount: SKIP, currency: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @amount = amount unless amount == SKIP @currency = currency unless currency == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#amount ⇒ Float
A numerical amount of a specific currency.
14 15 16 |
# File 'lib/the_plaid_api/models/pay.rb', line 14 def amount @amount end |
#currency ⇒ String
Currency code, e.g. USD
18 19 20 |
# File 'lib/the_plaid_api/models/pay.rb', line 18 def currency @currency end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/the_plaid_api/models/pay.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. amount = hash.key?('amount') ? hash['amount'] : SKIP currency = hash.key?('currency') ? hash['currency'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Pay.new(amount: amount, currency: currency, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/the_plaid_api/models/pay.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['amount'] = 'amount' @_hash['currency'] = 'currency' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 40 41 42 |
# File 'lib/the_plaid_api/models/pay.rb', line 37 def self.nullables %w[ amount currency ] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/the_plaid_api/models/pay.rb', line 29 def self.optionals %w[ amount currency ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/the_plaid_api/models/pay.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} amount: #{@amount.inspect}, currency: #{@currency.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/the_plaid_api/models/pay.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} amount: #{@amount}, currency: #{@currency}, additional_properties:"\ " #{@additional_properties}>" end |