Class: ThePlaidApi::PayStubTaxpayerId

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/pay_stub_taxpayer_id.rb

Overview

Taxpayer ID of the individual receiving the paystub.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id_type:, id_mask:, additional_properties: nil) ⇒ PayStubTaxpayerId

Returns a new instance of PayStubTaxpayerId.



41
42
43
44
45
46
47
48
# File 'lib/the_plaid_api/models/pay_stub_taxpayer_id.rb', line 41

def initialize(id_type:, id_mask:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id_type = id_type
  @id_mask = id_mask
  @additional_properties = additional_properties
end

Instance Attribute Details

#id_maskString

ID mask; i.e. last 4 digits of the taxpayer ID.

Returns:

  • (String)


18
19
20
# File 'lib/the_plaid_api/models/pay_stub_taxpayer_id.rb', line 18

def id_mask
  @id_mask
end

#id_typeString

Type of ID, e.g. ‘SSN’.

Returns:

  • (String)


14
15
16
# File 'lib/the_plaid_api/models/pay_stub_taxpayer_id.rb', line 14

def id_type
  @id_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/the_plaid_api/models/pay_stub_taxpayer_id.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id_type = hash.key?('id_type') ? hash['id_type'] : nil
  id_mask = hash.key?('id_mask') ? hash['id_mask'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PayStubTaxpayerId.new(id_type: id_type,
                        id_mask: id_mask,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/the_plaid_api/models/pay_stub_taxpayer_id.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id_type'] = 'id_type'
  @_hash['id_mask'] = 'id_mask'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
37
38
39
# File 'lib/the_plaid_api/models/pay_stub_taxpayer_id.rb', line 34

def self.nullables
  %w[
    id_type
    id_mask
  ]
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/the_plaid_api/models/pay_stub_taxpayer_id.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/the_plaid_api/models/pay_stub_taxpayer_id.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id_type: #{@id_type.inspect}, id_mask: #{@id_mask.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/the_plaid_api/models/pay_stub_taxpayer_id.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id_type: #{@id_type}, id_mask: #{@id_mask}, additional_properties:"\
  " #{@additional_properties}>"
end