Class: ThePlaidApi::PaymentAmountToRefund

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/payment_amount_to_refund.rb

Overview

The amount and currency of a payment

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(currency:, value:, additional_properties: nil) ⇒ PaymentAmountToRefund

Returns a new instance of PaymentAmountToRefund.



41
42
43
44
45
46
47
48
# File 'lib/the_plaid_api/models/payment_amount_to_refund.rb', line 41

def initialize(currency:, value:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @currency = currency
  @value = value
  @additional_properties = additional_properties
end

Instance Attribute Details

#currencyPaymentAmountCurrency

The ISO-4217 currency code of the payment. For standing orders and payment consents, ‘“GBP”` must be used. For Poland, Denmark, Sweden and Norway, only the local currency is currently supported.



16
17
18
# File 'lib/the_plaid_api/models/payment_amount_to_refund.rb', line 16

def currency
  @currency
end

#valueFloat

The amount of the payment. Must contain at most two digits of precision e.g. ‘1.23`.

Returns:

  • (Float)


21
22
23
# File 'lib/the_plaid_api/models/payment_amount_to_refund.rb', line 21

def value
  @value
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/the_plaid_api/models/payment_amount_to_refund.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  currency = hash.key?('currency') ? hash['currency'] : nil
  value = hash.key?('value') ? hash['value'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaymentAmountToRefund.new(currency: currency,
                            value: value,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
29
# File 'lib/the_plaid_api/models/payment_amount_to_refund.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['currency'] = 'currency'
  @_hash['value'] = 'value'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/the_plaid_api/models/payment_amount_to_refund.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



32
33
34
# File 'lib/the_plaid_api/models/payment_amount_to_refund.rb', line 32

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/the_plaid_api/models/payment_amount_to_refund.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} currency: #{@currency.inspect}, value: #{@value.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/the_plaid_api/models/payment_amount_to_refund.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} currency: #{@currency}, value: #{@value}, additional_properties:"\
  " #{@additional_properties}>"
end