Class: ThePlaidApi::PaymentConsentPeriodicAmount

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/payment_consent_periodic_amount.rb

Overview

Defines consent payments limitations per period.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(amount:, interval:, alignment:, additional_properties: nil) ⇒ PaymentConsentPeriodicAmount

Returns a new instance of PaymentConsentPeriodicAmount.



46
47
48
49
50
51
52
53
54
# File 'lib/the_plaid_api/models/payment_consent_periodic_amount.rb', line 46

def initialize(amount:, interval:, alignment:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @amount = amount
  @interval = interval
  @alignment = alignment
  @additional_properties = additional_properties
end

Instance Attribute Details

#alignmentPaymentConsentPeriodicAlignment

Where the payment consent period should start. If the institution is Monzo, only ‘CONSENT` alignments are supported. `CALENDAR`: line up with a calendar. `CONSENT`: on the date of consent creation.



25
26
27
# File 'lib/the_plaid_api/models/payment_consent_periodic_amount.rb', line 25

def alignment
  @alignment
end

#amountPaymentAmount

Maximum cumulative amount for all payments in the specified interval.

Returns:



14
15
16
# File 'lib/the_plaid_api/models/payment_consent_periodic_amount.rb', line 14

def amount
  @amount
end

#intervalPaymentConsentPeriodicInterval

Payment consent periodic interval.



18
19
20
# File 'lib/the_plaid_api/models/payment_consent_periodic_amount.rb', line 18

def interval
  @interval
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/the_plaid_api/models/payment_consent_periodic_amount.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  amount = PaymentAmount.from_hash(hash['amount']) if hash['amount']
  interval = hash.key?('interval') ? hash['interval'] : nil
  alignment = hash.key?('alignment') ? hash['alignment'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaymentConsentPeriodicAmount.new(amount: amount,
                                   interval: interval,
                                   alignment: alignment,
                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



28
29
30
31
32
33
34
# File 'lib/the_plaid_api/models/payment_consent_periodic_amount.rb', line 28

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['amount'] = 'amount'
  @_hash['interval'] = 'interval'
  @_hash['alignment'] = 'alignment'
  @_hash
end

.nullablesObject

An array for nullable fields



42
43
44
# File 'lib/the_plaid_api/models/payment_consent_periodic_amount.rb', line 42

def self.nullables
  []
end

.optionalsObject

An array for optional fields



37
38
39
# File 'lib/the_plaid_api/models/payment_consent_periodic_amount.rb', line 37

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



87
88
89
90
91
# File 'lib/the_plaid_api/models/payment_consent_periodic_amount.rb', line 87

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} amount: #{@amount.inspect}, interval: #{@interval.inspect}, alignment:"\
  " #{@alignment.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



80
81
82
83
84
# File 'lib/the_plaid_api/models/payment_consent_periodic_amount.rb', line 80

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} amount: #{@amount}, interval: #{@interval}, alignment: #{@alignment},"\
  " additional_properties: #{@additional_properties}>"
end