Class: ThePlaidApi::PaymentInitiationConsentCreateResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/payment_initiation_consent_create_response.rb

Overview

PaymentInitiationConsentCreateResponse defines the response schema for ‘/payment_initiation/consent/create`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(consent_id:, status:, request_id:, additional_properties: nil) ⇒ PaymentInitiationConsentCreateResponse

Returns a new instance of PaymentInitiationConsentCreateResponse.



51
52
53
54
55
56
57
58
59
60
# File 'lib/the_plaid_api/models/payment_initiation_consent_create_response.rb', line 51

def initialize(consent_id:, status:, request_id:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @consent_id = consent_id
  @status = status
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

A unique ID identifying the payment consent.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/payment_initiation_consent_create_response.rb', line 15

def consent_id
  @consent_id
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


30
31
32
# File 'lib/the_plaid_api/models/payment_initiation_consent_create_response.rb', line 30

def request_id
  @request_id
end

#statusPaymentInitiationConsentStatus

The status of the payment consent. ‘UNAUTHORISED`: Consent created, but requires user authorisation. `REJECTED`: Consent authorisation was rejected by the bank. `AUTHORISED`: Consent is active and ready to be used. `REVOKED`: Consent has been revoked and can no longer be used. `EXPIRED`: Consent is no longer valid.



24
25
26
# File 'lib/the_plaid_api/models/payment_initiation_consent_create_response.rb', line 24

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/the_plaid_api/models/payment_initiation_consent_create_response.rb', line 63

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  consent_id = hash.key?('consent_id') ? hash['consent_id'] : nil
  status = hash.key?('status') ? hash['status'] : nil
  request_id = hash.key?('request_id') ? hash['request_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaymentInitiationConsentCreateResponse.new(consent_id: consent_id,
                                             status: status,
                                             request_id: request_id,
                                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
# File 'lib/the_plaid_api/models/payment_initiation_consent_create_response.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['consent_id'] = 'consent_id'
  @_hash['status'] = 'status'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



47
48
49
# File 'lib/the_plaid_api/models/payment_initiation_consent_create_response.rb', line 47

def self.nullables
  []
end

.optionalsObject

An array for optional fields



42
43
44
# File 'lib/the_plaid_api/models/payment_initiation_consent_create_response.rb', line 42

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



93
94
95
96
97
# File 'lib/the_plaid_api/models/payment_initiation_consent_create_response.rb', line 93

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} consent_id: #{@consent_id.inspect}, status: #{@status.inspect}, request_id:"\
  " #{@request_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



86
87
88
89
90
# File 'lib/the_plaid_api/models/payment_initiation_consent_create_response.rb', line 86

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} consent_id: #{@consent_id}, status: #{@status}, request_id: #{@request_id},"\
  " additional_properties: #{@additional_properties}>"
end