Class: ThePlaidApi::PaymentInitiationPaymentCreateResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::PaymentInitiationPaymentCreateResponse
- Defined in:
- lib/the_plaid_api/models/payment_initiation_payment_create_response.rb
Overview
PaymentInitiationPaymentCreateResponse defines the response schema for ‘/payment_initiation/payment/create`
Instance Attribute Summary collapse
-
#payment_id ⇒ String
A unique ID identifying the payment.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
-
#status ⇒ String
readonly
For a payment returned by this endpoint, there is only one possible value: ‘PAYMENT_STATUS_INPUT_NEEDED`: The initial phase of the payment.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(payment_id:, request_id:, additional_properties: nil) ⇒ PaymentInitiationPaymentCreateResponse
constructor
A new instance of PaymentInitiationPaymentCreateResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(payment_id:, request_id:, additional_properties: nil) ⇒ PaymentInitiationPaymentCreateResponse
Returns a new instance of PaymentInitiationPaymentCreateResponse.
47 48 49 50 51 52 53 54 55 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_create_response.rb', line 47 def initialize(payment_id:, request_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @payment_id = payment_id @status = 'PAYMENT_STATUS_INPUT_NEEDED' @request_id = request_id @additional_properties = additional_properties end |
Instance Attribute Details
#payment_id ⇒ String
A unique ID identifying the payment
15 16 17 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_create_response.rb', line 15 def payment_id @payment_id end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
26 27 28 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_create_response.rb', line 26 def request_id @request_id end |
#status ⇒ String (readonly)
For a payment returned by this endpoint, there is only one possible value: ‘PAYMENT_STATUS_INPUT_NEEDED`: The initial phase of the payment
20 21 22 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_create_response.rb', line 20 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_create_response.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. payment_id = hash.key?('payment_id') ? hash['payment_id'] : nil request_id = hash.key?('request_id') ? hash['request_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PaymentInitiationPaymentCreateResponse.new(payment_id: payment_id, request_id: request_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_create_response.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['payment_id'] = 'payment_id' @_hash['status'] = 'status' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_create_response.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
38 39 40 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_create_response.rb', line 38 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_create_response.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} payment_id: #{@payment_id.inspect}, status: #{@status.inspect}, request_id:"\ " #{@request_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_create_response.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} payment_id: #{@payment_id}, status: #{@status}, request_id: #{@request_id},"\ " additional_properties: #{@additional_properties}>" end |