Class: ThePlaidApi::PaymentInitiationRecipientListRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/payment_initiation_recipient_list_request.rb

Overview

PaymentInitiationRecipientListRequest defines the request schema for ‘/payment_initiation/recipient/list`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(client_id: SKIP, secret: SKIP, count: 100, cursor: SKIP, additional_properties: nil) ⇒ PaymentInitiationRecipientListRequest

Returns a new instance of PaymentInitiationRecipientListRequest.



66
67
68
69
70
71
72
73
74
75
76
# File 'lib/the_plaid_api/models/payment_initiation_recipient_list_request.rb', line 66

def initialize(client_id: SKIP, secret: SKIP, count: 100, cursor: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @count = count unless count == SKIP
  @cursor = cursor unless cursor == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/payment_initiation_recipient_list_request.rb', line 17

def client_id
  @client_id
end

#countInteger

The maximum number of recipients to return. If ‘count` is not specified, a maximum of 100 recipients will be returned, beginning with the recipient at the cursor (if specified).

Returns:

  • (Integer)


28
29
30
# File 'lib/the_plaid_api/models/payment_initiation_recipient_list_request.rb', line 28

def count
  @count
end

#cursorString

A value representing the latest recipient to be included in the response. Set this from ‘next_cursor` received from the previous `/payment_initiation/recipient/list` request. If provided, the response will only contain that recipient and recipients created before it. If omitted, the response will contain recipients starting from the most recent, and in descending order by the `created_at` time.

Returns:

  • (String)


37
38
39
# File 'lib/the_plaid_api/models/payment_initiation_recipient_list_request.rb', line 37

def cursor
  @cursor
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/payment_initiation_recipient_list_request.rb', line 22

def secret
  @secret
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/the_plaid_api/models/payment_initiation_recipient_list_request.rb', line 79

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  count = hash['count'] ||= 100
  cursor = hash.key?('cursor') ? hash['cursor'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaymentInitiationRecipientListRequest.new(client_id: client_id,
                                            secret: secret,
                                            count: count,
                                            cursor: cursor,
                                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



40
41
42
43
44
45
46
47
# File 'lib/the_plaid_api/models/payment_initiation_recipient_list_request.rb', line 40

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['count'] = 'count'
  @_hash['cursor'] = 'cursor'
  @_hash
end

.nullablesObject

An array for nullable fields



60
61
62
63
64
# File 'lib/the_plaid_api/models/payment_initiation_recipient_list_request.rb', line 60

def self.nullables
  %w[
    count
  ]
end

.optionalsObject

An array for optional fields



50
51
52
53
54
55
56
57
# File 'lib/the_plaid_api/models/payment_initiation_recipient_list_request.rb', line 50

def self.optionals
  %w[
    client_id
    secret
    count
    cursor
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



111
112
113
114
115
116
# File 'lib/the_plaid_api/models/payment_initiation_recipient_list_request.rb', line 111

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, count:"\
  " #{@count.inspect}, cursor: #{@cursor.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



104
105
106
107
108
# File 'lib/the_plaid_api/models/payment_initiation_recipient_list_request.rb', line 104

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, count: #{@count}, cursor:"\
  " #{@cursor}, additional_properties: #{@additional_properties}>"
end