Class: ThePlaidApi::PaymentInitiationRecipientListResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::PaymentInitiationRecipientListResponse
- Defined in:
- lib/the_plaid_api/models/payment_initiation_recipient_list_response.rb
Overview
PaymentInitiationRecipientListResponse defines the response schema for ‘/payment_initiation/recipient/list`
Instance Attribute Summary collapse
-
#next_cursor ⇒ String
The value that, when used as the optional ‘cursor` parameter to `/payment_initiation/recipient/list`, will return the corresponding recipient as its first recipient.
-
#recipients ⇒ Array[PaymentInitiationRecipient]
An array of payment recipients created for Payment Initiation.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(recipients:, request_id:, next_cursor: SKIP, additional_properties: nil) ⇒ PaymentInitiationRecipientListResponse
constructor
A new instance of PaymentInitiationRecipientListResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(recipients:, request_id:, next_cursor: SKIP, additional_properties: nil) ⇒ PaymentInitiationRecipientListResponse
Returns a new instance of PaymentInitiationRecipientListResponse.
50 51 52 53 54 55 56 57 58 59 |
# File 'lib/the_plaid_api/models/payment_initiation_recipient_list_response.rb', line 50 def initialize(recipients:, request_id:, next_cursor: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @recipients = recipients @request_id = request_id @next_cursor = next_cursor unless next_cursor == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#next_cursor ⇒ String
The value that, when used as the optional ‘cursor` parameter to `/payment_initiation/recipient/list`, will return the corresponding recipient as its first recipient.
27 28 29 |
# File 'lib/the_plaid_api/models/payment_initiation_recipient_list_response.rb', line 27 def next_cursor @next_cursor end |
#recipients ⇒ Array[PaymentInitiationRecipient]
An array of payment recipients created for Payment Initiation
15 16 17 |
# File 'lib/the_plaid_api/models/payment_initiation_recipient_list_response.rb', line 15 def recipients @recipients end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
21 22 23 |
# File 'lib/the_plaid_api/models/payment_initiation_recipient_list_response.rb', line 21 def request_id @request_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/the_plaid_api/models/payment_initiation_recipient_list_response.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it recipients = nil unless hash['recipients'].nil? recipients = [] hash['recipients'].each do |structure| recipients << (PaymentInitiationRecipient.from_hash(structure) if structure) end end recipients = nil unless hash.key?('recipients') request_id = hash.key?('request_id') ? hash['request_id'] : nil next_cursor = hash.key?('next_cursor') ? hash['next_cursor'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PaymentInitiationRecipientListResponse.new(recipients: recipients, request_id: request_id, next_cursor: next_cursor, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
30 31 32 33 34 35 36 |
# File 'lib/the_plaid_api/models/payment_initiation_recipient_list_response.rb', line 30 def self.names @_hash = {} if @_hash.nil? @_hash['recipients'] = 'recipients' @_hash['request_id'] = 'request_id' @_hash['next_cursor'] = 'next_cursor' @_hash end |
.nullables ⇒ Object
An array for nullable fields
46 47 48 |
# File 'lib/the_plaid_api/models/payment_initiation_recipient_list_response.rb', line 46 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 |
# File 'lib/the_plaid_api/models/payment_initiation_recipient_list_response.rb', line 39 def self.optionals %w[ next_cursor ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
101 102 103 104 105 |
# File 'lib/the_plaid_api/models/payment_initiation_recipient_list_response.rb', line 101 def inspect class_name = self.class.name.split('::').last "<#{class_name} recipients: #{@recipients.inspect}, request_id: #{@request_id.inspect},"\ " next_cursor: #{@next_cursor.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
94 95 96 97 98 |
# File 'lib/the_plaid_api/models/payment_initiation_recipient_list_response.rb', line 94 def to_s class_name = self.class.name.split('::').last "<#{class_name} recipients: #{@recipients}, request_id: #{@request_id}, next_cursor:"\ " #{@next_cursor}, additional_properties: #{@additional_properties}>" end |