Class: ThePlaidApi::PayrollItemStatus
- Defined in:
- lib/the_plaid_api/models/payroll_item_status.rb
Overview
Details about the status of the payroll item.
Instance Attribute Summary collapse
-
#processing_status ⇒ String
Denotes the processing status for the verification.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(processing_status: SKIP, additional_properties: nil) ⇒ PayrollItemStatus
constructor
A new instance of PayrollItemStatus.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(processing_status: SKIP, additional_properties: nil) ⇒ PayrollItemStatus
Returns a new instance of PayrollItemStatus.
45 46 47 48 49 50 51 |
# File 'lib/the_plaid_api/models/payroll_item_status.rb', line 45 def initialize(processing_status: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @processing_status = processing_status unless processing_status == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#processing_status ⇒ String
Denotes the processing status for the verification. ‘UNKNOWN`: The processing status could not be determined. `PROCESSING_COMPLETE`: The processing has completed and the user has approved for sharing. The data is available to be retrieved. `PROCESSING`: The verification is still processing. The data is not available yet. `FAILED`: The processing failed to complete successfully. `APPROVAL_STATUS_PENDING`: The processing has completed but the user has not yet approved the sharing of the data.
22 23 24 |
# File 'lib/the_plaid_api/models/payroll_item_status.rb', line 22 def processing_status @processing_status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/the_plaid_api/models/payroll_item_status.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. processing_status = hash.key?('processing_status') ? hash['processing_status'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PayrollItemStatus.new(processing_status: processing_status, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 |
# File 'lib/the_plaid_api/models/payroll_item_status.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['processing_status'] = 'processing_status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 42 43 |
# File 'lib/the_plaid_api/models/payroll_item_status.rb', line 39 def self.nullables %w[ processing_status ] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 35 36 |
# File 'lib/the_plaid_api/models/payroll_item_status.rb', line 32 def self.optionals %w[ processing_status ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/the_plaid_api/models/payroll_item_status.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} processing_status: #{@processing_status.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/the_plaid_api/models/payroll_item_status.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} processing_status: #{@processing_status}, additional_properties:"\ " #{@additional_properties}>" end |