Class: ThePlaidApi::PaystubDeduction

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/paystub_deduction.rb

Overview

Deduction on the paystub

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(type:, is_pretax:, total:, additional_properties: nil) ⇒ PaystubDeduction

Returns a new instance of PaystubDeduction.



48
49
50
51
52
53
54
55
56
# File 'lib/the_plaid_api/models/paystub_deduction.rb', line 48

def initialize(type:, is_pretax:, total:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @type = type
  @is_pretax = is_pretax
  @total = total
  @additional_properties = additional_properties
end

Instance Attribute Details

#is_pretaxTrueClass | FalseClass

‘true` if the deduction is pre-tax; `false` otherwise.

Returns:

  • (TrueClass | FalseClass)


19
20
21
# File 'lib/the_plaid_api/models/paystub_deduction.rb', line 19

def is_pretax
  @is_pretax
end

#totalFloat

The amount of the deduction.

Returns:

  • (Float)


23
24
25
# File 'lib/the_plaid_api/models/paystub_deduction.rb', line 23

def total
  @total
end

#typeString

The description of the deduction, as provided on the paystub. For example: ‘“401(k)”`, `“FICA MED TAX”`.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/paystub_deduction.rb', line 15

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/the_plaid_api/models/paystub_deduction.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  type = hash.key?('type') ? hash['type'] : nil
  is_pretax = hash.key?('is_pretax') ? hash['is_pretax'] : nil
  total = hash.key?('total') ? hash['total'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaystubDeduction.new(type: type,
                       is_pretax: is_pretax,
                       total: total,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/the_plaid_api/models/paystub_deduction.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['type'] = 'type'
  @_hash['is_pretax'] = 'is_pretax'
  @_hash['total'] = 'total'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
43
44
45
46
# File 'lib/the_plaid_api/models/paystub_deduction.rb', line 40

def self.nullables
  %w[
    type
    is_pretax
    total
  ]
end

.optionalsObject

An array for optional fields



35
36
37
# File 'lib/the_plaid_api/models/paystub_deduction.rb', line 35

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/the_plaid_api/models/paystub_deduction.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type.inspect}, is_pretax: #{@is_pretax.inspect}, total:"\
  " #{@total.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/the_plaid_api/models/paystub_deduction.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type}, is_pretax: #{@is_pretax}, total: #{@total},"\
  " additional_properties: #{@additional_properties}>"
end