Class: ThePlaidApi::PaystubOverride

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/paystub_override.rb

Overview

An object representing data from a paystub.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(employer: SKIP, employee: SKIP, income_breakdown: SKIP, net_pay: SKIP, deductions: SKIP, earnings: SKIP, pay_period_details: SKIP, additional_properties: nil) ⇒ PaystubOverride

Returns a new instance of PaystubOverride.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/the_plaid_api/models/paystub_override.rb', line 73

def initialize(employer: SKIP, employee: SKIP, income_breakdown: SKIP,
               net_pay: SKIP, deductions: SKIP, earnings: SKIP,
               pay_period_details: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @employer = employer unless employer == SKIP
  @employee = employee unless employee == SKIP
  @income_breakdown = income_breakdown unless income_breakdown == SKIP
  @net_pay = net_pay unless net_pay == SKIP
  @deductions = deductions unless deductions == SKIP
  @earnings = earnings unless earnings == SKIP
  @pay_period_details = pay_period_details unless pay_period_details == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#deductionsPaystubOverrideDeductions

An object with the deduction information found on a paystub.



31
32
33
# File 'lib/the_plaid_api/models/paystub_override.rb', line 31

def deductions
  @deductions
end

#earningsPaystubOverrideEarnings

An object representing both a breakdown of earnings on a paystub and the total earnings.



36
37
38
# File 'lib/the_plaid_api/models/paystub_override.rb', line 36

def earnings
  @earnings
end

#employeePaystubOverrideEmployee

The employee on the paystub.



18
19
20
# File 'lib/the_plaid_api/models/paystub_override.rb', line 18

def employee
  @employee
end

#employerPaystubOverrideEmployer

The employer on the paystub.



14
15
16
# File 'lib/the_plaid_api/models/paystub_override.rb', line 14

def employer
  @employer
end

#income_breakdownArray[IncomeBreakdown]

The employee on the paystub.

Returns:



22
23
24
# File 'lib/the_plaid_api/models/paystub_override.rb', line 22

def income_breakdown
  @income_breakdown
end

#net_payPaystubOverrideNetPay

An object representing information about the net pay amount on the paystub.



27
28
29
# File 'lib/the_plaid_api/models/paystub_override.rb', line 27

def net_pay
  @net_pay
end

#pay_period_detailsPaystubOverridePayPeriodDetails

Details about the pay period.



40
41
42
# File 'lib/the_plaid_api/models/paystub_override.rb', line 40

def pay_period_details
  @pay_period_details
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/the_plaid_api/models/paystub_override.rb', line 90

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  employer = PaystubOverrideEmployer.from_hash(hash['employer']) if hash['employer']
  employee = PaystubOverrideEmployee.from_hash(hash['employee']) if hash['employee']
  # Parameter is an array, so we need to iterate through it
  income_breakdown = nil
  unless hash['income_breakdown'].nil?
    income_breakdown = []
    hash['income_breakdown'].each do |structure|
      income_breakdown << (IncomeBreakdown.from_hash(structure) if structure)
    end
  end

  income_breakdown = SKIP unless hash.key?('income_breakdown')
  net_pay = PaystubOverrideNetPay.from_hash(hash['net_pay']) if hash['net_pay']
  deductions = PaystubOverrideDeductions.from_hash(hash['deductions']) if hash['deductions']
  earnings = PaystubOverrideEarnings.from_hash(hash['earnings']) if hash['earnings']
  pay_period_details = PaystubOverridePayPeriodDetails.from_hash(hash['pay_period_details']) if
    hash['pay_period_details']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaystubOverride.new(employer: employer,
                      employee: employee,
                      income_breakdown: income_breakdown,
                      net_pay: net_pay,
                      deductions: deductions,
                      earnings: earnings,
                      pay_period_details: pay_period_details,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



43
44
45
46
47
48
49
50
51
52
53
# File 'lib/the_plaid_api/models/paystub_override.rb', line 43

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['employer'] = 'employer'
  @_hash['employee'] = 'employee'
  @_hash['income_breakdown'] = 'income_breakdown'
  @_hash['net_pay'] = 'net_pay'
  @_hash['deductions'] = 'deductions'
  @_hash['earnings'] = 'earnings'
  @_hash['pay_period_details'] = 'pay_period_details'
  @_hash
end

.nullablesObject

An array for nullable fields



69
70
71
# File 'lib/the_plaid_api/models/paystub_override.rb', line 69

def self.nullables
  []
end

.optionalsObject

An array for optional fields



56
57
58
59
60
61
62
63
64
65
66
# File 'lib/the_plaid_api/models/paystub_override.rb', line 56

def self.optionals
  %w[
    employer
    employee
    income_breakdown
    net_pay
    deductions
    earnings
    pay_period_details
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



140
141
142
143
144
145
146
# File 'lib/the_plaid_api/models/paystub_override.rb', line 140

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} employer: #{@employer.inspect}, employee: #{@employee.inspect},"\
  " income_breakdown: #{@income_breakdown.inspect}, net_pay: #{@net_pay.inspect}, deductions:"\
  " #{@deductions.inspect}, earnings: #{@earnings.inspect}, pay_period_details:"\
  " #{@pay_period_details.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



131
132
133
134
135
136
137
# File 'lib/the_plaid_api/models/paystub_override.rb', line 131

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} employer: #{@employer}, employee: #{@employee}, income_breakdown:"\
  " #{@income_breakdown}, net_pay: #{@net_pay}, deductions: #{@deductions}, earnings:"\
  " #{@earnings}, pay_period_details: #{@pay_period_details}, additional_properties:"\
  " #{@additional_properties}>"
end