Class: ThePlaidApi::PaystubOverrideDeductions

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/paystub_override_deductions.rb

Overview

An object with the deduction information found on a paystub.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(breakdown: SKIP, total: SKIP, additional_properties: nil) ⇒ PaystubOverrideDeductions

Returns a new instance of PaystubOverrideDeductions.



41
42
43
44
45
46
47
48
# File 'lib/the_plaid_api/models/paystub_override_deductions.rb', line 41

def initialize(breakdown: SKIP, total: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @breakdown = breakdown unless breakdown == SKIP
  @total = total unless total == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#breakdownArray[PaystubOverrideDeductionsBreakdown]

TODO: Write general description for this method



14
15
16
# File 'lib/the_plaid_api/models/paystub_override_deductions.rb', line 14

def breakdown
  @breakdown
end

#totalPaystubOverrideDeductionsTotal

An object representing the total deductions for the pay period



18
19
20
# File 'lib/the_plaid_api/models/paystub_override_deductions.rb', line 18

def total
  @total
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/the_plaid_api/models/paystub_override_deductions.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  breakdown = nil
  unless hash['breakdown'].nil?
    breakdown = []
    hash['breakdown'].each do |structure|
      breakdown << (PaystubOverrideDeductionsBreakdown.from_hash(structure) if structure)
    end
  end

  breakdown = SKIP unless hash.key?('breakdown')
  total = PaystubOverrideDeductionsTotal.from_hash(hash['total']) if hash['total']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaystubOverrideDeductions.new(breakdown: breakdown,
                                total: total,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/the_plaid_api/models/paystub_override_deductions.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['breakdown'] = 'breakdown'
  @_hash['total'] = 'total'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/the_plaid_api/models/paystub_override_deductions.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/the_plaid_api/models/paystub_override_deductions.rb', line 29

def self.optionals
  %w[
    breakdown
    total
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



88
89
90
91
92
# File 'lib/the_plaid_api/models/paystub_override_deductions.rb', line 88

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} breakdown: #{@breakdown.inspect}, total: #{@total.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



81
82
83
84
85
# File 'lib/the_plaid_api/models/paystub_override_deductions.rb', line 81

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} breakdown: #{@breakdown}, total: #{@total}, additional_properties:"\
  " #{@additional_properties}>"
end