Class: ThePlaidApi::PendingExpirationWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/pending_expiration_webhook.rb

Overview

Fired when an Item’s access consent is expiring in 7 days. This can be resolved by having the user go through Link’s update mode. This webhook is fired only for Items associated with institutions in Europe (including the UK); for Items associated with institutions in the US or Canada, see [‘PENDING_DISCONNECT`](plaid.com/docs/api/items/#pending_disconnect) instead.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, item_id:, consent_expiration_time:, environment:, user_id: SKIP, additional_properties: nil) ⇒ PendingExpirationWebhook

Returns a new instance of PendingExpirationWebhook.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/the_plaid_api/models/pending_expiration_webhook.rb', line 68

def initialize(webhook_type:, webhook_code:, item_id:,
               consent_expiration_time:, environment:, user_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @item_id = item_id
  @user_id = user_id unless user_id == SKIP
  @consent_expiration_time = consent_expiration_time
  @environment = environment
  @additional_properties = additional_properties
end

Instance Attribute Details

The date and time at which the Item’s access consent will expire, in [ISO 8601](wikipedia.org/wiki/ISO_8601) format.

Returns:

  • (DateTime)


38
39
40
# File 'lib/the_plaid_api/models/pending_expiration_webhook.rb', line 38

def consent_expiration_time
  @consent_expiration_time
end

#environmentWebhookEnvironmentValues

The Plaid environment the webhook was sent from



42
43
44
# File 'lib/the_plaid_api/models/pending_expiration_webhook.rb', line 42

def environment
  @environment
end

#item_idString

The ‘item_id` of the Item associated with this webhook, warning, or error

Returns:

  • (String)


28
29
30
# File 'lib/the_plaid_api/models/pending_expiration_webhook.rb', line 28

def item_id
  @item_id
end

#user_idString

The Plaid ‘user_id` of the User associated with this webhook, warning, or error.

Returns:

  • (String)


33
34
35
# File 'lib/the_plaid_api/models/pending_expiration_webhook.rb', line 33

def user_id
  @user_id
end

#webhook_codeString

‘PENDING_EXPIRATION`

Returns:

  • (String)


24
25
26
# File 'lib/the_plaid_api/models/pending_expiration_webhook.rb', line 24

def webhook_code
  @webhook_code
end

#webhook_typeString

‘ITEM`

Returns:

  • (String)


20
21
22
# File 'lib/the_plaid_api/models/pending_expiration_webhook.rb', line 20

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/the_plaid_api/models/pending_expiration_webhook.rb', line 84

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  item_id = hash.key?('item_id') ? hash['item_id'] : nil
  consent_expiration_time = if hash.key?('consent_expiration_time')
                              (DateTimeHelper.from_rfc3339(hash['consent_expiration_time']) if hash['consent_expiration_time'])
                            end
  environment = hash.key?('environment') ? hash['environment'] : nil
  user_id = hash.key?('user_id') ? hash['user_id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PendingExpirationWebhook.new(webhook_type: webhook_type,
                               webhook_code: webhook_code,
                               item_id: item_id,
                               consent_expiration_time: consent_expiration_time,
                               environment: environment,
                               user_id: user_id,
                               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



45
46
47
48
49
50
51
52
53
54
# File 'lib/the_plaid_api/models/pending_expiration_webhook.rb', line 45

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['item_id'] = 'item_id'
  @_hash['user_id'] = 'user_id'
  @_hash['consent_expiration_time'] = 'consent_expiration_time'
  @_hash['environment'] = 'environment'
  @_hash
end

.nullablesObject

An array for nullable fields



64
65
66
# File 'lib/the_plaid_api/models/pending_expiration_webhook.rb', line 64

def self.nullables
  []
end

.optionalsObject

An array for optional fields



57
58
59
60
61
# File 'lib/the_plaid_api/models/pending_expiration_webhook.rb', line 57

def self.optionals
  %w[
    user_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



127
128
129
130
131
132
133
# File 'lib/the_plaid_api/models/pending_expiration_webhook.rb', line 127

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, item_id: #{@item_id.inspect}, user_id: #{@user_id.inspect},"\
  " consent_expiration_time: #{@consent_expiration_time.inspect}, environment:"\
  " #{@environment.inspect}, additional_properties: #{@additional_properties}>"
end


114
115
116
# File 'lib/the_plaid_api/models/pending_expiration_webhook.rb', line 114

def to_custom_consent_expiration_time
  DateTimeHelper.to_rfc3339(consent_expiration_time)
end

#to_sObject

Provides a human-readable string representation of the object.



119
120
121
122
123
124
# File 'lib/the_plaid_api/models/pending_expiration_webhook.rb', line 119

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, item_id:"\
  " #{@item_id}, user_id: #{@user_id}, consent_expiration_time: #{@consent_expiration_time},"\
  " environment: #{@environment}, additional_properties: #{@additional_properties}>"
end