Class: ThePlaidApi::PhoneNumber

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/phone_number.rb

Overview

A phone number

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(data:, primary:, type:, additional_properties: nil) ⇒ PhoneNumber

Returns a new instance of PhoneNumber.



44
45
46
47
48
49
50
51
52
# File 'lib/the_plaid_api/models/phone_number.rb', line 44

def initialize(data:, primary:, type:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @data = data
  @primary = primary
  @type = type
  @additional_properties = additional_properties
end

Instance Attribute Details

#dataString

The phone number.

Returns:

  • (String)


14
15
16
# File 'lib/the_plaid_api/models/phone_number.rb', line 14

def data
  @data
end

#primaryTrueClass | FalseClass

When ‘true`, identifies the phone number as the primary number on an account.

Returns:

  • (TrueClass | FalseClass)


19
20
21
# File 'lib/the_plaid_api/models/phone_number.rb', line 19

def primary
  @primary
end

#typeType

The type of phone number.

Returns:



23
24
25
# File 'lib/the_plaid_api/models/phone_number.rb', line 23

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/the_plaid_api/models/phone_number.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  data = hash.key?('data') ? hash['data'] : nil
  primary = hash.key?('primary') ? hash['primary'] : nil
  type = hash.key?('type') ? hash['type'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PhoneNumber.new(data: data,
                  primary: primary,
                  type: type,
                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/the_plaid_api/models/phone_number.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['data'] = 'data'
  @_hash['primary'] = 'primary'
  @_hash['type'] = 'type'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/the_plaid_api/models/phone_number.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
# File 'lib/the_plaid_api/models/phone_number.rb', line 35

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



85
86
87
88
89
# File 'lib/the_plaid_api/models/phone_number.rb', line 85

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} data: #{@data.inspect}, primary: #{@primary.inspect}, type:"\
  " #{@type.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



78
79
80
81
82
# File 'lib/the_plaid_api/models/phone_number.rb', line 78

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} data: #{@data}, primary: #{@primary}, type: #{@type},"\
  " additional_properties: #{@additional_properties}>"
end