Class: ThePlaidApi::ProcessorDefaultUpdateWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/processor_default_update_webhook.rb

Overview

This webhook is only sent to [Plaid processor partners](plaid.com/docs/auth/partnerships/). Fired when new transaction data is available for an Item. Plaid will typically check for new transaction data several times a day. This webhook is intended for use with ‘/processor/transactions/get`; if you are using the newer `/processor/transactions/sync` endpoint, this webhook will still be fired to maintain backwards compatibility, but it is recommended to listen for and respond to the `SYNC_UPDATES_AVAILABLE` webhook instead.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, new_transactions:, account_id:, environment:, error: SKIP, additional_properties: nil) ⇒ ProcessorDefaultUpdateWebhook

Returns a new instance of ProcessorDefaultUpdateWebhook.



78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/the_plaid_api/models/processor_default_update_webhook.rb', line 78

def initialize(webhook_type:, webhook_code:, new_transactions:, account_id:,
               environment:, error: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @error = error unless error == SKIP
  @new_transactions = new_transactions
  @account_id = 
  @environment = environment
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_idString

The ID of the account.

Returns:

  • (String)


46
47
48
# File 'lib/the_plaid_api/models/processor_default_update_webhook.rb', line 46

def 
  @account_id
end

#environmentWebhookEnvironmentValues

The Plaid environment the webhook was sent from



50
51
52
# File 'lib/the_plaid_api/models/processor_default_update_webhook.rb', line 50

def environment
  @environment
end

#errorError

Errors are identified by ‘error_code` and categorized by `error_type`. Use these in preference to HTTP status codes to identify and handle specific errors. HTTP status codes are set and provide the broadest categorization of errors: 4xx codes are for developer- or user-related errors, and 5xx codes are for Plaid-related errors, and the status will be 2xx in non-error cases. An Item with a non-`null` error object will only be part of an API response when calling `/item/get` to view Item status. Otherwise, error fields will be `null` if no error has occurred; if an error has occurred, an error code will be returned instead.

Returns:



37
38
39
# File 'lib/the_plaid_api/models/processor_default_update_webhook.rb', line 37

def error
  @error
end

#new_transactionsFloat

The number of new transactions detected since the last time this webhook was fired.

Returns:

  • (Float)


42
43
44
# File 'lib/the_plaid_api/models/processor_default_update_webhook.rb', line 42

def new_transactions
  @new_transactions
end

#webhook_codeString

‘DEFAULT_UPDATE`

Returns:

  • (String)


25
26
27
# File 'lib/the_plaid_api/models/processor_default_update_webhook.rb', line 25

def webhook_code
  @webhook_code
end

#webhook_typeString

‘TRANSACTIONS`

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/processor_default_update_webhook.rb', line 21

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/the_plaid_api/models/processor_default_update_webhook.rb', line 93

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  new_transactions =
    hash.key?('new_transactions') ? hash['new_transactions'] : nil
   = hash.key?('account_id') ? hash['account_id'] : nil
  environment = hash.key?('environment') ? hash['environment'] : nil
  error = Error.from_hash(hash['error']) if hash['error']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProcessorDefaultUpdateWebhook.new(webhook_type: webhook_type,
                                    webhook_code: webhook_code,
                                    new_transactions: new_transactions,
                                    account_id: ,
                                    environment: environment,
                                    error: error,
                                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



53
54
55
56
57
58
59
60
61
62
# File 'lib/the_plaid_api/models/processor_default_update_webhook.rb', line 53

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['error'] = 'error'
  @_hash['new_transactions'] = 'new_transactions'
  @_hash['account_id'] = 'account_id'
  @_hash['environment'] = 'environment'
  @_hash
end

.nullablesObject

An array for nullable fields



72
73
74
75
76
# File 'lib/the_plaid_api/models/processor_default_update_webhook.rb', line 72

def self.nullables
  %w[
    error
  ]
end

.optionalsObject

An array for optional fields



65
66
67
68
69
# File 'lib/the_plaid_api/models/processor_default_update_webhook.rb', line 65

def self.optionals
  %w[
    error
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



131
132
133
134
135
136
137
# File 'lib/the_plaid_api/models/processor_default_update_webhook.rb', line 131

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, error: #{@error.inspect}, new_transactions:"\
  " #{@new_transactions.inspect}, account_id: #{@account_id.inspect}, environment:"\
  " #{@environment.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



123
124
125
126
127
128
# File 'lib/the_plaid_api/models/processor_default_update_webhook.rb', line 123

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, error:"\
  " #{@error}, new_transactions: #{@new_transactions}, account_id: #{@account_id},"\
  " environment: #{@environment}, additional_properties: #{@additional_properties}>"
end