Class: ThePlaidApi::ProcessorIdentityMatchRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/processor_identity_match_request.rb

Overview

ProcessorIdentityMatchRequest defines the request schema for ‘/processor/identity/match`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(processor_token:, client_id: SKIP, secret: SKIP, user: SKIP, additional_properties: nil) ⇒ ProcessorIdentityMatchRequest

Returns a new instance of ProcessorIdentityMatchRequest.



60
61
62
63
64
65
66
67
68
69
70
# File 'lib/the_plaid_api/models/processor_identity_match_request.rb', line 60

def initialize(processor_token:, client_id: SKIP, secret: SKIP, user: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @processor_token = processor_token
  @user = user unless user == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/processor_identity_match_request.rb', line 17

def client_id
  @client_id
end

#processor_tokenString

The processor token obtained from the Plaid integration partner. Processor tokens are in the format: ‘processor-<environment>-<identifier>`

Returns:

  • (String)


27
28
29
# File 'lib/the_plaid_api/models/processor_identity_match_request.rb', line 27

def processor_token
  @processor_token
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/processor_identity_match_request.rb', line 22

def secret
  @secret
end

#userIdentityMatchUser

The user’s legal name, phone number, email address and address used to perform fuzzy match. If Financial Account Matching is enabled in the Identity Verification product, leave this field empty to automatically match against PII collected from the Identity Verification checks.

Returns:



34
35
36
# File 'lib/the_plaid_api/models/processor_identity_match_request.rb', line 34

def user
  @user
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/the_plaid_api/models/processor_identity_match_request.rb', line 73

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  processor_token =
    hash.key?('processor_token') ? hash['processor_token'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  user = IdentityMatchUser.from_hash(hash['user']) if hash['user']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProcessorIdentityMatchRequest.new(processor_token: processor_token,
                                    client_id: client_id,
                                    secret: secret,
                                    user: user,
                                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
# File 'lib/the_plaid_api/models/processor_identity_match_request.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['processor_token'] = 'processor_token'
  @_hash['user'] = 'user'
  @_hash
end

.nullablesObject

An array for nullable fields



56
57
58
# File 'lib/the_plaid_api/models/processor_identity_match_request.rb', line 56

def self.nullables
  []
end

.optionalsObject

An array for optional fields



47
48
49
50
51
52
53
# File 'lib/the_plaid_api/models/processor_identity_match_request.rb', line 47

def self.optionals
  %w[
    client_id
    secret
    user
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



106
107
108
109
110
111
# File 'lib/the_plaid_api/models/processor_identity_match_request.rb', line 106

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\
  " processor_token: #{@processor_token.inspect}, user: #{@user.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



99
100
101
102
103
# File 'lib/the_plaid_api/models/processor_identity_match_request.rb', line 99

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, processor_token:"\
  " #{@processor_token}, user: #{@user}, additional_properties: #{@additional_properties}>"
end