Class: ThePlaidApi::ProcessorLiabilitiesGetResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ProcessorLiabilitiesGetResponse
- Defined in:
- lib/the_plaid_api/models/processor_liabilities_get_response.rb
Overview
ProcessorLiabilitiesGetResponse defines the response schema for ‘/processor/liabilities/get`
Instance Attribute Summary collapse
-
#account ⇒ Account
A single account at a financial institution.
-
#liabilities ⇒ LiabilitiesObject
An object containing liability accounts.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account:, liabilities:, request_id:, additional_properties: nil) ⇒ ProcessorLiabilitiesGetResponse
constructor
A new instance of ProcessorLiabilitiesGetResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account:, liabilities:, request_id:, additional_properties: nil) ⇒ ProcessorLiabilitiesGetResponse
Returns a new instance of ProcessorLiabilitiesGetResponse.
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/the_plaid_api/models/processor_liabilities_get_response.rb', line 46 def initialize(account:, liabilities:, request_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account = account @liabilities = liabilities @request_id = request_id @additional_properties = additional_properties end |
Instance Attribute Details
#account ⇒ Account
A single account at a financial institution.
15 16 17 |
# File 'lib/the_plaid_api/models/processor_liabilities_get_response.rb', line 15 def account @account end |
#liabilities ⇒ LiabilitiesObject
An object containing liability accounts
19 20 21 |
# File 'lib/the_plaid_api/models/processor_liabilities_get_response.rb', line 19 def liabilities @liabilities end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
25 26 27 |
# File 'lib/the_plaid_api/models/processor_liabilities_get_response.rb', line 25 def request_id @request_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/the_plaid_api/models/processor_liabilities_get_response.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account = Account.from_hash(hash['account']) if hash['account'] liabilities = LiabilitiesObject.from_hash(hash['liabilities']) if hash['liabilities'] request_id = hash.key?('request_id') ? hash['request_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProcessorLiabilitiesGetResponse.new(account: account, liabilities: liabilities, request_id: request_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
28 29 30 31 32 33 34 |
# File 'lib/the_plaid_api/models/processor_liabilities_get_response.rb', line 28 def self.names @_hash = {} if @_hash.nil? @_hash['account'] = 'account' @_hash['liabilities'] = 'liabilities' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
42 43 44 |
# File 'lib/the_plaid_api/models/processor_liabilities_get_response.rb', line 42 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
37 38 39 |
# File 'lib/the_plaid_api/models/processor_liabilities_get_response.rb', line 37 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
88 89 90 91 92 |
# File 'lib/the_plaid_api/models/processor_liabilities_get_response.rb', line 88 def inspect class_name = self.class.name.split('::').last "<#{class_name} account: #{@account.inspect}, liabilities: #{@liabilities.inspect},"\ " request_id: #{@request_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
81 82 83 84 85 |
# File 'lib/the_plaid_api/models/processor_liabilities_get_response.rb', line 81 def to_s class_name = self.class.name.split('::').last "<#{class_name} account: #{@account}, liabilities: #{@liabilities}, request_id:"\ " #{@request_id}, additional_properties: #{@additional_properties}>" end |