Class: ThePlaidApi::ProcessorNumber

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/processor_number.rb

Overview

An object containing identifying numbers used for making electronic transfers to and from the ‘account`. The identifying number type (ACH, EFT, IBAN, or BACS) used will depend on the country of the account. An account may have more than one number type. If a particular identifying number type is not used by the `account` for which auth data has been requested, a null value will be returned.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(ach: SKIP, eft: SKIP, international: SKIP, bacs: SKIP, additional_properties: nil) ⇒ ProcessorNumber

Returns a new instance of ProcessorNumber.



67
68
69
70
71
72
73
74
75
76
77
# File 'lib/the_plaid_api/models/processor_number.rb', line 67

def initialize(ach: SKIP, eft: SKIP, international: SKIP, bacs: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @ach = ach unless ach == SKIP
  @eft = eft unless eft == SKIP
  @international = international unless international == SKIP
  @bacs = bacs unless bacs == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#achNumbersAchNullable

Identifying information for transferring money to or from a US account via ACH or wire transfer.

Returns:



20
21
22
# File 'lib/the_plaid_api/models/processor_number.rb', line 20

def ach
  @ach
end

#bacsNumbersBacsNullable

Identifying information for transferring money to or from a UK bank account via BACS.

Returns:



35
36
37
# File 'lib/the_plaid_api/models/processor_number.rb', line 35

def bacs
  @bacs
end

#eftNumbersEftNullable

Identifying information for transferring money to or from a Canadian bank account via EFT.

Returns:



25
26
27
# File 'lib/the_plaid_api/models/processor_number.rb', line 25

def eft
  @eft
end

#internationalNumbersInternationalNullable

Identifying information for transferring money to or from an international bank account via wire transfer.



30
31
32
# File 'lib/the_plaid_api/models/processor_number.rb', line 30

def international
  @international
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/the_plaid_api/models/processor_number.rb', line 80

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  ach = NumbersAchNullable.from_hash(hash['ach']) if hash['ach']
  eft = NumbersEftNullable.from_hash(hash['eft']) if hash['eft']
  international = NumbersInternationalNullable.from_hash(hash['international']) if
    hash['international']
  bacs = NumbersBacsNullable.from_hash(hash['bacs']) if hash['bacs']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProcessorNumber.new(ach: ach,
                      eft: eft,
                      international: international,
                      bacs: bacs,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



38
39
40
41
42
43
44
45
# File 'lib/the_plaid_api/models/processor_number.rb', line 38

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['ach'] = 'ach'
  @_hash['eft'] = 'eft'
  @_hash['international'] = 'international'
  @_hash['bacs'] = 'bacs'
  @_hash
end

.nullablesObject

An array for nullable fields



58
59
60
61
62
63
64
65
# File 'lib/the_plaid_api/models/processor_number.rb', line 58

def self.nullables
  %w[
    ach
    eft
    international
    bacs
  ]
end

.optionalsObject

An array for optional fields



48
49
50
51
52
53
54
55
# File 'lib/the_plaid_api/models/processor_number.rb', line 48

def self.optionals
  %w[
    ach
    eft
    international
    bacs
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



113
114
115
116
117
118
# File 'lib/the_plaid_api/models/processor_number.rb', line 113

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} ach: #{@ach.inspect}, eft: #{@eft.inspect}, international:"\
  " #{@international.inspect}, bacs: #{@bacs.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



106
107
108
109
110
# File 'lib/the_plaid_api/models/processor_number.rb', line 106

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} ach: #{@ach}, eft: #{@eft}, international: #{@international}, bacs:"\
  " #{@bacs}, additional_properties: #{@additional_properties}>"
end