Class: ThePlaidApi::ProcessorTokenCreateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/processor_token_create_request.rb

Overview

ProcessorTokenCreateRequest defines the request schema for ‘/processor/token/create`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(access_token:, account_id:, processor:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ ProcessorTokenCreateRequest

Returns a new instance of ProcessorTokenCreateRequest.



60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/the_plaid_api/models/processor_token_create_request.rb', line 60

def initialize(access_token:, account_id:, processor:, client_id: SKIP,
               secret: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @access_token = access_token
  @account_id = 
  @processor = processor
  @additional_properties = additional_properties
end

Instance Attribute Details

#access_tokenString

The access token associated with the Item data is being requested for.

Returns:

  • (String)


26
27
28
# File 'lib/the_plaid_api/models/processor_token_create_request.rb', line 26

def access_token
  @access_token
end

#account_idString

The ‘account_id` value obtained from the `onSuccess` callback in Link

Returns:

  • (String)


30
31
32
# File 'lib/the_plaid_api/models/processor_token_create_request.rb', line 30

def 
  @account_id
end

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/processor_token_create_request.rb', line 17

def client_id
  @client_id
end

#processorProcessor

The processor you are integrating with.

Returns:



34
35
36
# File 'lib/the_plaid_api/models/processor_token_create_request.rb', line 34

def processor
  @processor
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/processor_token_create_request.rb', line 22

def secret
  @secret
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/the_plaid_api/models/processor_token_create_request.rb', line 74

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  access_token = hash.key?('access_token') ? hash['access_token'] : nil
   = hash.key?('account_id') ? hash['account_id'] : nil
  processor = hash.key?('processor') ? hash['processor'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProcessorTokenCreateRequest.new(access_token: access_token,
                                  account_id: ,
                                  processor: processor,
                                  client_id: client_id,
                                  secret: secret,
                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
45
# File 'lib/the_plaid_api/models/processor_token_create_request.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['access_token'] = 'access_token'
  @_hash['account_id'] = 'account_id'
  @_hash['processor'] = 'processor'
  @_hash
end

.nullablesObject

An array for nullable fields



56
57
58
# File 'lib/the_plaid_api/models/processor_token_create_request.rb', line 56

def self.nullables
  []
end

.optionalsObject

An array for optional fields



48
49
50
51
52
53
# File 'lib/the_plaid_api/models/processor_token_create_request.rb', line 48

def self.optionals
  %w[
    client_id
    secret
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



109
110
111
112
113
114
# File 'lib/the_plaid_api/models/processor_token_create_request.rb', line 109

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, access_token:"\
  " #{@access_token.inspect}, account_id: #{@account_id.inspect}, processor:"\
  " #{@processor.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



101
102
103
104
105
106
# File 'lib/the_plaid_api/models/processor_token_create_request.rb', line 101

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, access_token:"\
  " #{@access_token}, account_id: #{@account_id}, processor: #{@processor},"\
  " additional_properties: #{@additional_properties}>"
end