Class: ThePlaidApi::ProcessorTokenCreateResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/processor_token_create_response.rb

Overview

ProcessorTokenCreateResponse defines the response schema for ‘/processor/token/create` and `/processor/apex/processor_token/create`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(processor_token:, request_id:, additional_properties: nil) ⇒ ProcessorTokenCreateResponse

Returns a new instance of ProcessorTokenCreateResponse.



42
43
44
45
46
47
48
49
# File 'lib/the_plaid_api/models/processor_token_create_response.rb', line 42

def initialize(processor_token:, request_id:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @processor_token = processor_token
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#processor_tokenString

The ‘processor_token` that can then be used by the Plaid partner to make API requests

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/processor_token_create_response.rb', line 16

def processor_token
  @processor_token
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/processor_token_create_response.rb', line 22

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/the_plaid_api/models/processor_token_create_response.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  processor_token =
    hash.key?('processor_token') ? hash['processor_token'] : nil
  request_id = hash.key?('request_id') ? hash['request_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProcessorTokenCreateResponse.new(processor_token: processor_token,
                                   request_id: request_id,
                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
# File 'lib/the_plaid_api/models/processor_token_create_response.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['processor_token'] = 'processor_token'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/the_plaid_api/models/processor_token_create_response.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



33
34
35
# File 'lib/the_plaid_api/models/processor_token_create_response.rb', line 33

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



81
82
83
84
85
# File 'lib/the_plaid_api/models/processor_token_create_response.rb', line 81

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} processor_token: #{@processor_token.inspect}, request_id:"\
  " #{@request_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



74
75
76
77
78
# File 'lib/the_plaid_api/models/processor_token_create_response.rb', line 74

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} processor_token: #{@processor_token}, request_id: #{@request_id},"\
  " additional_properties: #{@additional_properties}>"
end