Class: ThePlaidApi::ProcessorTokenPermissionsSetRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ProcessorTokenPermissionsSetRequest
- Defined in:
- lib/the_plaid_api/models/processor_token_permissions_set_request.rb
Overview
ProcessorTokenPermissionsSetRequest defines the request schema for ‘/processor/token/permissions/set`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#processor_token ⇒ String
The processor token obtained from the Plaid integration partner.
-
#products ⇒ Array[Products]
A list of products the processor token should have access to.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(processor_token:, products:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ ProcessorTokenPermissionsSetRequest
constructor
A new instance of ProcessorTokenPermissionsSetRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(processor_token:, products:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ ProcessorTokenPermissionsSetRequest
Returns a new instance of ProcessorTokenPermissionsSetRequest.
57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/the_plaid_api/models/processor_token_permissions_set_request.rb', line 57 def initialize(processor_token:, products:, client_id: SKIP, secret: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @processor_token = processor_token @products = products @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/processor_token_permissions_set_request.rb', line 17 def client_id @client_id end |
#processor_token ⇒ String
The processor token obtained from the Plaid integration partner. Processor tokens are in the format: ‘processor-<environment>-<identifier>`
27 28 29 |
# File 'lib/the_plaid_api/models/processor_token_permissions_set_request.rb', line 27 def processor_token @processor_token end |
#products ⇒ Array[Products]
A list of products the processor token should have access to. An empty list will grant access to all products.
32 33 34 |
# File 'lib/the_plaid_api/models/processor_token_permissions_set_request.rb', line 32 def products @products end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/the_plaid_api/models/processor_token_permissions_set_request.rb', line 22 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/the_plaid_api/models/processor_token_permissions_set_request.rb', line 70 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. processor_token = hash.key?('processor_token') ? hash['processor_token'] : nil products = hash.key?('products') ? hash['products'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProcessorTokenPermissionsSetRequest.new(processor_token: processor_token, products: products, client_id: client_id, secret: secret, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
35 36 37 38 39 40 41 42 |
# File 'lib/the_plaid_api/models/processor_token_permissions_set_request.rb', line 35 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['processor_token'] = 'processor_token' @_hash['products'] = 'products' @_hash end |
.nullables ⇒ Object
An array for nullable fields
53 54 55 |
# File 'lib/the_plaid_api/models/processor_token_permissions_set_request.rb', line 53 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
45 46 47 48 49 50 |
# File 'lib/the_plaid_api/models/processor_token_permissions_set_request.rb', line 45 def self.optionals %w[ client_id secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
104 105 106 107 108 109 |
# File 'lib/the_plaid_api/models/processor_token_permissions_set_request.rb', line 104 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\ " processor_token: #{@processor_token.inspect}, products: #{@products.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
96 97 98 99 100 101 |
# File 'lib/the_plaid_api/models/processor_token_permissions_set_request.rb', line 96 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, processor_token:"\ " #{@processor_token}, products: #{@products}, additional_properties:"\ " #{@additional_properties}>" end |