Class: ThePlaidApi::ProcessorTransactionsGetResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/processor_transactions_get_response.rb

Overview

ProcessorTransactionsGetResponse defines the response schema for ‘/processor/transactions/get`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account:, transactions:, total_transactions:, request_id:, additional_properties: nil) ⇒ ProcessorTransactionsGetResponse

Returns a new instance of ProcessorTransactionsGetResponse.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/the_plaid_api/models/processor_transactions_get_response.rb', line 57

def initialize(account:, transactions:, total_transactions:, request_id:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @account = 
  @transactions = transactions
  @total_transactions = total_transactions
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#accountAccount

A single account at a financial institution.

Returns:



15
16
17
# File 'lib/the_plaid_api/models/processor_transactions_get_response.rb', line 15

def 
  @account
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


35
36
37
# File 'lib/the_plaid_api/models/processor_transactions_get_response.rb', line 35

def request_id
  @request_id
end

#total_transactionsInteger

The total number of transactions available within the date range specified. If ‘total_transactions` is larger than the size of the `transactions` array, more transactions are available and can be fetched via manipulating the `offset` parameter.

Returns:

  • (Integer)


29
30
31
# File 'lib/the_plaid_api/models/processor_transactions_get_response.rb', line 29

def total_transactions
  @total_transactions
end

#transactionsArray[Transaction]

An array containing transactions from the account. Transactions are returned in reverse chronological order, with the most recent at the beginning of the array. The maximum number of transactions returned is determined by the ‘count` parameter.

Returns:



22
23
24
# File 'lib/the_plaid_api/models/processor_transactions_get_response.rb', line 22

def transactions
  @transactions
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/the_plaid_api/models/processor_transactions_get_response.rb', line 70

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = Account.from_hash(hash['account']) if hash['account']
  # Parameter is an array, so we need to iterate through it
  transactions = nil
  unless hash['transactions'].nil?
    transactions = []
    hash['transactions'].each do |structure|
      transactions << (Transaction.from_hash(structure) if structure)
    end
  end

  transactions = nil unless hash.key?('transactions')
  total_transactions =
    hash.key?('total_transactions') ? hash['total_transactions'] : nil
  request_id = hash.key?('request_id') ? hash['request_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProcessorTransactionsGetResponse.new(account: ,
                                       transactions: transactions,
                                       total_transactions: total_transactions,
                                       request_id: request_id,
                                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



38
39
40
41
42
43
44
45
# File 'lib/the_plaid_api/models/processor_transactions_get_response.rb', line 38

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account'] = 'account'
  @_hash['transactions'] = 'transactions'
  @_hash['total_transactions'] = 'total_transactions'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



53
54
55
# File 'lib/the_plaid_api/models/processor_transactions_get_response.rb', line 53

def self.nullables
  []
end

.optionalsObject

An array for optional fields



48
49
50
# File 'lib/the_plaid_api/models/processor_transactions_get_response.rb', line 48

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



113
114
115
116
117
118
# File 'lib/the_plaid_api/models/processor_transactions_get_response.rb', line 113

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account: #{@account.inspect}, transactions: #{@transactions.inspect},"\
  " total_transactions: #{@total_transactions.inspect}, request_id: #{@request_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



105
106
107
108
109
110
# File 'lib/the_plaid_api/models/processor_transactions_get_response.rb', line 105

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account: #{@account}, transactions: #{@transactions}, total_transactions:"\
  " #{@total_transactions}, request_id: #{@request_id}, additional_properties:"\
  " #{@additional_properties}>"
end