Class: ThePlaidApi::ProcessorTransactionsRecurringGetRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ProcessorTransactionsRecurringGetRequest
- Defined in:
- lib/the_plaid_api/models/processor_transactions_recurring_get_request.rb
Overview
ProcessorTransactionsRecurringGetRequest defines the request schema for ‘/processor/transactions/recurring/get`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#options ⇒ TransactionsRecurringGetRequestOptions
An optional object to be used with the request.
-
#processor_token ⇒ String
The processor token obtained from the Plaid integration partner.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(processor_token:, client_id: SKIP, secret: SKIP, options: SKIP, additional_properties: nil) ⇒ ProcessorTransactionsRecurringGetRequest
constructor
A new instance of ProcessorTransactionsRecurringGetRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(processor_token:, client_id: SKIP, secret: SKIP, options: SKIP, additional_properties: nil) ⇒ ProcessorTransactionsRecurringGetRequest
Returns a new instance of ProcessorTransactionsRecurringGetRequest.
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/the_plaid_api/models/processor_transactions_recurring_get_request.rb', line 58 def initialize(processor_token:, client_id: SKIP, secret: SKIP, options: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @processor_token = processor_token @secret = secret unless secret == SKIP @options = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/processor_transactions_recurring_get_request.rb', line 17 def client_id @client_id end |
#options ⇒ TransactionsRecurringGetRequestOptions
An optional object to be used with the request. If specified, ‘options` must not be `null`.
32 33 34 |
# File 'lib/the_plaid_api/models/processor_transactions_recurring_get_request.rb', line 32 def @options end |
#processor_token ⇒ String
The processor token obtained from the Plaid integration partner. Processor tokens are in the format: ‘processor-<environment>-<identifier>`
22 23 24 |
# File 'lib/the_plaid_api/models/processor_transactions_recurring_get_request.rb', line 22 def processor_token @processor_token end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
27 28 29 |
# File 'lib/the_plaid_api/models/processor_transactions_recurring_get_request.rb', line 27 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/the_plaid_api/models/processor_transactions_recurring_get_request.rb', line 71 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. processor_token = hash.key?('processor_token') ? hash['processor_token'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP = TransactionsRecurringGetRequestOptions.from_hash(hash['options']) if hash['options'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProcessorTransactionsRecurringGetRequest.new(processor_token: processor_token, client_id: client_id, secret: secret, options: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
35 36 37 38 39 40 41 42 |
# File 'lib/the_plaid_api/models/processor_transactions_recurring_get_request.rb', line 35 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['processor_token'] = 'processor_token' @_hash['secret'] = 'secret' @_hash['options'] = 'options' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 |
# File 'lib/the_plaid_api/models/processor_transactions_recurring_get_request.rb', line 54 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
45 46 47 48 49 50 51 |
# File 'lib/the_plaid_api/models/processor_transactions_recurring_get_request.rb', line 45 def self.optionals %w[ client_id secret options ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
105 106 107 108 109 110 |
# File 'lib/the_plaid_api/models/processor_transactions_recurring_get_request.rb', line 105 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, processor_token:"\ " #{@processor_token.inspect}, secret: #{@secret.inspect}, options: #{@options.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
98 99 100 101 102 |
# File 'lib/the_plaid_api/models/processor_transactions_recurring_get_request.rb', line 98 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, processor_token: #{@processor_token}, secret:"\ " #{@secret}, options: #{@options}, additional_properties: #{@additional_properties}>" end |