Class: ThePlaidApi::ProcessorTransactionsRemovedWebhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ProcessorTransactionsRemovedWebhook
- Defined in:
- lib/the_plaid_api/models/processor_transactions_removed_webhook.rb
Overview
This webhook is only sent to [Plaid processor partners](plaid.com/docs/auth/partnerships/). Fired when transaction(s) for an Item are deleted. The deleted transaction IDs are included in the webhook payload. Plaid will typically check for deleted transaction data several times a day. This webhook is intended for use with ‘/processor/transactions/get`; if you are using the newer `/processor/transactions/sync` endpoint, this webhook will still be fired to maintain backwards compatibility, but it is recommended to listen for and respond to the `SYNC_UPDATES_AVAILABLE` webhook instead.
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ID of the account.
-
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from.
-
#error ⇒ Error
Errors are identified by ‘error_code` and categorized by `error_type`.
-
#removed_transactions ⇒ Array[String]
An array of ‘transaction_ids` corresponding to the removed transactions.
-
#webhook_code ⇒ String
‘TRANSACTIONS_REMOVED`.
-
#webhook_type ⇒ String
‘TRANSACTIONS`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, removed_transactions:, account_id:, environment:, error: SKIP, additional_properties: nil) ⇒ ProcessorTransactionsRemovedWebhook
constructor
A new instance of ProcessorTransactionsRemovedWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, removed_transactions:, account_id:, environment:, error: SKIP, additional_properties: nil) ⇒ ProcessorTransactionsRemovedWebhook
Returns a new instance of ProcessorTransactionsRemovedWebhook.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/the_plaid_api/models/processor_transactions_removed_webhook.rb', line 78 def initialize(webhook_type:, webhook_code:, removed_transactions:, account_id:, environment:, error: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @error = error unless error == SKIP @removed_transactions = removed_transactions @account_id = account_id @environment = environment @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
The ID of the account.
46 47 48 |
# File 'lib/the_plaid_api/models/processor_transactions_removed_webhook.rb', line 46 def account_id @account_id end |
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from
50 51 52 |
# File 'lib/the_plaid_api/models/processor_transactions_removed_webhook.rb', line 50 def environment @environment end |
#error ⇒ Error
Errors are identified by ‘error_code` and categorized by `error_type`. Use these in preference to HTTP status codes to identify and handle specific errors. HTTP status codes are set and provide the broadest categorization of errors: 4xx codes are for developer- or user-related errors, and 5xx codes are for Plaid-related errors, and the status will be 2xx in non-error cases. An Item with a non-`null` error object will only be part of an API response when calling `/item/get` to view Item status. Otherwise, error fields will be `null` if no error has occurred; if an error has occurred, an error code will be returned instead.
38 39 40 |
# File 'lib/the_plaid_api/models/processor_transactions_removed_webhook.rb', line 38 def error @error end |
#removed_transactions ⇒ Array[String]
An array of ‘transaction_ids` corresponding to the removed transactions
42 43 44 |
# File 'lib/the_plaid_api/models/processor_transactions_removed_webhook.rb', line 42 def removed_transactions @removed_transactions end |
#webhook_code ⇒ String
‘TRANSACTIONS_REMOVED`
26 27 28 |
# File 'lib/the_plaid_api/models/processor_transactions_removed_webhook.rb', line 26 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘TRANSACTIONS`
22 23 24 |
# File 'lib/the_plaid_api/models/processor_transactions_removed_webhook.rb', line 22 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/the_plaid_api/models/processor_transactions_removed_webhook.rb', line 94 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil removed_transactions = hash.key?('removed_transactions') ? hash['removed_transactions'] : nil account_id = hash.key?('account_id') ? hash['account_id'] : nil environment = hash.key?('environment') ? hash['environment'] : nil error = Error.from_hash(hash['error']) if hash['error'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProcessorTransactionsRemovedWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, removed_transactions: removed_transactions, account_id: account_id, environment: environment, error: error, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
53 54 55 56 57 58 59 60 61 62 |
# File 'lib/the_plaid_api/models/processor_transactions_removed_webhook.rb', line 53 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['error'] = 'error' @_hash['removed_transactions'] = 'removed_transactions' @_hash['account_id'] = 'account_id' @_hash['environment'] = 'environment' @_hash end |
.nullables ⇒ Object
An array for nullable fields
72 73 74 75 76 |
# File 'lib/the_plaid_api/models/processor_transactions_removed_webhook.rb', line 72 def self.nullables %w[ error ] end |
.optionals ⇒ Object
An array for optional fields
65 66 67 68 69 |
# File 'lib/the_plaid_api/models/processor_transactions_removed_webhook.rb', line 65 def self.optionals %w[ error ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
132 133 134 135 136 137 138 |
# File 'lib/the_plaid_api/models/processor_transactions_removed_webhook.rb', line 132 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, error: #{@error.inspect}, removed_transactions:"\ " #{@removed_transactions.inspect}, account_id: #{@account_id.inspect}, environment:"\ " #{@environment.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
124 125 126 127 128 129 |
# File 'lib/the_plaid_api/models/processor_transactions_removed_webhook.rb', line 124 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, error:"\ " #{@error}, removed_transactions: #{@removed_transactions}, account_id: #{@account_id},"\ " environment: #{@environment}, additional_properties: #{@additional_properties}>" end |