Class: ThePlaidApi::ProductPermissionsRequiredIdentityWebhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ProductPermissionsRequiredIdentityWebhook
- Defined in:
- lib/the_plaid_api/models/product_permissions_required_identity_webhook.rb
Overview
Fired when an ‘ACCESS_NOT_GRANTED` error is hit for Identity. The error can be resolved by putting the user through update mode with `identity` in the `products` array, as well as through the limited beta for update mode Identity product validations.
Instance Attribute Summary collapse
-
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from.
-
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error.
-
#webhook_code ⇒ String
‘PRODUCT_PERMISSIONS_REQUIRED`.
-
#webhook_type ⇒ String
‘IDENTITY`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, item_id:, environment:, additional_properties: nil) ⇒ ProductPermissionsRequiredIdentityWebhook
constructor
A new instance of ProductPermissionsRequiredIdentityWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, item_id:, environment:, additional_properties: nil) ⇒ ProductPermissionsRequiredIdentityWebhook
Returns a new instance of ProductPermissionsRequiredIdentityWebhook.
51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/the_plaid_api/models/product_permissions_required_identity_webhook.rb', line 51 def initialize(webhook_type:, webhook_code:, item_id:, environment:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @item_id = item_id @environment = environment @additional_properties = additional_properties end |
Instance Attribute Details
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from
29 30 31 |
# File 'lib/the_plaid_api/models/product_permissions_required_identity_webhook.rb', line 29 def environment @environment end |
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error
25 26 27 |
# File 'lib/the_plaid_api/models/product_permissions_required_identity_webhook.rb', line 25 def item_id @item_id end |
#webhook_code ⇒ String
‘PRODUCT_PERMISSIONS_REQUIRED`
21 22 23 |
# File 'lib/the_plaid_api/models/product_permissions_required_identity_webhook.rb', line 21 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘IDENTITY`
17 18 19 |
# File 'lib/the_plaid_api/models/product_permissions_required_identity_webhook.rb', line 17 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/the_plaid_api/models/product_permissions_required_identity_webhook.rb', line 64 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil item_id = hash.key?('item_id') ? hash['item_id'] : nil environment = hash.key?('environment') ? hash['environment'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProductPermissionsRequiredIdentityWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, item_id: item_id, environment: environment, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
32 33 34 35 36 37 38 39 |
# File 'lib/the_plaid_api/models/product_permissions_required_identity_webhook.rb', line 32 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['item_id'] = 'item_id' @_hash['environment'] = 'environment' @_hash end |
.nullables ⇒ Object
An array for nullable fields
47 48 49 |
# File 'lib/the_plaid_api/models/product_permissions_required_identity_webhook.rb', line 47 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
42 43 44 |
# File 'lib/the_plaid_api/models/product_permissions_required_identity_webhook.rb', line 42 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
97 98 99 100 101 102 |
# File 'lib/the_plaid_api/models/product_permissions_required_identity_webhook.rb', line 97 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, item_id: #{@item_id.inspect}, environment:"\ " #{@environment.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
89 90 91 92 93 94 |
# File 'lib/the_plaid_api/models/product_permissions_required_identity_webhook.rb', line 89 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, item_id:"\ " #{@item_id}, environment: #{@environment}, additional_properties:"\ " #{@additional_properties}>" end |