Class: ThePlaidApi::ProtectComputeResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/protect_compute_response.rb

Overview

Response object for /protect/compute

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(request_id:, score: SKIP, model: SKIP, attributes: SKIP, additional_properties: nil) ⇒ ProtectComputeResponse

Returns a new instance of ProtectComputeResponse.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/the_plaid_api/models/protect_compute_response.rb', line 57

def initialize(request_id:, score: SKIP, model: SKIP, attributes: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @score = score unless score == SKIP
  @model = model unless model == SKIP
  @attributes = attributes unless attributes == SKIP
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#attributesObject

Event fraud attributes as an arbitrary set of key-value pairs.

Returns:

  • (Object)


22
23
24
# File 'lib/the_plaid_api/models/protect_compute_response.rb', line 22

def attributes
  @attributes
end

#modelString

The versioned name of the Trust Index model used for scoring.

Returns:

  • (String)


18
19
20
# File 'lib/the_plaid_api/models/protect_compute_response.rb', line 18

def model
  @model
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


28
29
30
# File 'lib/the_plaid_api/models/protect_compute_response.rb', line 28

def request_id
  @request_id
end

#scoreInteger

The trust index score.

Returns:

  • (Integer)


14
15
16
# File 'lib/the_plaid_api/models/protect_compute_response.rb', line 14

def score
  @score
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/the_plaid_api/models/protect_compute_response.rb', line 70

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  request_id = hash.key?('request_id') ? hash['request_id'] : nil
  score = hash.key?('score') ? hash['score'] : SKIP
  model = hash.key?('model') ? hash['model'] : SKIP
  attributes = hash.key?('attributes') ? hash['attributes'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProtectComputeResponse.new(request_id: request_id,
                             score: score,
                             model: model,
                             attributes: attributes,
                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



31
32
33
34
35
36
37
38
# File 'lib/the_plaid_api/models/protect_compute_response.rb', line 31

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['score'] = 'score'
  @_hash['model'] = 'model'
  @_hash['attributes'] = 'attributes'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



50
51
52
53
54
55
# File 'lib/the_plaid_api/models/protect_compute_response.rb', line 50

def self.nullables
  %w[
    score
    attributes
  ]
end

.optionalsObject

An array for optional fields



41
42
43
44
45
46
47
# File 'lib/the_plaid_api/models/protect_compute_response.rb', line 41

def self.optionals
  %w[
    score
    model
    attributes
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



102
103
104
105
106
107
# File 'lib/the_plaid_api/models/protect_compute_response.rb', line 102

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} score: #{@score.inspect}, model: #{@model.inspect}, attributes:"\
  " #{@attributes.inspect}, request_id: #{@request_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



95
96
97
98
99
# File 'lib/the_plaid_api/models/protect_compute_response.rb', line 95

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} score: #{@score}, model: #{@model}, attributes: #{@attributes}, request_id:"\
  " #{@request_id}, additional_properties: #{@additional_properties}>"
end