Class: ThePlaidApi::ProtectModelInputs
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ProtectModelInputs
- Defined in:
- lib/the_plaid_api/models/protect_model_inputs.rb
Overview
Inputs for the Trust Index model. The ‘link` field is required for any link session model type.
Instance Attribute Summary collapse
-
#link ⇒ ProtectLinkModelInputs
Inputs for link session Trust Index models.
-
#sdk ⇒ ProtectSdkModelInputs
Inputs for Protect SDK Trust Index models.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(link: SKIP, sdk: SKIP, additional_properties: nil) ⇒ ProtectModelInputs
constructor
A new instance of ProtectModelInputs.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(link: SKIP, sdk: SKIP, additional_properties: nil) ⇒ ProtectModelInputs
Returns a new instance of ProtectModelInputs.
45 46 47 48 49 50 51 52 |
# File 'lib/the_plaid_api/models/protect_model_inputs.rb', line 45 def initialize(link: SKIP, sdk: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @link = link unless link == SKIP @sdk = sdk unless sdk == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#link ⇒ ProtectLinkModelInputs
Inputs for link session Trust Index models.
15 16 17 |
# File 'lib/the_plaid_api/models/protect_model_inputs.rb', line 15 def link @link end |
#sdk ⇒ ProtectSdkModelInputs
Inputs for Protect SDK Trust Index models.
19 20 21 |
# File 'lib/the_plaid_api/models/protect_model_inputs.rb', line 19 def sdk @sdk end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/the_plaid_api/models/protect_model_inputs.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. link = ProtectLinkModelInputs.from_hash(hash['link']) if hash['link'] sdk = ProtectSdkModelInputs.from_hash(hash['sdk']) if hash['sdk'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProtectModelInputs.new(link: link, sdk: sdk, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/the_plaid_api/models/protect_model_inputs.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['link'] = 'link' @_hash['sdk'] = 'sdk' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 41 42 43 |
# File 'lib/the_plaid_api/models/protect_model_inputs.rb', line 38 def self.nullables %w[ link sdk ] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/the_plaid_api/models/protect_model_inputs.rb', line 30 def self.optionals %w[ link sdk ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
83 84 85 86 87 |
# File 'lib/the_plaid_api/models/protect_model_inputs.rb', line 83 def inspect class_name = self.class.name.split('::').last "<#{class_name} link: #{@link.inspect}, sdk: #{@sdk.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
76 77 78 79 80 |
# File 'lib/the_plaid_api/models/protect_model_inputs.rb', line 76 def to_s class_name = self.class.name.split('::').last "<#{class_name} link: #{@link}, sdk: #{@sdk}, additional_properties:"\ " #{@additional_properties}>" end |