Class: ThePlaidApi::ProtectReportSource

Inherits:
Object
  • Object
show all
Defined in:
lib/the_plaid_api/models/protect_report_source.rb

Overview

The source that identified or reported the incident. ‘INTERNAL_REVIEW` - Incident was identified through internal fraud investigations or review processes. `USER_SELF_REPORTED` - Incident was reported directly by the affected user. `BANK_FEEDBACK` - Incident was identified through bank feedback, including ACH returns and connection revocations. `NETWORK_FEEDBACK` - Incident was identified through card network alerts or chargebacks. `AUTOMATED_SYSTEM` - Incident was detected by automated systems such as fraud models or rule engines. `THIRD_PARTY_ALERT` - Incident was identified through external vendor or consortium alerts. `OTHER` - Incident was identified through a source not covered by other categories.

Constant Summary collapse

PROTECT_REPORT_SOURCE =
[
  # TODO: Write general description for INTERNAL_REVIEW
  INTERNAL_REVIEW = 'INTERNAL_REVIEW'.freeze,

  # TODO: Write general description for USER_SELF_REPORTED
  USER_SELF_REPORTED = 'USER_SELF_REPORTED'.freeze,

  # TODO: Write general description for BANK_FEEDBACK
  BANK_FEEDBACK = 'BANK_FEEDBACK'.freeze,

  # TODO: Write general description for NETWORK_FEEDBACK
  NETWORK_FEEDBACK = 'NETWORK_FEEDBACK'.freeze,

  # TODO: Write general description for AUTOMATED_SYSTEM
  AUTOMATED_SYSTEM = 'AUTOMATED_SYSTEM'.freeze,

  # TODO: Write general description for THIRD_PARTY_ALERT
  THIRD_PARTY_ALERT = 'THIRD_PARTY_ALERT'.freeze,

  # TODO: Write general description for OTHER
  OTHER = 'OTHER'.freeze
].freeze

Class Method Summary collapse

Class Method Details

.from_value(value, default_value = INTERNAL_REVIEW) ⇒ Object



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/the_plaid_api/models/protect_report_source.rb', line 47

def self.from_value(value, default_value = INTERNAL_REVIEW)
  return default_value if value.nil?

  str = value.to_s.strip

  case str.downcase
  when 'internal_review' then INTERNAL_REVIEW
  when 'user_self_reported' then USER_SELF_REPORTED
  when 'bank_feedback' then BANK_FEEDBACK
  when 'network_feedback' then NETWORK_FEEDBACK
  when 'automated_system' then AUTOMATED_SYSTEM
  when 'third_party_alert' then THIRD_PARTY_ALERT
  when 'other' then OTHER
  else
    default_value
  end
end

.validate(value) ⇒ Object



41
42
43
44
45
# File 'lib/the_plaid_api/models/protect_report_source.rb', line 41

def self.validate(value)
  return false if value.nil?

  PROTECT_REPORT_SOURCE.include?(value)
end