Class: ThePlaidApi::ProtectUser

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/protect_user.rb

Overview

Represents an end user for /protect/compute requests.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(user_id: SKIP, client_user_id: SKIP, additional_properties: nil) ⇒ ProtectUser

Returns a new instance of ProtectUser.



45
46
47
48
49
50
51
52
53
# File 'lib/the_plaid_api/models/protect_user.rb', line 45

def initialize(user_id: SKIP, client_user_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @user_id = user_id unless user_id == SKIP
  @client_user_id = client_user_id unless client_user_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_user_idString

A unique ID representing the end user. Maximum of 128 characters. Typically this will be a user ID number from your application. Personally identifiable information, such as an email address or phone number, should not be used in the ‘client_user_id`.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/protect_user.rb', line 22

def client_user_id
  @client_user_id
end

#user_idString

The Plaid User ID returned from a previous call to ‘/user/create`. This or `client_user_id` can be provided, not both.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/protect_user.rb', line 15

def user_id
  @user_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/the_plaid_api/models/protect_user.rb', line 56

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  user_id = hash.key?('user_id') ? hash['user_id'] : SKIP
  client_user_id =
    hash.key?('client_user_id') ? hash['client_user_id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProtectUser.new(user_id: user_id,
                  client_user_id: client_user_id,
                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
# File 'lib/the_plaid_api/models/protect_user.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['user_id'] = 'user_id'
  @_hash['client_user_id'] = 'client_user_id'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
# File 'lib/the_plaid_api/models/protect_user.rb', line 41

def self.nullables
  []
end

.optionalsObject

An array for optional fields



33
34
35
36
37
38
# File 'lib/the_plaid_api/models/protect_user.rb', line 33

def self.optionals
  %w[
    user_id
    client_user_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



85
86
87
88
89
# File 'lib/the_plaid_api/models/protect_user.rb', line 85

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} user_id: #{@user_id.inspect}, client_user_id: #{@client_user_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



78
79
80
81
82
# File 'lib/the_plaid_api/models/protect_user.rb', line 78

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} user_id: #{@user_id}, client_user_id: #{@client_user_id},"\
  " additional_properties: #{@additional_properties}>"
end