Class: ThePlaidApi::ProviderBusinessAddress

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/provider_business_address.rb

Overview

Detailed address information for a business from data provider

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(street:, street2:, city:, region:, postal_code:, country:, is_primary:, additional_properties: nil) ⇒ ProviderBusinessAddress

Returns a new instance of ProviderBusinessAddress.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/the_plaid_api/models/provider_business_address.rb', line 81

def initialize(street:, street2:, city:, region:, postal_code:, country:,
               is_primary:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @street = street
  @street2 = street2
  @city = city
  @region = region
  @postal_code = postal_code
  @country = country
  @is_primary = is_primary
  @additional_properties = additional_properties
end

Instance Attribute Details

#cityString

City from the address. A string with at least one non-whitespace alphabetical character, with a max length of 100 characters.

Returns:

  • (String)


27
28
29
# File 'lib/the_plaid_api/models/provider_business_address.rb', line 27

def city
  @city
end

#countryString

Valid, capitalized, two-letter ISO code representing the country of this object. Must be in ISO 3166-1 alpha-2 form.

Returns:

  • (String)


46
47
48
# File 'lib/the_plaid_api/models/provider_business_address.rb', line 46

def country
  @country
end

#is_primaryTrueClass | FalseClass

Whether this is the primary address for the business

Returns:

  • (TrueClass | FalseClass)


50
51
52
# File 'lib/the_plaid_api/models/provider_business_address.rb', line 50

def is_primary
  @is_primary
end

#postal_codeString

The postal code for the associated address. Between 2 and 10 alphanumeric characters. For US-based addresses this must be 5 numeric digits.

Returns:

  • (String)


41
42
43
# File 'lib/the_plaid_api/models/provider_business_address.rb', line 41

def postal_code
  @postal_code
end

#regionString

A subdivision code. “Subdivision” is a generic term for “state”, “province”, “prefecture”, “zone”, etc. For the list of valid codes, see [country subdivision codes](plaid.com/documents/country_subdivision_codes.json). Country prefixes are omitted, since they are inferred from the ‘country` field.

Returns:

  • (String)


36
37
38
# File 'lib/the_plaid_api/models/provider_business_address.rb', line 36

def region
  @region
end

#streetString

The primary street portion of an address. If an address is provided, this field will always be filled. A string with at least one non-whitespace alphabetical character, with a max length of 80 characters.

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/provider_business_address.rb', line 16

def street
  @street
end

#street2String

Extra street information, like an apartment or suite number. If provided, a string with at least one non-whitespace character, with a max length of 50 characters.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/provider_business_address.rb', line 22

def street2
  @street2
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/the_plaid_api/models/provider_business_address.rb', line 97

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  street = hash.key?('street') ? hash['street'] : nil
  street2 = hash.key?('street2') ? hash['street2'] : nil
  city = hash.key?('city') ? hash['city'] : nil
  region = hash.key?('region') ? hash['region'] : nil
  postal_code = hash.key?('postal_code') ? hash['postal_code'] : nil
  country = hash.key?('country') ? hash['country'] : nil
  is_primary = hash.key?('is_primary') ? hash['is_primary'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProviderBusinessAddress.new(street: street,
                              street2: street2,
                              city: city,
                              region: region,
                              postal_code: postal_code,
                              country: country,
                              is_primary: is_primary,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/the_plaid_api/models/provider_business_address.rb', line 53

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['street'] = 'street'
  @_hash['street2'] = 'street2'
  @_hash['city'] = 'city'
  @_hash['region'] = 'region'
  @_hash['postal_code'] = 'postal_code'
  @_hash['country'] = 'country'
  @_hash['is_primary'] = 'is_primary'
  @_hash
end

.nullablesObject

An array for nullable fields



71
72
73
74
75
76
77
78
79
# File 'lib/the_plaid_api/models/provider_business_address.rb', line 71

def self.nullables
  %w[
    street
    street2
    city
    region
    postal_code
  ]
end

.optionalsObject

An array for optional fields



66
67
68
# File 'lib/the_plaid_api/models/provider_business_address.rb', line 66

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



136
137
138
139
140
141
142
# File 'lib/the_plaid_api/models/provider_business_address.rb', line 136

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} street: #{@street.inspect}, street2: #{@street2.inspect}, city:"\
  " #{@city.inspect}, region: #{@region.inspect}, postal_code: #{@postal_code.inspect},"\
  " country: #{@country.inspect}, is_primary: #{@is_primary.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



128
129
130
131
132
133
# File 'lib/the_plaid_api/models/provider_business_address.rb', line 128

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} street: #{@street}, street2: #{@street2}, city: #{@city}, region:"\
  " #{@region}, postal_code: #{@postal_code}, country: #{@country}, is_primary:"\
  " #{@is_primary}, additional_properties: #{@additional_properties}>"
end