Class: ThePlaidApi::ProviderBusinessName

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/provider_business_name.rb

Overview

Name associated with a business

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(is_primary:, name:, additional_properties: nil) ⇒ ProviderBusinessName

Returns a new instance of ProviderBusinessName.



41
42
43
44
45
46
47
48
# File 'lib/the_plaid_api/models/provider_business_name.rb', line 41

def initialize(is_primary:, name:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @is_primary = is_primary
  @name = name
  @additional_properties = additional_properties
end

Instance Attribute Details

#is_primaryTrueClass | FalseClass

Indicates whether this is the primary name for the business.

Returns:

  • (TrueClass | FalseClass)


14
15
16
# File 'lib/the_plaid_api/models/provider_business_name.rb', line 14

def is_primary
  @is_primary
end

#nameString

The name of the business. Must have at least one character and a maximum length of 500 characters.

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/provider_business_name.rb', line 19

def name
  @name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/the_plaid_api/models/provider_business_name.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  is_primary = hash.key?('is_primary') ? hash['is_primary'] : nil
  name = hash.key?('name') ? hash['name'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProviderBusinessName.new(is_primary: is_primary,
                           name: name,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/the_plaid_api/models/provider_business_name.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['is_primary'] = 'is_primary'
  @_hash['name'] = 'name'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
38
39
# File 'lib/the_plaid_api/models/provider_business_name.rb', line 35

def self.nullables
  %w[
    name
  ]
end

.optionalsObject

An array for optional fields



30
31
32
# File 'lib/the_plaid_api/models/provider_business_name.rb', line 30

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/the_plaid_api/models/provider_business_name.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} is_primary: #{@is_primary.inspect}, name: #{@name.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/the_plaid_api/models/provider_business_name.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} is_primary: #{@is_primary}, name: #{@name}, additional_properties:"\
  " #{@additional_properties}>"
end