Class: ThePlaidApi::RecurringCancelledWebhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::RecurringCancelledWebhook
- Defined in:
- lib/the_plaid_api/models/recurring_cancelled_webhook.rb
Overview
Fired when a recurring transfer is cancelled by Plaid.
Instance Attribute Summary collapse
-
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from.
-
#recurring_transfer_id ⇒ String
Plaid’s unique identifier for a recurring transfer.
-
#webhook_code ⇒ String
‘RECURRING_CANCELLED`.
-
#webhook_type ⇒ String
‘TRANSFER`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, recurring_transfer_id:, environment:, additional_properties: nil) ⇒ RecurringCancelledWebhook
constructor
A new instance of RecurringCancelledWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, recurring_transfer_id:, environment:, additional_properties: nil) ⇒ RecurringCancelledWebhook
Returns a new instance of RecurringCancelledWebhook.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/the_plaid_api/models/recurring_cancelled_webhook.rb', line 48 def initialize(webhook_type:, webhook_code:, recurring_transfer_id:, environment:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @recurring_transfer_id = recurring_transfer_id @environment = environment @additional_properties = additional_properties end |
Instance Attribute Details
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from
26 27 28 |
# File 'lib/the_plaid_api/models/recurring_cancelled_webhook.rb', line 26 def environment @environment end |
#recurring_transfer_id ⇒ String
Plaid’s unique identifier for a recurring transfer.
22 23 24 |
# File 'lib/the_plaid_api/models/recurring_cancelled_webhook.rb', line 22 def recurring_transfer_id @recurring_transfer_id end |
#webhook_code ⇒ String
‘RECURRING_CANCELLED`
18 19 20 |
# File 'lib/the_plaid_api/models/recurring_cancelled_webhook.rb', line 18 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘TRANSFER`
14 15 16 |
# File 'lib/the_plaid_api/models/recurring_cancelled_webhook.rb', line 14 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/the_plaid_api/models/recurring_cancelled_webhook.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil recurring_transfer_id = hash.key?('recurring_transfer_id') ? hash['recurring_transfer_id'] : nil environment = hash.key?('environment') ? hash['environment'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. RecurringCancelledWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, recurring_transfer_id: recurring_transfer_id, environment: environment, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/the_plaid_api/models/recurring_cancelled_webhook.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['recurring_transfer_id'] = 'recurring_transfer_id' @_hash['environment'] = 'environment' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/the_plaid_api/models/recurring_cancelled_webhook.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/the_plaid_api/models/recurring_cancelled_webhook.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
95 96 97 98 99 100 |
# File 'lib/the_plaid_api/models/recurring_cancelled_webhook.rb', line 95 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, recurring_transfer_id: #{@recurring_transfer_id.inspect},"\ " environment: #{@environment.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
87 88 89 90 91 92 |
# File 'lib/the_plaid_api/models/recurring_cancelled_webhook.rb', line 87 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code},"\ " recurring_transfer_id: #{@recurring_transfer_id}, environment: #{@environment},"\ " additional_properties: #{@additional_properties}>" end |