Class: ThePlaidApi::RecurringNewTransferWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/recurring_new_transfer_webhook.rb

Overview

Fired when a new transfer of a recurring transfer is originated.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, recurring_transfer_id:, transfer_id:, environment:, additional_properties: nil) ⇒ RecurringNewTransferWebhook

Returns a new instance of RecurringNewTransferWebhook.



53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/the_plaid_api/models/recurring_new_transfer_webhook.rb', line 53

def initialize(webhook_type:, webhook_code:, recurring_transfer_id:,
               transfer_id:, environment:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @recurring_transfer_id = recurring_transfer_id
  @transfer_id = transfer_id
  @environment = environment
  @additional_properties = additional_properties
end

Instance Attribute Details

#environmentWebhookEnvironmentValues

The Plaid environment the webhook was sent from



30
31
32
# File 'lib/the_plaid_api/models/recurring_new_transfer_webhook.rb', line 30

def environment
  @environment
end

#recurring_transfer_idString

Plaid’s unique identifier for a recurring transfer.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/recurring_new_transfer_webhook.rb', line 22

def recurring_transfer_id
  @recurring_transfer_id
end

#transfer_idString

Plaid’s unique identifier for a transfer.

Returns:

  • (String)


26
27
28
# File 'lib/the_plaid_api/models/recurring_new_transfer_webhook.rb', line 26

def transfer_id
  @transfer_id
end

#webhook_codeString

‘RECURRING_NEW_TRANSFER`

Returns:

  • (String)


18
19
20
# File 'lib/the_plaid_api/models/recurring_new_transfer_webhook.rb', line 18

def webhook_code
  @webhook_code
end

#webhook_typeString

‘TRANSFER`

Returns:

  • (String)


14
15
16
# File 'lib/the_plaid_api/models/recurring_new_transfer_webhook.rb', line 14

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/the_plaid_api/models/recurring_new_transfer_webhook.rb', line 67

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  recurring_transfer_id =
    hash.key?('recurring_transfer_id') ? hash['recurring_transfer_id'] : nil
  transfer_id = hash.key?('transfer_id') ? hash['transfer_id'] : nil
  environment = hash.key?('environment') ? hash['environment'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RecurringNewTransferWebhook.new(webhook_type: webhook_type,
                                  webhook_code: webhook_code,
                                  recurring_transfer_id: recurring_transfer_id,
                                  transfer_id: transfer_id,
                                  environment: environment,
                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
# File 'lib/the_plaid_api/models/recurring_new_transfer_webhook.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['recurring_transfer_id'] = 'recurring_transfer_id'
  @_hash['transfer_id'] = 'transfer_id'
  @_hash['environment'] = 'environment'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/the_plaid_api/models/recurring_new_transfer_webhook.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
# File 'lib/the_plaid_api/models/recurring_new_transfer_webhook.rb', line 44

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



103
104
105
106
107
108
109
# File 'lib/the_plaid_api/models/recurring_new_transfer_webhook.rb', line 103

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, recurring_transfer_id: #{@recurring_transfer_id.inspect},"\
  " transfer_id: #{@transfer_id.inspect}, environment: #{@environment.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



95
96
97
98
99
100
# File 'lib/the_plaid_api/models/recurring_new_transfer_webhook.rb', line 95

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code},"\
  " recurring_transfer_id: #{@recurring_transfer_id}, transfer_id: #{@transfer_id},"\
  " environment: #{@environment}, additional_properties: #{@additional_properties}>"
end