Class: ThePlaidApi::ReportingInformation
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ReportingInformation
- Defined in:
- lib/the_plaid_api/models/reporting_information.rb
Overview
Information about an report identifier and a report name.
Instance Attribute Summary collapse
-
#reporting_information_identifier ⇒ String
Documentation not found in the MISMO model viewer and not provided by Freddie Mac.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(reporting_information_identifier:, additional_properties: nil) ⇒ ReportingInformation
constructor
A new instance of ReportingInformation.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(reporting_information_identifier:, additional_properties: nil) ⇒ ReportingInformation
Returns a new instance of ReportingInformation.
35 36 37 38 39 40 41 42 |
# File 'lib/the_plaid_api/models/reporting_information.rb', line 35 def initialize(reporting_information_identifier:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @reporting_information_identifier = reporting_information_identifier @additional_properties = additional_properties end |
Instance Attribute Details
#reporting_information_identifier ⇒ String
Documentation not found in the MISMO model viewer and not provided by Freddie Mac.
15 16 17 |
# File 'lib/the_plaid_api/models/reporting_information.rb', line 15 def reporting_information_identifier @reporting_information_identifier end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/the_plaid_api/models/reporting_information.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. reporting_information_identifier = hash.key?('ReportingInformationIdentifier') ? hash['ReportingInformationIdentifier'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ReportingInformation.new(reporting_information_identifier: reporting_information_identifier, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 23 |
# File 'lib/the_plaid_api/models/reporting_information.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['reporting_information_identifier'] = 'ReportingInformationIdentifier' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/the_plaid_api/models/reporting_information.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
26 27 28 |
# File 'lib/the_plaid_api/models/reporting_information.rb', line 26 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
72 73 74 75 76 77 |
# File 'lib/the_plaid_api/models/reporting_information.rb', line 72 def inspect class_name = self.class.name.split('::').last "<#{class_name} reporting_information_identifier:"\ " #{@reporting_information_identifier.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
65 66 67 68 69 |
# File 'lib/the_plaid_api/models/reporting_information.rb', line 65 def to_s class_name = self.class.name.split('::').last "<#{class_name} reporting_information_identifier: #{@reporting_information_identifier},"\ " additional_properties: #{@additional_properties}>" end |