Class: ThePlaidApi::RiskCheckFacialDuplicate

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/risk_check_facial_duplicate.rb

Overview

Result summary object specifying values for the ‘facial_duplicate` attributes of risk check.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id:, similarity:, matched_after_completed:, additional_properties: nil) ⇒ RiskCheckFacialDuplicate

Returns a new instance of RiskCheckFacialDuplicate.



45
46
47
48
49
50
51
52
53
54
# File 'lib/the_plaid_api/models/risk_check_facial_duplicate.rb', line 45

def initialize(id:, similarity:, matched_after_completed:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id
  @similarity = similarity
  @matched_after_completed = matched_after_completed
  @additional_properties = additional_properties
end

Instance Attribute Details

#idString

ID of the associated Identity Verification attempt.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/risk_check_facial_duplicate.rb', line 15

def id
  @id
end

#matched_after_completedTrueClass | FalseClass

Whether this match occurred after the session was complete. For example, this would be ‘true` if a later session ended up matching this one.

Returns:

  • (TrueClass | FalseClass)


24
25
26
# File 'lib/the_plaid_api/models/risk_check_facial_duplicate.rb', line 24

def matched_after_completed
  @matched_after_completed
end

#similarityInteger

Similarity score of the match. Ranges from 0 to 100.

Returns:

  • (Integer)


19
20
21
# File 'lib/the_plaid_api/models/risk_check_facial_duplicate.rb', line 19

def similarity
  @similarity
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/the_plaid_api/models/risk_check_facial_duplicate.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  similarity = hash.key?('similarity') ? hash['similarity'] : nil
  matched_after_completed =
    hash.key?('matched_after_completed') ? hash['matched_after_completed'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RiskCheckFacialDuplicate.new(id: id,
                               similarity: similarity,
                               matched_after_completed: matched_after_completed,
                               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
# File 'lib/the_plaid_api/models/risk_check_facial_duplicate.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['similarity'] = 'similarity'
  @_hash['matched_after_completed'] = 'matched_after_completed'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
# File 'lib/the_plaid_api/models/risk_check_facial_duplicate.rb', line 41

def self.nullables
  []
end

.optionalsObject

An array for optional fields



36
37
38
# File 'lib/the_plaid_api/models/risk_check_facial_duplicate.rb', line 36

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



88
89
90
91
92
93
# File 'lib/the_plaid_api/models/risk_check_facial_duplicate.rb', line 88

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, similarity: #{@similarity.inspect},"\
  " matched_after_completed: #{@matched_after_completed.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



81
82
83
84
85
# File 'lib/the_plaid_api/models/risk_check_facial_duplicate.rb', line 81

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, similarity: #{@similarity}, matched_after_completed:"\
  " #{@matched_after_completed}, additional_properties: #{@additional_properties}>"
end