Class: ThePlaidApi::RiskCheckNetwork

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/risk_check_network.rb

Overview

Result summary object specifying values for network attributes of risk check.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(risk_level:, factors:, additional_properties: nil) ⇒ RiskCheckNetwork

Returns a new instance of RiskCheckNetwork.



40
41
42
43
44
45
46
47
# File 'lib/the_plaid_api/models/risk_check_network.rb', line 40

def initialize(risk_level:, factors:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @risk_level = risk_level
  @factors = factors
  @additional_properties = additional_properties
end

Instance Attribute Details

#factorsArray[String]

List of factors, when available, that contribute towards the risk level of the given risk check type.

Returns:

  • (Array[String])


20
21
22
# File 'lib/the_plaid_api/models/risk_check_network.rb', line 20

def factors
  @factors
end

#risk_levelRiskLevel

Risk level for the given risk check type.

Returns:



15
16
17
# File 'lib/the_plaid_api/models/risk_check_network.rb', line 15

def risk_level
  @risk_level
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/the_plaid_api/models/risk_check_network.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  risk_level = hash.key?('risk_level') ? hash['risk_level'] : nil
  factors = hash.key?('factors') ? hash['factors'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RiskCheckNetwork.new(risk_level: risk_level,
                       factors: factors,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/the_plaid_api/models/risk_check_network.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['risk_level'] = 'risk_level'
  @_hash['factors'] = 'factors'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
# File 'lib/the_plaid_api/models/risk_check_network.rb', line 36

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
# File 'lib/the_plaid_api/models/risk_check_network.rb', line 31

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
82
# File 'lib/the_plaid_api/models/risk_check_network.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} risk_level: #{@risk_level.inspect}, factors: #{@factors.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



71
72
73
74
75
# File 'lib/the_plaid_api/models/risk_check_network.rb', line 71

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} risk_level: #{@risk_level}, factors: #{@factors}, additional_properties:"\
  " #{@additional_properties}>"
end