Class: ThePlaidApi::RiskCheckSyntheticIdentity

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/risk_check_synthetic_identity.rb

Overview

Field containing the data used in determining the outcome of the synthetic identity risk check. Contains the following fields: ‘score` - A score from 0 to 100 indicating the likelihood that the user is a synthetic identity.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(score:, risk_level: SKIP, first_party_synthetic_fraud: SKIP, third_party_synthetic_fraud: SKIP, additional_properties: nil) ⇒ RiskCheckSyntheticIdentity

Returns a new instance of RiskCheckSyntheticIdentity.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/the_plaid_api/models/risk_check_synthetic_identity.rb', line 60

def initialize(score:, risk_level: SKIP, first_party_synthetic_fraud: SKIP,
               third_party_synthetic_fraud: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @score = score
  @risk_level = risk_level unless risk_level == SKIP
  unless first_party_synthetic_fraud == SKIP
    @first_party_synthetic_fraud =
      first_party_synthetic_fraud
  end
  unless third_party_synthetic_fraud == SKIP
    @third_party_synthetic_fraud =
      third_party_synthetic_fraud
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#first_party_synthetic_fraudSyntheticFraud

Field containing the data used in determining the outcome of a synthetic fraud risk check.

Returns:



26
27
28
# File 'lib/the_plaid_api/models/risk_check_synthetic_identity.rb', line 26

def first_party_synthetic_fraud
  @first_party_synthetic_fraud
end

#risk_levelRiskLevel

Risk level for the given risk check type.

Returns:



21
22
23
# File 'lib/the_plaid_api/models/risk_check_synthetic_identity.rb', line 21

def risk_level
  @risk_level
end

#scoreInteger

A score from 0 to 100 indicating the likelihood that the user is a synthetic identity.

Returns:

  • (Integer)


17
18
19
# File 'lib/the_plaid_api/models/risk_check_synthetic_identity.rb', line 17

def score
  @score
end

#third_party_synthetic_fraudSyntheticFraud

Field containing the data used in determining the outcome of a synthetic fraud risk check.

Returns:



31
32
33
# File 'lib/the_plaid_api/models/risk_check_synthetic_identity.rb', line 31

def third_party_synthetic_fraud
  @third_party_synthetic_fraud
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/the_plaid_api/models/risk_check_synthetic_identity.rb', line 80

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  score = hash.key?('score') ? hash['score'] : nil
  risk_level = hash.key?('risk_level') ? hash['risk_level'] : SKIP
  first_party_synthetic_fraud = SyntheticFraud.from_hash(hash['first_party_synthetic_fraud']) if
    hash['first_party_synthetic_fraud']
  third_party_synthetic_fraud = SyntheticFraud.from_hash(hash['third_party_synthetic_fraud']) if
    hash['third_party_synthetic_fraud']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RiskCheckSyntheticIdentity.new(score: score,
                                 risk_level: risk_level,
                                 first_party_synthetic_fraud: first_party_synthetic_fraud,
                                 third_party_synthetic_fraud: third_party_synthetic_fraud,
                                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



34
35
36
37
38
39
40
41
# File 'lib/the_plaid_api/models/risk_check_synthetic_identity.rb', line 34

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['score'] = 'score'
  @_hash['risk_level'] = 'risk_level'
  @_hash['first_party_synthetic_fraud'] = 'first_party_synthetic_fraud'
  @_hash['third_party_synthetic_fraud'] = 'third_party_synthetic_fraud'
  @_hash
end

.nullablesObject

An array for nullable fields



53
54
55
56
57
58
# File 'lib/the_plaid_api/models/risk_check_synthetic_identity.rb', line 53

def self.nullables
  %w[
    first_party_synthetic_fraud
    third_party_synthetic_fraud
  ]
end

.optionalsObject

An array for optional fields



44
45
46
47
48
49
50
# File 'lib/the_plaid_api/models/risk_check_synthetic_identity.rb', line 44

def self.optionals
  %w[
    risk_level
    first_party_synthetic_fraud
    third_party_synthetic_fraud
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



115
116
117
118
119
120
121
# File 'lib/the_plaid_api/models/risk_check_synthetic_identity.rb', line 115

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} score: #{@score.inspect}, risk_level: #{@risk_level.inspect},"\
  " first_party_synthetic_fraud: #{@first_party_synthetic_fraud.inspect},"\
  " third_party_synthetic_fraud: #{@third_party_synthetic_fraud.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



107
108
109
110
111
112
# File 'lib/the_plaid_api/models/risk_check_synthetic_identity.rb', line 107

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} score: #{@score}, risk_level: #{@risk_level}, first_party_synthetic_fraud:"\
  " #{@first_party_synthetic_fraud}, third_party_synthetic_fraud:"\
  " #{@third_party_synthetic_fraud}, additional_properties: #{@additional_properties}>"
end