Class: ThePlaidApi::RiskReason

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/risk_reason.rb

Overview

This object includes a code and description to describe medium risk transactions and above on /accounts/balance/get.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(code:, description:, additional_properties: nil) ⇒ RiskReason

Returns a new instance of RiskReason.



46
47
48
49
50
51
52
53
# File 'lib/the_plaid_api/models/risk_reason.rb', line 46

def initialize(code:, description:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @code = code
  @description = description
  @additional_properties = additional_properties
end

Instance Attribute Details

#codeString

A code that represents the type of risk associated with the proposed transaction. The codes are from PL01 to PL08 and from BK01 to BK07. For a full listing of risk reason codes, see [Risk codes](plaid.com/docs/balance/balance-plus/#risk-codes).

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/risk_reason.rb', line 19

def code
  @code
end

#descriptionString

A human-readable description explaining the risk code associated with the proposed transaction and some recommended actions. This field is subject to change; any programmatic logic should be based on the ‘code` field instead.

Returns:

  • (String)


26
27
28
# File 'lib/the_plaid_api/models/risk_reason.rb', line 26

def description
  @description
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/the_plaid_api/models/risk_reason.rb', line 56

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  code = hash.key?('code') ? hash['code'] : nil
  description = hash.key?('description') ? hash['description'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RiskReason.new(code: code,
                 description: description,
                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
# File 'lib/the_plaid_api/models/risk_reason.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['code'] = 'code'
  @_hash['description'] = 'description'
  @_hash
end

.nullablesObject

An array for nullable fields



42
43
44
# File 'lib/the_plaid_api/models/risk_reason.rb', line 42

def self.nullables
  []
end

.optionalsObject

An array for optional fields



37
38
39
# File 'lib/the_plaid_api/models/risk_reason.rb', line 37

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



84
85
86
87
88
# File 'lib/the_plaid_api/models/risk_reason.rb', line 84

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code.inspect}, description: #{@description.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



77
78
79
80
81
# File 'lib/the_plaid_api/models/risk_reason.rb', line 77

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code}, description: #{@description}, additional_properties:"\
  " #{@additional_properties}>"
end