Class: ThePlaidApi::RoleDetail

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/role_detail.rb

Overview

Documentation not found in the MISMO model viewer and not provided by Freddie Mac.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(additional_properties: nil) ⇒ RoleDetail

Returns a new instance of RoleDetail.



39
40
41
42
43
44
45
# File 'lib/the_plaid_api/models/role_detail.rb', line 39

def initialize(additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @party_role_type = 'Borrower'
  @additional_properties = additional_properties
end

Instance Attribute Details

#party_role_typeString (readonly)

A value from a MISMO defined list that identifies the role that the party plays in the transaction. Parties may be either a person or legal entity. A party may play multiple roles in a transaction.A value from a MISMO defined list that identifies the role that the party plays in the transaction. Parties may be either a person or legal entity. A party may play multiple roles in a transaction.

Returns:

  • (String)


20
21
22
# File 'lib/the_plaid_api/models/role_detail.rb', line 20

def party_role_type
  @party_role_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/the_plaid_api/models/role_detail.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.


  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RoleDetail.new(additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
# File 'lib/the_plaid_api/models/role_detail.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['party_role_type'] = 'PartyRoleType'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
# File 'lib/the_plaid_api/models/role_detail.rb', line 35

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
# File 'lib/the_plaid_api/models/role_detail.rb', line 30

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



73
74
75
76
77
# File 'lib/the_plaid_api/models/role_detail.rb', line 73

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} party_role_type: #{@party_role_type.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



66
67
68
69
70
# File 'lib/the_plaid_api/models/role_detail.rb', line 66

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} party_role_type: #{@party_role_type}, additional_properties:"\
  " #{@additional_properties}>"
end