Class: ThePlaidApi::SandboxBankIncomeFireWebhookRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/sandbox_bank_income_fire_webhook_request.rb

Overview

SandboxBankIncomeFireWebhookRequest defines the request schema for ‘/sandbox/bank_income/fire_webhook`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_code:, webhook_fields:, client_id: SKIP, secret: SKIP, webhook_override: SKIP, additional_properties: nil) ⇒ SandboxBankIncomeFireWebhookRequest

Returns a new instance of SandboxBankIncomeFireWebhookRequest.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/the_plaid_api/models/sandbox_bank_income_fire_webhook_request.rb', line 62

def initialize(webhook_code:, webhook_fields:, client_id: SKIP,
               secret: SKIP, webhook_override: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @webhook_override = webhook_override unless webhook_override == SKIP
  @webhook_code = webhook_code
  @webhook_fields = webhook_fields
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/sandbox_bank_income_fire_webhook_request.rb', line 17

def client_id
  @client_id
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/sandbox_bank_income_fire_webhook_request.rb', line 22

def secret
  @secret
end

#webhook_codeSandboxBankIncomeWebhookFireRequestWebhookCode

The webhook codes this endpoint can be used to test



31
32
33
# File 'lib/the_plaid_api/models/sandbox_bank_income_fire_webhook_request.rb', line 31

def webhook_code
  @webhook_code
end

#webhook_fieldsSandboxBankIncomeWebhookFireRequestWebhookFields

Optional fields which will be populated in the simulated webhook



35
36
37
# File 'lib/the_plaid_api/models/sandbox_bank_income_fire_webhook_request.rb', line 35

def webhook_fields
  @webhook_fields
end

#webhook_overrideString

The URL to which the webhook should be sent. If provided, this will override the URL set in the dashboard.

Returns:

  • (String)


27
28
29
# File 'lib/the_plaid_api/models/sandbox_bank_income_fire_webhook_request.rb', line 27

def webhook_override
  @webhook_override
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/the_plaid_api/models/sandbox_bank_income_fire_webhook_request.rb', line 77

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  if hash['webhook_fields']
    webhook_fields = SandboxBankIncomeWebhookFireRequestWebhookFields.from_hash(hash['webhook_fields'])
  end
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  webhook_override =
    hash.key?('webhook_override') ? hash['webhook_override'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  SandboxBankIncomeFireWebhookRequest.new(webhook_code: webhook_code,
                                          webhook_fields: webhook_fields,
                                          client_id: client_id,
                                          secret: secret,
                                          webhook_override: webhook_override,
                                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



38
39
40
41
42
43
44
45
46
# File 'lib/the_plaid_api/models/sandbox_bank_income_fire_webhook_request.rb', line 38

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['webhook_override'] = 'webhook_override'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['webhook_fields'] = 'webhook_fields'
  @_hash
end

.nullablesObject

An array for nullable fields



58
59
60
# File 'lib/the_plaid_api/models/sandbox_bank_income_fire_webhook_request.rb', line 58

def self.nullables
  []
end

.optionalsObject

An array for optional fields



49
50
51
52
53
54
55
# File 'lib/the_plaid_api/models/sandbox_bank_income_fire_webhook_request.rb', line 49

def self.optionals
  %w[
    client_id
    secret
    webhook_override
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



115
116
117
118
119
120
121
# File 'lib/the_plaid_api/models/sandbox_bank_income_fire_webhook_request.rb', line 115

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\
  " webhook_override: #{@webhook_override.inspect}, webhook_code: #{@webhook_code.inspect},"\
  " webhook_fields: #{@webhook_fields.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



107
108
109
110
111
112
# File 'lib/the_plaid_api/models/sandbox_bank_income_fire_webhook_request.rb', line 107

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, webhook_override:"\
  " #{@webhook_override}, webhook_code: #{@webhook_code}, webhook_fields: #{@webhook_fields},"\
  " additional_properties: #{@additional_properties}>"
end