Class: ThePlaidApi::SandboxBankIncomeWebhookFireRequestWebhookFields
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::SandboxBankIncomeWebhookFireRequestWebhookFields
- Defined in:
- lib/the_plaid_api/models/sandbox_bank_income_webhook_fire_request_webhook_fields.rb
Overview
Optional fields which will be populated in the simulated webhook
Instance Attribute Summary collapse
-
#bank_income_refresh_complete_result ⇒ BankIncomeRefreshCompleteResult
The result of the bank income refresh report generation ‘SUCCESS`: The refreshed report was successfully generated and can be retrieved via `/credit/bank_income/get`.
-
#user_id ⇒ String
The user id to be returned in INCOME webhooks.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(user_id:, bank_income_refresh_complete_result: SKIP, additional_properties: nil) ⇒ SandboxBankIncomeWebhookFireRequestWebhookFields
constructor
A new instance of SandboxBankIncomeWebhookFireRequestWebhookFields.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(user_id:, bank_income_refresh_complete_result: SKIP, additional_properties: nil) ⇒ SandboxBankIncomeWebhookFireRequestWebhookFields
Returns a new instance of SandboxBankIncomeWebhookFireRequestWebhookFields.
44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/the_plaid_api/models/sandbox_bank_income_webhook_fire_request_webhook_fields.rb', line 44 def initialize(user_id:, bank_income_refresh_complete_result: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @user_id = user_id unless bank_income_refresh_complete_result == SKIP @bank_income_refresh_complete_result = bank_income_refresh_complete_result end @additional_properties = additional_properties end |
Instance Attribute Details
#bank_income_refresh_complete_result ⇒ BankIncomeRefreshCompleteResult
The result of the bank income refresh report generation ‘SUCCESS`: The refreshed report was successfully generated and can be retrieved via `/credit/bank_income/get`. `FAILURE`: The refreshed report failed to be generated
21 22 23 |
# File 'lib/the_plaid_api/models/sandbox_bank_income_webhook_fire_request_webhook_fields.rb', line 21 def bank_income_refresh_complete_result @bank_income_refresh_complete_result end |
#user_id ⇒ String
The user id to be returned in INCOME webhooks
14 15 16 |
# File 'lib/the_plaid_api/models/sandbox_bank_income_webhook_fire_request_webhook_fields.rb', line 14 def user_id @user_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/the_plaid_api/models/sandbox_bank_income_webhook_fire_request_webhook_fields.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. user_id = hash.key?('user_id') ? hash['user_id'] : nil bank_income_refresh_complete_result = hash.key?('bank_income_refresh_complete_result') ? hash['bank_income_refresh_complete_result'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SandboxBankIncomeWebhookFireRequestWebhookFields.new(user_id: user_id, bank_income_refresh_complete_result: bank_income_refresh_complete_result, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 30 |
# File 'lib/the_plaid_api/models/sandbox_bank_income_webhook_fire_request_webhook_fields.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['user_id'] = 'user_id' @_hash['bank_income_refresh_complete_result'] = 'bank_income_refresh_complete_result' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/the_plaid_api/models/sandbox_bank_income_webhook_fire_request_webhook_fields.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
33 34 35 36 37 |
# File 'lib/the_plaid_api/models/sandbox_bank_income_webhook_fire_request_webhook_fields.rb', line 33 def self.optionals %w[ bank_income_refresh_complete_result ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
88 89 90 91 92 93 |
# File 'lib/the_plaid_api/models/sandbox_bank_income_webhook_fire_request_webhook_fields.rb', line 88 def inspect class_name = self.class.name.split('::').last "<#{class_name} user_id: #{@user_id.inspect}, bank_income_refresh_complete_result:"\ " #{@bank_income_refresh_complete_result.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
80 81 82 83 84 85 |
# File 'lib/the_plaid_api/models/sandbox_bank_income_webhook_fire_request_webhook_fields.rb', line 80 def to_s class_name = self.class.name.split('::').last "<#{class_name} user_id: #{@user_id}, bank_income_refresh_complete_result:"\ " #{@bank_income_refresh_complete_result}, additional_properties:"\ " #{@additional_properties}>" end |