Class: ThePlaidApi::SandboxBankTransferSimulateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/sandbox_bank_transfer_simulate_request.rb

Overview

Defines the request schema for ‘/sandbox/bank_transfer/simulate`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(bank_transfer_id:, event_type:, client_id: SKIP, secret: SKIP, failure_reason: SKIP, additional_properties: nil) ⇒ SandboxBankTransferSimulateRequest

Returns a new instance of SandboxBankTransferSimulateRequest.



70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/the_plaid_api/models/sandbox_bank_transfer_simulate_request.rb', line 70

def initialize(bank_transfer_id:, event_type:, client_id: SKIP,
               secret: SKIP, failure_reason: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @bank_transfer_id = bank_transfer_id
  @event_type = event_type
  @failure_reason = failure_reason unless failure_reason == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#bank_transfer_idString

Plaid’s unique identifier for a bank transfer.

Returns:

  • (String)


25
26
27
# File 'lib/the_plaid_api/models/sandbox_bank_transfer_simulate_request.rb', line 25

def bank_transfer_id
  @bank_transfer_id
end

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/sandbox_bank_transfer_simulate_request.rb', line 16

def client_id
  @client_id
end

#event_typeString

The asynchronous event to be simulated. May be: ‘posted`, `failed`, or `reversed`. An error will be returned if the event type is incompatible with the current transfer status. Compatible status –> event type transitions include: `pending` –> `failed` `pending` –> `posted` `posted` –> `reversed`

Returns:

  • (String)


36
37
38
# File 'lib/the_plaid_api/models/sandbox_bank_transfer_simulate_request.rb', line 36

def event_type
  @event_type
end

#failure_reasonBankTransferFailure

The failure reason if the type of this transfer is ‘“failed”` or `“reversed”`. Null value otherwise.

Returns:



41
42
43
# File 'lib/the_plaid_api/models/sandbox_bank_transfer_simulate_request.rb', line 41

def failure_reason
  @failure_reason
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/sandbox_bank_transfer_simulate_request.rb', line 21

def secret
  @secret
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/the_plaid_api/models/sandbox_bank_transfer_simulate_request.rb', line 85

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  bank_transfer_id =
    hash.key?('bank_transfer_id') ? hash['bank_transfer_id'] : nil
  event_type = hash.key?('event_type') ? hash['event_type'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  failure_reason = BankTransferFailure.from_hash(hash['failure_reason']) if
    hash['failure_reason']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  SandboxBankTransferSimulateRequest.new(bank_transfer_id: bank_transfer_id,
                                         event_type: event_type,
                                         client_id: client_id,
                                         secret: secret,
                                         failure_reason: failure_reason,
                                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



44
45
46
47
48
49
50
51
52
# File 'lib/the_plaid_api/models/sandbox_bank_transfer_simulate_request.rb', line 44

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['bank_transfer_id'] = 'bank_transfer_id'
  @_hash['event_type'] = 'event_type'
  @_hash['failure_reason'] = 'failure_reason'
  @_hash
end

.nullablesObject

An array for nullable fields



64
65
66
67
68
# File 'lib/the_plaid_api/models/sandbox_bank_transfer_simulate_request.rb', line 64

def self.nullables
  %w[
    failure_reason
  ]
end

.optionalsObject

An array for optional fields



55
56
57
58
59
60
61
# File 'lib/the_plaid_api/models/sandbox_bank_transfer_simulate_request.rb', line 55

def self.optionals
  %w[
    client_id
    secret
    failure_reason
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



122
123
124
125
126
127
128
# File 'lib/the_plaid_api/models/sandbox_bank_transfer_simulate_request.rb', line 122

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\
  " bank_transfer_id: #{@bank_transfer_id.inspect}, event_type: #{@event_type.inspect},"\
  " failure_reason: #{@failure_reason.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



114
115
116
117
118
119
# File 'lib/the_plaid_api/models/sandbox_bank_transfer_simulate_request.rb', line 114

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, bank_transfer_id:"\
  " #{@bank_transfer_id}, event_type: #{@event_type}, failure_reason: #{@failure_reason},"\
  " additional_properties: #{@additional_properties}>"
end