Class: ThePlaidApi::SandboxPaymentSimulateRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::SandboxPaymentSimulateRequest
- Defined in:
- lib/the_plaid_api/models/sandbox_payment_simulate_request.rb
Overview
SandboxPaymentSimulateRequest defines the request schema for ‘/sandbox/payment/simulate`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#payment_id ⇒ String
The ID of the payment to simulate.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#status ⇒ String
The status to set the payment to.
-
#webhook ⇒ String
The webhook url to use for any payment events triggered by the simulated status change.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(payment_id:, webhook:, status:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ SandboxPaymentSimulateRequest
constructor
A new instance of SandboxPaymentSimulateRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(payment_id:, webhook:, status:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ SandboxPaymentSimulateRequest
Returns a new instance of SandboxPaymentSimulateRequest.
69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/the_plaid_api/models/sandbox_payment_simulate_request.rb', line 69 def initialize(payment_id:, webhook:, status:, client_id: SKIP, secret: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @payment_id = payment_id @webhook = webhook @status = status @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/sandbox_payment_simulate_request.rb', line 17 def client_id @client_id end |
#payment_id ⇒ String
The ID of the payment to simulate
26 27 28 |
# File 'lib/the_plaid_api/models/sandbox_payment_simulate_request.rb', line 26 def payment_id @payment_id end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/the_plaid_api/models/sandbox_payment_simulate_request.rb', line 22 def secret @secret end |
#status ⇒ String
The status to set the payment to. Valid statuses include:
-
‘PAYMENT_STATUS_INITIATED`
-
‘PAYMENT_STATUS_INSUFFICIENT_FUNDS`
-
‘PAYMENT_STATUS_FAILED`
-
‘PAYMENT_STATUS_EXECUTED`
-
‘PAYMENT_STATUS_SETTLED`
-
‘PAYMENT_STATUS_CANCELLED`
-
‘PAYMENT_STATUS_REJECTED`
43 44 45 |
# File 'lib/the_plaid_api/models/sandbox_payment_simulate_request.rb', line 43 def status @status end |
#webhook ⇒ String
The webhook url to use for any payment events triggered by the simulated status change.
31 32 33 |
# File 'lib/the_plaid_api/models/sandbox_payment_simulate_request.rb', line 31 def webhook @webhook end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/the_plaid_api/models/sandbox_payment_simulate_request.rb', line 83 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. payment_id = hash.key?('payment_id') ? hash['payment_id'] : nil webhook = hash.key?('webhook') ? hash['webhook'] : nil status = hash.key?('status') ? hash['status'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SandboxPaymentSimulateRequest.new(payment_id: payment_id, webhook: webhook, status: status, client_id: client_id, secret: secret, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
46 47 48 49 50 51 52 53 54 |
# File 'lib/the_plaid_api/models/sandbox_payment_simulate_request.rb', line 46 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['payment_id'] = 'payment_id' @_hash['webhook'] = 'webhook' @_hash['status'] = 'status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
65 66 67 |
# File 'lib/the_plaid_api/models/sandbox_payment_simulate_request.rb', line 65 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
57 58 59 60 61 62 |
# File 'lib/the_plaid_api/models/sandbox_payment_simulate_request.rb', line 57 def self.optionals %w[ client_id secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
118 119 120 121 122 123 |
# File 'lib/the_plaid_api/models/sandbox_payment_simulate_request.rb', line 118 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, payment_id:"\ " #{@payment_id.inspect}, webhook: #{@webhook.inspect}, status: #{@status.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
110 111 112 113 114 115 |
# File 'lib/the_plaid_api/models/sandbox_payment_simulate_request.rb', line 110 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, payment_id: #{@payment_id},"\ " webhook: #{@webhook}, status: #{@status}, additional_properties:"\ " #{@additional_properties}>" end |