Class: ThePlaidApi::SandboxProcessorTokenCreateRequestOptions
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::SandboxProcessorTokenCreateRequestOptions
- Defined in:
- lib/the_plaid_api/models/sandbox_processor_token_create_request_options.rb
Overview
An optional set of options to be used when configuring the Item. If specified, must not be ‘null`.
Instance Attribute Summary collapse
-
#override_password ⇒ String
Test password to use for the creation of the Sandbox Item.
-
#override_username ⇒ String
Test username to use for the creation of the Sandbox Item.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(override_username: 'user_good', override_password: 'pass_good', additional_properties: nil) ⇒ SandboxProcessorTokenCreateRequestOptions
constructor
A new instance of SandboxProcessorTokenCreateRequestOptions.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(override_username: 'user_good', override_password: 'pass_good', additional_properties: nil) ⇒ SandboxProcessorTokenCreateRequestOptions
Returns a new instance of SandboxProcessorTokenCreateRequestOptions.
47 48 49 50 51 52 53 54 55 |
# File 'lib/the_plaid_api/models/sandbox_processor_token_create_request_options.rb', line 47 def initialize(override_username: 'user_good', override_password: 'pass_good', additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @override_username = override_username unless override_username == SKIP @override_password = override_password unless override_password == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#override_password ⇒ String
Test password to use for the creation of the Sandbox Item. Default value is ‘pass_good`.
21 22 23 |
# File 'lib/the_plaid_api/models/sandbox_processor_token_create_request_options.rb', line 21 def override_password @override_password end |
#override_username ⇒ String
Test username to use for the creation of the Sandbox Item. Default value is ‘user_good`.
16 17 18 |
# File 'lib/the_plaid_api/models/sandbox_processor_token_create_request_options.rb', line 16 def override_username @override_username end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/the_plaid_api/models/sandbox_processor_token_create_request_options.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. override_username = hash['override_username'] ||= 'user_good' override_password = hash['override_password'] ||= 'pass_good' # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SandboxProcessorTokenCreateRequestOptions.new(override_username: override_username, override_password: override_password, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/the_plaid_api/models/sandbox_processor_token_create_request_options.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['override_username'] = 'override_username' @_hash['override_password'] = 'override_password' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 43 44 45 |
# File 'lib/the_plaid_api/models/sandbox_processor_token_create_request_options.rb', line 40 def self.nullables %w[ override_username override_password ] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 35 36 37 |
# File 'lib/the_plaid_api/models/sandbox_processor_token_create_request_options.rb', line 32 def self.optionals %w[ override_username override_password ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 |
# File 'lib/the_plaid_api/models/sandbox_processor_token_create_request_options.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} override_username: #{@override_username.inspect}, override_password:"\ " #{@override_password.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/the_plaid_api/models/sandbox_processor_token_create_request_options.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} override_username: #{@override_username}, override_password:"\ " #{@override_password}, additional_properties: #{@additional_properties}>" end |