Class: ThePlaidApi::SandboxPublicTokenCreateRequestOptionsStatements
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::SandboxPublicTokenCreateRequestOptionsStatements
- Defined in:
- lib/the_plaid_api/models/sandbox_public_token_create_request_options_statements.rb
Overview
An optional set of parameters corresponding to statements options.
Instance Attribute Summary collapse
-
#end_date ⇒ Date
The most recent date for which to fetch statements history.
-
#start_date ⇒ Date
The earliest date for which to fetch statements history.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(start_date:, end_date:, additional_properties: nil) ⇒ SandboxPublicTokenCreateRequestOptionsStatements
constructor
A new instance of SandboxPublicTokenCreateRequestOptionsStatements.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(start_date:, end_date:, additional_properties: nil) ⇒ SandboxPublicTokenCreateRequestOptionsStatements
Returns a new instance of SandboxPublicTokenCreateRequestOptionsStatements.
40 41 42 43 44 45 46 47 |
# File 'lib/the_plaid_api/models/sandbox_public_token_create_request_options_statements.rb', line 40 def initialize(start_date:, end_date:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @start_date = start_date @end_date = end_date @additional_properties = additional_properties end |
Instance Attribute Details
#end_date ⇒ Date
The most recent date for which to fetch statements history. Dates should be formatted as YYYY-MM-DD.
20 21 22 |
# File 'lib/the_plaid_api/models/sandbox_public_token_create_request_options_statements.rb', line 20 def end_date @end_date end |
#start_date ⇒ Date
The earliest date for which to fetch statements history. Dates should be formatted as YYYY-MM-DD.
15 16 17 |
# File 'lib/the_plaid_api/models/sandbox_public_token_create_request_options_statements.rb', line 15 def start_date @start_date end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/the_plaid_api/models/sandbox_public_token_create_request_options_statements.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. start_date = hash.key?('start_date') ? hash['start_date'] : nil end_date = hash.key?('end_date') ? hash['end_date'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SandboxPublicTokenCreateRequestOptionsStatements.new(start_date: start_date, end_date: end_date, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/the_plaid_api/models/sandbox_public_token_create_request_options_statements.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['start_date'] = 'start_date' @_hash['end_date'] = 'end_date' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/the_plaid_api/models/sandbox_public_token_create_request_options_statements.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 |
# File 'lib/the_plaid_api/models/sandbox_public_token_create_request_options_statements.rb', line 31 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/the_plaid_api/models/sandbox_public_token_create_request_options_statements.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} start_date: #{@start_date.inspect}, end_date: #{@end_date.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/the_plaid_api/models/sandbox_public_token_create_request_options_statements.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} start_date: #{@start_date}, end_date: #{@end_date}, additional_properties:"\ " #{@additional_properties}>" end |