Class: ThePlaidApi::SandboxTransferLedgerWithdrawSimulateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/sandbox_transfer_ledger_withdraw_simulate_request.rb

Overview

Defines the request schema for ‘/sandbox/transfer/ledger/withdraw/simulate`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(sweep_id:, event_type:, client_id: SKIP, secret: SKIP, failure_reason: SKIP, additional_properties: nil) ⇒ SandboxTransferLedgerWithdrawSimulateRequest

Returns a new instance of SandboxTransferLedgerWithdrawSimulateRequest.



72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/the_plaid_api/models/sandbox_transfer_ledger_withdraw_simulate_request.rb', line 72

def initialize(sweep_id:, event_type:, client_id: SKIP, secret: SKIP,
               failure_reason: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @sweep_id = sweep_id
  @event_type = event_type
  @failure_reason = failure_reason unless failure_reason == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/sandbox_transfer_ledger_withdraw_simulate_request.rb', line 16

def client_id
  @client_id
end

#event_typeTransferLedgerSweepSimulateEventType

The asynchronous event to be simulated. May be: ‘posted`, `settled`, `failed`, or `returned`. An error will be returned if the event type is incompatible with the current ledger sweep status. Compatible status –> event type transitions include: `sweep.pending` –> `sweep.posted` `sweep.pending` –> `sweep.failed` `sweep.posted` –> `sweep.settled` `sweep.posted` –> `sweep.returned` `sweep.settled` –> `sweep.returned`



38
39
40
# File 'lib/the_plaid_api/models/sandbox_transfer_ledger_withdraw_simulate_request.rb', line 38

def event_type
  @event_type
end

#failure_reasonTransferFailure

The failure reason if the event type for a transfer is ‘“failed”` or `“returned”`. Null value otherwise.

Returns:



43
44
45
# File 'lib/the_plaid_api/models/sandbox_transfer_ledger_withdraw_simulate_request.rb', line 43

def failure_reason
  @failure_reason
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/sandbox_transfer_ledger_withdraw_simulate_request.rb', line 21

def secret
  @secret
end

#sweep_idString

Plaid’s unique identifier for a sweep.

Returns:

  • (String)


25
26
27
# File 'lib/the_plaid_api/models/sandbox_transfer_ledger_withdraw_simulate_request.rb', line 25

def sweep_id
  @sweep_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/the_plaid_api/models/sandbox_transfer_ledger_withdraw_simulate_request.rb', line 86

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  sweep_id = hash.key?('sweep_id') ? hash['sweep_id'] : nil
  event_type = hash.key?('event_type') ? hash['event_type'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  failure_reason = TransferFailure.from_hash(hash['failure_reason']) if hash['failure_reason']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  SandboxTransferLedgerWithdrawSimulateRequest.new(sweep_id: sweep_id,
                                                   event_type: event_type,
                                                   client_id: client_id,
                                                   secret: secret,
                                                   failure_reason: failure_reason,
                                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



46
47
48
49
50
51
52
53
54
# File 'lib/the_plaid_api/models/sandbox_transfer_ledger_withdraw_simulate_request.rb', line 46

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['sweep_id'] = 'sweep_id'
  @_hash['event_type'] = 'event_type'
  @_hash['failure_reason'] = 'failure_reason'
  @_hash
end

.nullablesObject

An array for nullable fields



66
67
68
69
70
# File 'lib/the_plaid_api/models/sandbox_transfer_ledger_withdraw_simulate_request.rb', line 66

def self.nullables
  %w[
    failure_reason
  ]
end

.optionalsObject

An array for optional fields



57
58
59
60
61
62
63
# File 'lib/the_plaid_api/models/sandbox_transfer_ledger_withdraw_simulate_request.rb', line 57

def self.optionals
  %w[
    client_id
    secret
    failure_reason
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



121
122
123
124
125
126
# File 'lib/the_plaid_api/models/sandbox_transfer_ledger_withdraw_simulate_request.rb', line 121

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, sweep_id:"\
  " #{@sweep_id.inspect}, event_type: #{@event_type.inspect}, failure_reason:"\
  " #{@failure_reason.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



113
114
115
116
117
118
# File 'lib/the_plaid_api/models/sandbox_transfer_ledger_withdraw_simulate_request.rb', line 113

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, sweep_id: #{@sweep_id},"\
  " event_type: #{@event_type}, failure_reason: #{@failure_reason}, additional_properties:"\
  " #{@additional_properties}>"
end