Class: ThePlaidApi::SandboxTransferSweepSimulateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/sandbox_transfer_sweep_simulate_request.rb

Overview

Defines the request schema for ‘/sandbox/transfer/sweep/simulate`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(client_id: SKIP, secret: SKIP, test_clock_id: SKIP, webhook: SKIP, additional_properties: nil) ⇒ SandboxTransferSweepSimulateRequest

Returns a new instance of SandboxTransferSweepSimulateRequest.



62
63
64
65
66
67
68
69
70
71
72
# File 'lib/the_plaid_api/models/sandbox_transfer_sweep_simulate_request.rb', line 62

def initialize(client_id: SKIP, secret: SKIP, test_clock_id: SKIP,
               webhook: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @test_clock_id = test_clock_id unless test_clock_id == SKIP
  @webhook = webhook unless webhook == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/sandbox_transfer_sweep_simulate_request.rb', line 16

def client_id
  @client_id
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/sandbox_transfer_sweep_simulate_request.rb', line 21

def secret
  @secret
end

#test_clock_idString

Plaid’s unique identifier for a test clock. If provided, the sweep to be simulated is created on the day of the ‘virtual_time` on the `test_clock`. If the date of `virtual_time` is on weekend or a federal holiday, the next available banking day is used.

Returns:

  • (String)


28
29
30
# File 'lib/the_plaid_api/models/sandbox_transfer_sweep_simulate_request.rb', line 28

def test_clock_id
  @test_clock_id
end

#webhookString

The webhook URL to which a ‘TRANSFER_EVENTS_UPDATE` webhook should be sent.

Returns:

  • (String)


33
34
35
# File 'lib/the_plaid_api/models/sandbox_transfer_sweep_simulate_request.rb', line 33

def webhook
  @webhook
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/the_plaid_api/models/sandbox_transfer_sweep_simulate_request.rb', line 75

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  test_clock_id = hash.key?('test_clock_id') ? hash['test_clock_id'] : SKIP
  webhook = hash.key?('webhook') ? hash['webhook'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  SandboxTransferSweepSimulateRequest.new(client_id: client_id,
                                          secret: secret,
                                          test_clock_id: test_clock_id,
                                          webhook: webhook,
                                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



36
37
38
39
40
41
42
43
# File 'lib/the_plaid_api/models/sandbox_transfer_sweep_simulate_request.rb', line 36

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['test_clock_id'] = 'test_clock_id'
  @_hash['webhook'] = 'webhook'
  @_hash
end

.nullablesObject

An array for nullable fields



56
57
58
59
60
# File 'lib/the_plaid_api/models/sandbox_transfer_sweep_simulate_request.rb', line 56

def self.nullables
  %w[
    test_clock_id
  ]
end

.optionalsObject

An array for optional fields



46
47
48
49
50
51
52
53
# File 'lib/the_plaid_api/models/sandbox_transfer_sweep_simulate_request.rb', line 46

def self.optionals
  %w[
    client_id
    secret
    test_clock_id
    webhook
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



108
109
110
111
112
113
# File 'lib/the_plaid_api/models/sandbox_transfer_sweep_simulate_request.rb', line 108

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\
  " test_clock_id: #{@test_clock_id.inspect}, webhook: #{@webhook.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



100
101
102
103
104
105
# File 'lib/the_plaid_api/models/sandbox_transfer_sweep_simulate_request.rb', line 100

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, test_clock_id:"\
  " #{@test_clock_id}, webhook: #{@webhook}, additional_properties:"\
  " #{@additional_properties}>"
end