Class: ThePlaidApi::SandboxTransferSweepSimulateResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/sandbox_transfer_sweep_simulate_response.rb

Overview

Defines the response schema for ‘/sandbox/transfer/sweep/simulate`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(request_id:, sweep: SKIP, additional_properties: nil) ⇒ SandboxTransferSweepSimulateResponse

Returns a new instance of SandboxTransferSweepSimulateResponse.



45
46
47
48
49
50
51
52
# File 'lib/the_plaid_api/models/sandbox_transfer_sweep_simulate_response.rb', line 45

def initialize(request_id:, sweep: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @sweep = sweep unless sweep == SKIP
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/sandbox_transfer_sweep_simulate_response.rb', line 21

def request_id
  @request_id
end

#sweepSimulatedTransferSweep

A sweep returned from the ‘/sandbox/transfer/sweep/simulate` endpoint. Can be null if there are no transfers to include in a sweep.



15
16
17
# File 'lib/the_plaid_api/models/sandbox_transfer_sweep_simulate_response.rb', line 15

def sweep
  @sweep
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/the_plaid_api/models/sandbox_transfer_sweep_simulate_response.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  request_id = hash.key?('request_id') ? hash['request_id'] : nil
  sweep = SimulatedTransferSweep.from_hash(hash['sweep']) if hash['sweep']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  SandboxTransferSweepSimulateResponse.new(request_id: request_id,
                                           sweep: sweep,
                                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
29
# File 'lib/the_plaid_api/models/sandbox_transfer_sweep_simulate_response.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['sweep'] = 'sweep'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
42
43
# File 'lib/the_plaid_api/models/sandbox_transfer_sweep_simulate_response.rb', line 39

def self.nullables
  %w[
    sweep
  ]
end

.optionalsObject

An array for optional fields



32
33
34
35
36
# File 'lib/the_plaid_api/models/sandbox_transfer_sweep_simulate_response.rb', line 32

def self.optionals
  %w[
    sweep
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



83
84
85
86
87
# File 'lib/the_plaid_api/models/sandbox_transfer_sweep_simulate_response.rb', line 83

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} sweep: #{@sweep.inspect}, request_id: #{@request_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



76
77
78
79
80
# File 'lib/the_plaid_api/models/sandbox_transfer_sweep_simulate_response.rb', line 76

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} sweep: #{@sweep}, request_id: #{@request_id}, additional_properties:"\
  " #{@additional_properties}>"
end