Class: ThePlaidApi::SandboxTransferTestClockCreateRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::SandboxTransferTestClockCreateRequest
- Defined in:
- lib/the_plaid_api/models/sandbox_transfer_test_clock_create_request.rb
Overview
Defines the request schema for ‘/sandbox/transfer/test_clock/create`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#virtual_time ⇒ DateTime
The virtual timestamp on the test clock.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_id: SKIP, secret: SKIP, virtual_time: SKIP, additional_properties: nil) ⇒ SandboxTransferTestClockCreateRequest
constructor
A new instance of SandboxTransferTestClockCreateRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_virtual_time ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_id: SKIP, secret: SKIP, virtual_time: SKIP, additional_properties: nil) ⇒ SandboxTransferTestClockCreateRequest
Returns a new instance of SandboxTransferTestClockCreateRequest.
54 55 56 57 58 59 60 61 62 63 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_create_request.rb', line 54 def initialize(client_id: SKIP, secret: SKIP, virtual_time: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @virtual_time = virtual_time unless virtual_time == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_create_request.rb', line 17 def client_id @client_id end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_create_request.rb', line 22 def secret @secret end |
#virtual_time ⇒ DateTime
The virtual timestamp on the test clock. If not provided, the current timestamp will be used. This will be of the form ‘2006-01-02T15:04:05Z`.
27 28 29 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_create_request.rb', line 27 def virtual_time @virtual_time end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_create_request.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP virtual_time = if hash.key?('virtual_time') (DateTimeHelper.from_rfc3339(hash['virtual_time']) if hash['virtual_time']) else SKIP end # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SandboxTransferTestClockCreateRequest.new(client_id: client_id, secret: secret, virtual_time: virtual_time, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
30 31 32 33 34 35 36 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_create_request.rb', line 30 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['virtual_time'] = 'virtual_time' @_hash end |
.nullables ⇒ Object
An array for nullable fields
48 49 50 51 52 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_create_request.rb', line 48 def self.nullables %w[ virtual_time ] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_create_request.rb', line 39 def self.optionals %w[ client_id secret virtual_time ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
104 105 106 107 108 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_create_request.rb', line 104 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, virtual_time:"\ " #{@virtual_time.inspect}, additional_properties: #{@additional_properties}>" end |
#to_custom_virtual_time ⇒ Object
92 93 94 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_create_request.rb', line 92 def to_custom_virtual_time DateTimeHelper.to_rfc3339(virtual_time) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
97 98 99 100 101 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_create_request.rb', line 97 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, virtual_time:"\ " #{@virtual_time}, additional_properties: #{@additional_properties}>" end |