Class: ThePlaidApi::SandboxTransferTestClockGetRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::SandboxTransferTestClockGetRequest
- Defined in:
- lib/the_plaid_api/models/sandbox_transfer_test_clock_get_request.rb
Overview
Defines the request schema for ‘/sandbox/transfer/test_clock/get`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#test_clock_id ⇒ String
Plaid’s unique identifier for a test clock.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(test_clock_id:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ SandboxTransferTestClockGetRequest
constructor
A new instance of SandboxTransferTestClockGetRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(test_clock_id:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ SandboxTransferTestClockGetRequest
Returns a new instance of SandboxTransferTestClockGetRequest.
54 55 56 57 58 59 60 61 62 63 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_get_request.rb', line 54 def initialize(test_clock_id:, client_id: SKIP, secret: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @test_clock_id = test_clock_id @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_get_request.rb', line 16 def client_id @client_id end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
21 22 23 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_get_request.rb', line 21 def secret @secret end |
#test_clock_id ⇒ String
Plaid’s unique identifier for a test clock. This field is only populated in the Sandbox environment, and only if a ‘test_clock_id` was included in the `/transfer/recurring/create` request. For more details, see [Simulating recurring transfers](plaid.com/docs/transfer/sandbox/#simulating-recurring-t ransfers).
30 31 32 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_get_request.rb', line 30 def test_clock_id @test_clock_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_get_request.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. test_clock_id = hash.key?('test_clock_id') ? hash['test_clock_id'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SandboxTransferTestClockGetRequest.new(test_clock_id: test_clock_id, client_id: client_id, secret: secret, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_get_request.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['test_clock_id'] = 'test_clock_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
50 51 52 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_get_request.rb', line 50 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
42 43 44 45 46 47 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_get_request.rb', line 42 def self.optionals %w[ client_id secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
96 97 98 99 100 101 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_get_request.rb', line 96 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\ " test_clock_id: #{@test_clock_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
89 90 91 92 93 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_get_request.rb', line 89 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, test_clock_id:"\ " #{@test_clock_id}, additional_properties: #{@additional_properties}>" end |