Class: ThePlaidApi::ScreeningHitDateOfBirthItem

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/screening_hit_date_of_birth_item.rb

Overview

Analyzed date of birth for the associated hit

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(analysis: SKIP, data: SKIP, additional_properties: nil) ⇒ ScreeningHitDateOfBirthItem

Returns a new instance of ScreeningHitDateOfBirthItem.



41
42
43
44
45
46
47
48
# File 'lib/the_plaid_api/models/screening_hit_date_of_birth_item.rb', line 41

def initialize(analysis: SKIP, data: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @analysis = analysis unless analysis == SKIP
  @data = data unless data == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#analysisMatchSummary

Summary object reflecting the match result of the associated data

Returns:



14
15
16
# File 'lib/the_plaid_api/models/screening_hit_date_of_birth_item.rb', line 14

def analysis
  @analysis
end

#dataDateRange

A date range with a start and end date

Returns:



18
19
20
# File 'lib/the_plaid_api/models/screening_hit_date_of_birth_item.rb', line 18

def data
  @data
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/the_plaid_api/models/screening_hit_date_of_birth_item.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  analysis = MatchSummary.from_hash(hash['analysis']) if hash['analysis']
  data = DateRange.from_hash(hash['data']) if hash['data']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ScreeningHitDateOfBirthItem.new(analysis: analysis,
                                  data: data,
                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/the_plaid_api/models/screening_hit_date_of_birth_item.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['analysis'] = 'analysis'
  @_hash['data'] = 'data'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/the_plaid_api/models/screening_hit_date_of_birth_item.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/the_plaid_api/models/screening_hit_date_of_birth_item.rb', line 29

def self.optionals
  %w[
    analysis
    data
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/the_plaid_api/models/screening_hit_date_of_birth_item.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} analysis: #{@analysis.inspect}, data: #{@data.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/the_plaid_api/models/screening_hit_date_of_birth_item.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} analysis: #{@analysis}, data: #{@data}, additional_properties:"\
  " #{@additional_properties}>"
end