Class: ThePlaidApi::SelfieCheck
- Defined in:
- lib/the_plaid_api/models/selfie_check.rb
Overview
Additional information for the ‘selfie_check` step. This field will be `null` unless `steps.selfie_check` has reached a terminal state of either `success` or `failed`.
Instance Attribute Summary collapse
-
#selfies ⇒ Array[SelfieCheckSelfie]
An array of selfies submitted to the ‘selfie_check` step.
-
#status ⇒ SelfieCheckStatus
The outcome status for the associated Identity Verification attempt’s ‘selfie_check` step.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(status:, selfies:, additional_properties: nil) ⇒ SelfieCheck
constructor
A new instance of SelfieCheck.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(status:, selfies:, additional_properties: nil) ⇒ SelfieCheck
Returns a new instance of SelfieCheck.
43 44 45 46 47 48 49 50 |
# File 'lib/the_plaid_api/models/selfie_check.rb', line 43 def initialize(status:, selfies:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @status = status @selfies = selfies @additional_properties = additional_properties end |
Instance Attribute Details
#selfies ⇒ Array[SelfieCheckSelfie]
An array of selfies submitted to the ‘selfie_check` step. Each entry represents one user submission.
23 24 25 |
# File 'lib/the_plaid_api/models/selfie_check.rb', line 23 def selfies @selfies end |
#status ⇒ SelfieCheckStatus
The outcome status for the associated Identity Verification attempt’s ‘selfie_check` step. This field will always have the same value as `steps.selfie_check`.
18 19 20 |
# File 'lib/the_plaid_api/models/selfie_check.rb', line 18 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/the_plaid_api/models/selfie_check.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. status = hash.key?('status') ? hash['status'] : nil # Parameter is an array, so we need to iterate through it selfies = nil unless hash['selfies'].nil? selfies = [] hash['selfies'].each do |structure| selfies << (SelfieCheckSelfie.from_hash(structure) if structure) end end selfies = nil unless hash.key?('selfies') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SelfieCheck.new(status: status, selfies: selfies, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 |
# File 'lib/the_plaid_api/models/selfie_check.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['status'] = 'status' @_hash['selfies'] = 'selfies' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/the_plaid_api/models/selfie_check.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/the_plaid_api/models/selfie_check.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
90 91 92 93 94 |
# File 'lib/the_plaid_api/models/selfie_check.rb', line 90 def inspect class_name = self.class.name.split('::').last "<#{class_name} status: #{@status.inspect}, selfies: #{@selfies.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 87 |
# File 'lib/the_plaid_api/models/selfie_check.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} status: #{@status}, selfies: #{@selfies}, additional_properties:"\ " #{@additional_properties}>" end |