Class: ThePlaidApi::SelfieCheckStatus
- Inherits:
-
Object
- Object
- ThePlaidApi::SelfieCheckStatus
- Defined in:
- lib/the_plaid_api/models/selfie_check_status.rb
Overview
The outcome status for the associated Identity Verification attempt’s ‘selfie_check` step. This field will always have the same value as `steps.selfie_check`.
Constant Summary collapse
- SELFIE_CHECK_STATUS =
[ # TODO: Write general description for SUCCESS SUCCESS = 'success'.freeze, # TODO: Write general description for FAILED FAILED = 'failed'.freeze ].freeze
Class Method Summary collapse
Class Method Details
.from_value(value, default_value = SUCCESS) ⇒ Object
25 26 27 28 29 30 31 32 33 34 35 36 |
# File 'lib/the_plaid_api/models/selfie_check_status.rb', line 25 def self.from_value(value, default_value = SUCCESS) return default_value if value.nil? str = value.to_s.strip case str.downcase when 'success' then SUCCESS when 'failed' then FAILED else default_value end end |
.validate(value) ⇒ Object
19 20 21 22 23 |
# File 'lib/the_plaid_api/models/selfie_check_status.rb', line 19 def self.validate(value) return false if value.nil? SELFIE_CHECK_STATUS.include?(value) end |