Class: ThePlaidApi::Service

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/service.rb

Overview

A collection of details related to a fulfillment service or product in terms of request, process and result.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(verification_of_asset:, statuses:, additional_properties: nil) ⇒ Service

Returns a new instance of Service.



40
41
42
43
44
45
46
47
48
# File 'lib/the_plaid_api/models/service.rb', line 40

def initialize(verification_of_asset:, statuses:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @verification_of_asset = verification_of_asset
  @statuses = statuses
  @additional_properties = additional_properties
end

Instance Attribute Details

#statusesStatuses

A collection of STATUS containers.

Returns:



20
21
22
# File 'lib/the_plaid_api/models/service.rb', line 20

def statuses
  @statuses
end

#verification_of_assetVerificationOfAsset

Documentation not found in the MISMO model viewer and not provided by Freddie Mac.

Returns:



16
17
18
# File 'lib/the_plaid_api/models/service.rb', line 16

def verification_of_asset
  @verification_of_asset
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/the_plaid_api/models/service.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  verification_of_asset = VerificationOfAsset.from_hash(hash['VERIFICATION_OF_ASSET']) if
    hash['VERIFICATION_OF_ASSET']
  statuses = Statuses.from_hash(hash['STATUSES']) if hash['STATUSES']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Service.new(verification_of_asset: verification_of_asset,
              statuses: statuses,
              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/the_plaid_api/models/service.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['verification_of_asset'] = 'VERIFICATION_OF_ASSET'
  @_hash['statuses'] = 'STATUSES'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
# File 'lib/the_plaid_api/models/service.rb', line 36

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
# File 'lib/the_plaid_api/models/service.rb', line 31

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/the_plaid_api/models/service.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} verification_of_asset: #{@verification_of_asset.inspect}, statuses:"\
  " #{@statuses.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/the_plaid_api/models/service.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} verification_of_asset: #{@verification_of_asset}, statuses: #{@statuses},"\
  " additional_properties: #{@additional_properties}>"
end