Class: ThePlaidApi::ServiceProductFulfillment
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ServiceProductFulfillment
- Defined in:
- lib/the_plaid_api/models/service_product_fulfillment.rb
Overview
A collection of details related to a fulfillment service or product in terms of request, process and result.
Instance Attribute Summary collapse
-
#service_product_fulfillment_detail ⇒ ServiceProductFulfillmentDetail
Documentation not found in the MISMO model viewer and not provided by Freddie Mac.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(service_product_fulfillment_detail:, additional_properties: nil) ⇒ ServiceProductFulfillment
constructor
A new instance of ServiceProductFulfillment.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(service_product_fulfillment_detail:, additional_properties: nil) ⇒ ServiceProductFulfillment
Returns a new instance of ServiceProductFulfillment.
36 37 38 39 40 41 42 43 |
# File 'lib/the_plaid_api/models/service_product_fulfillment.rb', line 36 def initialize(service_product_fulfillment_detail:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @service_product_fulfillment_detail = service_product_fulfillment_detail @additional_properties = additional_properties end |
Instance Attribute Details
#service_product_fulfillment_detail ⇒ ServiceProductFulfillmentDetail
Documentation not found in the MISMO model viewer and not provided by Freddie Mac.
16 17 18 |
# File 'lib/the_plaid_api/models/service_product_fulfillment.rb', line 16 def service_product_fulfillment_detail @service_product_fulfillment_detail end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/the_plaid_api/models/service_product_fulfillment.rb', line 46 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. if hash['SERVICE_PRODUCT_FULFILLMENT_DETAIL'] service_product_fulfillment_detail = ServiceProductFulfillmentDetail.from_hash(hash['SERVICE_PRODUCT_FULFILLMENT_DETAIL']) end # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ServiceProductFulfillment.new(service_product_fulfillment_detail: service_product_fulfillment_detail, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
19 20 21 22 23 24 |
# File 'lib/the_plaid_api/models/service_product_fulfillment.rb', line 19 def self.names @_hash = {} if @_hash.nil? @_hash['service_product_fulfillment_detail'] = 'SERVICE_PRODUCT_FULFILLMENT_DETAIL' @_hash end |
.nullables ⇒ Object
An array for nullable fields
32 33 34 |
# File 'lib/the_plaid_api/models/service_product_fulfillment.rb', line 32 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
27 28 29 |
# File 'lib/the_plaid_api/models/service_product_fulfillment.rb', line 27 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
74 75 76 77 78 79 |
# File 'lib/the_plaid_api/models/service_product_fulfillment.rb', line 74 def inspect class_name = self.class.name.split('::').last "<#{class_name} service_product_fulfillment_detail:"\ " #{@service_product_fulfillment_detail.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 71 |
# File 'lib/the_plaid_api/models/service_product_fulfillment.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} service_product_fulfillment_detail: #{@service_product_fulfillment_detail},"\ " additional_properties: #{@additional_properties}>" end |