Class: ThePlaidApi::SessionTokenCreateRequestUser

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/session_token_create_request_user.rb

Overview

Details about the end user. Required if a root-level ‘user_id` is not provided.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(client_user_id:, user_id: SKIP, additional_properties: nil) ⇒ SessionTokenCreateRequestUser

Returns a new instance of SessionTokenCreateRequestUser.



49
50
51
52
53
54
55
56
# File 'lib/the_plaid_api/models/session_token_create_request_user.rb', line 49

def initialize(client_user_id:, user_id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_user_id = client_user_id
  @user_id = user_id unless user_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_user_idString

A unique ID representing the end user. Typically this will be a user ID number from your application. Personally identifiable information, such as an email address or phone number, should not be used in the ‘client_user_id`. It is currently used as a means of searching logs for the given user in the Plaid Dashboard.

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/session_token_create_request_user.rb', line 19

def client_user_id
  @client_user_id
end

#user_idString

A unique ID representing the end user. Typically this will be a user ID number from your application. Personally identifiable information, such as an email address or phone number, should not be used in the ‘client_user_id`. It is currently used as a means of searching logs for the given user in the Plaid Dashboard.

Returns:

  • (String)


27
28
29
# File 'lib/the_plaid_api/models/session_token_create_request_user.rb', line 27

def user_id
  @user_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/the_plaid_api/models/session_token_create_request_user.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  client_user_id =
    hash.key?('client_user_id') ? hash['client_user_id'] : nil
  user_id = hash.key?('user_id') ? hash['user_id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  SessionTokenCreateRequestUser.new(client_user_id: client_user_id,
                                    user_id: user_id,
                                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



30
31
32
33
34
35
# File 'lib/the_plaid_api/models/session_token_create_request_user.rb', line 30

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_user_id'] = 'client_user_id'
  @_hash['user_id'] = 'user_id'
  @_hash
end

.nullablesObject

An array for nullable fields



45
46
47
# File 'lib/the_plaid_api/models/session_token_create_request_user.rb', line 45

def self.nullables
  []
end

.optionalsObject

An array for optional fields



38
39
40
41
42
# File 'lib/the_plaid_api/models/session_token_create_request_user.rb', line 38

def self.optionals
  %w[
    user_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



88
89
90
91
92
# File 'lib/the_plaid_api/models/session_token_create_request_user.rb', line 88

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_user_id: #{@client_user_id.inspect}, user_id: #{@user_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



81
82
83
84
85
# File 'lib/the_plaid_api/models/session_token_create_request_user.rb', line 81

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_user_id: #{@client_user_id}, user_id: #{@user_id},"\
  " additional_properties: #{@additional_properties}>"
end