Class: ThePlaidApi::SignalEvaluateRiskProfile

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/signal_evaluate_risk_profile.rb

Overview

RiskProfile is deprecated, use ‘ruleset` instead.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(key: SKIP, outcome: SKIP, additional_properties: nil) ⇒ SignalEvaluateRiskProfile

Returns a new instance of SignalEvaluateRiskProfile.



44
45
46
47
48
49
50
51
# File 'lib/the_plaid_api/models/signal_evaluate_risk_profile.rb', line 44

def initialize(key: SKIP, outcome: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @key = key unless key == SKIP
  @outcome = outcome unless outcome == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#keyString

The key of the risk profile used for this transaction.

Returns:

  • (String)


14
15
16
# File 'lib/the_plaid_api/models/signal_evaluate_risk_profile.rb', line 14

def key
  @key
end

#outcomeString

Legacy method of inspecting the result of the ruleset. New integrations should simply use the “result” property instead. This value will be omitted if you do not have a live existing integration with rules using this field.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/signal_evaluate_risk_profile.rb', line 21

def outcome
  @outcome
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/the_plaid_api/models/signal_evaluate_risk_profile.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  key = hash.key?('key') ? hash['key'] : SKIP
  outcome = hash.key?('outcome') ? hash['outcome'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  SignalEvaluateRiskProfile.new(key: key,
                                outcome: outcome,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
29
# File 'lib/the_plaid_api/models/signal_evaluate_risk_profile.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['key'] = 'key'
  @_hash['outcome'] = 'outcome'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/the_plaid_api/models/signal_evaluate_risk_profile.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



32
33
34
35
36
37
# File 'lib/the_plaid_api/models/signal_evaluate_risk_profile.rb', line 32

def self.optionals
  %w[
    key
    outcome
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



82
83
84
85
86
# File 'lib/the_plaid_api/models/signal_evaluate_risk_profile.rb', line 82

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} key: #{@key.inspect}, outcome: #{@outcome.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



75
76
77
78
79
# File 'lib/the_plaid_api/models/signal_evaluate_risk_profile.rb', line 75

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} key: #{@key}, outcome: #{@outcome}, additional_properties:"\
  " #{@additional_properties}>"
end