Class: ThePlaidApi::SignalScheduleDefaultPaymentMethod

Inherits:
Object
  • Object
show all
Defined in:
lib/the_plaid_api/models/signal_schedule_default_payment_method.rb

Overview

The payment method specified in the ‘default_payment_method` field directly impacts the timing recommendations provided by the API for submitting the debit entry to your processor or ODFI. If unspecified, defaults to `STANDARD_ACH`. `SAME_DAY_ACH`: Same Day ACH (as defined by Nacha). The API assumes the settlement will occur on the same business day if the `/signal/schedule` request is submitted by 6:00 PM UTC. Note: The actual cutoff time can vary depending on your payment processor or ODFI. Nacha has established three processing windows for Same Day ACH (UTC): 2:30 PM, 6:45 PM, and 8:45 PM. `STANDARD_ACH`: Standard ACH (as defined by Nacha), typically settled one to three business days after submission. `MULTIPLE_PAYMENT_METHODS`: Indicates that there is no default debit rail or multiple payment methods are available, and the transaction could use any of them based on customer policy or availability.

Constant Summary collapse

SIGNAL_SCHEDULE_DEFAULT_PAYMENT_METHOD =
[
  # TODO: Write general description for SAME_DAY_ACH
  SAME_DAY_ACH = 'SAME_DAY_ACH'.freeze,

  # TODO: Write general description for STANDARD_ACH
  STANDARD_ACH = 'STANDARD_ACH'.freeze,

  # TODO: Write general description for MULTIPLE_PAYMENT_METHODS
  MULTIPLE_PAYMENT_METHODS = 'MULTIPLE_PAYMENT_METHODS'.freeze
].freeze

Class Method Summary collapse

Class Method Details

.from_value(value, default_value = SAME_DAY_ACH) ⇒ Object



38
39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/the_plaid_api/models/signal_schedule_default_payment_method.rb', line 38

def self.from_value(value, default_value = SAME_DAY_ACH)
  return default_value if value.nil?

  str = value.to_s.strip

  case str.downcase
  when 'same_day_ach' then SAME_DAY_ACH
  when 'standard_ach' then STANDARD_ACH
  when 'multiple_payment_methods' then MULTIPLE_PAYMENT_METHODS
  else
    default_value
  end
end

.validate(value) ⇒ Object



32
33
34
35
36
# File 'lib/the_plaid_api/models/signal_schedule_default_payment_method.rb', line 32

def self.validate(value)
  return false if value.nil?

  SIGNAL_SCHEDULE_DEFAULT_PAYMENT_METHOD.include?(value)
end