Class: ThePlaidApi::StandaloneCurrencyCodeList

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/standalone_currency_code_list.rb

Overview

The following currency codes are supported by Plaid.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(iso_currency_code:, unofficial_currency_code:, additional_properties: nil) ⇒ StandaloneCurrencyCodeList

Returns a new instance of StandaloneCurrencyCodeList.



38
39
40
41
42
43
44
45
46
# File 'lib/the_plaid_api/models/standalone_currency_code_list.rb', line 38

def initialize(iso_currency_code:, unofficial_currency_code:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @iso_currency_code = iso_currency_code
  @unofficial_currency_code = unofficial_currency_code
  @additional_properties = additional_properties
end

Instance Attribute Details

#iso_currency_codeString

Plaid supports all ISO 4217 currency codes.

Returns:

  • (String)


14
15
16
# File 'lib/the_plaid_api/models/standalone_currency_code_list.rb', line 14

def iso_currency_code
  @iso_currency_code
end

#unofficial_currency_codeUnofficialCurrencyCodeList

List of unofficial currency codes



18
19
20
# File 'lib/the_plaid_api/models/standalone_currency_code_list.rb', line 18

def unofficial_currency_code
  @unofficial_currency_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/the_plaid_api/models/standalone_currency_code_list.rb', line 49

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  iso_currency_code =
    hash.key?('iso_currency_code') ? hash['iso_currency_code'] : nil
  if hash['unofficial_currency_code']
    unofficial_currency_code = UnofficialCurrencyCodeList.from_hash(hash['unofficial_currency_code'])
  end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  StandaloneCurrencyCodeList.new(iso_currency_code: iso_currency_code,
                                 unofficial_currency_code: unofficial_currency_code,
                                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/the_plaid_api/models/standalone_currency_code_list.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['iso_currency_code'] = 'iso_currency_code'
  @_hash['unofficial_currency_code'] = 'unofficial_currency_code'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/the_plaid_api/models/standalone_currency_code_list.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/the_plaid_api/models/standalone_currency_code_list.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/the_plaid_api/models/standalone_currency_code_list.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} iso_currency_code: #{@iso_currency_code.inspect}, unofficial_currency_code:"\
  " #{@unofficial_currency_code.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/the_plaid_api/models/standalone_currency_code_list.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} iso_currency_code: #{@iso_currency_code}, unofficial_currency_code:"\
  " #{@unofficial_currency_code}, additional_properties: #{@additional_properties}>"
end