Class: ThePlaidApi::StatementsDownloadRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/statements_download_request.rb

Overview

StatementsDownloadRequest defines the request schema for ‘/statements/download`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(access_token:, statement_id:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ StatementsDownloadRequest

Returns a new instance of StatementsDownloadRequest.



55
56
57
58
59
60
61
62
63
64
65
# File 'lib/the_plaid_api/models/statements_download_request.rb', line 55

def initialize(access_token:, statement_id:, client_id: SKIP, secret: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @access_token = access_token
  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @statement_id = statement_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#access_tokenString

The access token associated with the Item data is being requested for.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/statements_download_request.rb', line 15

def access_token
  @access_token
end

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/statements_download_request.rb', line 21

def client_id
  @client_id
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


26
27
28
# File 'lib/the_plaid_api/models/statements_download_request.rb', line 26

def secret
  @secret
end

#statement_idString

Plaid’s unique identifier for the statement.

Returns:

  • (String)


30
31
32
# File 'lib/the_plaid_api/models/statements_download_request.rb', line 30

def statement_id
  @statement_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/the_plaid_api/models/statements_download_request.rb', line 68

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  access_token = hash.key?('access_token') ? hash['access_token'] : nil
  statement_id = hash.key?('statement_id') ? hash['statement_id'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  StatementsDownloadRequest.new(access_token: access_token,
                                statement_id: statement_id,
                                client_id: client_id,
                                secret: secret,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
# File 'lib/the_plaid_api/models/statements_download_request.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['access_token'] = 'access_token'
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['statement_id'] = 'statement_id'
  @_hash
end

.nullablesObject

An array for nullable fields



51
52
53
# File 'lib/the_plaid_api/models/statements_download_request.rb', line 51

def self.nullables
  []
end

.optionalsObject

An array for optional fields



43
44
45
46
47
48
# File 'lib/the_plaid_api/models/statements_download_request.rb', line 43

def self.optionals
  %w[
    client_id
    secret
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



101
102
103
104
105
106
# File 'lib/the_plaid_api/models/statements_download_request.rb', line 101

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} access_token: #{@access_token.inspect}, client_id: #{@client_id.inspect},"\
  " secret: #{@secret.inspect}, statement_id: #{@statement_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



93
94
95
96
97
98
# File 'lib/the_plaid_api/models/statements_download_request.rb', line 93

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} access_token: #{@access_token}, client_id: #{@client_id}, secret:"\
  " #{@secret}, statement_id: #{@statement_id}, additional_properties:"\
  " #{@additional_properties}>"
end