Class: ThePlaidApi::StatementsRefreshCompleteWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/statements_refresh_complete_webhook.rb

Overview

Fired when refreshed statements extraction is completed or failed to be completed. Triggered by calling ‘/statements/refresh`.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, item_id:, result:, environment:, additional_properties: nil) ⇒ StatementsRefreshCompleteWebhook

Returns a new instance of StatementsRefreshCompleteWebhook.



60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/the_plaid_api/models/statements_refresh_complete_webhook.rb', line 60

def initialize(webhook_type:, webhook_code:, item_id:, result:,
               environment:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @item_id = item_id
  @result = result
  @environment = environment
  @additional_properties = additional_properties
end

Instance Attribute Details

#environmentWebhookEnvironmentValues

The Plaid environment the webhook was sent from



37
38
39
# File 'lib/the_plaid_api/models/statements_refresh_complete_webhook.rb', line 37

def environment
  @environment
end

#item_idString

The Plaid Item ID. The ‘item_id` is always unique; linking the same account at the same institution twice will result in two Items with different `item_id` values. Like all Plaid identifiers, the `item_id` is case-sensitive.

Returns:

  • (String)


26
27
28
# File 'lib/the_plaid_api/models/statements_refresh_complete_webhook.rb', line 26

def item_id
  @item_id
end

#resultStatementsRefreshCompleteResult

The result of the statement refresh extraction ‘SUCCESS`: The statements were successfully extracted and can be listed via `/statements/list/` and downloaded via `/statements/download/`. `FAILURE`: The statements failed to be extracted.



33
34
35
# File 'lib/the_plaid_api/models/statements_refresh_complete_webhook.rb', line 33

def result
  @result
end

#webhook_codeString

‘STATEMENTS_REFRESH_COMPLETE`

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/statements_refresh_complete_webhook.rb', line 19

def webhook_code
  @webhook_code
end

#webhook_typeString

‘STATEMENTS`

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/statements_refresh_complete_webhook.rb', line 15

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/the_plaid_api/models/statements_refresh_complete_webhook.rb', line 74

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  item_id = hash.key?('item_id') ? hash['item_id'] : nil
  result = hash.key?('result') ? hash['result'] : nil
  environment = hash.key?('environment') ? hash['environment'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  StatementsRefreshCompleteWebhook.new(webhook_type: webhook_type,
                                       webhook_code: webhook_code,
                                       item_id: item_id,
                                       result: result,
                                       environment: environment,
                                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



40
41
42
43
44
45
46
47
48
# File 'lib/the_plaid_api/models/statements_refresh_complete_webhook.rb', line 40

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['item_id'] = 'item_id'
  @_hash['result'] = 'result'
  @_hash['environment'] = 'environment'
  @_hash
end

.nullablesObject

An array for nullable fields



56
57
58
# File 'lib/the_plaid_api/models/statements_refresh_complete_webhook.rb', line 56

def self.nullables
  []
end

.optionalsObject

An array for optional fields



51
52
53
# File 'lib/the_plaid_api/models/statements_refresh_complete_webhook.rb', line 51

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



109
110
111
112
113
114
# File 'lib/the_plaid_api/models/statements_refresh_complete_webhook.rb', line 109

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, item_id: #{@item_id.inspect}, result: #{@result.inspect},"\
  " environment: #{@environment.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



101
102
103
104
105
106
# File 'lib/the_plaid_api/models/statements_refresh_complete_webhook.rb', line 101

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, item_id:"\
  " #{@item_id}, result: #{@result}, environment: #{@environment}, additional_properties:"\
  " #{@additional_properties}>"
end