Class: ThePlaidApi::Status

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/status.rb

Overview

Documentation not found in the MISMO model viewer and not provided by Freddie Mac.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(status_code:, status_description:, additional_properties: nil) ⇒ Status

Returns a new instance of Status.



42
43
44
45
46
47
48
49
50
# File 'lib/the_plaid_api/models/status.rb', line 42

def initialize(status_code:, status_description:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @status_code = status_code
  @status_description = status_description
  @additional_properties = additional_properties
end

Instance Attribute Details

#status_codeString

Satus Code.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/status.rb', line 15

def status_code
  @status_code
end

#status_descriptionString

Status Description.

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/status.rb', line 19

def status_description
  @status_description
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/the_plaid_api/models/status.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  status_code = hash.key?('StatusCode') ? hash['StatusCode'] : nil
  status_description =
    hash.key?('StatusDescription') ? hash['StatusDescription'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Status.new(status_code: status_code,
             status_description: status_description,
             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/the_plaid_api/models/status.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['status_code'] = 'StatusCode'
  @_hash['status_description'] = 'StatusDescription'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
38
39
40
# File 'lib/the_plaid_api/models/status.rb', line 35

def self.nullables
  %w[
    status_code
    status_description
  ]
end

.optionalsObject

An array for optional fields



30
31
32
# File 'lib/the_plaid_api/models/status.rb', line 30

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



82
83
84
85
86
# File 'lib/the_plaid_api/models/status.rb', line 82

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} status_code: #{@status_code.inspect}, status_description:"\
  " #{@status_description.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



75
76
77
78
79
# File 'lib/the_plaid_api/models/status.rb', line 75

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} status_code: #{@status_code}, status_description: #{@status_description},"\
  " additional_properties: #{@additional_properties}>"
end