Class: ThePlaidApi::StudentLoanRepaymentModel

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/student_loan_repayment_model.rb

Overview

Student loan repayment information used to configure Sandbox test data for the Liabilities product

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(type:, non_repayment_months:, repayment_months:, additional_properties: nil) ⇒ StudentLoanRepaymentModel

Returns a new instance of StudentLoanRepaymentModel.



44
45
46
47
48
49
50
51
52
53
# File 'lib/the_plaid_api/models/student_loan_repayment_model.rb', line 44

def initialize(type:, non_repayment_months:, repayment_months:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @type = type
  @non_repayment_months = non_repayment_months
  @repayment_months = repayment_months
  @additional_properties = additional_properties
end

Instance Attribute Details

#non_repayment_monthsFloat

Configures the number of months before repayment starts.

Returns:

  • (Float)


19
20
21
# File 'lib/the_plaid_api/models/student_loan_repayment_model.rb', line 19

def non_repayment_months
  @non_repayment_months
end

#repayment_monthsFloat

Configures the number of months of repayments before the loan is paid off.

Returns:

  • (Float)


23
24
25
# File 'lib/the_plaid_api/models/student_loan_repayment_model.rb', line 23

def repayment_months
  @repayment_months
end

#typeString

The only currently supported value for this field is ‘standard`.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/student_loan_repayment_model.rb', line 15

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/the_plaid_api/models/student_loan_repayment_model.rb', line 56

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  type = hash.key?('type') ? hash['type'] : nil
  non_repayment_months =
    hash.key?('non_repayment_months') ? hash['non_repayment_months'] : nil
  repayment_months =
    hash.key?('repayment_months') ? hash['repayment_months'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  StudentLoanRepaymentModel.new(type: type,
                                non_repayment_months: non_repayment_months,
                                repayment_months: repayment_months,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/the_plaid_api/models/student_loan_repayment_model.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['type'] = 'type'
  @_hash['non_repayment_months'] = 'non_repayment_months'
  @_hash['repayment_months'] = 'repayment_months'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/the_plaid_api/models/student_loan_repayment_model.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
# File 'lib/the_plaid_api/models/student_loan_repayment_model.rb', line 35

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



88
89
90
91
92
93
# File 'lib/the_plaid_api/models/student_loan_repayment_model.rb', line 88

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type.inspect}, non_repayment_months:"\
  " #{@non_repayment_months.inspect}, repayment_months: #{@repayment_months.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



81
82
83
84
85
# File 'lib/the_plaid_api/models/student_loan_repayment_model.rb', line 81

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type}, non_repayment_months: #{@non_repayment_months},"\
  " repayment_months: #{@repayment_months}, additional_properties: #{@additional_properties}>"
end