Class: ThePlaidApi::StudentLoanStatus

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/student_loan_status.rb

Overview

An object representing the status of the student loan

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(end_date:, type:, additional_properties: nil) ⇒ StudentLoanStatus

Returns a new instance of StudentLoanStatus.



43
44
45
46
47
48
49
50
# File 'lib/the_plaid_api/models/student_loan_status.rb', line 43

def initialize(end_date:, type:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @end_date = end_date
  @type = type
  @additional_properties = additional_properties
end

Instance Attribute Details

#end_dateDate

The date until which the loan will be in its current status. Dates are returned in an [ISO 8601](wikipedia.org/wiki/ISO_8601) format (YYYY-MM-DD).

Returns:

  • (Date)


16
17
18
# File 'lib/the_plaid_api/models/student_loan_status.rb', line 16

def end_date
  @end_date
end

#typeType2

The status type of the student loan

Returns:



20
21
22
# File 'lib/the_plaid_api/models/student_loan_status.rb', line 20

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/the_plaid_api/models/student_loan_status.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  end_date = hash.key?('end_date') ? hash['end_date'] : nil
  type = hash.key?('type') ? hash['type'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  StudentLoanStatus.new(end_date: end_date,
                        type: type,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/the_plaid_api/models/student_loan_status.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['end_date'] = 'end_date'
  @_hash['type'] = 'type'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
39
40
41
# File 'lib/the_plaid_api/models/student_loan_status.rb', line 36

def self.nullables
  %w[
    end_date
    type
  ]
end

.optionalsObject

An array for optional fields



31
32
33
# File 'lib/the_plaid_api/models/student_loan_status.rb', line 31

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



81
82
83
84
85
# File 'lib/the_plaid_api/models/student_loan_status.rb', line 81

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} end_date: #{@end_date.inspect}, type: #{@type.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



74
75
76
77
78
# File 'lib/the_plaid_api/models/student_loan_status.rb', line 74

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} end_date: #{@end_date}, type: #{@type}, additional_properties:"\
  " #{@additional_properties}>"
end