Class: ThePlaidApi::StudentRepaymentPlan

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/student_repayment_plan.rb

Overview

An object representing the repayment plan for the student loan

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(description:, type:, additional_properties: nil) ⇒ StudentRepaymentPlan

Returns a new instance of StudentRepaymentPlan.



41
42
43
44
45
46
47
48
# File 'lib/the_plaid_api/models/student_repayment_plan.rb', line 41

def initialize(description:, type:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @description = description
  @type = type
  @additional_properties = additional_properties
end

Instance Attribute Details

#descriptionString

The description of the repayment plan as provided by the servicer.

Returns:

  • (String)


14
15
16
# File 'lib/the_plaid_api/models/student_repayment_plan.rb', line 14

def description
  @description
end

#typeType3

The type of the repayment plan.

Returns:



18
19
20
# File 'lib/the_plaid_api/models/student_repayment_plan.rb', line 18

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/the_plaid_api/models/student_repayment_plan.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  description = hash.key?('description') ? hash['description'] : nil
  type = hash.key?('type') ? hash['type'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  StudentRepaymentPlan.new(description: description,
                           type: type,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/the_plaid_api/models/student_repayment_plan.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['description'] = 'description'
  @_hash['type'] = 'type'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
37
38
39
# File 'lib/the_plaid_api/models/student_repayment_plan.rb', line 34

def self.nullables
  %w[
    description
    type
  ]
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/the_plaid_api/models/student_repayment_plan.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/the_plaid_api/models/student_repayment_plan.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} description: #{@description.inspect}, type: #{@type.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/the_plaid_api/models/student_repayment_plan.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} description: #{@description}, type: #{@type}, additional_properties:"\
  " #{@additional_properties}>"
end