Class: ThePlaidApi::TaxpayerIdentifiers

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/taxpayer_identifiers.rb

Overview

The collection of ‘TAXPAYER_IDENTIFICATION` elements

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(taxpayer_identifier:, additional_properties: nil) ⇒ TaxpayerIdentifiers

Returns a new instance of TaxpayerIdentifiers.



34
35
36
37
38
39
40
# File 'lib/the_plaid_api/models/taxpayer_identifiers.rb', line 34

def initialize(taxpayer_identifier:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @taxpayer_identifier = taxpayer_identifier
  @additional_properties = additional_properties
end

Instance Attribute Details

#taxpayer_identifierTaxpayerIdentifier

Information about the Taxpayer identification values assigned to the individual or legal entity.

Returns:



15
16
17
# File 'lib/the_plaid_api/models/taxpayer_identifiers.rb', line 15

def taxpayer_identifier
  @taxpayer_identifier
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/the_plaid_api/models/taxpayer_identifiers.rb', line 43

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  taxpayer_identifier = TaxpayerIdentifier.from_hash(hash['TAXPAYER_IDENTIFIER']) if
    hash['TAXPAYER_IDENTIFIER']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TaxpayerIdentifiers.new(taxpayer_identifier: taxpayer_identifier,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/the_plaid_api/models/taxpayer_identifiers.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['taxpayer_identifier'] = 'TAXPAYER_IDENTIFIER'
  @_hash
end

.nullablesObject

An array for nullable fields



30
31
32
# File 'lib/the_plaid_api/models/taxpayer_identifiers.rb', line 30

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
# File 'lib/the_plaid_api/models/taxpayer_identifiers.rb', line 25

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



70
71
72
73
74
# File 'lib/the_plaid_api/models/taxpayer_identifiers.rb', line 70

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} taxpayer_identifier: #{@taxpayer_identifier.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



63
64
65
66
67
# File 'lib/the_plaid_api/models/taxpayer_identifiers.rb', line 63

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} taxpayer_identifier: #{@taxpayer_identifier}, additional_properties:"\
  " #{@additional_properties}>"
end