Class: ThePlaidApi::TotalReportInflowAmount90D
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TotalReportInflowAmount90D
- Defined in:
- lib/the_plaid_api/models/total_report_inflow_amount90_d.rb
Overview
Total amount of debit transactions into the report’s account in the last 90 days. This field only takes into account USD transactions from the accounts.
Instance Attribute Summary collapse
-
#amount ⇒ Float
Value of amount with up to 2 decimal places.
-
#iso_currency_code ⇒ String
The ISO 4217 currency code of the amount or balance.
-
#unofficial_currency_code ⇒ String
The unofficial currency code associated with the amount or balance.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(amount:, iso_currency_code:, unofficial_currency_code:, additional_properties: nil) ⇒ TotalReportInflowAmount90D
constructor
A new instance of TotalReportInflowAmount90D.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(amount:, iso_currency_code:, unofficial_currency_code:, additional_properties: nil) ⇒ TotalReportInflowAmount90D
Returns a new instance of TotalReportInflowAmount90D.
51 52 53 54 55 56 57 58 59 60 |
# File 'lib/the_plaid_api/models/total_report_inflow_amount90_d.rb', line 51 def initialize(amount:, iso_currency_code:, unofficial_currency_code:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @amount = amount @iso_currency_code = iso_currency_code @unofficial_currency_code = unofficial_currency_code @additional_properties = additional_properties end |
Instance Attribute Details
#amount ⇒ Float
Value of amount with up to 2 decimal places.
15 16 17 |
# File 'lib/the_plaid_api/models/total_report_inflow_amount90_d.rb', line 15 def amount @amount end |
#iso_currency_code ⇒ String
The ISO 4217 currency code of the amount or balance.
19 20 21 |
# File 'lib/the_plaid_api/models/total_report_inflow_amount90_d.rb', line 19 def iso_currency_code @iso_currency_code end |
#unofficial_currency_code ⇒ String
The unofficial currency code associated with the amount or balance. Always ‘null` if `iso_currency_code` is non-null. Unofficial currency codes are used for currencies that do not have official ISO currency codes, such as cryptocurrencies and the currencies of certain countries.
27 28 29 |
# File 'lib/the_plaid_api/models/total_report_inflow_amount90_d.rb', line 27 def unofficial_currency_code @unofficial_currency_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/the_plaid_api/models/total_report_inflow_amount90_d.rb', line 63 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. amount = hash.key?('amount') ? hash['amount'] : nil iso_currency_code = hash.key?('iso_currency_code') ? hash['iso_currency_code'] : nil unofficial_currency_code = hash.key?('unofficial_currency_code') ? hash['unofficial_currency_code'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TotalReportInflowAmount90D.new(amount: amount, iso_currency_code: iso_currency_code, unofficial_currency_code: unofficial_currency_code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
30 31 32 33 34 35 36 |
# File 'lib/the_plaid_api/models/total_report_inflow_amount90_d.rb', line 30 def self.names @_hash = {} if @_hash.nil? @_hash['amount'] = 'amount' @_hash['iso_currency_code'] = 'iso_currency_code' @_hash['unofficial_currency_code'] = 'unofficial_currency_code' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 47 48 49 |
# File 'lib/the_plaid_api/models/total_report_inflow_amount90_d.rb', line 44 def self.nullables %w[ iso_currency_code unofficial_currency_code ] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/the_plaid_api/models/total_report_inflow_amount90_d.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
96 97 98 99 100 101 |
# File 'lib/the_plaid_api/models/total_report_inflow_amount90_d.rb', line 96 def inspect class_name = self.class.name.split('::').last "<#{class_name} amount: #{@amount.inspect}, iso_currency_code:"\ " #{@iso_currency_code.inspect}, unofficial_currency_code:"\ " #{@unofficial_currency_code.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
88 89 90 91 92 93 |
# File 'lib/the_plaid_api/models/total_report_inflow_amount90_d.rb', line 88 def to_s class_name = self.class.name.split('::').last "<#{class_name} amount: #{@amount}, iso_currency_code: #{@iso_currency_code},"\ " unofficial_currency_code: #{@unofficial_currency_code}, additional_properties:"\ " #{@additional_properties}>" end |