Class: ThePlaidApi::TransactionStreamAmount
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TransactionStreamAmount
- Defined in:
- lib/the_plaid_api/models/transaction_stream_amount.rb
Overview
Object with data pertaining to an amount on the transaction stream.
Instance Attribute Summary collapse
-
#amount ⇒ Float
Represents the numerical value of an amount.
-
#iso_currency_code ⇒ String
The ISO-4217 currency code of the amount.
-
#unofficial_currency_code ⇒ String
The unofficial currency code of the amount.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(amount: SKIP, iso_currency_code: SKIP, unofficial_currency_code: SKIP, additional_properties: nil) ⇒ TransactionStreamAmount
constructor
A new instance of TransactionStreamAmount.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(amount: SKIP, iso_currency_code: SKIP, unofficial_currency_code: SKIP, additional_properties: nil) ⇒ TransactionStreamAmount
Returns a new instance of TransactionStreamAmount.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/the_plaid_api/models/transaction_stream_amount.rb', line 57 def initialize(amount: SKIP, iso_currency_code: SKIP, unofficial_currency_code: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @amount = amount unless amount == SKIP @iso_currency_code = iso_currency_code unless iso_currency_code == SKIP @unofficial_currency_code = unofficial_currency_code unless unofficial_currency_code == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#amount ⇒ Float
Represents the numerical value of an amount.
14 15 16 |
# File 'lib/the_plaid_api/models/transaction_stream_amount.rb', line 14 def amount @amount end |
#iso_currency_code ⇒ String
The ISO-4217 currency code of the amount. Always ‘null` if `unofficial_currency_code` is non-`null`. See the [currency code schema](plaid.com/docs/api/accounts#currency-code-schema) for a full listing of supported `iso_currency_code`s.
22 23 24 |
# File 'lib/the_plaid_api/models/transaction_stream_amount.rb', line 22 def iso_currency_code @iso_currency_code end |
#unofficial_currency_code ⇒ String
The unofficial currency code of the amount. Always ‘null` if `iso_currency_code` is non-`null`. Unofficial currency codes are used for currencies that do not have official ISO currency codes, such as cryptocurrencies and the currencies of certain countries.
29 30 31 |
# File 'lib/the_plaid_api/models/transaction_stream_amount.rb', line 29 def unofficial_currency_code @unofficial_currency_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/the_plaid_api/models/transaction_stream_amount.rb', line 69 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. amount = hash.key?('amount') ? hash['amount'] : SKIP iso_currency_code = hash.key?('iso_currency_code') ? hash['iso_currency_code'] : SKIP unofficial_currency_code = hash.key?('unofficial_currency_code') ? hash['unofficial_currency_code'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransactionStreamAmount.new(amount: amount, iso_currency_code: iso_currency_code, unofficial_currency_code: unofficial_currency_code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
32 33 34 35 36 37 38 |
# File 'lib/the_plaid_api/models/transaction_stream_amount.rb', line 32 def self.names @_hash = {} if @_hash.nil? @_hash['amount'] = 'amount' @_hash['iso_currency_code'] = 'iso_currency_code' @_hash['unofficial_currency_code'] = 'unofficial_currency_code' @_hash end |
.nullables ⇒ Object
An array for nullable fields
50 51 52 53 54 55 |
# File 'lib/the_plaid_api/models/transaction_stream_amount.rb', line 50 def self.nullables %w[ iso_currency_code unofficial_currency_code ] end |
.optionals ⇒ Object
An array for optional fields
41 42 43 44 45 46 47 |
# File 'lib/the_plaid_api/models/transaction_stream_amount.rb', line 41 def self.optionals %w[ amount iso_currency_code unofficial_currency_code ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
102 103 104 105 106 107 |
# File 'lib/the_plaid_api/models/transaction_stream_amount.rb', line 102 def inspect class_name = self.class.name.split('::').last "<#{class_name} amount: #{@amount.inspect}, iso_currency_code:"\ " #{@iso_currency_code.inspect}, unofficial_currency_code:"\ " #{@unofficial_currency_code.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
94 95 96 97 98 99 |
# File 'lib/the_plaid_api/models/transaction_stream_amount.rb', line 94 def to_s class_name = self.class.name.split('::').last "<#{class_name} amount: #{@amount}, iso_currency_code: #{@iso_currency_code},"\ " unofficial_currency_code: #{@unofficial_currency_code}, additional_properties:"\ " #{@additional_properties}>" end |