Class: ThePlaidApi::TransactionsEnhanceGetRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/transactions_enhance_get_request.rb

Overview

TransactionsEnhanceGetRequest defines the request schema for ‘/transactions/enhance`.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_type:, transactions:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ TransactionsEnhanceGetRequest

Returns a new instance of TransactionsEnhanceGetRequest.



56
57
58
59
60
61
62
63
64
65
66
# File 'lib/the_plaid_api/models/transactions_enhance_get_request.rb', line 56

def initialize(account_type:, transactions:, client_id: SKIP, secret: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @account_type = 
  @transactions = transactions
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_typeString

The type of account for the requested transactions (‘depository` or `credit`).

Returns:

  • (String)


27
28
29
# File 'lib/the_plaid_api/models/transactions_enhance_get_request.rb', line 27

def 
  @account_type
end

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/transactions_enhance_get_request.rb', line 17

def client_id
  @client_id
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/transactions_enhance_get_request.rb', line 22

def secret
  @secret
end

#transactionsArray[ClientProvidedRawTransaction]

An array of raw transactions to be enhanced.

Returns:



31
32
33
# File 'lib/the_plaid_api/models/transactions_enhance_get_request.rb', line 31

def transactions
  @transactions
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/the_plaid_api/models/transactions_enhance_get_request.rb', line 69

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('account_type') ? hash['account_type'] : nil
  # Parameter is an array, so we need to iterate through it
  transactions = nil
  unless hash['transactions'].nil?
    transactions = []
    hash['transactions'].each do |structure|
      transactions << (ClientProvidedRawTransaction.from_hash(structure) if structure)
    end
  end

  transactions = nil unless hash.key?('transactions')
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransactionsEnhanceGetRequest.new(account_type: ,
                                    transactions: transactions,
                                    client_id: client_id,
                                    secret: secret,
                                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



34
35
36
37
38
39
40
41
# File 'lib/the_plaid_api/models/transactions_enhance_get_request.rb', line 34

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['account_type'] = 'account_type'
  @_hash['transactions'] = 'transactions'
  @_hash
end

.nullablesObject

An array for nullable fields



52
53
54
# File 'lib/the_plaid_api/models/transactions_enhance_get_request.rb', line 52

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
47
48
49
# File 'lib/the_plaid_api/models/transactions_enhance_get_request.rb', line 44

def self.optionals
  %w[
    client_id
    secret
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



111
112
113
114
115
116
# File 'lib/the_plaid_api/models/transactions_enhance_get_request.rb', line 111

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, account_type:"\
  " #{@account_type.inspect}, transactions: #{@transactions.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



103
104
105
106
107
108
# File 'lib/the_plaid_api/models/transactions_enhance_get_request.rb', line 103

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, account_type:"\
  " #{@account_type}, transactions: #{@transactions}, additional_properties:"\
  " #{@additional_properties}>"
end