Class: ThePlaidApi::TransactionsEnrichResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/transactions_enrich_response.rb

Overview

TransactionsEnrichResponse defines the response schema for ‘/transactions/enrich`.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(enriched_transactions:, request_id: SKIP, additional_properties: nil) ⇒ TransactionsEnrichResponse

Returns a new instance of TransactionsEnrichResponse.



43
44
45
46
47
48
49
50
51
# File 'lib/the_plaid_api/models/transactions_enrich_response.rb', line 43

def initialize(enriched_transactions:, request_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @enriched_transactions = enriched_transactions
  @request_id = request_id unless request_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#enriched_transactionsArray[ClientProvidedEnrichedTransaction]

A list of enriched transactions.



15
16
17
# File 'lib/the_plaid_api/models/transactions_enrich_response.rb', line 15

def enriched_transactions
  @enriched_transactions
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/transactions_enrich_response.rb', line 21

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/the_plaid_api/models/transactions_enrich_response.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  enriched_transactions = nil
  unless hash['enriched_transactions'].nil?
    enriched_transactions = []
    hash['enriched_transactions'].each do |structure|
      enriched_transactions << (ClientProvidedEnrichedTransaction.from_hash(structure) if structure)
    end
  end

  enriched_transactions = nil unless hash.key?('enriched_transactions')
  request_id = hash.key?('request_id') ? hash['request_id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransactionsEnrichResponse.new(enriched_transactions: enriched_transactions,
                                 request_id: request_id,
                                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
29
# File 'lib/the_plaid_api/models/transactions_enrich_response.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['enriched_transactions'] = 'enriched_transactions'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/the_plaid_api/models/transactions_enrich_response.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



32
33
34
35
36
# File 'lib/the_plaid_api/models/transactions_enrich_response.rb', line 32

def self.optionals
  %w[
    request_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



91
92
93
94
95
# File 'lib/the_plaid_api/models/transactions_enrich_response.rb', line 91

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} enriched_transactions: #{@enriched_transactions.inspect}, request_id:"\
  " #{@request_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
# File 'lib/the_plaid_api/models/transactions_enrich_response.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} enriched_transactions: #{@enriched_transactions}, request_id:"\
  " #{@request_id}, additional_properties: #{@additional_properties}>"
end