Class: ThePlaidApi::TransactionsGetRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TransactionsGetRequest
- Defined in:
- lib/the_plaid_api/models/transactions_get_request.rb
Overview
TransactionsGetRequest defines the request schema for ‘/transactions/get`
Instance Attribute Summary collapse
-
#access_token ⇒ String
The access token associated with the Item data is being requested for.
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#end_date ⇒ Date
The latest date for which data should be returned.
-
#options ⇒ TransactionsGetRequestOptions
An optional object to be used with the request.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#start_date ⇒ Date
The earliest date for which data should be returned.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(access_token:, start_date:, end_date:, client_id: SKIP, options: SKIP, secret: SKIP, additional_properties: nil) ⇒ TransactionsGetRequest
constructor
A new instance of TransactionsGetRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(access_token:, start_date:, end_date:, client_id: SKIP, options: SKIP, secret: SKIP, additional_properties: nil) ⇒ TransactionsGetRequest
Returns a new instance of TransactionsGetRequest.
68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/the_plaid_api/models/transactions_get_request.rb', line 68 def initialize(access_token:, start_date:, end_date:, client_id: SKIP, options: SKIP, secret: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @options = unless == SKIP @access_token = access_token @secret = secret unless secret == SKIP @start_date = start_date @end_date = end_date @additional_properties = additional_properties end |
Instance Attribute Details
#access_token ⇒ String
The access token associated with the Item data is being requested for.
25 26 27 |
# File 'lib/the_plaid_api/models/transactions_get_request.rb', line 25 def access_token @access_token end |
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/the_plaid_api/models/transactions_get_request.rb', line 16 def client_id @client_id end |
#end_date ⇒ Date
The latest date for which data should be returned. Dates should be formatted as YYYY-MM-DD.
40 41 42 |
# File 'lib/the_plaid_api/models/transactions_get_request.rb', line 40 def end_date @end_date end |
#options ⇒ TransactionsGetRequestOptions
An optional object to be used with the request. If specified, ‘options` must not be `null`.
21 22 23 |
# File 'lib/the_plaid_api/models/transactions_get_request.rb', line 21 def @options end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
30 31 32 |
# File 'lib/the_plaid_api/models/transactions_get_request.rb', line 30 def secret @secret end |
#start_date ⇒ Date
The earliest date for which data should be returned. Dates should be formatted as YYYY-MM-DD.
35 36 37 |
# File 'lib/the_plaid_api/models/transactions_get_request.rb', line 35 def start_date @start_date end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/the_plaid_api/models/transactions_get_request.rb', line 83 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. access_token = hash.key?('access_token') ? hash['access_token'] : nil start_date = hash.key?('start_date') ? hash['start_date'] : nil end_date = hash.key?('end_date') ? hash['end_date'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP = TransactionsGetRequestOptions.from_hash(hash['options']) if hash['options'] secret = hash.key?('secret') ? hash['secret'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransactionsGetRequest.new(access_token: access_token, start_date: start_date, end_date: end_date, client_id: client_id, options: , secret: secret, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/the_plaid_api/models/transactions_get_request.rb', line 43 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['options'] = 'options' @_hash['access_token'] = 'access_token' @_hash['secret'] = 'secret' @_hash['start_date'] = 'start_date' @_hash['end_date'] = 'end_date' @_hash end |
.nullables ⇒ Object
An array for nullable fields
64 65 66 |
# File 'lib/the_plaid_api/models/transactions_get_request.rb', line 64 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
55 56 57 58 59 60 61 |
# File 'lib/the_plaid_api/models/transactions_get_request.rb', line 55 def self.optionals %w[ client_id options secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
120 121 122 123 124 125 126 |
# File 'lib/the_plaid_api/models/transactions_get_request.rb', line 120 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, options: #{@options.inspect},"\ " access_token: #{@access_token.inspect}, secret: #{@secret.inspect}, start_date:"\ " #{@start_date.inspect}, end_date: #{@end_date.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
112 113 114 115 116 117 |
# File 'lib/the_plaid_api/models/transactions_get_request.rb', line 112 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, options: #{@options}, access_token:"\ " #{@access_token}, secret: #{@secret}, start_date: #{@start_date}, end_date: #{@end_date},"\ " additional_properties: #{@additional_properties}>" end |