Class: ThePlaidApi::TransactionsRecurringCreateInput
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TransactionsRecurringCreateInput
- Defined in:
- lib/the_plaid_api/models/transactions_recurring_create_input.rb
Overview
TransactionsRecurringCreateInput defines a single input to the ‘/transactions/recurring/streams/create` endpoint.
Instance Attribute Summary collapse
-
#transaction_ids ⇒ Array[String]
IDs of all the transactions that will be merged into one stream.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(transaction_ids: SKIP, additional_properties: nil) ⇒ TransactionsRecurringCreateInput
constructor
A new instance of TransactionsRecurringCreateInput.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(transaction_ids: SKIP, additional_properties: nil) ⇒ TransactionsRecurringCreateInput
Returns a new instance of TransactionsRecurringCreateInput.
38 39 40 41 42 43 44 |
# File 'lib/the_plaid_api/models/transactions_recurring_create_input.rb', line 38 def initialize(transaction_ids: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @transaction_ids = transaction_ids unless transaction_ids == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#transaction_ids ⇒ Array[String]
IDs of all the transactions that will be merged into one stream. If any transaction currently exists in another stream, it will be removed from the other stream.
17 18 19 |
# File 'lib/the_plaid_api/models/transactions_recurring_create_input.rb', line 17 def transaction_ids @transaction_ids end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/the_plaid_api/models/transactions_recurring_create_input.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. transaction_ids = hash.key?('transaction_ids') ? hash['transaction_ids'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransactionsRecurringCreateInput.new(transaction_ids: transaction_ids, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
20 21 22 23 24 |
# File 'lib/the_plaid_api/models/transactions_recurring_create_input.rb', line 20 def self.names @_hash = {} if @_hash.nil? @_hash['transaction_ids'] = 'transaction_ids' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/the_plaid_api/models/transactions_recurring_create_input.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
27 28 29 30 31 |
# File 'lib/the_plaid_api/models/transactions_recurring_create_input.rb', line 27 def self.optionals %w[ transaction_ids ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
74 75 76 77 78 |
# File 'lib/the_plaid_api/models/transactions_recurring_create_input.rb', line 74 def inspect class_name = self.class.name.split('::').last "<#{class_name} transaction_ids: #{@transaction_ids.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 71 |
# File 'lib/the_plaid_api/models/transactions_recurring_create_input.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} transaction_ids: #{@transaction_ids}, additional_properties:"\ " #{@additional_properties}>" end |