Class: ThePlaidApi::TransactionsRecurringCreateRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TransactionsRecurringCreateRequest
- Defined in:
- lib/the_plaid_api/models/transactions_recurring_create_request.rb
Overview
TransactionsRecurringCreateRequest defined the request schema for ‘/transactions/recurring/streams/create` endpoint.
Instance Attribute Summary collapse
-
#access_token ⇒ String
The access token associated with the Item data is being requested for.
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#inputs ⇒ Array[TransactionsRecurringCreateInput]
A list of all the operations to be performed.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(access_token:, inputs:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ TransactionsRecurringCreateRequest
constructor
A new instance of TransactionsRecurringCreateRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(access_token:, inputs:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ TransactionsRecurringCreateRequest
Returns a new instance of TransactionsRecurringCreateRequest.
56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/the_plaid_api/models/transactions_recurring_create_request.rb', line 56 def initialize(access_token:, inputs:, client_id: SKIP, secret: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @access_token = access_token @secret = secret unless secret == SKIP @inputs = inputs @additional_properties = additional_properties end |
Instance Attribute Details
#access_token ⇒ String
The access token associated with the Item data is being requested for.
21 22 23 |
# File 'lib/the_plaid_api/models/transactions_recurring_create_request.rb', line 21 def access_token @access_token end |
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/transactions_recurring_create_request.rb', line 17 def client_id @client_id end |
#inputs ⇒ Array[TransactionsRecurringCreateInput]
A list of all the operations to be performed. This will either all succeed or all fail.
31 32 33 |
# File 'lib/the_plaid_api/models/transactions_recurring_create_request.rb', line 31 def inputs @inputs end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
26 27 28 |
# File 'lib/the_plaid_api/models/transactions_recurring_create_request.rb', line 26 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/the_plaid_api/models/transactions_recurring_create_request.rb', line 69 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. access_token = hash.key?('access_token') ? hash['access_token'] : nil # Parameter is an array, so we need to iterate through it inputs = nil unless hash['inputs'].nil? inputs = [] hash['inputs'].each do |structure| inputs << (TransactionsRecurringCreateInput.from_hash(structure) if structure) end end inputs = nil unless hash.key?('inputs') client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransactionsRecurringCreateRequest.new(access_token: access_token, inputs: inputs, client_id: client_id, secret: secret, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
34 35 36 37 38 39 40 41 |
# File 'lib/the_plaid_api/models/transactions_recurring_create_request.rb', line 34 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['access_token'] = 'access_token' @_hash['secret'] = 'secret' @_hash['inputs'] = 'inputs' @_hash end |
.nullables ⇒ Object
An array for nullable fields
52 53 54 |
# File 'lib/the_plaid_api/models/transactions_recurring_create_request.rb', line 52 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 47 48 49 |
# File 'lib/the_plaid_api/models/transactions_recurring_create_request.rb', line 44 def self.optionals %w[ client_id secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
110 111 112 113 114 115 |
# File 'lib/the_plaid_api/models/transactions_recurring_create_request.rb', line 110 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, access_token: #{@access_token.inspect},"\ " secret: #{@secret.inspect}, inputs: #{@inputs.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
103 104 105 106 107 |
# File 'lib/the_plaid_api/models/transactions_recurring_create_request.rb', line 103 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, access_token: #{@access_token}, secret:"\ " #{@secret}, inputs: #{@inputs}, additional_properties: #{@additional_properties}>" end |