Class: ThePlaidApi::TransactionsRecurringUpdateInput
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TransactionsRecurringUpdateInput
- Defined in:
- lib/the_plaid_api/models/transactions_recurring_update_input.rb
Overview
TransactionsRecurringUpdateInput defines a single operation to the ‘/transactions/recurring/streams/update` endpoint.
Instance Attribute Summary collapse
-
#stream_id ⇒ String
ID of the stream that all the transactions will be added in to.
-
#transaction_ids ⇒ Array[String]
IDs of all the transactions that will be added into the stream.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(stream_id:, transaction_ids:, additional_properties: nil) ⇒ TransactionsRecurringUpdateInput
constructor
A new instance of TransactionsRecurringUpdateInput.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(stream_id:, transaction_ids:, additional_properties: nil) ⇒ TransactionsRecurringUpdateInput
Returns a new instance of TransactionsRecurringUpdateInput.
41 42 43 44 45 46 47 48 |
# File 'lib/the_plaid_api/models/transactions_recurring_update_input.rb', line 41 def initialize(stream_id:, transaction_ids:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @stream_id = stream_id @transaction_ids = transaction_ids @additional_properties = additional_properties end |
Instance Attribute Details
#stream_id ⇒ String
ID of the stream that all the transactions will be added in to.
15 16 17 |
# File 'lib/the_plaid_api/models/transactions_recurring_update_input.rb', line 15 def stream_id @stream_id end |
#transaction_ids ⇒ Array[String]
IDs of all the transactions that will be added into the stream. If any transaction currently exist in another stream, it will be removed from the other stream.
21 22 23 |
# File 'lib/the_plaid_api/models/transactions_recurring_update_input.rb', line 21 def transaction_ids @transaction_ids end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/the_plaid_api/models/transactions_recurring_update_input.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. stream_id = hash.key?('stream_id') ? hash['stream_id'] : nil transaction_ids = hash.key?('transaction_ids') ? hash['transaction_ids'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransactionsRecurringUpdateInput.new(stream_id: stream_id, transaction_ids: transaction_ids, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/the_plaid_api/models/transactions_recurring_update_input.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['stream_id'] = 'stream_id' @_hash['transaction_ids'] = 'transaction_ids' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/the_plaid_api/models/transactions_recurring_update_input.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 |
# File 'lib/the_plaid_api/models/transactions_recurring_update_input.rb', line 32 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
80 81 82 83 84 |
# File 'lib/the_plaid_api/models/transactions_recurring_update_input.rb', line 80 def inspect class_name = self.class.name.split('::').last "<#{class_name} stream_id: #{@stream_id.inspect}, transaction_ids:"\ " #{@transaction_ids.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 77 |
# File 'lib/the_plaid_api/models/transactions_recurring_update_input.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} stream_id: #{@stream_id}, transaction_ids: #{@transaction_ids},"\ " additional_properties: #{@additional_properties}>" end |