Class: ThePlaidApi::TransactionsRuleDetails

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/transactions_rule_details.rb

Overview

A representation of transactions rule details.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(field:, type:, query:, additional_properties: nil) ⇒ TransactionsRuleDetails

Returns a new instance of TransactionsRuleDetails.



46
47
48
49
50
51
52
53
54
# File 'lib/the_plaid_api/models/transactions_rule_details.rb', line 46

def initialize(field:, type:, query:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @field = field
  @type = type
  @query = query
  @additional_properties = additional_properties
end

Instance Attribute Details

#fieldTransactionsRuleField

Transaction field for which the rule is defined.



14
15
16
# File 'lib/the_plaid_api/models/transactions_rule_details.rb', line 14

def field
  @field
end

#queryString

For ‘TRANSACTION_ID` field, provide `transaction_id`. For `NAME` field, provide a string pattern.

Returns:

  • (String)


25
26
27
# File 'lib/the_plaid_api/models/transactions_rule_details.rb', line 25

def query
  @query
end

#typeTransactionsRuleType

Transaction rule’s match type. For ‘TRANSACTION_ID` field, `EXACT_MATCH` is available. Matches are case sensitive.



20
21
22
# File 'lib/the_plaid_api/models/transactions_rule_details.rb', line 20

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/the_plaid_api/models/transactions_rule_details.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  field = hash.key?('field') ? hash['field'] : nil
  type = hash.key?('type') ? hash['type'] : nil
  query = hash.key?('query') ? hash['query'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransactionsRuleDetails.new(field: field,
                              type: type,
                              query: query,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



28
29
30
31
32
33
34
# File 'lib/the_plaid_api/models/transactions_rule_details.rb', line 28

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['field'] = 'field'
  @_hash['type'] = 'type'
  @_hash['query'] = 'query'
  @_hash
end

.nullablesObject

An array for nullable fields



42
43
44
# File 'lib/the_plaid_api/models/transactions_rule_details.rb', line 42

def self.nullables
  []
end

.optionalsObject

An array for optional fields



37
38
39
# File 'lib/the_plaid_api/models/transactions_rule_details.rb', line 37

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



87
88
89
90
91
# File 'lib/the_plaid_api/models/transactions_rule_details.rb', line 87

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} field: #{@field.inspect}, type: #{@type.inspect}, query: #{@query.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



80
81
82
83
84
# File 'lib/the_plaid_api/models/transactions_rule_details.rb', line 80

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} field: #{@field}, type: #{@type}, query: #{@query}, additional_properties:"\
  " #{@additional_properties}>"
end