Class: ThePlaidApi::TransactionsRulesCreateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/transactions_rules_create_request.rb

Overview

TransactionsRulesCreateRequest defines the request schema for ‘beta/transactions/rules/v1/create`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(client_user_id:, pfc_primary_category:, pfc_detailed_category:, rule_details:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ TransactionsRulesCreateRequest

Returns a new instance of TransactionsRulesCreateRequest.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/the_plaid_api/models/transactions_rules_create_request.rb', line 72

def initialize(client_user_id:, pfc_primary_category:,
               pfc_detailed_category:, rule_details:, client_id: SKIP,
               secret: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @client_user_id = client_user_id
  @pfc_primary_category = pfc_primary_category
  @pfc_detailed_category = pfc_detailed_category
  @rule_details = rule_details
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/transactions_rules_create_request.rb', line 17

def client_id
  @client_id
end

#client_user_idString

A unique ID representing the end user. This ID is used to associate rules with a specific user.

Returns:

  • (String)


27
28
29
# File 'lib/the_plaid_api/models/transactions_rules_create_request.rb', line 27

def client_user_id
  @client_user_id
end

#pfc_detailed_categoryString

A personal finance detailed category. See the [taxonomy csv file](plaid.com/documents/pfc-taxonomy-all.csv) for a full list of personal finance categories.

Returns:

  • (String)


41
42
43
# File 'lib/the_plaid_api/models/transactions_rules_create_request.rb', line 41

def pfc_detailed_category
  @pfc_detailed_category
end

#pfc_primary_categoryString

A personal finance primary category. See the [taxonomy csv file](plaid.com/documents/pfc-taxonomy-all.csv) for a full list of personal finance categories.

Returns:

  • (String)


34
35
36
# File 'lib/the_plaid_api/models/transactions_rules_create_request.rb', line 34

def pfc_primary_category
  @pfc_primary_category
end

#rule_detailsTransactionsRuleDetails

A representation of transactions rule details.



45
46
47
# File 'lib/the_plaid_api/models/transactions_rules_create_request.rb', line 45

def rule_details
  @rule_details
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/transactions_rules_create_request.rb', line 22

def secret
  @secret
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/the_plaid_api/models/transactions_rules_create_request.rb', line 88

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  client_user_id =
    hash.key?('client_user_id') ? hash['client_user_id'] : nil
  pfc_primary_category =
    hash.key?('pfc_primary_category') ? hash['pfc_primary_category'] : nil
  pfc_detailed_category =
    hash.key?('pfc_detailed_category') ? hash['pfc_detailed_category'] : nil
  rule_details = TransactionsRuleDetails.from_hash(hash['rule_details']) if
    hash['rule_details']
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransactionsRulesCreateRequest.new(client_user_id: client_user_id,
                                     pfc_primary_category: pfc_primary_category,
                                     pfc_detailed_category: pfc_detailed_category,
                                     rule_details: rule_details,
                                     client_id: client_id,
                                     secret: secret,
                                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



48
49
50
51
52
53
54
55
56
57
# File 'lib/the_plaid_api/models/transactions_rules_create_request.rb', line 48

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['client_user_id'] = 'client_user_id'
  @_hash['pfc_primary_category'] = 'pfc_primary_category'
  @_hash['pfc_detailed_category'] = 'pfc_detailed_category'
  @_hash['rule_details'] = 'rule_details'
  @_hash
end

.nullablesObject

An array for nullable fields



68
69
70
# File 'lib/the_plaid_api/models/transactions_rules_create_request.rb', line 68

def self.nullables
  []
end

.optionalsObject

An array for optional fields



60
61
62
63
64
65
# File 'lib/the_plaid_api/models/transactions_rules_create_request.rb', line 60

def self.optionals
  %w[
    client_id
    secret
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



130
131
132
133
134
135
136
137
# File 'lib/the_plaid_api/models/transactions_rules_create_request.rb', line 130

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\
  " client_user_id: #{@client_user_id.inspect}, pfc_primary_category:"\
  " #{@pfc_primary_category.inspect}, pfc_detailed_category:"\
  " #{@pfc_detailed_category.inspect}, rule_details: #{@rule_details.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



121
122
123
124
125
126
127
# File 'lib/the_plaid_api/models/transactions_rules_create_request.rb', line 121

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, client_user_id:"\
  " #{@client_user_id}, pfc_primary_category: #{@pfc_primary_category}, pfc_detailed_category:"\
  " #{@pfc_detailed_category}, rule_details: #{@rule_details}, additional_properties:"\
  " #{@additional_properties}>"
end