Class: ThePlaidApi::TransactionsUserInsightsGetRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TransactionsUserInsightsGetRequest
- Defined in:
- lib/the_plaid_api/models/transactions_user_insights_get_request.rb
Overview
TransactionsUserInsightsGetRequest defines the request schema for ‘/beta/transactions/user_insights/v1/get`.
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#client_user_id ⇒ String
A unique client-provided ‘client_user_id` to retrieve insights for.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_user_id:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ TransactionsUserInsightsGetRequest
constructor
A new instance of TransactionsUserInsightsGetRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_user_id:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ TransactionsUserInsightsGetRequest
Returns a new instance of TransactionsUserInsightsGetRequest.
50 51 52 53 54 55 56 57 58 59 |
# File 'lib/the_plaid_api/models/transactions_user_insights_get_request.rb', line 50 def initialize(client_user_id:, client_id: SKIP, secret: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @client_user_id = client_user_id @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/transactions_user_insights_get_request.rb', line 17 def client_id @client_id end |
#client_user_id ⇒ String
A unique client-provided ‘client_user_id` to retrieve insights for.
26 27 28 |
# File 'lib/the_plaid_api/models/transactions_user_insights_get_request.rb', line 26 def client_user_id @client_user_id end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/the_plaid_api/models/transactions_user_insights_get_request.rb', line 22 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/the_plaid_api/models/transactions_user_insights_get_request.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_user_id = hash.key?('client_user_id') ? hash['client_user_id'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransactionsUserInsightsGetRequest.new(client_user_id: client_user_id, client_id: client_id, secret: secret, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 |
# File 'lib/the_plaid_api/models/transactions_user_insights_get_request.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['client_user_id'] = 'client_user_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
46 47 48 |
# File 'lib/the_plaid_api/models/transactions_user_insights_get_request.rb', line 46 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
38 39 40 41 42 43 |
# File 'lib/the_plaid_api/models/transactions_user_insights_get_request.rb', line 38 def self.optionals %w[ client_id secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 98 |
# File 'lib/the_plaid_api/models/transactions_user_insights_get_request.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\ " client_user_id: #{@client_user_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 |
# File 'lib/the_plaid_api/models/transactions_user_insights_get_request.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, client_user_id:"\ " #{@client_user_id}, additional_properties: #{@additional_properties}>" end |