Class: ThePlaidApi::TransferAchNetwork

Inherits:
Object
  • Object
show all
Defined in:
lib/the_plaid_api/models/transfer_ach_network.rb

Overview

The ACH networks used for the funds flow. For requests submitted as either ‘ach` or `same-day-ach` the cutoff for Same Day ACH is 3:00 PM Eastern Time and the cutoff for Standard ACH transfers is 8:30 PM Eastern Time. It is recommended to submit a request at least 15 minutes before the cutoff time in order to ensure that it will be processed before the cutoff. Any request that is indicated as `same-day-ach` and that misses the Same Day ACH cutoff, but is submitted in time for the Standard ACH cutoff, will be sent over Standard ACH rails and will not incur same-day charges.

Constant Summary collapse

TRANSFER_ACH_NETWORK =
[
  # TODO: Write general description for ACH
  ACH = 'ach'.freeze,

  # TODO: Write general description for SAMEDAYACH
  SAMEDAYACH = 'same-day-ach'.freeze
].freeze

Class Method Summary collapse

Class Method Details

.from_value(value, default_value = ACH) ⇒ Object



30
31
32
33
34
35
36
37
38
39
40
41
# File 'lib/the_plaid_api/models/transfer_ach_network.rb', line 30

def self.from_value(value, default_value = ACH)
  return default_value if value.nil?

  str = value.to_s.strip

  case str.downcase
  when 'ach' then ACH
  when 'samedayach' then SAMEDAYACH
  else
    default_value
  end
end

.validate(value) ⇒ Object



24
25
26
27
28
# File 'lib/the_plaid_api/models/transfer_ach_network.rb', line 24

def self.validate(value)
  return false if value.nil?

  TRANSFER_ACH_NETWORK.include?(value)
end