Class: ThePlaidApi::TransferAuthorizationDevice

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/transfer_authorization_device.rb

Overview

Information about the device being used to initiate the authorization. These fields are not currently incorporated into the risk check.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(ip_address: SKIP, user_agent: SKIP, additional_properties: nil) ⇒ TransferAuthorizationDevice

Returns a new instance of TransferAuthorizationDevice.



42
43
44
45
46
47
48
49
50
# File 'lib/the_plaid_api/models/transfer_authorization_device.rb', line 42

def initialize(ip_address: SKIP, user_agent: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @ip_address = ip_address unless ip_address == SKIP
  @user_agent = user_agent unless user_agent == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#ip_addressString

The IP address of the device being used to initiate the authorization.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/transfer_authorization_device.rb', line 15

def ip_address
  @ip_address
end

#user_agentString

The user agent of the device being used to initiate the authorization.

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/transfer_authorization_device.rb', line 19

def user_agent
  @user_agent
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/the_plaid_api/models/transfer_authorization_device.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  ip_address = hash.key?('ip_address') ? hash['ip_address'] : SKIP
  user_agent = hash.key?('user_agent') ? hash['user_agent'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransferAuthorizationDevice.new(ip_address: ip_address,
                                  user_agent: user_agent,
                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/the_plaid_api/models/transfer_authorization_device.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['ip_address'] = 'ip_address'
  @_hash['user_agent'] = 'user_agent'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/the_plaid_api/models/transfer_authorization_device.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/the_plaid_api/models/transfer_authorization_device.rb', line 30

def self.optionals
  %w[
    ip_address
    user_agent
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



81
82
83
84
85
# File 'lib/the_plaid_api/models/transfer_authorization_device.rb', line 81

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} ip_address: #{@ip_address.inspect}, user_agent: #{@user_agent.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



74
75
76
77
78
# File 'lib/the_plaid_api/models/transfer_authorization_device.rb', line 74

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} ip_address: #{@ip_address}, user_agent: #{@user_agent},"\
  " additional_properties: #{@additional_properties}>"
end