Class: ThePlaidApi::TransferBalanceGetRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/transfer_balance_get_request.rb

Overview

Defines the request schema for ‘/transfer/balance/get`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(client_id: SKIP, originator_client_id: SKIP, secret: SKIP, type: SKIP, additional_properties: nil) ⇒ TransferBalanceGetRequest

Returns a new instance of TransferBalanceGetRequest.



60
61
62
63
64
65
66
67
68
69
70
# File 'lib/the_plaid_api/models/transfer_balance_get_request.rb', line 60

def initialize(client_id: SKIP, originator_client_id: SKIP, secret: SKIP,
               type: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @originator_client_id = originator_client_id unless originator_client_id == SKIP
  @secret = secret unless secret == SKIP
  @type = type unless type == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/transfer_balance_get_request.rb', line 16

def client_id
  @client_id
end

#originator_client_idString

Client ID of the end customer.

Returns:

  • (String)


20
21
22
# File 'lib/the_plaid_api/models/transfer_balance_get_request.rb', line 20

def originator_client_id
  @originator_client_id
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


25
26
27
# File 'lib/the_plaid_api/models/transfer_balance_get_request.rb', line 25

def secret
  @secret
end

#typeTransferBalanceType

The type of balance. ‘prefunded_rtp_credits` - Your prefunded RTP credit balance with Plaid `prefunded_ach_credits` - Your prefunded ACH credit balance with Plaid

Returns:



31
32
33
# File 'lib/the_plaid_api/models/transfer_balance_get_request.rb', line 31

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/the_plaid_api/models/transfer_balance_get_request.rb', line 73

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  originator_client_id =
    hash.key?('originator_client_id') ? hash['originator_client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  type = hash.key?('type') ? hash['type'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransferBalanceGetRequest.new(client_id: client_id,
                                originator_client_id: originator_client_id,
                                secret: secret,
                                type: type,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



34
35
36
37
38
39
40
41
# File 'lib/the_plaid_api/models/transfer_balance_get_request.rb', line 34

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['originator_client_id'] = 'originator_client_id'
  @_hash['secret'] = 'secret'
  @_hash['type'] = 'type'
  @_hash
end

.nullablesObject

An array for nullable fields



54
55
56
57
58
# File 'lib/the_plaid_api/models/transfer_balance_get_request.rb', line 54

def self.nullables
  %w[
    originator_client_id
  ]
end

.optionalsObject

An array for optional fields



44
45
46
47
48
49
50
51
# File 'lib/the_plaid_api/models/transfer_balance_get_request.rb', line 44

def self.optionals
  %w[
    client_id
    originator_client_id
    secret
    type
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



106
107
108
109
110
111
# File 'lib/the_plaid_api/models/transfer_balance_get_request.rb', line 106

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, originator_client_id:"\
  " #{@originator_client_id.inspect}, secret: #{@secret.inspect}, type: #{@type.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



99
100
101
102
103
# File 'lib/the_plaid_api/models/transfer_balance_get_request.rb', line 99

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, originator_client_id: #{@originator_client_id},"\
  " secret: #{@secret}, type: #{@type}, additional_properties: #{@additional_properties}>"
end