Class: ThePlaidApi::TransferCapabilitiesGetRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/transfer_capabilities_get_request.rb

Overview

Defines the request schema for ‘/transfer/capabilities/get`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(access_token:, account_id:, client_id: SKIP, secret: SKIP, payment_profile_token: SKIP, additional_properties: nil) ⇒ TransferCapabilitiesGetRequest

Returns a new instance of TransferCapabilitiesGetRequest.



62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/the_plaid_api/models/transfer_capabilities_get_request.rb', line 62

def initialize(access_token:, account_id:, client_id: SKIP, secret: SKIP,
               payment_profile_token: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @access_token = access_token
  @account_id = 
  @payment_profile_token = payment_profile_token unless payment_profile_token == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#access_tokenString

The Plaid ‘access_token` for the account that will be debited or credited.

Returns:

  • (String)


25
26
27
# File 'lib/the_plaid_api/models/transfer_capabilities_get_request.rb', line 25

def access_token
  @access_token
end

#account_idString

The Plaid ‘account_id` corresponding to the end-user account that will be debited or credited.

Returns:

  • (String)


30
31
32
# File 'lib/the_plaid_api/models/transfer_capabilities_get_request.rb', line 30

def 
  @account_id
end

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/transfer_capabilities_get_request.rb', line 16

def client_id
  @client_id
end

#payment_profile_tokenString

A payment profile token associated with the Payment Profile data that is being requested.

Returns:

  • (String)


35
36
37
# File 'lib/the_plaid_api/models/transfer_capabilities_get_request.rb', line 35

def payment_profile_token
  @payment_profile_token
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/transfer_capabilities_get_request.rb', line 21

def secret
  @secret
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/the_plaid_api/models/transfer_capabilities_get_request.rb', line 76

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  access_token = hash.key?('access_token') ? hash['access_token'] : nil
   = hash.key?('account_id') ? hash['account_id'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  payment_profile_token =
    hash.key?('payment_profile_token') ? hash['payment_profile_token'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransferCapabilitiesGetRequest.new(access_token: access_token,
                                     account_id: ,
                                     client_id: client_id,
                                     secret: secret,
                                     payment_profile_token: payment_profile_token,
                                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



38
39
40
41
42
43
44
45
46
# File 'lib/the_plaid_api/models/transfer_capabilities_get_request.rb', line 38

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['access_token'] = 'access_token'
  @_hash['account_id'] = 'account_id'
  @_hash['payment_profile_token'] = 'payment_profile_token'
  @_hash
end

.nullablesObject

An array for nullable fields



58
59
60
# File 'lib/the_plaid_api/models/transfer_capabilities_get_request.rb', line 58

def self.nullables
  []
end

.optionalsObject

An array for optional fields



49
50
51
52
53
54
55
# File 'lib/the_plaid_api/models/transfer_capabilities_get_request.rb', line 49

def self.optionals
  %w[
    client_id
    secret
    payment_profile_token
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



112
113
114
115
116
117
# File 'lib/the_plaid_api/models/transfer_capabilities_get_request.rb', line 112

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, access_token:"\
  " #{@access_token.inspect}, account_id: #{@account_id.inspect}, payment_profile_token:"\
  " #{@payment_profile_token.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



104
105
106
107
108
109
# File 'lib/the_plaid_api/models/transfer_capabilities_get_request.rb', line 104

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, access_token:"\
  " #{@access_token}, account_id: #{@account_id}, payment_profile_token:"\
  " #{@payment_profile_token}, additional_properties: #{@additional_properties}>"
end