Class: ThePlaidApi::TransferConfigurationGetResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/transfer_configuration_get_response.rb

Overview

Defines the response schema for ‘/transfer/configuration/get`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(request_id:, max_single_transfer_amount:, max_single_transfer_credit_amount:, max_single_transfer_debit_amount:, max_daily_credit_amount:, max_daily_debit_amount:, max_monthly_amount:, max_monthly_credit_amount:, max_monthly_debit_amount:, iso_currency_code:, additional_properties: nil) ⇒ TransferConfigurationGetResponse

Returns a new instance of TransferConfigurationGetResponse.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/the_plaid_api/models/transfer_configuration_get_response.rb', line 90

def initialize(request_id:, max_single_transfer_amount:,
               max_single_transfer_credit_amount:,
               max_single_transfer_debit_amount:, max_daily_credit_amount:,
               max_daily_debit_amount:, max_monthly_amount:,
               max_monthly_credit_amount:, max_monthly_debit_amount:,
               iso_currency_code:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @request_id = request_id
  @max_single_transfer_amount = max_single_transfer_amount
  @max_single_transfer_credit_amount = max_single_transfer_credit_amount
  @max_single_transfer_debit_amount = max_single_transfer_debit_amount
  @max_daily_credit_amount = max_daily_credit_amount
  @max_daily_debit_amount = max_daily_debit_amount
  @max_monthly_amount = max_monthly_amount
  @max_monthly_credit_amount = max_monthly_credit_amount
  @max_monthly_debit_amount = max_monthly_debit_amount
  @iso_currency_code = iso_currency_code
  @additional_properties = additional_properties
end

Instance Attribute Details

#iso_currency_codeString

The currency of the dollar amount, e.g. “USD”.

Returns:

  • (String)


60
61
62
# File 'lib/the_plaid_api/models/transfer_configuration_get_response.rb', line 60

def iso_currency_code
  @iso_currency_code
end

#max_daily_credit_amountString

The max limit of sum of dollar amount of credit transfers in last 24 hours (decimal string with two digits of precision e.g. “10.00”).

Returns:

  • (String)


36
37
38
# File 'lib/the_plaid_api/models/transfer_configuration_get_response.rb', line 36

def max_daily_credit_amount
  @max_daily_credit_amount
end

#max_daily_debit_amountString

The max limit of sum of dollar amount of debit transfers in last 24 hours (decimal string with two digits of precision e.g. “10.00”).

Returns:

  • (String)


41
42
43
# File 'lib/the_plaid_api/models/transfer_configuration_get_response.rb', line 41

def max_daily_debit_amount
  @max_daily_debit_amount
end

#max_monthly_amountString

The max limit of sum of dollar amount of credit and debit transfers in one calendar month (decimal string with two digits of precision e.g. “10.00”).

Returns:

  • (String)


46
47
48
# File 'lib/the_plaid_api/models/transfer_configuration_get_response.rb', line 46

def max_monthly_amount
  @max_monthly_amount
end

#max_monthly_credit_amountString

The max limit of sum of dollar amount of credit transfers in one calendar month (decimal string with two digits of precision e.g. “10.00”).

Returns:

  • (String)


51
52
53
# File 'lib/the_plaid_api/models/transfer_configuration_get_response.rb', line 51

def max_monthly_credit_amount
  @max_monthly_credit_amount
end

#max_monthly_debit_amountString

The max limit of sum of dollar amount of debit transfers in one calendar month (decimal string with two digits of precision e.g. “10.00”).

Returns:

  • (String)


56
57
58
# File 'lib/the_plaid_api/models/transfer_configuration_get_response.rb', line 56

def max_monthly_debit_amount
  @max_monthly_debit_amount
end

#max_single_transfer_amountString

The max limit of dollar amount of a single transfer (decimal string with two digits of precision e.g. “10.00”).

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/transfer_configuration_get_response.rb', line 21

def max_single_transfer_amount
  @max_single_transfer_amount
end

#max_single_transfer_credit_amountString

The max limit of dollar amount of a single credit transfer (decimal string with two digits of precision e.g. “10.00”).

Returns:

  • (String)


26
27
28
# File 'lib/the_plaid_api/models/transfer_configuration_get_response.rb', line 26

def max_single_transfer_credit_amount
  @max_single_transfer_credit_amount
end

#max_single_transfer_debit_amountString

The max limit of dollar amount of a single debit transfer (decimal string with two digits of precision e.g. “10.00”).

Returns:

  • (String)


31
32
33
# File 'lib/the_plaid_api/models/transfer_configuration_get_response.rb', line 31

def max_single_transfer_debit_amount
  @max_single_transfer_debit_amount
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/transfer_configuration_get_response.rb', line 16

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/the_plaid_api/models/transfer_configuration_get_response.rb', line 113

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  request_id = hash.key?('request_id') ? hash['request_id'] : nil
  max_single_transfer_amount =
    hash.key?('max_single_transfer_amount') ? hash['max_single_transfer_amount'] : nil
  max_single_transfer_credit_amount =
    hash.key?('max_single_transfer_credit_amount') ? hash['max_single_transfer_credit_amount'] : nil
  max_single_transfer_debit_amount =
    hash.key?('max_single_transfer_debit_amount') ? hash['max_single_transfer_debit_amount'] : nil
  max_daily_credit_amount =
    hash.key?('max_daily_credit_amount') ? hash['max_daily_credit_amount'] : nil
  max_daily_debit_amount =
    hash.key?('max_daily_debit_amount') ? hash['max_daily_debit_amount'] : nil
  max_monthly_amount =
    hash.key?('max_monthly_amount') ? hash['max_monthly_amount'] : nil
  max_monthly_credit_amount =
    hash.key?('max_monthly_credit_amount') ? hash['max_monthly_credit_amount'] : nil
  max_monthly_debit_amount =
    hash.key?('max_monthly_debit_amount') ? hash['max_monthly_debit_amount'] : nil
  iso_currency_code =
    hash.key?('iso_currency_code') ? hash['iso_currency_code'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransferConfigurationGetResponse.new(request_id: request_id,
                                       max_single_transfer_amount: max_single_transfer_amount,
                                       max_single_transfer_credit_amount: max_single_transfer_credit_amount,
                                       max_single_transfer_debit_amount: max_single_transfer_debit_amount,
                                       max_daily_credit_amount: max_daily_credit_amount,
                                       max_daily_debit_amount: max_daily_debit_amount,
                                       max_monthly_amount: max_monthly_amount,
                                       max_monthly_credit_amount: max_monthly_credit_amount,
                                       max_monthly_debit_amount: max_monthly_debit_amount,
                                       iso_currency_code: iso_currency_code,
                                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/the_plaid_api/models/transfer_configuration_get_response.rb', line 63

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['request_id'] = 'request_id'
  @_hash['max_single_transfer_amount'] = 'max_single_transfer_amount'
  @_hash['max_single_transfer_credit_amount'] =
    'max_single_transfer_credit_amount'
  @_hash['max_single_transfer_debit_amount'] =
    'max_single_transfer_debit_amount'
  @_hash['max_daily_credit_amount'] = 'max_daily_credit_amount'
  @_hash['max_daily_debit_amount'] = 'max_daily_debit_amount'
  @_hash['max_monthly_amount'] = 'max_monthly_amount'
  @_hash['max_monthly_credit_amount'] = 'max_monthly_credit_amount'
  @_hash['max_monthly_debit_amount'] = 'max_monthly_debit_amount'
  @_hash['iso_currency_code'] = 'iso_currency_code'
  @_hash
end

.nullablesObject

An array for nullable fields



86
87
88
# File 'lib/the_plaid_api/models/transfer_configuration_get_response.rb', line 86

def self.nullables
  []
end

.optionalsObject

An array for optional fields



81
82
83
# File 'lib/the_plaid_api/models/transfer_configuration_get_response.rb', line 81

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/the_plaid_api/models/transfer_configuration_get_response.rb', line 173

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} request_id: #{@request_id.inspect}, max_single_transfer_amount:"\
  " #{@max_single_transfer_amount.inspect}, max_single_transfer_credit_amount:"\
  " #{@max_single_transfer_credit_amount.inspect}, max_single_transfer_debit_amount:"\
  " #{@max_single_transfer_debit_amount.inspect}, max_daily_credit_amount:"\
  " #{@max_daily_credit_amount.inspect}, max_daily_debit_amount:"\
  " #{@max_daily_debit_amount.inspect}, max_monthly_amount: #{@max_monthly_amount.inspect},"\
  " max_monthly_credit_amount: #{@max_monthly_credit_amount.inspect},"\
  " max_monthly_debit_amount: #{@max_monthly_debit_amount.inspect}, iso_currency_code:"\
  " #{@iso_currency_code.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/the_plaid_api/models/transfer_configuration_get_response.rb', line 159

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} request_id: #{@request_id}, max_single_transfer_amount:"\
  " #{@max_single_transfer_amount}, max_single_transfer_credit_amount:"\
  " #{@max_single_transfer_credit_amount}, max_single_transfer_debit_amount:"\
  " #{@max_single_transfer_debit_amount}, max_daily_credit_amount:"\
  " #{@max_daily_credit_amount}, max_daily_debit_amount: #{@max_daily_debit_amount},"\
  " max_monthly_amount: #{@max_monthly_amount}, max_monthly_credit_amount:"\
  " #{@max_monthly_credit_amount}, max_monthly_debit_amount: #{@max_monthly_debit_amount},"\
  " iso_currency_code: #{@iso_currency_code}, additional_properties:"\
  " #{@additional_properties}>"
end