Class: ThePlaidApi::TransferEventListResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TransferEventListResponse
- Defined in:
- lib/the_plaid_api/models/transfer_event_list_response.rb
Overview
Defines the response schema for ‘/transfer/event/list`
Instance Attribute Summary collapse
-
#has_more ⇒ TrueClass | FalseClass
Whether there are more events to be pulled from the endpoint that have not already been returned.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
-
#transfer_events ⇒ Array[TransferEvent]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(transfer_events:, has_more:, request_id:, additional_properties: nil) ⇒ TransferEventListResponse
constructor
A new instance of TransferEventListResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(transfer_events:, has_more:, request_id:, additional_properties: nil) ⇒ TransferEventListResponse
Returns a new instance of TransferEventListResponse.
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/the_plaid_api/models/transfer_event_list_response.rb', line 46 def initialize(transfer_events:, has_more:, request_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @transfer_events = transfer_events @has_more = has_more @request_id = request_id @additional_properties = additional_properties end |
Instance Attribute Details
#has_more ⇒ TrueClass | FalseClass
Whether there are more events to be pulled from the endpoint that have not already been returned
19 20 21 |
# File 'lib/the_plaid_api/models/transfer_event_list_response.rb', line 19 def has_more @has_more end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
25 26 27 |
# File 'lib/the_plaid_api/models/transfer_event_list_response.rb', line 25 def request_id @request_id end |
#transfer_events ⇒ Array[TransferEvent]
TODO: Write general description for this method
14 15 16 |
# File 'lib/the_plaid_api/models/transfer_event_list_response.rb', line 14 def transfer_events @transfer_events end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/the_plaid_api/models/transfer_event_list_response.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it transfer_events = nil unless hash['transfer_events'].nil? transfer_events = [] hash['transfer_events'].each do |structure| transfer_events << (TransferEvent.from_hash(structure) if structure) end end transfer_events = nil unless hash.key?('transfer_events') has_more = hash.key?('has_more') ? hash['has_more'] : nil request_id = hash.key?('request_id') ? hash['request_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransferEventListResponse.new(transfer_events: transfer_events, has_more: has_more, request_id: request_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
28 29 30 31 32 33 34 |
# File 'lib/the_plaid_api/models/transfer_event_list_response.rb', line 28 def self.names @_hash = {} if @_hash.nil? @_hash['transfer_events'] = 'transfer_events' @_hash['has_more'] = 'has_more' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
42 43 44 |
# File 'lib/the_plaid_api/models/transfer_event_list_response.rb', line 42 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
37 38 39 |
# File 'lib/the_plaid_api/models/transfer_event_list_response.rb', line 37 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
97 98 99 100 101 102 |
# File 'lib/the_plaid_api/models/transfer_event_list_response.rb', line 97 def inspect class_name = self.class.name.split('::').last "<#{class_name} transfer_events: #{@transfer_events.inspect}, has_more:"\ " #{@has_more.inspect}, request_id: #{@request_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
90 91 92 93 94 |
# File 'lib/the_plaid_api/models/transfer_event_list_response.rb', line 90 def to_s class_name = self.class.name.split('::').last "<#{class_name} transfer_events: #{@transfer_events}, has_more: #{@has_more}, request_id:"\ " #{@request_id}, additional_properties: #{@additional_properties}>" end |