Class: ThePlaidApi::TransferEventsUpdateWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/transfer_events_update_webhook.rb

Overview

Fired when new transfer events are available. Receiving this webhook indicates you should fetch the new events from ‘/transfer/event/sync`. If multiple transfer events occur within a single minute, only one webhook will be fired, so a single webhook instance may correspond to multiple transfer events.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, environment:, additional_properties: nil) ⇒ TransferEventsUpdateWebhook

Returns a new instance of TransferEventsUpdateWebhook.



47
48
49
50
51
52
53
54
55
56
# File 'lib/the_plaid_api/models/transfer_events_update_webhook.rb', line 47

def initialize(webhook_type:, webhook_code:, environment:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @environment = environment
  @additional_properties = additional_properties
end

Instance Attribute Details

#environmentWebhookEnvironmentValues

The Plaid environment the webhook was sent from



26
27
28
# File 'lib/the_plaid_api/models/transfer_events_update_webhook.rb', line 26

def environment
  @environment
end

#webhook_codeString

‘TRANSFER_EVENTS_UPDATE`

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/transfer_events_update_webhook.rb', line 22

def webhook_code
  @webhook_code
end

#webhook_typeString

‘TRANSFER`

Returns:

  • (String)


18
19
20
# File 'lib/the_plaid_api/models/transfer_events_update_webhook.rb', line 18

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/the_plaid_api/models/transfer_events_update_webhook.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  environment = hash.key?('environment') ? hash['environment'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransferEventsUpdateWebhook.new(webhook_type: webhook_type,
                                  webhook_code: webhook_code,
                                  environment: environment,
                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
# File 'lib/the_plaid_api/models/transfer_events_update_webhook.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['environment'] = 'environment'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/the_plaid_api/models/transfer_events_update_webhook.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



38
39
40
# File 'lib/the_plaid_api/models/transfer_events_update_webhook.rb', line 38

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
94
# File 'lib/the_plaid_api/models/transfer_events_update_webhook.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, environment: #{@environment.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/the_plaid_api/models/transfer_events_update_webhook.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code},"\
  " environment: #{@environment}, additional_properties: #{@additional_properties}>"
end