Class: ThePlaidApi::TransferExpectedSweepSettlementScheduleItem

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/transfer_expected_sweep_settlement_schedule_item.rb

Overview

Defines an expected sweep date and amount.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(sweep_settlement_date:, swept_settled_amount:, additional_properties: nil) ⇒ TransferExpectedSweepSettlementScheduleItem

Returns a new instance of TransferExpectedSweepSettlementScheduleItem.



38
39
40
41
42
43
44
45
46
# File 'lib/the_plaid_api/models/transfer_expected_sweep_settlement_schedule_item.rb', line 38

def initialize(sweep_settlement_date:, swept_settled_amount:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @sweep_settlement_date = sweep_settlement_date
  @swept_settled_amount = swept_settled_amount
  @additional_properties = additional_properties
end

Instance Attribute Details

#sweep_settlement_dateDate

The settlement date of a sweep for this transfer.

Returns:

  • (Date)


14
15
16
# File 'lib/the_plaid_api/models/transfer_expected_sweep_settlement_schedule_item.rb', line 14

def sweep_settlement_date
  @sweep_settlement_date
end

#swept_settled_amountString

The accumulated amount that has been swept by ‘sweep_settlement_date`.

Returns:

  • (String)


18
19
20
# File 'lib/the_plaid_api/models/transfer_expected_sweep_settlement_schedule_item.rb', line 18

def swept_settled_amount
  @swept_settled_amount
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/the_plaid_api/models/transfer_expected_sweep_settlement_schedule_item.rb', line 49

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  sweep_settlement_date =
    hash.key?('sweep_settlement_date') ? hash['sweep_settlement_date'] : nil
  swept_settled_amount =
    hash.key?('swept_settled_amount') ? hash['swept_settled_amount'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransferExpectedSweepSettlementScheduleItem.new(sweep_settlement_date: sweep_settlement_date,
                                                  swept_settled_amount: swept_settled_amount,
                                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/the_plaid_api/models/transfer_expected_sweep_settlement_schedule_item.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['sweep_settlement_date'] = 'sweep_settlement_date'
  @_hash['swept_settled_amount'] = 'swept_settled_amount'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/the_plaid_api/models/transfer_expected_sweep_settlement_schedule_item.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/the_plaid_api/models/transfer_expected_sweep_settlement_schedule_item.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
84
# File 'lib/the_plaid_api/models/transfer_expected_sweep_settlement_schedule_item.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} sweep_settlement_date: #{@sweep_settlement_date.inspect},"\
  " swept_settled_amount: #{@swept_settled_amount.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/the_plaid_api/models/transfer_expected_sweep_settlement_schedule_item.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} sweep_settlement_date: #{@sweep_settlement_date}, swept_settled_amount:"\
  " #{@swept_settled_amount}, additional_properties: #{@additional_properties}>"
end