Class: ThePlaidApi::TransferIntentCreateNetwork

Inherits:
Object
  • Object
show all
Defined in:
lib/the_plaid_api/models/transfer_intent_create_network.rb

Overview

The network or rails used for the transfer. Defaults to ‘same-day-ach`. For transfers submitted using `ach`, the Standard ACH cutoff is 8:30 PM Eastern Time. For transfers submitted using `same-day-ach`, the Same Day ACH cutoff is 3:00 PM Eastern Time. It is recommended to send the request 15 minutes prior to the cutoff to ensure that it will be processed in time for submission before the cutoff. If the transfer is processed after this cutoff but before the Standard ACH cutoff, it will be sent over Standard ACH rails and will not incur same-day charges. For transfers submitted using `rtp`, in the case that the account being credited does not support RTP, the transfer will be sent over ACH as long as an `ach_class` is provided in the request. If RTP isn’t supported by the account and no ‘ach_class` is provided, the transfer will fail to be submitted.

Constant Summary collapse

TRANSFER_INTENT_CREATE_NETWORK =
[
  # TODO: Write general description for ACH
  ACH = 'ach'.freeze,

  # TODO: Write general description for SAMEDAYACH
  SAMEDAYACH = 'same-day-ach'.freeze,

  # TODO: Write general description for RTP
  RTP = 'rtp'.freeze
].freeze

Class Method Summary collapse

Class Method Details

.from_value(value, default_value = ACH) ⇒ Object



37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/the_plaid_api/models/transfer_intent_create_network.rb', line 37

def self.from_value(value, default_value = ACH)
  return default_value if value.nil?

  str = value.to_s.strip

  case str.downcase
  when 'ach' then ACH
  when 'samedayach' then SAMEDAYACH
  when 'rtp' then RTP
  else
    default_value
  end
end

.validate(value) ⇒ Object



31
32
33
34
35
# File 'lib/the_plaid_api/models/transfer_intent_create_network.rb', line 31

def self.validate(value)
  return false if value.nil?

  TRANSFER_INTENT_CREATE_NETWORK.include?(value)
end