Class: ThePlaidApi::TransferIntentGetFailureReason

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/transfer_intent_get_failure_reason.rb

Overview

The reason for a failed transfer intent. Returned only if the transfer intent status is ‘failed`. Null otherwise.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(error_type: SKIP, error_code: SKIP, error_message: SKIP, additional_properties: nil) ⇒ TransferIntentGetFailureReason

Returns a new instance of TransferIntentGetFailureReason.



50
51
52
53
54
55
56
57
58
59
# File 'lib/the_plaid_api/models/transfer_intent_get_failure_reason.rb', line 50

def initialize(error_type: SKIP, error_code: SKIP, error_message: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @error_type = error_type unless error_type == SKIP
  @error_code = error_code unless error_code == SKIP
  @error_message = error_message unless error_message == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#error_codeString

A code representing the reason for a failed transfer intent (i.e., an API error or the authorization being declined).

Returns:

  • (String)


20
21
22
# File 'lib/the_plaid_api/models/transfer_intent_get_failure_reason.rb', line 20

def error_code
  @error_code
end

#error_messageString

A human-readable description of the code associated with a failed transfer intent.

Returns:

  • (String)


25
26
27
# File 'lib/the_plaid_api/models/transfer_intent_get_failure_reason.rb', line 25

def error_message
  @error_message
end

#error_typeString

A broad categorization of the error.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/transfer_intent_get_failure_reason.rb', line 15

def error_type
  @error_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/the_plaid_api/models/transfer_intent_get_failure_reason.rb', line 62

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  error_type = hash.key?('error_type') ? hash['error_type'] : SKIP
  error_code = hash.key?('error_code') ? hash['error_code'] : SKIP
  error_message = hash.key?('error_message') ? hash['error_message'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransferIntentGetFailureReason.new(error_type: error_type,
                                     error_code: error_code,
                                     error_message: error_message,
                                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



28
29
30
31
32
33
34
# File 'lib/the_plaid_api/models/transfer_intent_get_failure_reason.rb', line 28

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['error_type'] = 'error_type'
  @_hash['error_code'] = 'error_code'
  @_hash['error_message'] = 'error_message'
  @_hash
end

.nullablesObject

An array for nullable fields



46
47
48
# File 'lib/the_plaid_api/models/transfer_intent_get_failure_reason.rb', line 46

def self.nullables
  []
end

.optionalsObject

An array for optional fields



37
38
39
40
41
42
43
# File 'lib/the_plaid_api/models/transfer_intent_get_failure_reason.rb', line 37

def self.optionals
  %w[
    error_type
    error_code
    error_message
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



92
93
94
95
96
97
# File 'lib/the_plaid_api/models/transfer_intent_get_failure_reason.rb', line 92

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} error_type: #{@error_type.inspect}, error_code: #{@error_code.inspect},"\
  " error_message: #{@error_message.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



85
86
87
88
89
# File 'lib/the_plaid_api/models/transfer_intent_get_failure_reason.rb', line 85

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} error_type: #{@error_type}, error_code: #{@error_code}, error_message:"\
  " #{@error_message}, additional_properties: #{@additional_properties}>"
end