Class: ThePlaidApi::TransferLedgerEventListResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/transfer_ledger_event_list_response.rb

Overview

Defines the response schema for ‘/transfer/ledger/event/list`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(ledger_events:, has_more:, request_id:, additional_properties: nil) ⇒ TransferLedgerEventListResponse

Returns a new instance of TransferLedgerEventListResponse.



46
47
48
49
50
51
52
53
54
55
# File 'lib/the_plaid_api/models/transfer_ledger_event_list_response.rb', line 46

def initialize(ledger_events:, has_more:, request_id:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @ledger_events = ledger_events
  @has_more = has_more
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#has_moreTrueClass | FalseClass

Whether there are more events to be pulled from the endpoint that have not already been returned

Returns:

  • (TrueClass | FalseClass)


19
20
21
# File 'lib/the_plaid_api/models/transfer_ledger_event_list_response.rb', line 19

def has_more
  @has_more
end

#ledger_eventsArray[TransferLedgerEvent]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/the_plaid_api/models/transfer_ledger_event_list_response.rb', line 14

def ledger_events
  @ledger_events
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


25
26
27
# File 'lib/the_plaid_api/models/transfer_ledger_event_list_response.rb', line 25

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/the_plaid_api/models/transfer_ledger_event_list_response.rb', line 58

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  ledger_events = nil
  unless hash['ledger_events'].nil?
    ledger_events = []
    hash['ledger_events'].each do |structure|
      ledger_events << (TransferLedgerEvent.from_hash(structure) if structure)
    end
  end

  ledger_events = nil unless hash.key?('ledger_events')
  has_more = hash.key?('has_more') ? hash['has_more'] : nil
  request_id = hash.key?('request_id') ? hash['request_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransferLedgerEventListResponse.new(ledger_events: ledger_events,
                                      has_more: has_more,
                                      request_id: request_id,
                                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



28
29
30
31
32
33
34
# File 'lib/the_plaid_api/models/transfer_ledger_event_list_response.rb', line 28

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['ledger_events'] = 'ledger_events'
  @_hash['has_more'] = 'has_more'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



42
43
44
# File 'lib/the_plaid_api/models/transfer_ledger_event_list_response.rb', line 42

def self.nullables
  []
end

.optionalsObject

An array for optional fields



37
38
39
# File 'lib/the_plaid_api/models/transfer_ledger_event_list_response.rb', line 37

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



97
98
99
100
101
# File 'lib/the_plaid_api/models/transfer_ledger_event_list_response.rb', line 97

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} ledger_events: #{@ledger_events.inspect}, has_more: #{@has_more.inspect},"\
  " request_id: #{@request_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



90
91
92
93
94
# File 'lib/the_plaid_api/models/transfer_ledger_event_list_response.rb', line 90

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} ledger_events: #{@ledger_events}, has_more: #{@has_more}, request_id:"\
  " #{@request_id}, additional_properties: #{@additional_properties}>"
end