Class: ThePlaidApi::TransferLedgerGetRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TransferLedgerGetRequest
- Defined in:
- lib/the_plaid_api/models/transfer_ledger_get_request.rb
Overview
Defines the request schema for ‘/transfer/ledger/get`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#ledger_id ⇒ String
Specify which ledger balance to get.
-
#originator_client_id ⇒ String
Client ID of the end customer.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_id: SKIP, secret: SKIP, ledger_id: SKIP, originator_client_id: SKIP, additional_properties: nil) ⇒ TransferLedgerGetRequest
constructor
A new instance of TransferLedgerGetRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_id: SKIP, secret: SKIP, ledger_id: SKIP, originator_client_id: SKIP, additional_properties: nil) ⇒ TransferLedgerGetRequest
Returns a new instance of TransferLedgerGetRequest.
61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/the_plaid_api/models/transfer_ledger_get_request.rb', line 61 def initialize(client_id: SKIP, secret: SKIP, ledger_id: SKIP, originator_client_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @ledger_id = ledger_id unless ledger_id == SKIP @originator_client_id = originator_client_id unless originator_client_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/the_plaid_api/models/transfer_ledger_get_request.rb', line 16 def client_id @client_id end |
#ledger_id ⇒ String
Specify which ledger balance to get. Customers can find a list of ‘ledger_id`s in the Accounts page of your Plaid Dashboard. If this field is left blank, this will default to id of the default ledger balance.
27 28 29 |
# File 'lib/the_plaid_api/models/transfer_ledger_get_request.rb', line 27 def ledger_id @ledger_id end |
#originator_client_id ⇒ String
Client ID of the end customer.
31 32 33 |
# File 'lib/the_plaid_api/models/transfer_ledger_get_request.rb', line 31 def originator_client_id @originator_client_id end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
21 22 23 |
# File 'lib/the_plaid_api/models/transfer_ledger_get_request.rb', line 21 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/the_plaid_api/models/transfer_ledger_get_request.rb', line 74 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP ledger_id = hash.key?('ledger_id') ? hash['ledger_id'] : SKIP originator_client_id = hash.key?('originator_client_id') ? hash['originator_client_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransferLedgerGetRequest.new(client_id: client_id, secret: secret, ledger_id: ledger_id, originator_client_id: originator_client_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
34 35 36 37 38 39 40 41 |
# File 'lib/the_plaid_api/models/transfer_ledger_get_request.rb', line 34 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['ledger_id'] = 'ledger_id' @_hash['originator_client_id'] = 'originator_client_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 57 58 59 |
# File 'lib/the_plaid_api/models/transfer_ledger_get_request.rb', line 54 def self.nullables %w[ ledger_id originator_client_id ] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 47 48 49 50 51 |
# File 'lib/the_plaid_api/models/transfer_ledger_get_request.rb', line 44 def self.optionals %w[ client_id secret ledger_id originator_client_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
108 109 110 111 112 113 |
# File 'lib/the_plaid_api/models/transfer_ledger_get_request.rb', line 108 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, ledger_id:"\ " #{@ledger_id.inspect}, originator_client_id: #{@originator_client_id.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
100 101 102 103 104 105 |
# File 'lib/the_plaid_api/models/transfer_ledger_get_request.rb', line 100 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, ledger_id: #{@ledger_id},"\ " originator_client_id: #{@originator_client_id}, additional_properties:"\ " #{@additional_properties}>" end |