Class: ThePlaidApi::TransferLedgerWithdrawResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/transfer_ledger_withdraw_response.rb

Overview

Defines the response schema for ‘/transfer/ledger/withdraw`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(sweep:, request_id:, additional_properties: nil) ⇒ TransferLedgerWithdrawResponse

Returns a new instance of TransferLedgerWithdrawResponse.



50
51
52
53
54
55
56
57
# File 'lib/the_plaid_api/models/transfer_ledger_withdraw_response.rb', line 50

def initialize(sweep:, request_id:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @sweep = sweep
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


30
31
32
# File 'lib/the_plaid_api/models/transfer_ledger_withdraw_response.rb', line 30

def request_id
  @request_id
end

#sweepTransferSweep

Describes a sweep of funds to / from the sweep account. A sweep is associated with many sweep events (events of type ‘swept` or `return_swept`) which can be retrieved by invoking the `/transfer/event/list` endpoint with the corresponding `sweep_id`. `swept` events occur when the transfer amount is credited or debited from your sweep account, depending on the `type` of the transfer. `return_swept` events occur when a transfer is returned and Plaid undoes the credit or debit. The total sum of the `swept` and `return_swept` events is equal to the `amount` of the sweep Plaid creates and matches the amount of the entry on your sweep account ledger.

Returns:



24
25
26
# File 'lib/the_plaid_api/models/transfer_ledger_withdraw_response.rb', line 24

def sweep
  @sweep
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/the_plaid_api/models/transfer_ledger_withdraw_response.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  sweep = TransferSweep.from_hash(hash['sweep']) if hash['sweep']
  request_id = hash.key?('request_id') ? hash['request_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransferLedgerWithdrawResponse.new(sweep: sweep,
                                     request_id: request_id,
                                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
# File 'lib/the_plaid_api/models/transfer_ledger_withdraw_response.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['sweep'] = 'sweep'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



46
47
48
# File 'lib/the_plaid_api/models/transfer_ledger_withdraw_response.rb', line 46

def self.nullables
  []
end

.optionalsObject

An array for optional fields



41
42
43
# File 'lib/the_plaid_api/models/transfer_ledger_withdraw_response.rb', line 41

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



88
89
90
91
92
# File 'lib/the_plaid_api/models/transfer_ledger_withdraw_response.rb', line 88

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} sweep: #{@sweep.inspect}, request_id: #{@request_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



81
82
83
84
85
# File 'lib/the_plaid_api/models/transfer_ledger_withdraw_response.rb', line 81

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} sweep: #{@sweep}, request_id: #{@request_id}, additional_properties:"\
  " #{@additional_properties}>"
end