Class: ThePlaidApi::TransferMetricsGetReturnRates
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TransferMetricsGetReturnRates
- Defined in:
- lib/the_plaid_api/models/transfer_metrics_get_return_rates.rb
Overview
Details regarding return rates.
Instance Attribute Summary collapse
-
#last_60d ⇒ TransferMetricsGetReturnRatesOverInterval
Details regarding return rates.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(last_60d: SKIP, additional_properties: nil) ⇒ TransferMetricsGetReturnRates
constructor
A new instance of TransferMetricsGetReturnRates.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(last_60d: SKIP, additional_properties: nil) ⇒ TransferMetricsGetReturnRates
Returns a new instance of TransferMetricsGetReturnRates.
37 38 39 40 41 42 43 |
# File 'lib/the_plaid_api/models/transfer_metrics_get_return_rates.rb', line 37 def initialize(last_60d: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @last_60d = last_60d unless last_60d == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#last_60d ⇒ TransferMetricsGetReturnRatesOverInterval
Details regarding return rates.
14 15 16 |
# File 'lib/the_plaid_api/models/transfer_metrics_get_return_rates.rb', line 14 def last_60d @last_60d end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/the_plaid_api/models/transfer_metrics_get_return_rates.rb', line 46 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. last_60d = TransferMetricsGetReturnRatesOverInterval.from_hash(hash['last_60d']) if hash['last_60d'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransferMetricsGetReturnRates.new(last_60d: last_60d, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/the_plaid_api/models/transfer_metrics_get_return_rates.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['last_60d'] = 'last_60d' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 34 35 |
# File 'lib/the_plaid_api/models/transfer_metrics_get_return_rates.rb', line 31 def self.nullables %w[ last_60d ] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/the_plaid_api/models/transfer_metrics_get_return_rates.rb', line 24 def self.optionals %w[ last_60d ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
72 73 74 75 76 |
# File 'lib/the_plaid_api/models/transfer_metrics_get_return_rates.rb', line 72 def inspect class_name = self.class.name.split('::').last "<#{class_name} last_60d: #{@last_60d.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 |
# File 'lib/the_plaid_api/models/transfer_metrics_get_return_rates.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} last_60d: #{@last_60d}, additional_properties: #{@additional_properties}>" end |