Class: ThePlaidApi::TransferMigrateAccountRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TransferMigrateAccountRequest
- Defined in:
- lib/the_plaid_api/models/transfer_migrate_account_request.rb
Overview
Defines the request schema for ‘/transfer/migrate_account`
Instance Attribute Summary collapse
-
#account_number ⇒ String
The user’s account number.
-
#account_type ⇒ String
The type of the bank account (‘checking` or `savings`).
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#routing_number ⇒ String
The user’s routing number.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#wire_routing_number ⇒ String
The user’s wire transfer routing number.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_number:, routing_number:, account_type:, client_id: SKIP, secret: SKIP, wire_routing_number: SKIP, additional_properties: nil) ⇒ TransferMigrateAccountRequest
constructor
A new instance of TransferMigrateAccountRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_number:, routing_number:, account_type:, client_id: SKIP, secret: SKIP, wire_routing_number: SKIP, additional_properties: nil) ⇒ TransferMigrateAccountRequest
Returns a new instance of TransferMigrateAccountRequest.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/the_plaid_api/models/transfer_migrate_account_request.rb', line 68 def initialize(account_number:, routing_number:, account_type:, client_id: SKIP, secret: SKIP, wire_routing_number: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @account_number = account_number @routing_number = routing_number @wire_routing_number = wire_routing_number unless wire_routing_number == SKIP @account_type = account_type @additional_properties = additional_properties end |
Instance Attribute Details
#account_number ⇒ String
The user’s account number.
25 26 27 |
# File 'lib/the_plaid_api/models/transfer_migrate_account_request.rb', line 25 def account_number @account_number end |
#account_type ⇒ String
The type of the bank account (‘checking` or `savings`).
40 41 42 |
# File 'lib/the_plaid_api/models/transfer_migrate_account_request.rb', line 40 def account_type @account_type end |
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/the_plaid_api/models/transfer_migrate_account_request.rb', line 16 def client_id @client_id end |
#routing_number ⇒ String
The user’s routing number.
29 30 31 |
# File 'lib/the_plaid_api/models/transfer_migrate_account_request.rb', line 29 def routing_number @routing_number end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
21 22 23 |
# File 'lib/the_plaid_api/models/transfer_migrate_account_request.rb', line 21 def secret @secret end |
#wire_routing_number ⇒ String
The user’s wire transfer routing number. This is the ABA number; for some institutions, this may differ from the ACH number used in ‘routing_number`. This field must be set for the created item to be eligible for wire transfers.
36 37 38 |
# File 'lib/the_plaid_api/models/transfer_migrate_account_request.rb', line 36 def wire_routing_number @wire_routing_number end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/the_plaid_api/models/transfer_migrate_account_request.rb', line 84 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_number = hash.key?('account_number') ? hash['account_number'] : nil routing_number = hash.key?('routing_number') ? hash['routing_number'] : nil account_type = hash.key?('account_type') ? hash['account_type'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP wire_routing_number = hash.key?('wire_routing_number') ? hash['wire_routing_number'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransferMigrateAccountRequest.new(account_number: account_number, routing_number: routing_number, account_type: account_type, client_id: client_id, secret: secret, wire_routing_number: wire_routing_number, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/the_plaid_api/models/transfer_migrate_account_request.rb', line 43 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['account_number'] = 'account_number' @_hash['routing_number'] = 'routing_number' @_hash['wire_routing_number'] = 'wire_routing_number' @_hash['account_type'] = 'account_type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
64 65 66 |
# File 'lib/the_plaid_api/models/transfer_migrate_account_request.rb', line 64 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
55 56 57 58 59 60 61 |
# File 'lib/the_plaid_api/models/transfer_migrate_account_request.rb', line 55 def self.optionals %w[ client_id secret wire_routing_number ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
125 126 127 128 129 130 131 |
# File 'lib/the_plaid_api/models/transfer_migrate_account_request.rb', line 125 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\ " account_number: #{@account_number.inspect}, routing_number: #{@routing_number.inspect},"\ " wire_routing_number: #{@wire_routing_number.inspect}, account_type:"\ " #{@account_type.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
116 117 118 119 120 121 122 |
# File 'lib/the_plaid_api/models/transfer_migrate_account_request.rb', line 116 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, account_number:"\ " #{@account_number}, routing_number: #{@routing_number}, wire_routing_number:"\ " #{@wire_routing_number}, account_type: #{@account_type}, additional_properties:"\ " #{@additional_properties}>" end |