Class: ThePlaidApi::TransferNetwork

Inherits:
Object
  • Object
show all
Defined in:
lib/the_plaid_api/models/transfer_network.rb

Overview

The network or rails used for the transfer. For transfers submitted as ‘ach` or `same-day-ach`, the Standard ACH cutoff is 8:30 PM Eastern Time. For transfers submitted as `same-day-ach`, the Same Day ACH cutoff is 3:00 PM Eastern Time. It is recommended to send the request 15 minutes prior to the cutoff to ensure that it will be processed in time for submission before the cutoff. If the transfer is processed after this cutoff but before the Standard ACH cutoff, it will be sent over Standard ACH rails and will not incur same-day charges; this will apply to both legs of the transfer if applicable. The transaction limit for a Same Day ACH transfer is $1,000,000. Authorization requests sent with an amount greater than $1,000,000 will fail. For transfers submitted as `rtp`, Plaid will automatically route between Real Time Payment rail by TCH or FedNow rails as necessary. If a transfer is submitted as `rtp` and the counterparty account is not eligible for RTP, the `/transfer/authorization/create` request will fail with an `INVALID_FIELD` error code. To pre-check to determine whether a counterparty account can support RTP, call `/transfer/capabilities/get` before calling `/transfer/authorization/create`. Wire transfers are currently in early availability. To request access to `wire` as a payment network, contact your Account Manager. For transfers submitted as `wire`, the `type` must be `credit`; wire debits are not supported. The cutoff to submit a wire payment is 6:30 PM Eastern Time on a business day; wires submitted after that time will be processed on the next business day. The transaction limit for a wire is $999,999.99. Authorization requests sent with an amount greater than $999,999.99 will fail.

Constant Summary collapse

TRANSFER_NETWORK =
[
  # TODO: Write general description for ACH
  ACH = 'ach'.freeze,

  # TODO: Write general description for SAMEDAYACH
  SAMEDAYACH = 'same-day-ach'.freeze,

  # TODO: Write general description for RTP
  RTP = 'rtp'.freeze,

  # TODO: Write general description for WIRE
  WIRE = 'wire'.freeze
].freeze

Class Method Summary collapse

Class Method Details

.from_value(value, default_value = ACH) ⇒ Object



52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/the_plaid_api/models/transfer_network.rb', line 52

def self.from_value(value, default_value = ACH)
  return default_value if value.nil?

  str = value.to_s.strip

  case str.downcase
  when 'ach' then ACH
  when 'samedayach' then SAMEDAYACH
  when 'rtp' then RTP
  when 'wire' then WIRE
  else
    default_value
  end
end

.validate(value) ⇒ Object



46
47
48
49
50
# File 'lib/the_plaid_api/models/transfer_network.rb', line 46

def self.validate(value)
  return false if value.nil?

  TRANSFER_NETWORK.include?(value)
end