Class: ThePlaidApi::TransferOriginatorCreateRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TransferOriginatorCreateRequest
- Defined in:
- lib/the_plaid_api/models/transfer_originator_create_request.rb
Overview
Defines the request schema for ‘/transfer/originator/create`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#company_name ⇒ String
The company name of the end customer being created.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(company_name:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ TransferOriginatorCreateRequest
constructor
A new instance of TransferOriginatorCreateRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(company_name:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ TransferOriginatorCreateRequest
Returns a new instance of TransferOriginatorCreateRequest.
50 51 52 53 54 55 56 57 58 59 |
# File 'lib/the_plaid_api/models/transfer_originator_create_request.rb', line 50 def initialize(company_name:, client_id: SKIP, secret: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @company_name = company_name @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/the_plaid_api/models/transfer_originator_create_request.rb', line 16 def client_id @client_id end |
#company_name ⇒ String
The company name of the end customer being created. This will be displayed in public-facing surfaces, e.g. Plaid Dashboard.
26 27 28 |
# File 'lib/the_plaid_api/models/transfer_originator_create_request.rb', line 26 def company_name @company_name end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
21 22 23 |
# File 'lib/the_plaid_api/models/transfer_originator_create_request.rb', line 21 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/the_plaid_api/models/transfer_originator_create_request.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. company_name = hash.key?('company_name') ? hash['company_name'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransferOriginatorCreateRequest.new(company_name: company_name, client_id: client_id, secret: secret, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 |
# File 'lib/the_plaid_api/models/transfer_originator_create_request.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['company_name'] = 'company_name' @_hash end |
.nullables ⇒ Object
An array for nullable fields
46 47 48 |
# File 'lib/the_plaid_api/models/transfer_originator_create_request.rb', line 46 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
38 39 40 41 42 43 |
# File 'lib/the_plaid_api/models/transfer_originator_create_request.rb', line 38 def self.optionals %w[ client_id secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
92 93 94 95 96 |
# File 'lib/the_plaid_api/models/transfer_originator_create_request.rb', line 92 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, company_name:"\ " #{@company_name.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
85 86 87 88 89 |
# File 'lib/the_plaid_api/models/transfer_originator_create_request.rb', line 85 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, company_name:"\ " #{@company_name}, additional_properties: #{@additional_properties}>" end |