Class: ThePlaidApi::TransferOriginatorFundingAccountCreateResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TransferOriginatorFundingAccountCreateResponse
- Defined in:
- lib/the_plaid_api/models/transfer_originator_funding_account_create_response.rb
Overview
Defines the response schema for ‘/transfer/originator/funding_account/create`
Instance Attribute Summary collapse
-
#funding_account_id ⇒ String
The id of the funding account to use, available in the Plaid Dashboard.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(request_id:, funding_account_id: SKIP, additional_properties: nil) ⇒ TransferOriginatorFundingAccountCreateResponse
constructor
A new instance of TransferOriginatorFundingAccountCreateResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(request_id:, funding_account_id: SKIP, additional_properties: nil) ⇒ TransferOriginatorFundingAccountCreateResponse
Returns a new instance of TransferOriginatorFundingAccountCreateResponse.
45 46 47 48 49 50 51 52 53 |
# File 'lib/the_plaid_api/models/transfer_originator_funding_account_create_response.rb', line 45 def initialize(request_id:, funding_account_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @funding_account_id = funding_account_id unless funding_account_id == SKIP @request_id = request_id @additional_properties = additional_properties end |
Instance Attribute Details
#funding_account_id ⇒ String
The id of the funding account to use, available in the Plaid Dashboard. This determines which of your business checking accounts will be credited or debited.
17 18 19 |
# File 'lib/the_plaid_api/models/transfer_originator_funding_account_create_response.rb', line 17 def funding_account_id @funding_account_id end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
23 24 25 |
# File 'lib/the_plaid_api/models/transfer_originator_funding_account_create_response.rb', line 23 def request_id @request_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/the_plaid_api/models/transfer_originator_funding_account_create_response.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. request_id = hash.key?('request_id') ? hash['request_id'] : nil funding_account_id = hash.key?('funding_account_id') ? hash['funding_account_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransferOriginatorFundingAccountCreateResponse.new(request_id: request_id, funding_account_id: funding_account_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 |
# File 'lib/the_plaid_api/models/transfer_originator_funding_account_create_response.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['funding_account_id'] = 'funding_account_id' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/the_plaid_api/models/transfer_originator_funding_account_create_response.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 |
# File 'lib/the_plaid_api/models/transfer_originator_funding_account_create_response.rb', line 34 def self.optionals %w[ funding_account_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 |
# File 'lib/the_plaid_api/models/transfer_originator_funding_account_create_response.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} funding_account_id: #{@funding_account_id.inspect}, request_id:"\ " #{@request_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/the_plaid_api/models/transfer_originator_funding_account_create_response.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} funding_account_id: #{@funding_account_id}, request_id: #{@request_id},"\ " additional_properties: #{@additional_properties}>" end |