Class: ThePlaidApi::TransferOriginatorFundingAccountUpdateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/transfer_originator_funding_account_update_request.rb

Overview

Defines the request schema for ‘/transfer/originator/funding_account/update`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(originator_client_id:, funding_account:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ TransferOriginatorFundingAccountUpdateRequest

Returns a new instance of TransferOriginatorFundingAccountUpdateRequest.



55
56
57
58
59
60
61
62
63
64
65
# File 'lib/the_plaid_api/models/transfer_originator_funding_account_update_request.rb', line 55

def initialize(originator_client_id:, funding_account:, client_id: SKIP,
               secret: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @originator_client_id = originator_client_id
  @funding_account = 
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/transfer_originator_funding_account_update_request.rb', line 16

def client_id
  @client_id
end

#funding_accountTransferFundingAccount

The originator’s funding account, linked with Plaid Link or ‘/transfer/migrate_account`.



30
31
32
# File 'lib/the_plaid_api/models/transfer_originator_funding_account_update_request.rb', line 30

def 
  @funding_account
end

#originator_client_idString

The Plaid client ID of the transfer originator.

Returns:

  • (String)


25
26
27
# File 'lib/the_plaid_api/models/transfer_originator_funding_account_update_request.rb', line 25

def originator_client_id
  @originator_client_id
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/transfer_originator_funding_account_update_request.rb', line 21

def secret
  @secret
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/the_plaid_api/models/transfer_originator_funding_account_update_request.rb', line 68

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  originator_client_id =
    hash.key?('originator_client_id') ? hash['originator_client_id'] : nil
   = TransferFundingAccount.from_hash(hash['funding_account']) if
    hash['funding_account']
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransferOriginatorFundingAccountUpdateRequest.new(originator_client_id: originator_client_id,
                                                    funding_account: ,
                                                    client_id: client_id,
                                                    secret: secret,
                                                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
# File 'lib/the_plaid_api/models/transfer_originator_funding_account_update_request.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['originator_client_id'] = 'originator_client_id'
  @_hash['funding_account'] = 'funding_account'
  @_hash
end

.nullablesObject

An array for nullable fields



51
52
53
# File 'lib/the_plaid_api/models/transfer_originator_funding_account_update_request.rb', line 51

def self.nullables
  []
end

.optionalsObject

An array for optional fields



43
44
45
46
47
48
# File 'lib/the_plaid_api/models/transfer_originator_funding_account_update_request.rb', line 43

def self.optionals
  %w[
    client_id
    secret
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



103
104
105
106
107
108
# File 'lib/the_plaid_api/models/transfer_originator_funding_account_update_request.rb', line 103

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\
  " originator_client_id: #{@originator_client_id.inspect}, funding_account:"\
  " #{@funding_account.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



95
96
97
98
99
100
# File 'lib/the_plaid_api/models/transfer_originator_funding_account_update_request.rb', line 95

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, originator_client_id:"\
  " #{@originator_client_id}, funding_account: #{@funding_account}, additional_properties:"\
  " #{@additional_properties}>"
end