Class: ThePlaidApi::TransferPlatformPersonIdNumber

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/transfer_platform_person_id_number.rb

Overview

ID number of the person

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(value:, type:, additional_properties: nil) ⇒ TransferPlatformPersonIdNumber

Returns a new instance of TransferPlatformPersonIdNumber.



42
43
44
45
46
47
48
49
# File 'lib/the_plaid_api/models/transfer_platform_person_id_number.rb', line 42

def initialize(value:, type:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @value = value
  @type = type
  @additional_properties = additional_properties
end

Instance Attribute Details

#typeIdNumberType

A globally unique and human readable ID type, specific to the country and document category. For more context on this field, see [Input Validation Rules](cognitohq.com/docs/flow/flow-hybrid-input-validation#id-num bers).

Returns:



22
23
24
# File 'lib/the_plaid_api/models/transfer_platform_person_id_number.rb', line 22

def type
  @type
end

#valueString

Value of the person’s ID Number. Alpha-numeric, with all formatting characters stripped.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/transfer_platform_person_id_number.rb', line 15

def value
  @value
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/the_plaid_api/models/transfer_platform_person_id_number.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  value = hash.key?('value') ? hash['value'] : nil
  type = hash.key?('type') ? hash['type'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransferPlatformPersonIdNumber.new(value: value,
                                     type: type,
                                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
# File 'lib/the_plaid_api/models/transfer_platform_person_id_number.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['value'] = 'value'
  @_hash['type'] = 'type'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/the_plaid_api/models/transfer_platform_person_id_number.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



33
34
35
# File 'lib/the_plaid_api/models/transfer_platform_person_id_number.rb', line 33

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/the_plaid_api/models/transfer_platform_person_id_number.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} value: #{@value.inspect}, type: #{@type.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/the_plaid_api/models/transfer_platform_person_id_number.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} value: #{@value}, type: #{@type}, additional_properties:"\
  " #{@additional_properties}>"
end