Class: ThePlaidApi::TransferPlatformPersonName

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/transfer_platform_person_name.rb

Overview

The person’s legal name

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(given_name:, family_name:, additional_properties: nil) ⇒ TransferPlatformPersonName

Returns a new instance of TransferPlatformPersonName.



40
41
42
43
44
45
46
47
# File 'lib/the_plaid_api/models/transfer_platform_person_name.rb', line 40

def initialize(given_name:, family_name:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @given_name = given_name
  @family_name = family_name
  @additional_properties = additional_properties
end

Instance Attribute Details

#family_nameString

A string with at least one non-whitespace character, with a max length of 100 characters.

Returns:

  • (String)


20
21
22
# File 'lib/the_plaid_api/models/transfer_platform_person_name.rb', line 20

def family_name
  @family_name
end

#given_nameString

A string with at least one non-whitespace character, with a max length of 100 characters.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/transfer_platform_person_name.rb', line 15

def given_name
  @given_name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/the_plaid_api/models/transfer_platform_person_name.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  given_name = hash.key?('given_name') ? hash['given_name'] : nil
  family_name = hash.key?('family_name') ? hash['family_name'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransferPlatformPersonName.new(given_name: given_name,
                                 family_name: family_name,
                                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/the_plaid_api/models/transfer_platform_person_name.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['given_name'] = 'given_name'
  @_hash['family_name'] = 'family_name'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
# File 'lib/the_plaid_api/models/transfer_platform_person_name.rb', line 36

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
# File 'lib/the_plaid_api/models/transfer_platform_person_name.rb', line 31

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
82
# File 'lib/the_plaid_api/models/transfer_platform_person_name.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} given_name: #{@given_name.inspect}, family_name: #{@family_name.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



71
72
73
74
75
# File 'lib/the_plaid_api/models/transfer_platform_person_name.rb', line 71

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} given_name: #{@given_name}, family_name: #{@family_name},"\
  " additional_properties: #{@additional_properties}>"
end