Class: ThePlaidApi::TransferRefundCreateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/transfer_refund_create_request.rb

Overview

Defines the request schema for ‘/transfer/refund/create`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(transfer_id:, amount:, idempotency_key:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ TransferRefundCreateRequest

Returns a new instance of TransferRefundCreateRequest.



66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/the_plaid_api/models/transfer_refund_create_request.rb', line 66

def initialize(transfer_id:, amount:, idempotency_key:, client_id: SKIP,
               secret: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @transfer_id = transfer_id
  @amount = amount
  @idempotency_key = idempotency_key
  @additional_properties = additional_properties
end

Instance Attribute Details

#amountString

The amount of the refund (decimal string with two digits of precision e.g. “10.00”).

Returns:

  • (String)


30
31
32
# File 'lib/the_plaid_api/models/transfer_refund_create_request.rb', line 30

def amount
  @amount
end

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/transfer_refund_create_request.rb', line 16

def client_id
  @client_id
end

#idempotency_keyString

A random key provided by the client, per unique refund. Maximum of 50 characters. The API supports idempotency for safely retrying requests without accidentally performing the same operation twice. For example, if a request to create a refund fails due to a network connection error, you can retry the request with the same idempotency key to guarantee that only a single refund is created.

Returns:

  • (String)


40
41
42
# File 'lib/the_plaid_api/models/transfer_refund_create_request.rb', line 40

def idempotency_key
  @idempotency_key
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/transfer_refund_create_request.rb', line 21

def secret
  @secret
end

#transfer_idString

The ID of the transfer to refund.

Returns:

  • (String)


25
26
27
# File 'lib/the_plaid_api/models/transfer_refund_create_request.rb', line 25

def transfer_id
  @transfer_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/the_plaid_api/models/transfer_refund_create_request.rb', line 80

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  transfer_id = hash.key?('transfer_id') ? hash['transfer_id'] : nil
  amount = hash.key?('amount') ? hash['amount'] : nil
  idempotency_key =
    hash.key?('idempotency_key') ? hash['idempotency_key'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransferRefundCreateRequest.new(transfer_id: transfer_id,
                                  amount: amount,
                                  idempotency_key: idempotency_key,
                                  client_id: client_id,
                                  secret: secret,
                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



43
44
45
46
47
48
49
50
51
# File 'lib/the_plaid_api/models/transfer_refund_create_request.rb', line 43

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['transfer_id'] = 'transfer_id'
  @_hash['amount'] = 'amount'
  @_hash['idempotency_key'] = 'idempotency_key'
  @_hash
end

.nullablesObject

An array for nullable fields



62
63
64
# File 'lib/the_plaid_api/models/transfer_refund_create_request.rb', line 62

def self.nullables
  []
end

.optionalsObject

An array for optional fields



54
55
56
57
58
59
# File 'lib/the_plaid_api/models/transfer_refund_create_request.rb', line 54

def self.optionals
  %w[
    client_id
    secret
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



116
117
118
119
120
121
# File 'lib/the_plaid_api/models/transfer_refund_create_request.rb', line 116

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, transfer_id:"\
  " #{@transfer_id.inspect}, amount: #{@amount.inspect}, idempotency_key:"\
  " #{@idempotency_key.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



108
109
110
111
112
113
# File 'lib/the_plaid_api/models/transfer_refund_create_request.rb', line 108

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, transfer_id: #{@transfer_id},"\
  " amount: #{@amount}, idempotency_key: #{@idempotency_key}, additional_properties:"\
  " #{@additional_properties}>"
end