Class: ThePlaidApi::TransferRefundCreateResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TransferRefundCreateResponse
- Defined in:
- lib/the_plaid_api/models/transfer_refund_create_response.rb
Overview
Defines the response schema for ‘/transfer/refund/create`
Instance Attribute Summary collapse
-
#refund ⇒ TransferRefund
Represents a refund within the Transfers API.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(refund:, request_id:, additional_properties: nil) ⇒ TransferRefundCreateResponse
constructor
A new instance of TransferRefundCreateResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(refund:, request_id:, additional_properties: nil) ⇒ TransferRefundCreateResponse
Returns a new instance of TransferRefundCreateResponse.
40 41 42 43 44 45 46 47 |
# File 'lib/the_plaid_api/models/transfer_refund_create_response.rb', line 40 def initialize(refund:, request_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @refund = refund @request_id = request_id @additional_properties = additional_properties end |
Instance Attribute Details
#refund ⇒ TransferRefund
Represents a refund within the Transfers API.
14 15 16 |
# File 'lib/the_plaid_api/models/transfer_refund_create_response.rb', line 14 def refund @refund end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
20 21 22 |
# File 'lib/the_plaid_api/models/transfer_refund_create_response.rb', line 20 def request_id @request_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/the_plaid_api/models/transfer_refund_create_response.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. refund = TransferRefund.from_hash(hash['refund']) if hash['refund'] request_id = hash.key?('request_id') ? hash['request_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransferRefundCreateResponse.new(refund: refund, request_id: request_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/the_plaid_api/models/transfer_refund_create_response.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['refund'] = 'refund' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/the_plaid_api/models/transfer_refund_create_response.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 |
# File 'lib/the_plaid_api/models/transfer_refund_create_response.rb', line 31 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/the_plaid_api/models/transfer_refund_create_response.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} refund: #{@refund.inspect}, request_id: #{@request_id.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/the_plaid_api/models/transfer_refund_create_response.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} refund: #{@refund}, request_id: #{@request_id}, additional_properties:"\ " #{@additional_properties}>" end |