Class: ThePlaidApi::TransferRepaymentReturn

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/transfer_repayment_return.rb

Overview

Represents a return on a Guaranteed ACH transfer that is included in the specified repayment.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(transfer_id:, event_id:, amount:, iso_currency_code:, additional_properties: nil) ⇒ TransferRepaymentReturn

Returns a new instance of TransferRepaymentReturn.



49
50
51
52
53
54
55
56
57
58
59
# File 'lib/the_plaid_api/models/transfer_repayment_return.rb', line 49

def initialize(transfer_id:, event_id:, amount:, iso_currency_code:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @transfer_id = transfer_id
  @event_id = event_id
  @amount = amount
  @iso_currency_code = iso_currency_code
  @additional_properties = additional_properties
end

Instance Attribute Details

#amountString

The value of the returned transfer.

Returns:

  • (String)


23
24
25
# File 'lib/the_plaid_api/models/transfer_repayment_return.rb', line 23

def amount
  @amount
end

#event_idInteger

The unique identifier of the corresponding ‘returned` transfer event.

Returns:

  • (Integer)


19
20
21
# File 'lib/the_plaid_api/models/transfer_repayment_return.rb', line 19

def event_id
  @event_id
end

#iso_currency_codeString

The currency of the repayment, e.g. “USD”.

Returns:

  • (String)


27
28
29
# File 'lib/the_plaid_api/models/transfer_repayment_return.rb', line 27

def iso_currency_code
  @iso_currency_code
end

#transfer_idString

The unique identifier of the guaranteed transfer that was returned.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/transfer_repayment_return.rb', line 15

def transfer_id
  @transfer_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/the_plaid_api/models/transfer_repayment_return.rb', line 62

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  transfer_id = hash.key?('transfer_id') ? hash['transfer_id'] : nil
  event_id = hash.key?('event_id') ? hash['event_id'] : nil
  amount = hash.key?('amount') ? hash['amount'] : nil
  iso_currency_code =
    hash.key?('iso_currency_code') ? hash['iso_currency_code'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransferRepaymentReturn.new(transfer_id: transfer_id,
                              event_id: event_id,
                              amount: amount,
                              iso_currency_code: iso_currency_code,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



30
31
32
33
34
35
36
37
# File 'lib/the_plaid_api/models/transfer_repayment_return.rb', line 30

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['transfer_id'] = 'transfer_id'
  @_hash['event_id'] = 'event_id'
  @_hash['amount'] = 'amount'
  @_hash['iso_currency_code'] = 'iso_currency_code'
  @_hash
end

.nullablesObject

An array for nullable fields



45
46
47
# File 'lib/the_plaid_api/models/transfer_repayment_return.rb', line 45

def self.nullables
  []
end

.optionalsObject

An array for optional fields



40
41
42
# File 'lib/the_plaid_api/models/transfer_repayment_return.rb', line 40

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



96
97
98
99
100
101
# File 'lib/the_plaid_api/models/transfer_repayment_return.rb', line 96

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} transfer_id: #{@transfer_id.inspect}, event_id: #{@event_id.inspect},"\
  " amount: #{@amount.inspect}, iso_currency_code: #{@iso_currency_code.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



88
89
90
91
92
93
# File 'lib/the_plaid_api/models/transfer_repayment_return.rb', line 88

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} transfer_id: #{@transfer_id}, event_id: #{@event_id}, amount: #{@amount},"\
  " iso_currency_code: #{@iso_currency_code}, additional_properties:"\
  " #{@additional_properties}>"
end