Class: ThePlaidApi::TransferRepaymentReturnListRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/transfer_repayment_return_list_request.rb

Overview

Defines the request schema for ‘/transfer/repayment/return/list`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(repayment_id:, client_id: SKIP, secret: SKIP, count: 25, offset: 0, additional_properties: nil) ⇒ TransferRepaymentReturnListRequest

Returns a new instance of TransferRepaymentReturnListRequest.



63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/the_plaid_api/models/transfer_repayment_return_list_request.rb', line 63

def initialize(repayment_id:, client_id: SKIP, secret: SKIP, count: 25,
               offset: 0, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @repayment_id = repayment_id
  @count = count unless count == SKIP
  @offset = offset unless offset == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/transfer_repayment_return_list_request.rb', line 16

def client_id
  @client_id
end

#countInteger

The maximum number of repayments to return.

Returns:

  • (Integer)


29
30
31
# File 'lib/the_plaid_api/models/transfer_repayment_return_list_request.rb', line 29

def count
  @count
end

#offsetInteger

The number of repayments to skip before returning results.

Returns:

  • (Integer)


33
34
35
# File 'lib/the_plaid_api/models/transfer_repayment_return_list_request.rb', line 33

def offset
  @offset
end

#repayment_idString

Identifier of the repayment to query.

Returns:

  • (String)


25
26
27
# File 'lib/the_plaid_api/models/transfer_repayment_return_list_request.rb', line 25

def repayment_id
  @repayment_id
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/transfer_repayment_return_list_request.rb', line 21

def secret
  @secret
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/the_plaid_api/models/transfer_repayment_return_list_request.rb', line 77

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  repayment_id = hash.key?('repayment_id') ? hash['repayment_id'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  count = hash['count'] ||= 25
  offset = hash['offset'] ||= 0

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransferRepaymentReturnListRequest.new(repayment_id: repayment_id,
                                         client_id: client_id,
                                         secret: secret,
                                         count: count,
                                         offset: offset,
                                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



36
37
38
39
40
41
42
43
44
# File 'lib/the_plaid_api/models/transfer_repayment_return_list_request.rb', line 36

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['repayment_id'] = 'repayment_id'
  @_hash['count'] = 'count'
  @_hash['offset'] = 'offset'
  @_hash
end

.nullablesObject

An array for nullable fields



57
58
59
60
61
# File 'lib/the_plaid_api/models/transfer_repayment_return_list_request.rb', line 57

def self.nullables
  %w[
    count
  ]
end

.optionalsObject

An array for optional fields



47
48
49
50
51
52
53
54
# File 'lib/the_plaid_api/models/transfer_repayment_return_list_request.rb', line 47

def self.optionals
  %w[
    client_id
    secret
    count
    offset
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



112
113
114
115
116
117
# File 'lib/the_plaid_api/models/transfer_repayment_return_list_request.rb', line 112

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, repayment_id:"\
  " #{@repayment_id.inspect}, count: #{@count.inspect}, offset: #{@offset.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



104
105
106
107
108
109
# File 'lib/the_plaid_api/models/transfer_repayment_return_list_request.rb', line 104

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, repayment_id:"\
  " #{@repayment_id}, count: #{@count}, offset: #{@offset}, additional_properties:"\
  " #{@additional_properties}>"
end