Class: ThePlaidApi::TransferWireDetails

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/transfer_wire_details.rb

Overview

Information specific to wire transfers.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(message_to_beneficiary: SKIP, wire_return_fee: SKIP, additional_properties: nil) ⇒ TransferWireDetails

Returns a new instance of TransferWireDetails.



46
47
48
49
50
51
52
53
54
# File 'lib/the_plaid_api/models/transfer_wire_details.rb', line 46

def initialize(message_to_beneficiary: SKIP, wire_return_fee: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @message_to_beneficiary = message_to_beneficiary unless message_to_beneficiary == SKIP
  @wire_return_fee = wire_return_fee unless wire_return_fee == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#message_to_beneficiaryString

Additional information from the wire originator to the beneficiary. Max 140 characters.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/transfer_wire_details.rb', line 15

def message_to_beneficiary
  @message_to_beneficiary
end

#wire_return_feeString

The fee amount deducted from the original transfer during a wire return, if applicable.

Returns:

  • (String)


20
21
22
# File 'lib/the_plaid_api/models/transfer_wire_details.rb', line 20

def wire_return_fee
  @wire_return_fee
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/the_plaid_api/models/transfer_wire_details.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  message_to_beneficiary =
    hash.key?('message_to_beneficiary') ? hash['message_to_beneficiary'] : SKIP
  wire_return_fee =
    hash.key?('wire_return_fee') ? hash['wire_return_fee'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransferWireDetails.new(message_to_beneficiary: message_to_beneficiary,
                          wire_return_fee: wire_return_fee,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/the_plaid_api/models/transfer_wire_details.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['message_to_beneficiary'] = 'message_to_beneficiary'
  @_hash['wire_return_fee'] = 'wire_return_fee'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
42
43
44
# File 'lib/the_plaid_api/models/transfer_wire_details.rb', line 39

def self.nullables
  %w[
    message_to_beneficiary
    wire_return_fee
  ]
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/the_plaid_api/models/transfer_wire_details.rb', line 31

def self.optionals
  %w[
    message_to_beneficiary
    wire_return_fee
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



87
88
89
90
91
92
# File 'lib/the_plaid_api/models/transfer_wire_details.rb', line 87

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} message_to_beneficiary: #{@message_to_beneficiary.inspect},"\
  " wire_return_fee: #{@wire_return_fee.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



80
81
82
83
84
# File 'lib/the_plaid_api/models/transfer_wire_details.rb', line 80

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} message_to_beneficiary: #{@message_to_beneficiary}, wire_return_fee:"\
  " #{@wire_return_fee}, additional_properties: #{@additional_properties}>"
end