Class: ThePlaidApi::TrustIndexSubscores
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TrustIndexSubscores
- Defined in:
- lib/the_plaid_api/models/trust_index_subscores.rb
Overview
Contains sub-score metadata.
Instance Attribute Summary collapse
-
#bank_account_insights ⇒ TrustIndexSubscore
Represents Trust Index Subscore.
-
#device_and_connection ⇒ TrustIndexSubscore
Represents Trust Index Subscore.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_and_connection: SKIP, bank_account_insights: SKIP, additional_properties: nil) ⇒ TrustIndexSubscores
constructor
A new instance of TrustIndexSubscores.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_and_connection: SKIP, bank_account_insights: SKIP, additional_properties: nil) ⇒ TrustIndexSubscores
Returns a new instance of TrustIndexSubscores.
44 45 46 47 48 49 50 51 52 |
# File 'lib/the_plaid_api/models/trust_index_subscores.rb', line 44 def initialize(device_and_connection: SKIP, bank_account_insights: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @device_and_connection = device_and_connection unless device_and_connection == SKIP @bank_account_insights = bank_account_insights unless bank_account_insights == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#bank_account_insights ⇒ TrustIndexSubscore
Represents Trust Index Subscore.
18 19 20 |
# File 'lib/the_plaid_api/models/trust_index_subscores.rb', line 18 def bank_account_insights @bank_account_insights end |
#device_and_connection ⇒ TrustIndexSubscore
Represents Trust Index Subscore.
14 15 16 |
# File 'lib/the_plaid_api/models/trust_index_subscores.rb', line 14 def device_and_connection @device_and_connection end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/the_plaid_api/models/trust_index_subscores.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. device_and_connection = TrustIndexSubscore.from_hash(hash['device_and_connection']) if hash['device_and_connection'] bank_account_insights = TrustIndexSubscore.from_hash(hash['bank_account_insights']) if hash['bank_account_insights'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TrustIndexSubscores.new(device_and_connection: device_and_connection, bank_account_insights: bank_account_insights, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/the_plaid_api/models/trust_index_subscores.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['device_and_connection'] = 'device_and_connection' @_hash['bank_account_insights'] = 'bank_account_insights' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 40 41 42 |
# File 'lib/the_plaid_api/models/trust_index_subscores.rb', line 37 def self.nullables %w[ device_and_connection bank_account_insights ] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/the_plaid_api/models/trust_index_subscores.rb', line 29 def self.optionals %w[ device_and_connection bank_account_insights ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 90 |
# File 'lib/the_plaid_api/models/trust_index_subscores.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_and_connection: #{@device_and_connection.inspect},"\ " bank_account_insights: #{@bank_account_insights.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/the_plaid_api/models/trust_index_subscores.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_and_connection: #{@device_and_connection}, bank_account_insights:"\ " #{@bank_account_insights}, additional_properties: #{@additional_properties}>" end |