Class: ThePlaidApi::TrustedDeviceData

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/trusted_device_data.rb

Overview

Trusted Device data associated with the previous Link session.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(trust_level: SKIP, device_id: SKIP, additional_properties: nil) ⇒ TrustedDeviceData

Returns a new instance of TrustedDeviceData.



41
42
43
44
45
46
47
48
49
# File 'lib/the_plaid_api/models/trusted_device_data.rb', line 41

def initialize(trust_level: SKIP, device_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @trust_level = trust_level unless trust_level == SKIP
  @device_id = device_id unless device_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#device_idDeviceId

Device Id associated with the device used during the previous link session

Returns:



18
19
20
# File 'lib/the_plaid_api/models/trusted_device_data.rb', line 18

def device_id
  @device_id
end

#trust_levelInteger

TODO: Write general description for this method

Returns:

  • (Integer)


14
15
16
# File 'lib/the_plaid_api/models/trusted_device_data.rb', line 14

def trust_level
  @trust_level
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/the_plaid_api/models/trusted_device_data.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  trust_level = hash.key?('trust_level') ? hash['trust_level'] : SKIP
  device_id = DeviceId.from_hash(hash['device_id']) if hash['device_id']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TrustedDeviceData.new(trust_level: trust_level,
                        device_id: device_id,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/the_plaid_api/models/trusted_device_data.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['trust_level'] = 'trust_level'
  @_hash['device_id'] = 'device_id'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/the_plaid_api/models/trusted_device_data.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/the_plaid_api/models/trusted_device_data.rb', line 29

def self.optionals
  %w[
    trust_level
    device_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/the_plaid_api/models/trusted_device_data.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} trust_level: #{@trust_level.inspect}, device_id: #{@device_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/the_plaid_api/models/trusted_device_data.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} trust_level: #{@trust_level}, device_id: #{@device_id},"\
  " additional_properties: #{@additional_properties}>"
end