Class: ThePlaidApi::UpdateIndividualScreeningRequestSearchTerms
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::UpdateIndividualScreeningRequestSearchTerms
- Defined in:
- lib/the_plaid_api/models/update_individual_screening_request_search_terms.rb
Overview
Search terms for editing an individual watchlist screening
Instance Attribute Summary collapse
-
#country ⇒ String
Valid, capitalized, two-letter ISO code representing the country of this object.
-
#date_of_birth ⇒ Date
A date in the format YYYY-MM-DD (RFC 3339 Section 5.6).
-
#document_number ⇒ String
The numeric or alphanumeric identifier associated with this document.
-
#legal_name ⇒ String
The legal name of the individual being screened.
-
#watchlist_program_id ⇒ String
ID of the associated program.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(watchlist_program_id: SKIP, legal_name: SKIP, date_of_birth: SKIP, document_number: SKIP, country: SKIP, additional_properties: nil) ⇒ UpdateIndividualScreeningRequestSearchTerms
constructor
A new instance of UpdateIndividualScreeningRequestSearchTerms.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(watchlist_program_id: SKIP, legal_name: SKIP, date_of_birth: SKIP, document_number: SKIP, country: SKIP, additional_properties: nil) ⇒ UpdateIndividualScreeningRequestSearchTerms
Returns a new instance of UpdateIndividualScreeningRequestSearchTerms.
64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/the_plaid_api/models/update_individual_screening_request_search_terms.rb', line 64 def initialize(watchlist_program_id: SKIP, legal_name: SKIP, date_of_birth: SKIP, document_number: SKIP, country: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @watchlist_program_id = watchlist_program_id unless watchlist_program_id == SKIP @legal_name = legal_name unless legal_name == SKIP @date_of_birth = date_of_birth unless date_of_birth == SKIP @document_number = document_number unless document_number == SKIP @country = country unless country == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#country ⇒ String
Valid, capitalized, two-letter ISO code representing the country of this object. Must be in ISO 3166-1 alpha-2 form.
35 36 37 |
# File 'lib/the_plaid_api/models/update_individual_screening_request_search_terms.rb', line 35 def country @country end |
#date_of_birth ⇒ Date
A date in the format YYYY-MM-DD (RFC 3339 Section 5.6).
24 25 26 |
# File 'lib/the_plaid_api/models/update_individual_screening_request_search_terms.rb', line 24 def date_of_birth @date_of_birth end |
#document_number ⇒ String
The numeric or alphanumeric identifier associated with this document. Must be between 4 and 32 characters long, and cannot have leading or trailing spaces.
30 31 32 |
# File 'lib/the_plaid_api/models/update_individual_screening_request_search_terms.rb', line 30 def document_number @document_number end |
#legal_name ⇒ String
The legal name of the individual being screened. Must have at least one alphabetical character, have a maximum length of 100 characters, and not include leading or trailing spaces.
20 21 22 |
# File 'lib/the_plaid_api/models/update_individual_screening_request_search_terms.rb', line 20 def legal_name @legal_name end |
#watchlist_program_id ⇒ String
ID of the associated program.
14 15 16 |
# File 'lib/the_plaid_api/models/update_individual_screening_request_search_terms.rb', line 14 def watchlist_program_id @watchlist_program_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/the_plaid_api/models/update_individual_screening_request_search_terms.rb', line 79 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. watchlist_program_id = hash.key?('watchlist_program_id') ? hash['watchlist_program_id'] : SKIP legal_name = hash.key?('legal_name') ? hash['legal_name'] : SKIP date_of_birth = hash.key?('date_of_birth') ? hash['date_of_birth'] : SKIP document_number = hash.key?('document_number') ? hash['document_number'] : SKIP country = hash.key?('country') ? hash['country'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UpdateIndividualScreeningRequestSearchTerms.new(watchlist_program_id: watchlist_program_id, legal_name: legal_name, date_of_birth: date_of_birth, document_number: document_number, country: country, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
38 39 40 41 42 43 44 45 46 |
# File 'lib/the_plaid_api/models/update_individual_screening_request_search_terms.rb', line 38 def self.names @_hash = {} if @_hash.nil? @_hash['watchlist_program_id'] = 'watchlist_program_id' @_hash['legal_name'] = 'legal_name' @_hash['date_of_birth'] = 'date_of_birth' @_hash['document_number'] = 'document_number' @_hash['country'] = 'country' @_hash end |
.nullables ⇒ Object
An array for nullable fields
60 61 62 |
# File 'lib/the_plaid_api/models/update_individual_screening_request_search_terms.rb', line 60 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 52 53 54 55 56 57 |
# File 'lib/the_plaid_api/models/update_individual_screening_request_search_terms.rb', line 49 def self.optionals %w[ watchlist_program_id legal_name date_of_birth document_number country ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
116 117 118 119 120 121 122 |
# File 'lib/the_plaid_api/models/update_individual_screening_request_search_terms.rb', line 116 def inspect class_name = self.class.name.split('::').last "<#{class_name} watchlist_program_id: #{@watchlist_program_id.inspect}, legal_name:"\ " #{@legal_name.inspect}, date_of_birth: #{@date_of_birth.inspect}, document_number:"\ " #{@document_number.inspect}, country: #{@country.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
108 109 110 111 112 113 |
# File 'lib/the_plaid_api/models/update_individual_screening_request_search_terms.rb', line 108 def to_s class_name = self.class.name.split('::').last "<#{class_name} watchlist_program_id: #{@watchlist_program_id}, legal_name: #{@legal_name},"\ " date_of_birth: #{@date_of_birth}, document_number: #{@document_number}, country:"\ " #{@country}, additional_properties: #{@additional_properties}>" end |