Class: ThePlaidApi::UserAccountIdentityOfficialDocument
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::UserAccountIdentityOfficialDocument
- Defined in:
- lib/the_plaid_api/models/user_account_identity_official_document.rb
Overview
Official identity document edit statistics.
Instance Attribute Summary collapse
-
#ssn ⇒ UserAccountIdentityEditCounts
Edit counts over various time periods.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(ssn: SKIP, additional_properties: nil) ⇒ UserAccountIdentityOfficialDocument
constructor
A new instance of UserAccountIdentityOfficialDocument.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(ssn: SKIP, additional_properties: nil) ⇒ UserAccountIdentityOfficialDocument
Returns a new instance of UserAccountIdentityOfficialDocument.
35 36 37 38 39 40 41 |
# File 'lib/the_plaid_api/models/user_account_identity_official_document.rb', line 35 def initialize(ssn: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @ssn = ssn unless ssn == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#ssn ⇒ UserAccountIdentityEditCounts
Edit counts over various time periods.
14 15 16 |
# File 'lib/the_plaid_api/models/user_account_identity_official_document.rb', line 14 def ssn @ssn end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/the_plaid_api/models/user_account_identity_official_document.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. ssn = UserAccountIdentityEditCounts.from_hash(hash['ssn']) if hash['ssn'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UserAccountIdentityOfficialDocument.new(ssn: ssn, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/the_plaid_api/models/user_account_identity_official_document.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['ssn'] = 'ssn' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/the_plaid_api/models/user_account_identity_official_document.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/the_plaid_api/models/user_account_identity_official_document.rb', line 24 def self.optionals %w[ ssn ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
69 70 71 72 |
# File 'lib/the_plaid_api/models/user_account_identity_official_document.rb', line 69 def inspect class_name = self.class.name.split('::').last "<#{class_name} ssn: #{@ssn.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
63 64 65 66 |
# File 'lib/the_plaid_api/models/user_account_identity_official_document.rb', line 63 def to_s class_name = self.class.name.split('::').last "<#{class_name} ssn: #{@ssn}, additional_properties: #{@additional_properties}>" end |