Class: ThePlaidApi::UserAddress

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/user_address.rb

Overview

Home address for the user. Supported values are: not provided, address with only country code or full address. For more context on this field, see [Input Validation by Country](plaid.com/docs/identity-verification/hybrid-input-validatio n/#input-validation-by-country).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(country:, street: SKIP, street2: SKIP, city: SKIP, region: SKIP, postal_code: SKIP, additional_properties: nil) ⇒ UserAddress

Returns a new instance of UserAddress.



86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/the_plaid_api/models/user_address.rb', line 86

def initialize(country:, street: SKIP, street2: SKIP, city: SKIP,
               region: SKIP, postal_code: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @street = street unless street == SKIP
  @street2 = street2 unless street2 == SKIP
  @city = city unless city == SKIP
  @region = region unless region == SKIP
  @postal_code = postal_code unless postal_code == SKIP
  @country = country
  @additional_properties = additional_properties
end

Instance Attribute Details

#cityString

City from the address. A string with at least one non-whitespace alphabetical character, with a max length of 100 characters.

Returns:

  • (String)


31
32
33
# File 'lib/the_plaid_api/models/user_address.rb', line 31

def city
  @city
end

#countryString

Valid, capitalized, two-letter ISO code representing the country of this object. Must be in ISO 3166-1 alpha-2 form.

Returns:

  • (String)


50
51
52
# File 'lib/the_plaid_api/models/user_address.rb', line 50

def country
  @country
end

#postal_codeString

The postal code for the associated address. Between 2 and 10 alphanumeric characters. For US-based addresses this must be 5 numeric digits.

Returns:

  • (String)


45
46
47
# File 'lib/the_plaid_api/models/user_address.rb', line 45

def postal_code
  @postal_code
end

#regionString

A subdivision code. “Subdivision” is a generic term for “state”, “province”, “prefecture”, “zone”, etc. For the list of valid codes, see [country subdivision codes](plaid.com/documents/country_subdivision_codes.json). Country prefixes are omitted, since they are inferred from the ‘country` field.

Returns:

  • (String)


40
41
42
# File 'lib/the_plaid_api/models/user_address.rb', line 40

def region
  @region
end

#streetString

The primary street portion of an address. If an address is provided, this field will always be filled. A string with at least one non-whitespace alphabetical character, with a max length of 80 characters.

Returns:

  • (String)


20
21
22
# File 'lib/the_plaid_api/models/user_address.rb', line 20

def street
  @street
end

#street2String

Extra street information, like an apartment or suite number. If provided, a string with at least one non-whitespace character, with a max length of 50 characters.

Returns:

  • (String)


26
27
28
# File 'lib/the_plaid_api/models/user_address.rb', line 26

def street2
  @street2
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/the_plaid_api/models/user_address.rb', line 101

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  country = hash.key?('country') ? hash['country'] : nil
  street = hash.key?('street') ? hash['street'] : SKIP
  street2 = hash.key?('street2') ? hash['street2'] : SKIP
  city = hash.key?('city') ? hash['city'] : SKIP
  region = hash.key?('region') ? hash['region'] : SKIP
  postal_code = hash.key?('postal_code') ? hash['postal_code'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UserAddress.new(country: country,
                  street: street,
                  street2: street2,
                  city: city,
                  region: region,
                  postal_code: postal_code,
                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



53
54
55
56
57
58
59
60
61
62
# File 'lib/the_plaid_api/models/user_address.rb', line 53

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['street'] = 'street'
  @_hash['street2'] = 'street2'
  @_hash['city'] = 'city'
  @_hash['region'] = 'region'
  @_hash['postal_code'] = 'postal_code'
  @_hash['country'] = 'country'
  @_hash
end

.nullablesObject

An array for nullable fields



76
77
78
79
80
81
82
83
84
# File 'lib/the_plaid_api/models/user_address.rb', line 76

def self.nullables
  %w[
    street
    street2
    city
    region
    postal_code
  ]
end

.optionalsObject

An array for optional fields



65
66
67
68
69
70
71
72
73
# File 'lib/the_plaid_api/models/user_address.rb', line 65

def self.optionals
  %w[
    street
    street2
    city
    region
    postal_code
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



138
139
140
141
142
143
# File 'lib/the_plaid_api/models/user_address.rb', line 138

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} street: #{@street.inspect}, street2: #{@street2.inspect}, city:"\
  " #{@city.inspect}, region: #{@region.inspect}, postal_code: #{@postal_code.inspect},"\
  " country: #{@country.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



130
131
132
133
134
135
# File 'lib/the_plaid_api/models/user_address.rb', line 130

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} street: #{@street}, street2: #{@street2}, city: #{@city}, region:"\
  " #{@region}, postal_code: #{@postal_code}, country: #{@country}, additional_properties:"\
  " #{@additional_properties}>"
end