Class: ThePlaidApi::UserCreateResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/user_create_response.rb

Overview

UserCreateResponse defines the response schema for ‘/user/create`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(user_id:, request_id:, user_token: SKIP, additional_properties: nil) ⇒ UserCreateResponse

Returns a new instance of UserCreateResponse.



54
55
56
57
58
59
60
61
62
63
# File 'lib/the_plaid_api/models/user_create_response.rb', line 54

def initialize(user_id:, request_id:, user_token: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @user_token = user_token unless user_token == SKIP
  @user_id = user_id
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


31
32
33
# File 'lib/the_plaid_api/models/user_create_response.rb', line 31

def request_id
  @request_id
end

#user_idString

A unique user identifier, created by ‘/user/create`. Integrations that began using `/user/create` after December 10, 2025 use this field to identify a user instead of the `user_token`. For more details, see [new user APIs](plaid.com/docs/api/users/user-apis).

Returns:

  • (String)


25
26
27
# File 'lib/the_plaid_api/models/user_create_response.rb', line 25

def user_id
  @user_id
end

#user_tokenString

The user token associated with the User data is being requested for. This field is used only by customers with pre-existing integrations that already use the ‘user_token` field. All other customers should use the `user_id` instead. For more details, see [New User APIs](plaid.com/docs/api/users/user-apis).

Returns:

  • (String)


18
19
20
# File 'lib/the_plaid_api/models/user_create_response.rb', line 18

def user_token
  @user_token
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/the_plaid_api/models/user_create_response.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  user_id = hash.key?('user_id') ? hash['user_id'] : nil
  request_id = hash.key?('request_id') ? hash['request_id'] : nil
  user_token = hash.key?('user_token') ? hash['user_token'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UserCreateResponse.new(user_id: user_id,
                         request_id: request_id,
                         user_token: user_token,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



34
35
36
37
38
39
40
# File 'lib/the_plaid_api/models/user_create_response.rb', line 34

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['user_token'] = 'user_token'
  @_hash['user_id'] = 'user_id'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



50
51
52
# File 'lib/the_plaid_api/models/user_create_response.rb', line 50

def self.nullables
  []
end

.optionalsObject

An array for optional fields



43
44
45
46
47
# File 'lib/the_plaid_api/models/user_create_response.rb', line 43

def self.optionals
  %w[
    user_token
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



96
97
98
99
100
# File 'lib/the_plaid_api/models/user_create_response.rb', line 96

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} user_token: #{@user_token.inspect}, user_id: #{@user_id.inspect},"\
  " request_id: #{@request_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



89
90
91
92
93
# File 'lib/the_plaid_api/models/user_create_response.rb', line 89

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} user_token: #{@user_token}, user_id: #{@user_id}, request_id:"\
  " #{@request_id}, additional_properties: #{@additional_properties}>"
end