Class: ThePlaidApi::UserFinancialDataRefreshResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::UserFinancialDataRefreshResponse
- Defined in:
- lib/the_plaid_api/models/user_financial_data_refresh_response.rb
Overview
UserFinancialDataRefreshResponse defines the response schema for ‘user/financial_data/refresh`
Instance Attribute Summary collapse
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
-
#results ⇒ Array[RefreshResult]
The user ID associated with the refresh request.
-
#user_id ⇒ String
The user ID associated with the refresh request.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(request_id: SKIP, user_id: SKIP, results: SKIP, additional_properties: nil) ⇒ UserFinancialDataRefreshResponse
constructor
A new instance of UserFinancialDataRefreshResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(request_id: SKIP, user_id: SKIP, results: SKIP, additional_properties: nil) ⇒ UserFinancialDataRefreshResponse
Returns a new instance of UserFinancialDataRefreshResponse.
50 51 52 53 54 55 56 57 58 59 |
# File 'lib/the_plaid_api/models/user_financial_data_refresh_response.rb', line 50 def initialize(request_id: SKIP, user_id: SKIP, results: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @request_id = request_id unless request_id == SKIP @user_id = user_id unless user_id == SKIP @results = results unless results == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
17 18 19 |
# File 'lib/the_plaid_api/models/user_financial_data_refresh_response.rb', line 17 def request_id @request_id end |
#results ⇒ Array[RefreshResult]
The user ID associated with the refresh request.
25 26 27 |
# File 'lib/the_plaid_api/models/user_financial_data_refresh_response.rb', line 25 def results @results end |
#user_id ⇒ String
The user ID associated with the refresh request.
21 22 23 |
# File 'lib/the_plaid_api/models/user_financial_data_refresh_response.rb', line 21 def user_id @user_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/the_plaid_api/models/user_financial_data_refresh_response.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. request_id = hash.key?('request_id') ? hash['request_id'] : SKIP user_id = hash.key?('user_id') ? hash['user_id'] : SKIP # Parameter is an array, so we need to iterate through it results = nil unless hash['results'].nil? results = [] hash['results'].each do |structure| results << (RefreshResult.from_hash(structure) if structure) end end results = SKIP unless hash.key?('results') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UserFinancialDataRefreshResponse.new(request_id: request_id, user_id: user_id, results: results, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
28 29 30 31 32 33 34 |
# File 'lib/the_plaid_api/models/user_financial_data_refresh_response.rb', line 28 def self.names @_hash = {} if @_hash.nil? @_hash['request_id'] = 'request_id' @_hash['user_id'] = 'user_id' @_hash['results'] = 'results' @_hash end |
.nullables ⇒ Object
An array for nullable fields
46 47 48 |
# File 'lib/the_plaid_api/models/user_financial_data_refresh_response.rb', line 46 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
37 38 39 40 41 42 43 |
# File 'lib/the_plaid_api/models/user_financial_data_refresh_response.rb', line 37 def self.optionals %w[ request_id user_id results ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
101 102 103 104 105 |
# File 'lib/the_plaid_api/models/user_financial_data_refresh_response.rb', line 101 def inspect class_name = self.class.name.split('::').last "<#{class_name} request_id: #{@request_id.inspect}, user_id: #{@user_id.inspect}, results:"\ " #{@results.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
94 95 96 97 98 |
# File 'lib/the_plaid_api/models/user_financial_data_refresh_response.rb', line 94 def to_s class_name = self.class.name.split('::').last "<#{class_name} request_id: #{@request_id}, user_id: #{@user_id}, results: #{@results},"\ " additional_properties: #{@additional_properties}>" end |