Class: ThePlaidApi::UserIdNumber

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/user_id_number.rb

Overview

ID number submitted by the user, currently used only for the Identity Verification product. If the user has not submitted this data yet, this field will be ‘null`. Otherwise, both fields are guaranteed to be filled.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(value:, type:, additional_properties: nil) ⇒ UserIdNumber

Returns a new instance of UserIdNumber.



47
48
49
50
51
52
53
54
# File 'lib/the_plaid_api/models/user_id_number.rb', line 47

def initialize(value:, type:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @value = value
  @type = type
  @additional_properties = additional_properties
end

Instance Attribute Details

#typeIdNumberType

A globally unique and human readable ID type, specific to the country and document category. For more context on this field, see [Input Validation Rules](cognitohq.com/docs/flow/flow-hybrid-input-validation#id-num bers).

Returns:



27
28
29
# File 'lib/the_plaid_api/models/user_id_number.rb', line 27

def type
  @type
end

#valueString

Value of identity document value typed in by user. Alpha-numeric, with all formatting characters stripped. For specific format requirements by ID type, see [Input Validation Rules](plaid.com/docs/identity-verification/hybrid-input-validatio n/#id-numbers).

Returns:

  • (String)


20
21
22
# File 'lib/the_plaid_api/models/user_id_number.rb', line 20

def value
  @value
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/the_plaid_api/models/user_id_number.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  value = hash.key?('value') ? hash['value'] : nil
  type = hash.key?('type') ? hash['type'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UserIdNumber.new(value: value,
                   type: type,
                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



30
31
32
33
34
35
# File 'lib/the_plaid_api/models/user_id_number.rb', line 30

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['value'] = 'value'
  @_hash['type'] = 'type'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/the_plaid_api/models/user_id_number.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



38
39
40
# File 'lib/the_plaid_api/models/user_id_number.rb', line 38

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



85
86
87
88
89
# File 'lib/the_plaid_api/models/user_id_number.rb', line 85

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} value: #{@value.inspect}, type: #{@type.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



78
79
80
81
82
# File 'lib/the_plaid_api/models/user_id_number.rb', line 78

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} value: #{@value}, type: #{@type}, additional_properties:"\
  " #{@additional_properties}>"
end