Class: ThePlaidApi::UserItemsAssociateRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::UserItemsAssociateRequest
- Defined in:
- lib/the_plaid_api/models/user_items_associate_request.rb
Overview
UserItemsAssociateRequest defines the request schema for ‘/user/items/associate`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#item_ids ⇒ Array[String]
An array of ‘item_id`s to be associated with the `user_id`.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#user_id ⇒ String
A unique user identifier, created by ‘/user/create`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(user_id:, item_ids:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ UserItemsAssociateRequest
constructor
A new instance of UserItemsAssociateRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(user_id:, item_ids:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ UserItemsAssociateRequest
Returns a new instance of UserItemsAssociateRequest.
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/the_plaid_api/models/user_items_associate_request.rb', line 58 def initialize(user_id:, item_ids:, client_id: SKIP, secret: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @user_id = user_id @item_ids = item_ids @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/user_items_associate_request.rb', line 17 def client_id @client_id end |
#item_ids ⇒ Array[String]
An array of ‘item_id`s to be associated with the `user_id`.
33 34 35 |
# File 'lib/the_plaid_api/models/user_items_associate_request.rb', line 33 def item_ids @item_ids end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/the_plaid_api/models/user_items_associate_request.rb', line 22 def secret @secret end |
#user_id ⇒ String
A unique user identifier, created by ‘/user/create`. Integrations that began using `/user/create` after December 10, 2025 use this field to identify a user instead of the `user_token`. For more details, see [new user APIs](plaid.com/docs/api/users/user-apis).
29 30 31 |
# File 'lib/the_plaid_api/models/user_items_associate_request.rb', line 29 def user_id @user_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/the_plaid_api/models/user_items_associate_request.rb', line 71 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. user_id = hash.key?('user_id') ? hash['user_id'] : nil item_ids = hash.key?('item_ids') ? hash['item_ids'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UserItemsAssociateRequest.new(user_id: user_id, item_ids: item_ids, client_id: client_id, secret: secret, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
36 37 38 39 40 41 42 43 |
# File 'lib/the_plaid_api/models/user_items_associate_request.rb', line 36 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['user_id'] = 'user_id' @_hash['item_ids'] = 'item_ids' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 |
# File 'lib/the_plaid_api/models/user_items_associate_request.rb', line 54 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
46 47 48 49 50 51 |
# File 'lib/the_plaid_api/models/user_items_associate_request.rb', line 46 def self.optionals %w[ client_id secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
103 104 105 106 107 108 |
# File 'lib/the_plaid_api/models/user_items_associate_request.rb', line 103 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, user_id:"\ " #{@user_id.inspect}, item_ids: #{@item_ids.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
96 97 98 99 100 |
# File 'lib/the_plaid_api/models/user_items_associate_request.rb', line 96 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, user_id: #{@user_id},"\ " item_ids: #{@item_ids}, additional_properties: #{@additional_properties}>" end |