Class: ThePlaidApi::UserPermissionRevokedWebhook

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/user_permission_revoked_webhook.rb

Overview

The ‘USER_PERMISSION_REVOKED` webhook may be fired when an end user has revoked the permission that they previously granted to access an Item. If the end user revoked their permissions through Plaid (such as via the Plaid Portal or by contacting Plaid Support), the webhook will fire. If the end user revoked their permissions directly through the institution, this webhook may not always fire, since some institutions’ consent portals do not trigger this webhook. To attempt to restore the Item, it can be sent through [update mode](plaid.com/docs/link/update-mode). Depending on the exact process the end user used to revoke permissions, it may not be possible to launch update mode for the Item. If you encounter an error when attempting to create a Link token for update mode on an Item with revoked permissions, create a fresh Link token for the user. Note that when working with tokenized account numbers with Auth or Transfer, the account number provided by Plaid will no longer work for creating transfers once user permission has been revoked, except for US Bank Items.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(webhook_type:, webhook_code:, item_id:, environment:, user_id: SKIP, error: SKIP, additional_properties: nil) ⇒ UserPermissionRevokedWebhook

Returns a new instance of UserPermissionRevokedWebhook.



86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/the_plaid_api/models/user_permission_revoked_webhook.rb', line 86

def initialize(webhook_type:, webhook_code:, item_id:, environment:,
               user_id: SKIP, error: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @webhook_type = webhook_type
  @webhook_code = webhook_code
  @item_id = item_id
  @user_id = user_id unless user_id == SKIP
  @error = error unless error == SKIP
  @environment = environment
  @additional_properties = additional_properties
end

Instance Attribute Details

#environmentWebhookEnvironmentValues

The Plaid environment the webhook was sent from



57
58
59
# File 'lib/the_plaid_api/models/user_permission_revoked_webhook.rb', line 57

def environment
  @environment
end

#errorError

Errors are identified by ‘error_code` and categorized by `error_type`. Use these in preference to HTTP status codes to identify and handle specific errors. HTTP status codes are set and provide the broadest categorization of errors: 4xx codes are for developer- or user-related errors, and 5xx codes are for Plaid-related errors, and the status will be 2xx in non-error cases. An Item with a non-`null` error object will only be part of an API response when calling `/item/get` to view Item status. Otherwise, error fields will be `null` if no error has occurred; if an error has occurred, an error code will be returned instead.

Returns:



53
54
55
# File 'lib/the_plaid_api/models/user_permission_revoked_webhook.rb', line 53

def error
  @error
end

#item_idString

The ‘item_id` of the Item associated with this webhook, warning, or error

Returns:

  • (String)


36
37
38
# File 'lib/the_plaid_api/models/user_permission_revoked_webhook.rb', line 36

def item_id
  @item_id
end

#user_idString

The Plaid ‘user_id` of the User associated with this webhook, warning, or error.

Returns:

  • (String)


41
42
43
# File 'lib/the_plaid_api/models/user_permission_revoked_webhook.rb', line 41

def user_id
  @user_id
end

#webhook_codeString

‘USER_PERMISSION_REVOKED`

Returns:

  • (String)


32
33
34
# File 'lib/the_plaid_api/models/user_permission_revoked_webhook.rb', line 32

def webhook_code
  @webhook_code
end

#webhook_typeString

‘ITEM`

Returns:

  • (String)


28
29
30
# File 'lib/the_plaid_api/models/user_permission_revoked_webhook.rb', line 28

def webhook_type
  @webhook_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/the_plaid_api/models/user_permission_revoked_webhook.rb', line 101

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil
  webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil
  item_id = hash.key?('item_id') ? hash['item_id'] : nil
  environment = hash.key?('environment') ? hash['environment'] : nil
  user_id = hash.key?('user_id') ? hash['user_id'] : SKIP
  error = Error.from_hash(hash['error']) if hash['error']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UserPermissionRevokedWebhook.new(webhook_type: webhook_type,
                                   webhook_code: webhook_code,
                                   item_id: item_id,
                                   environment: environment,
                                   user_id: user_id,
                                   error: error,
                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



60
61
62
63
64
65
66
67
68
69
# File 'lib/the_plaid_api/models/user_permission_revoked_webhook.rb', line 60

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['webhook_type'] = 'webhook_type'
  @_hash['webhook_code'] = 'webhook_code'
  @_hash['item_id'] = 'item_id'
  @_hash['user_id'] = 'user_id'
  @_hash['error'] = 'error'
  @_hash['environment'] = 'environment'
  @_hash
end

.nullablesObject

An array for nullable fields



80
81
82
83
84
# File 'lib/the_plaid_api/models/user_permission_revoked_webhook.rb', line 80

def self.nullables
  %w[
    error
  ]
end

.optionalsObject

An array for optional fields



72
73
74
75
76
77
# File 'lib/the_plaid_api/models/user_permission_revoked_webhook.rb', line 72

def self.optionals
  %w[
    user_id
    error
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



138
139
140
141
142
143
144
# File 'lib/the_plaid_api/models/user_permission_revoked_webhook.rb', line 138

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\
  " #{@webhook_code.inspect}, item_id: #{@item_id.inspect}, user_id: #{@user_id.inspect},"\
  " error: #{@error.inspect}, environment: #{@environment.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



130
131
132
133
134
135
# File 'lib/the_plaid_api/models/user_permission_revoked_webhook.rb', line 130

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, item_id:"\
  " #{@item_id}, user_id: #{@user_id}, error: #{@error}, environment: #{@environment},"\
  " additional_properties: #{@additional_properties}>"
end