Class: ThePlaidApi::UserProductsTerminateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/user_products_terminate_request.rb

Overview

UserProductsTerminateRequest defines the request schema for ‘/user/products/terminate`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(user_id:, client_id: SKIP, secret: SKIP, products: SKIP, additional_properties: nil) ⇒ UserProductsTerminateRequest

Returns a new instance of UserProductsTerminateRequest.



60
61
62
63
64
65
66
67
68
69
70
# File 'lib/the_plaid_api/models/user_products_terminate_request.rb', line 60

def initialize(user_id:, client_id: SKIP, secret: SKIP, products: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @user_id = user_id
  @products = products unless products == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/user_products_terminate_request.rb', line 17

def client_id
  @client_id
end

#productsArray[UserBasedProducts]

An optional list of user-based products to terminate. If not provided, all user-based products will be terminated.

Returns:



34
35
36
# File 'lib/the_plaid_api/models/user_products_terminate_request.rb', line 34

def products
  @products
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/user_products_terminate_request.rb', line 22

def secret
  @secret
end

#user_idString

A unique user identifier, created by ‘/user/create`. Integrations that began using `/user/create` after December 10, 2025 use this field to identify a user instead of the `user_token`. For more details, see [new user APIs](plaid.com/docs/api/users/user-apis).

Returns:

  • (String)


29
30
31
# File 'lib/the_plaid_api/models/user_products_terminate_request.rb', line 29

def user_id
  @user_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/the_plaid_api/models/user_products_terminate_request.rb', line 73

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  user_id = hash.key?('user_id') ? hash['user_id'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  products = hash.key?('products') ? hash['products'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UserProductsTerminateRequest.new(user_id: user_id,
                                   client_id: client_id,
                                   secret: secret,
                                   products: products,
                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
# File 'lib/the_plaid_api/models/user_products_terminate_request.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['user_id'] = 'user_id'
  @_hash['products'] = 'products'
  @_hash
end

.nullablesObject

An array for nullable fields



56
57
58
# File 'lib/the_plaid_api/models/user_products_terminate_request.rb', line 56

def self.nullables
  []
end

.optionalsObject

An array for optional fields



47
48
49
50
51
52
53
# File 'lib/the_plaid_api/models/user_products_terminate_request.rb', line 47

def self.optionals
  %w[
    client_id
    secret
    products
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



105
106
107
108
109
110
# File 'lib/the_plaid_api/models/user_products_terminate_request.rb', line 105

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, user_id:"\
  " #{@user_id.inspect}, products: #{@products.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



98
99
100
101
102
# File 'lib/the_plaid_api/models/user_products_terminate_request.rb', line 98

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, user_id: #{@user_id},"\
  " products: #{@products}, additional_properties: #{@additional_properties}>"
end