Class: ThePlaidApi::UserThirdPartyTokenCreateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/user_third_party_token_create_request.rb

Overview

UserThirdPartyTokenCreateRequest defines the request schema for ‘/user/third_party_token/create`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(third_party_client_id:, client_id: SKIP, secret: SKIP, user_token: SKIP, expiration_time: SKIP, user_id: SKIP, additional_properties: nil) ⇒ UserThirdPartyTokenCreateRequest

Returns a new instance of UserThirdPartyTokenCreateRequest.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/the_plaid_api/models/user_third_party_token_create_request.rb', line 83

def initialize(third_party_client_id:, client_id: SKIP, secret: SKIP,
               user_token: SKIP, expiration_time: SKIP, user_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @user_token = user_token unless user_token == SKIP
  @third_party_client_id = third_party_client_id
  @expiration_time = expiration_time unless expiration_time == SKIP
  @user_id = user_id unless user_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


18
19
20
# File 'lib/the_plaid_api/models/user_third_party_token_create_request.rb', line 18

def client_id
  @client_id
end

#expiration_timeDateTime

The expiration date and time for the third-party user token in [ISO 8601](wikipedia.org/wiki/ISO_8601) format (‘YYYY-MM-DDThh:mm:ssZ`). The expiration is restricted to a maximum of 24 hours from the token’s creation time. If not provided, the token will automatically expire after 24 hours.

Returns:

  • (DateTime)


44
45
46
# File 'lib/the_plaid_api/models/user_third_party_token_create_request.rb', line 44

def expiration_time
  @expiration_time
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


23
24
25
# File 'lib/the_plaid_api/models/user_third_party_token_create_request.rb', line 23

def secret
  @secret
end

#third_party_client_idString

The Plaid API ‘client_id` of the third-party client the token will be shared with. The token will only be valid for the specified client.

Returns:

  • (String)


36
37
38
# File 'lib/the_plaid_api/models/user_third_party_token_create_request.rb', line 36

def third_party_client_id
  @third_party_client_id
end

#user_idString

A unique user identifier, created by ‘/user/create`. Integrations that began using `/user/create` after December 10, 2025 use this field to identify a user instead of the `user_token`. For more details, see [new user APIs](plaid.com/docs/api/users/user-apis).

Returns:

  • (String)


51
52
53
# File 'lib/the_plaid_api/models/user_third_party_token_create_request.rb', line 51

def user_id
  @user_id
end

#user_tokenString

The user token associated with the User data is being requested for. This field is used only by customers with pre-existing integrations that already use the ‘user_token` field. All other customers should use the `user_id` instead. For more details, see [New User APIs](plaid.com/docs/api/users/user-apis).

Returns:

  • (String)


31
32
33
# File 'lib/the_plaid_api/models/user_third_party_token_create_request.rb', line 31

def user_token
  @user_token
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/the_plaid_api/models/user_third_party_token_create_request.rb', line 99

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  third_party_client_id =
    hash.key?('third_party_client_id') ? hash['third_party_client_id'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  user_token = hash.key?('user_token') ? hash['user_token'] : SKIP
  expiration_time = if hash.key?('expiration_time')
                      (DateTimeHelper.from_rfc3339(hash['expiration_time']) if hash['expiration_time'])
                    else
                      SKIP
                    end
  user_id = hash.key?('user_id') ? hash['user_id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  UserThirdPartyTokenCreateRequest.new(third_party_client_id: third_party_client_id,
                                       client_id: client_id,
                                       secret: secret,
                                       user_token: user_token,
                                       expiration_time: expiration_time,
                                       user_id: user_id,
                                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



54
55
56
57
58
59
60
61
62
63
# File 'lib/the_plaid_api/models/user_third_party_token_create_request.rb', line 54

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['user_token'] = 'user_token'
  @_hash['third_party_client_id'] = 'third_party_client_id'
  @_hash['expiration_time'] = 'expiration_time'
  @_hash['user_id'] = 'user_id'
  @_hash
end

.nullablesObject

An array for nullable fields



77
78
79
80
81
# File 'lib/the_plaid_api/models/user_third_party_token_create_request.rb', line 77

def self.nullables
  %w[
    expiration_time
  ]
end

.optionalsObject

An array for optional fields



66
67
68
69
70
71
72
73
74
# File 'lib/the_plaid_api/models/user_third_party_token_create_request.rb', line 66

def self.optionals
  %w[
    client_id
    secret
    user_token
    expiration_time
    user_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



145
146
147
148
149
150
151
# File 'lib/the_plaid_api/models/user_third_party_token_create_request.rb', line 145

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, user_token:"\
  " #{@user_token.inspect}, third_party_client_id: #{@third_party_client_id.inspect},"\
  " expiration_time: #{@expiration_time.inspect}, user_id: #{@user_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_custom_expiration_timeObject



132
133
134
# File 'lib/the_plaid_api/models/user_third_party_token_create_request.rb', line 132

def to_custom_expiration_time
  DateTimeHelper.to_rfc3339(expiration_time)
end

#to_sObject

Provides a human-readable string representation of the object.



137
138
139
140
141
142
# File 'lib/the_plaid_api/models/user_third_party_token_create_request.rb', line 137

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, user_token: #{@user_token},"\
  " third_party_client_id: #{@third_party_client_id}, expiration_time: #{@expiration_time},"\
  " user_id: #{@user_id}, additional_properties: #{@additional_properties}>"
end