Class: ThePlaidApi::ValidationSource

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/validation_source.rb

Overview

Documentation not found in the MISMO model viewer and not provided by Freddie Mac.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(validation_source_name:, validation_source_reference_identifier:, additional_properties: nil) ⇒ ValidationSource

Returns a new instance of ValidationSource.



45
46
47
48
49
50
51
52
53
54
# File 'lib/the_plaid_api/models/validation_source.rb', line 45

def initialize(validation_source_name:,
               validation_source_reference_identifier:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @validation_source_name = validation_source_name
  @validation_source_reference_identifier = validation_source_reference_identifier
  @additional_properties = additional_properties
end

Instance Attribute Details

#validation_source_nameString

Documentation not found in the MISMO model viewer and not provided by Freddie Mac.

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/validation_source.rb', line 16

def validation_source_name
  @validation_source_name
end

#validation_source_reference_identifierString

Documentation not found in the MISMO model viewer and not provided by Freddie Mac.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/validation_source.rb', line 21

def validation_source_reference_identifier
  @validation_source_reference_identifier
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/the_plaid_api/models/validation_source.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  validation_source_name =
    hash.key?('ValidationSourceName') ? hash['ValidationSourceName'] : nil
  validation_source_reference_identifier =
    hash.key?('ValidationSourceReferenceIdentifier') ? hash['ValidationSourceReferenceIdentifier'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ValidationSource.new(validation_source_name: validation_source_name,
                       validation_source_reference_identifier: validation_source_reference_identifier,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
29
30
# File 'lib/the_plaid_api/models/validation_source.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['validation_source_name'] = 'ValidationSourceName'
  @_hash['validation_source_reference_identifier'] =
    'ValidationSourceReferenceIdentifier'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
41
42
43
# File 'lib/the_plaid_api/models/validation_source.rb', line 38

def self.nullables
  %w[
    validation_source_name
    validation_source_reference_identifier
  ]
end

.optionalsObject

An array for optional fields



33
34
35
# File 'lib/the_plaid_api/models/validation_source.rb', line 33

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



88
89
90
91
92
93
94
# File 'lib/the_plaid_api/models/validation_source.rb', line 88

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} validation_source_name: #{@validation_source_name.inspect},"\
  ' validation_source_reference_identifier:'\
  " #{@validation_source_reference_identifier.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



80
81
82
83
84
85
# File 'lib/the_plaid_api/models/validation_source.rb', line 80

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} validation_source_name: #{@validation_source_name},"\
  " validation_source_reference_identifier: #{@validation_source_reference_identifier},"\
  " additional_properties: #{@additional_properties}>"
end