Class: ThePlaidApi::ValidationSources
- Defined in:
- lib/the_plaid_api/models/validation_sources.rb
Overview
Documentation not found in the MISMO model viewer and not provided by Freddie Mac.
Instance Attribute Summary collapse
-
#validation_source ⇒ Array[ValidationSource]
Documentation not found in the MISMO model viewer and not provided by Freddie Mac.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(validation_source:, additional_properties: nil) ⇒ ValidationSources
constructor
A new instance of ValidationSources.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(validation_source:, additional_properties: nil) ⇒ ValidationSources
Returns a new instance of ValidationSources.
35 36 37 38 39 40 41 |
# File 'lib/the_plaid_api/models/validation_sources.rb', line 35 def initialize(validation_source:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @validation_source = validation_source @additional_properties = additional_properties end |
Instance Attribute Details
#validation_source ⇒ Array[ValidationSource]
Documentation not found in the MISMO model viewer and not provided by Freddie Mac.
16 17 18 |
# File 'lib/the_plaid_api/models/validation_sources.rb', line 16 def validation_source @validation_source end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/the_plaid_api/models/validation_sources.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it validation_source = nil unless hash['VALIDATION_SOURCE'].nil? validation_source = [] hash['VALIDATION_SOURCE'].each do |structure| validation_source << (ValidationSource.from_hash(structure) if structure) end end validation_source = nil unless hash.key?('VALIDATION_SOURCE') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ValidationSources.new(validation_source: validation_source, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
19 20 21 22 23 |
# File 'lib/the_plaid_api/models/validation_sources.rb', line 19 def self.names @_hash = {} if @_hash.nil? @_hash['validation_source'] = 'VALIDATION_SOURCE' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/the_plaid_api/models/validation_sources.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
26 27 28 |
# File 'lib/the_plaid_api/models/validation_sources.rb', line 26 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/the_plaid_api/models/validation_sources.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} validation_source: #{@validation_source.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/the_plaid_api/models/validation_sources.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} validation_source: #{@validation_source}, additional_properties:"\ " #{@additional_properties}>" end |