Class: ThePlaidApi::VerificationOfAsset

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/verification_of_asset.rb

Overview

Documentation not found in the MISMO model viewer and not provided by Freddie Mac.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(reporting_information:, service_product_fulfillment:, verification_of_asset_response:, additional_properties: nil) ⇒ VerificationOfAsset

Returns a new instance of VerificationOfAsset.



47
48
49
50
51
52
53
54
55
56
# File 'lib/the_plaid_api/models/verification_of_asset.rb', line 47

def initialize(reporting_information:, service_product_fulfillment:,
               verification_of_asset_response:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @reporting_information = reporting_information
  @service_product_fulfillment = service_product_fulfillment
  @verification_of_asset_response = verification_of_asset_response
  @additional_properties = additional_properties
end

Instance Attribute Details

#reporting_informationReportingInformation

Information about an report identifier and a report name.



15
16
17
# File 'lib/the_plaid_api/models/verification_of_asset.rb', line 15

def reporting_information
  @reporting_information
end

#service_product_fulfillmentServiceProductFulfillment

A collection of details related to a fulfillment service or product in terms of request, process and result.



20
21
22
# File 'lib/the_plaid_api/models/verification_of_asset.rb', line 20

def service_product_fulfillment
  @service_product_fulfillment
end

#verification_of_asset_responseVerificationOfAssetResponse

Documentation not found in the MISMO model viewer and not provided by Freddie Mac.



25
26
27
# File 'lib/the_plaid_api/models/verification_of_asset.rb', line 25

def verification_of_asset_response
  @verification_of_asset_response
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/the_plaid_api/models/verification_of_asset.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  reporting_information = ReportingInformation.from_hash(hash['REPORTING_INFORMATION']) if
    hash['REPORTING_INFORMATION']
  if hash['SERVICE_PRODUCT_FULFILLMENT']
    service_product_fulfillment = ServiceProductFulfillment.from_hash(hash['SERVICE_PRODUCT_FULFILLMENT'])
  end
  if hash['VERIFICATION_OF_ASSET_RESPONSE']
    verification_of_asset_response = VerificationOfAssetResponse.from_hash(hash['VERIFICATION_OF_ASSET_RESPONSE'])
  end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  VerificationOfAsset.new(reporting_information: reporting_information,
                          service_product_fulfillment: service_product_fulfillment,
                          verification_of_asset_response: verification_of_asset_response,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



28
29
30
31
32
33
34
35
# File 'lib/the_plaid_api/models/verification_of_asset.rb', line 28

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['reporting_information'] = 'REPORTING_INFORMATION'
  @_hash['service_product_fulfillment'] = 'SERVICE_PRODUCT_FULFILLMENT'
  @_hash['verification_of_asset_response'] =
    'VERIFICATION_OF_ASSET_RESPONSE'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/the_plaid_api/models/verification_of_asset.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



38
39
40
# File 'lib/the_plaid_api/models/verification_of_asset.rb', line 38

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



96
97
98
99
100
101
102
# File 'lib/the_plaid_api/models/verification_of_asset.rb', line 96

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} reporting_information: #{@reporting_information.inspect},"\
  " service_product_fulfillment: #{@service_product_fulfillment.inspect},"\
  " verification_of_asset_response: #{@verification_of_asset_response.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



87
88
89
90
91
92
93
# File 'lib/the_plaid_api/models/verification_of_asset.rb', line 87

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} reporting_information: #{@reporting_information},"\
  " service_product_fulfillment: #{@service_product_fulfillment},"\
  " verification_of_asset_response: #{@verification_of_asset_response}, additional_properties:"\
  " #{@additional_properties}>"
end