Class: ThePlaidApi::VerificationStatus5

Inherits:
Object
  • Object
show all
Defined in:
lib/the_plaid_api/models/verification_status5.rb

Overview

Indicates an Item’s micro-deposit-based verification or database verification status. This field is only populated when using Auth and falling back to micro-deposit or database verification. Possible values are: ‘pending_automatic_verification`: The Item is pending automatic verification. `pending_manual_verification`: The Item is pending manual micro-deposit verification. Items remain in this state until the user successfully verifies the code. `automatically_verified`: The Item has successfully been automatically verified. `manually_verified`: The Item has successfully been manually verified. `verification_expired`: Plaid was unable to automatically verify the deposit within 7 calendar days and will no longer attempt to validate the Item. Users may retry by submitting their information again through Link. `verification_failed`: The Item failed manual micro-deposit verification because the user exhausted all 3 verification attempts. Users may retry by submitting their information again through Link. `unsent`: The Item is pending micro-deposit verification, but Plaid has not yet sent the micro-deposit. `database_insights_pending`: The Database Auth result is pending and will be available upon Auth request. `database_insights_fail`: The Item’s numbers have been verified using Plaid’s data sources and have signal for being invalid and/or have no signal for being valid. Typically this indicates that the routing number is invalid, the account number does not match the account number format associated with the routing number, or the account has been reported as closed or frozen. Only returned for Auth Items created via Database Auth. ‘database_insights_pass`: The Item’s numbers have been verified using Plaid’s data sources: the routing and account number match a routing and account number of an account recognized on the Plaid network, and the account is not known by Plaid to be frozen or closed. Only returned for Auth Items created via Database Auth. ‘database_insights_pass_with_caution`: The Item’s numbers have been verified using Plaid’s data sources and have some signal for being valid: the routing and account number were not recognized on the Plaid network, but the routing number is valid and the account number is a potential valid account number for that routing number. Only returned for Auth Items created via Database Auth. ‘database_matched`: (deprecated) The Item has successfully been verified using Plaid’s data sources. Only returned for Auth Items created via Database Match. ‘null` or empty string: Neither micro-deposit-based verification nor database verification are being used for the Item.

Constant Summary collapse

VERIFICATION_STATUS5 =
[
  # TODO: Write general description for AUTOMATICALLY_VERIFIED
  AUTOMATICALLY_VERIFIED = 'automatically_verified'.freeze,

  # TODO: Write general description for PENDING_AUTOMATIC_VERIFICATION
  PENDING_AUTOMATIC_VERIFICATION = 'pending_automatic_verification'.freeze,

  # TODO: Write general description for PENDING_MANUAL_VERIFICATION
  PENDING_MANUAL_VERIFICATION = 'pending_manual_verification'.freeze,

  # TODO: Write general description for UNSENT
  UNSENT = 'unsent'.freeze,

  # TODO: Write general description for MANUALLY_VERIFIED
  MANUALLY_VERIFIED = 'manually_verified'.freeze,

  # TODO: Write general description for VERIFICATION_EXPIRED
  VERIFICATION_EXPIRED = 'verification_expired'.freeze,

  # TODO: Write general description for VERIFICATION_FAILED
  VERIFICATION_FAILED = 'verification_failed'.freeze,

  # TODO: Write general description for DATABASE_MATCHED
  DATABASE_MATCHED = 'database_matched'.freeze,

  # TODO: Write general description for DATABASE_INSIGHTS_PASS
  DATABASE_INSIGHTS_PASS = 'database_insights_pass'.freeze,

  # TODO: Write general description for DATABASE_INSIGHTS_PASS_WITH_CAUTION
  DATABASE_INSIGHTS_PASS_WITH_CAUTION = 'database_insights_pass_with_caution'.freeze,

  # TODO: Write general description for DATABASE_INSIGHTS_FAIL
  DATABASE_INSIGHTS_FAIL = 'database_insights_fail'.freeze
].freeze

Class Method Summary collapse

Class Method Details

.from_value(value, default_value = AUTOMATICALLY_VERIFIED) ⇒ Object



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/the_plaid_api/models/verification_status5.rb', line 86

def self.from_value(value, default_value = AUTOMATICALLY_VERIFIED)
  return default_value if value.nil?

  str = value.to_s.strip

  case str.downcase
  when 'automatically_verified' then AUTOMATICALLY_VERIFIED
  when 'pending_automatic_verification' then PENDING_AUTOMATIC_VERIFICATION
  when 'pending_manual_verification' then PENDING_MANUAL_VERIFICATION
  when 'unsent' then UNSENT
  when 'manually_verified' then MANUALLY_VERIFIED
  when 'verification_expired' then VERIFICATION_EXPIRED
  when 'verification_failed' then VERIFICATION_FAILED
  when 'database_matched' then DATABASE_MATCHED
  when 'database_insights_pass' then DATABASE_INSIGHTS_PASS
  when 'database_insights_pass_with_caution' then DATABASE_INSIGHTS_PASS_WITH_CAUTION
  when 'database_insights_fail' then DATABASE_INSIGHTS_FAIL
  else
    default_value
  end
end

.validate(value) ⇒ Object



80
81
82
83
84
# File 'lib/the_plaid_api/models/verification_status5.rb', line 80

def self.validate(value)
  return false if value.nil?

  VERIFICATION_STATUS5.include?(value)
end