Class: ThePlaidApi::VerifySmsDetails

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/verify_sms_details.rb

Overview

Additional information for the ‘verify_sms` step.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(status:, verifications:, additional_properties: nil) ⇒ VerifySmsDetails

Returns a new instance of VerifySmsDetails.



43
44
45
46
47
48
49
50
# File 'lib/the_plaid_api/models/verify_sms_details.rb', line 43

def initialize(status:, verifications:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @status = status
  @verifications = verifications
  @additional_properties = additional_properties
end

Instance Attribute Details

#statusVerifySmsDetailsStatus

The outcome status for the associated Identity Verification attempt’s ‘verify_sms` step. This field will always have the same value as `steps.verify_sms`.



16
17
18
# File 'lib/the_plaid_api/models/verify_sms_details.rb', line 16

def status
  @status
end

#verificationsArray[SmsVerification]

An array where each entry represents a verification attempt for the ‘verify_sms` step. Each entry represents one user-submitted phone number. Phone number edits, and in some cases error handling due to edge cases like rate limiting, may generate additional verifications.

Returns:



23
24
25
# File 'lib/the_plaid_api/models/verify_sms_details.rb', line 23

def verifications
  @verifications
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/the_plaid_api/models/verify_sms_details.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  status = hash.key?('status') ? hash['status'] : nil
  # Parameter is an array, so we need to iterate through it
  verifications = nil
  unless hash['verifications'].nil?
    verifications = []
    hash['verifications'].each do |structure|
      verifications << (SmsVerification.from_hash(structure) if structure)
    end
  end

  verifications = nil unless hash.key?('verifications')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  VerifySmsDetails.new(status: status,
                       verifications: verifications,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
# File 'lib/the_plaid_api/models/verify_sms_details.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['status'] = 'status'
  @_hash['verifications'] = 'verifications'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/the_plaid_api/models/verify_sms_details.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/the_plaid_api/models/verify_sms_details.rb', line 34

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
# File 'lib/the_plaid_api/models/verify_sms_details.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status.inspect}, verifications: #{@verifications.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
# File 'lib/the_plaid_api/models/verify_sms_details.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status}, verifications: #{@verifications},"\
  " additional_properties: #{@additional_properties}>"
end