Class: ThePlaidApi::W2Box12

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/w2_box12.rb

Overview

Data on the W2 Box 12

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(code: SKIP, amount: SKIP, additional_properties: nil) ⇒ W2Box12

Returns a new instance of W2Box12.



44
45
46
47
48
49
50
51
# File 'lib/the_plaid_api/models/w2_box12.rb', line 44

def initialize(code: SKIP, amount: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @code = code unless code == SKIP
  @amount = amount unless amount == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#amountString

W2 Box 12 amount.

Returns:

  • (String)


18
19
20
# File 'lib/the_plaid_api/models/w2_box12.rb', line 18

def amount
  @amount
end

#codeString

W2 Box 12 code.

Returns:

  • (String)


14
15
16
# File 'lib/the_plaid_api/models/w2_box12.rb', line 14

def code
  @code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/the_plaid_api/models/w2_box12.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  code = hash.key?('code') ? hash['code'] : SKIP
  amount = hash.key?('amount') ? hash['amount'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  W2Box12.new(code: code,
              amount: amount,
              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/the_plaid_api/models/w2_box12.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['code'] = 'code'
  @_hash['amount'] = 'amount'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
40
41
42
# File 'lib/the_plaid_api/models/w2_box12.rb', line 37

def self.nullables
  %w[
    code
    amount
  ]
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/the_plaid_api/models/w2_box12.rb', line 29

def self.optionals
  %w[
    code
    amount
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



82
83
84
85
86
# File 'lib/the_plaid_api/models/w2_box12.rb', line 82

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code.inspect}, amount: #{@amount.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



75
76
77
78
79
# File 'lib/the_plaid_api/models/w2_box12.rb', line 75

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code}, amount: #{@amount}, additional_properties:"\
  " #{@additional_properties}>"
end