Class: ThePlaidApi::WalletCreateRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::WalletCreateRequest
- Defined in:
- lib/the_plaid_api/models/wallet_create_request.rb
Overview
WalletCreateRequest defines the request schema for ‘/wallet/create`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#iso_currency_code ⇒ IsoCurrencyCode
An ISO-4217 currency code, used with e-wallets and transactions.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(iso_currency_code:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ WalletCreateRequest
constructor
A new instance of WalletCreateRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(iso_currency_code:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ WalletCreateRequest
Returns a new instance of WalletCreateRequest.
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/the_plaid_api/models/wallet_create_request.rb', line 49 def initialize(iso_currency_code:, client_id: SKIP, secret: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @iso_currency_code = iso_currency_code @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/the_plaid_api/models/wallet_create_request.rb', line 16 def client_id @client_id end |
#iso_currency_code ⇒ IsoCurrencyCode
An ISO-4217 currency code, used with e-wallets and transactions.
25 26 27 |
# File 'lib/the_plaid_api/models/wallet_create_request.rb', line 25 def iso_currency_code @iso_currency_code end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
21 22 23 |
# File 'lib/the_plaid_api/models/wallet_create_request.rb', line 21 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/the_plaid_api/models/wallet_create_request.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. iso_currency_code = hash.key?('iso_currency_code') ? hash['iso_currency_code'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. WalletCreateRequest.new(iso_currency_code: iso_currency_code, client_id: client_id, secret: secret, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
28 29 30 31 32 33 34 |
# File 'lib/the_plaid_api/models/wallet_create_request.rb', line 28 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['iso_currency_code'] = 'iso_currency_code' @_hash end |
.nullables ⇒ Object
An array for nullable fields
45 46 47 |
# File 'lib/the_plaid_api/models/wallet_create_request.rb', line 45 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
37 38 39 40 41 42 |
# File 'lib/the_plaid_api/models/wallet_create_request.rb', line 37 def self.optionals %w[ client_id secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
92 93 94 95 96 97 |
# File 'lib/the_plaid_api/models/wallet_create_request.rb', line 92 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\ " iso_currency_code: #{@iso_currency_code.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
85 86 87 88 89 |
# File 'lib/the_plaid_api/models/wallet_create_request.rb', line 85 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, iso_currency_code:"\ " #{@iso_currency_code}, additional_properties: #{@additional_properties}>" end |