Class: ThePlaidApi::WalletListRequest
- Defined in:
- lib/the_plaid_api/models/wallet_list_request.rb
Overview
WalletListRequest defines the request schema for ‘/wallet/list`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#count ⇒ Integer
The number of e-wallets to fetch.
-
#cursor ⇒ String
A base64 value representing the latest e-wallet that has already been requested.
-
#iso_currency_code ⇒ IsoCurrencyCode
An ISO-4217 currency code, used with e-wallets and transactions.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_id: SKIP, secret: SKIP, iso_currency_code: SKIP, cursor: SKIP, count: 10, additional_properties: nil) ⇒ WalletListRequest
constructor
A new instance of WalletListRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_id: SKIP, secret: SKIP, iso_currency_code: SKIP, cursor: SKIP, count: 10, additional_properties: nil) ⇒ WalletListRequest
Returns a new instance of WalletListRequest.
66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/the_plaid_api/models/wallet_list_request.rb', line 66 def initialize(client_id: SKIP, secret: SKIP, iso_currency_code: SKIP, cursor: SKIP, count: 10, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @iso_currency_code = iso_currency_code unless iso_currency_code == SKIP @cursor = cursor unless cursor == SKIP @count = count unless count == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/the_plaid_api/models/wallet_list_request.rb', line 16 def client_id @client_id end |
#count ⇒ Integer
The number of e-wallets to fetch
37 38 39 |
# File 'lib/the_plaid_api/models/wallet_list_request.rb', line 37 def count @count end |
#cursor ⇒ String
A base64 value representing the latest e-wallet that has already been requested. Set this to ‘next_cursor` received from the previous `/wallet/list` request. If provided, the response will only contain e-wallets created before that e-wallet. If omitted, the response will contain e-wallets starting from the most recent, and in descending order.
33 34 35 |
# File 'lib/the_plaid_api/models/wallet_list_request.rb', line 33 def cursor @cursor end |
#iso_currency_code ⇒ IsoCurrencyCode
An ISO-4217 currency code, used with e-wallets and transactions.
25 26 27 |
# File 'lib/the_plaid_api/models/wallet_list_request.rb', line 25 def iso_currency_code @iso_currency_code end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
21 22 23 |
# File 'lib/the_plaid_api/models/wallet_list_request.rb', line 21 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/the_plaid_api/models/wallet_list_request.rb', line 80 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP iso_currency_code = hash.key?('iso_currency_code') ? hash['iso_currency_code'] : SKIP cursor = hash.key?('cursor') ? hash['cursor'] : SKIP count = hash['count'] ||= 10 # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. WalletListRequest.new(client_id: client_id, secret: secret, iso_currency_code: iso_currency_code, cursor: cursor, count: count, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
40 41 42 43 44 45 46 47 48 |
# File 'lib/the_plaid_api/models/wallet_list_request.rb', line 40 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['iso_currency_code'] = 'iso_currency_code' @_hash['cursor'] = 'cursor' @_hash['count'] = 'count' @_hash end |
.nullables ⇒ Object
An array for nullable fields
62 63 64 |
# File 'lib/the_plaid_api/models/wallet_list_request.rb', line 62 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
51 52 53 54 55 56 57 58 59 |
# File 'lib/the_plaid_api/models/wallet_list_request.rb', line 51 def self.optionals %w[ client_id secret iso_currency_code cursor count ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
116 117 118 119 120 121 |
# File 'lib/the_plaid_api/models/wallet_list_request.rb', line 116 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\ " iso_currency_code: #{@iso_currency_code.inspect}, cursor: #{@cursor.inspect}, count:"\ " #{@count.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
108 109 110 111 112 113 |
# File 'lib/the_plaid_api/models/wallet_list_request.rb', line 108 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, iso_currency_code:"\ " #{@iso_currency_code}, cursor: #{@cursor}, count: #{@count}, additional_properties:"\ " #{@additional_properties}>" end |