Class: ThePlaidApi::WalletNumbers

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/wallet_numbers.rb

Overview

An object representing the e-wallet account numbers

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(bacs: SKIP, international: SKIP, additional_properties: nil) ⇒ WalletNumbers

Returns a new instance of WalletNumbers.



47
48
49
50
51
52
53
54
# File 'lib/the_plaid_api/models/wallet_numbers.rb', line 47

def initialize(bacs: SKIP, international: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @bacs = bacs unless bacs == SKIP
  @international = international unless international == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#bacsRecipientBacs

An object containing a BACS account number and sort code. If an IBAN is not provided or if you need to accept domestic GBP-denominated payments, BACS data is required.

Returns:



16
17
18
# File 'lib/the_plaid_api/models/wallet_numbers.rb', line 16

def bacs
  @bacs
end

#internationalNumbersInternationalIban

Account numbers using the International Bank Account Number and BIC/SWIFT code format.



21
22
23
# File 'lib/the_plaid_api/models/wallet_numbers.rb', line 21

def international
  @international
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/the_plaid_api/models/wallet_numbers.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  bacs = RecipientBacs.from_hash(hash['bacs']) if hash['bacs']
  international = NumbersInternationalIban.from_hash(hash['international']) if
    hash['international']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  WalletNumbers.new(bacs: bacs,
                    international: international,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
29
# File 'lib/the_plaid_api/models/wallet_numbers.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['bacs'] = 'bacs'
  @_hash['international'] = 'international'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
43
44
45
# File 'lib/the_plaid_api/models/wallet_numbers.rb', line 40

def self.nullables
  %w[
    bacs
    international
  ]
end

.optionalsObject

An array for optional fields



32
33
34
35
36
37
# File 'lib/the_plaid_api/models/wallet_numbers.rb', line 32

def self.optionals
  %w[
    bacs
    international
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



86
87
88
89
90
# File 'lib/the_plaid_api/models/wallet_numbers.rb', line 86

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} bacs: #{@bacs.inspect}, international: #{@international.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



79
80
81
82
83
# File 'lib/the_plaid_api/models/wallet_numbers.rb', line 79

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} bacs: #{@bacs}, international: #{@international}, additional_properties:"\
  " #{@additional_properties}>"
end