Class: ThePlaidApi::WalletTransactionListRequestOptions

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/wallet_transaction_list_request_options.rb

Overview

Additional wallet transaction options

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(start_time: SKIP, end_time: SKIP, additional_properties: nil) ⇒ WalletTransactionListRequestOptions

Returns a new instance of WalletTransactionListRequestOptions.



46
47
48
49
50
51
52
53
# File 'lib/the_plaid_api/models/wallet_transaction_list_request_options.rb', line 46

def initialize(start_time: SKIP, end_time: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @start_time = start_time unless start_time == SKIP
  @end_time = end_time unless end_time == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#end_timeDateTime

Timestamp in [ISO 8601](wikipedia.org/wiki/ISO_8601) format (YYYY-MM-DDThh:mm:ssZ) for filtering transactions, inclusive of the provided date.

Returns:

  • (DateTime)


23
24
25
# File 'lib/the_plaid_api/models/wallet_transaction_list_request_options.rb', line 23

def end_time
  @end_time
end

#start_timeDateTime

Timestamp in [ISO 8601](wikipedia.org/wiki/ISO_8601) format (YYYY-MM-DDThh:mm:ssZ) for filtering transactions, inclusive of the provided date.

Returns:

  • (DateTime)


17
18
19
# File 'lib/the_plaid_api/models/wallet_transaction_list_request_options.rb', line 17

def start_time
  @start_time
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/the_plaid_api/models/wallet_transaction_list_request_options.rb', line 56

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  start_time = if hash.key?('start_time')
                 (DateTimeHelper.from_rfc3339(hash['start_time']) if hash['start_time'])
               else
                 SKIP
               end
  end_time = if hash.key?('end_time')
               (DateTimeHelper.from_rfc3339(hash['end_time']) if hash['end_time'])
             else
               SKIP
             end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  WalletTransactionListRequestOptions.new(start_time: start_time,
                                          end_time: end_time,
                                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
# File 'lib/the_plaid_api/models/wallet_transaction_list_request_options.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['start_time'] = 'start_time'
  @_hash['end_time'] = 'end_time'
  @_hash
end

.nullablesObject

An array for nullable fields



42
43
44
# File 'lib/the_plaid_api/models/wallet_transaction_list_request_options.rb', line 42

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
# File 'lib/the_plaid_api/models/wallet_transaction_list_request_options.rb', line 34

def self.optionals
  %w[
    start_time
    end_time
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



100
101
102
103
104
# File 'lib/the_plaid_api/models/wallet_transaction_list_request_options.rb', line 100

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} start_time: #{@start_time.inspect}, end_time: #{@end_time.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_custom_end_timeObject



88
89
90
# File 'lib/the_plaid_api/models/wallet_transaction_list_request_options.rb', line 88

def to_custom_end_time
  DateTimeHelper.to_rfc3339(end_time)
end

#to_custom_start_timeObject



84
85
86
# File 'lib/the_plaid_api/models/wallet_transaction_list_request_options.rb', line 84

def to_custom_start_time
  DateTimeHelper.to_rfc3339(start_time)
end

#to_sObject

Provides a human-readable string representation of the object.



93
94
95
96
97
# File 'lib/the_plaid_api/models/wallet_transaction_list_request_options.rb', line 93

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} start_time: #{@start_time}, end_time: #{@end_time}, additional_properties:"\
  " #{@additional_properties}>"
end