Class: ThePlaidApi::WalletTransactionPayeeVerificationStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/the_plaid_api/models/wallet_transaction_payee_verification_status.rb

Overview

Result of payee verification check for EUR payouts. Payee verification checks whether the payee name provided matches the account holder name at the destination institution. ‘FULL_MATCH`: The payee name fully matches the account holder. `PARTIAL_MATCH`: The payee name partially matches the account holder. `NO_MATCH`: The payee name does not match the account holder. `ERROR`: An error occurred during payee verification. `CHECK_NOT_POSSIBLE`: Payee verification could not be performed. This field is only populated for applicable EUR payout transactions and will be `null` for other transaction types.

Constant Summary collapse

WALLET_TRANSACTION_PAYEE_VERIFICATION_STATUS =
[
  # TODO: Write general description for FULL_MATCH
  FULL_MATCH = 'FULL_MATCH'.freeze,

  # TODO: Write general description for PARTIAL_MATCH
  PARTIAL_MATCH = 'PARTIAL_MATCH'.freeze,

  # TODO: Write general description for NO_MATCH
  NO_MATCH = 'NO_MATCH'.freeze,

  # TODO: Write general description for ERROR
  ERROR = 'ERROR'.freeze,

  # TODO: Write general description for CHECK_NOT_POSSIBLE
  CHECK_NOT_POSSIBLE = 'CHECK_NOT_POSSIBLE'.freeze
].freeze

Class Method Summary collapse

Class Method Details

.from_value(value, default_value = FULL_MATCH) ⇒ Object



40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/the_plaid_api/models/wallet_transaction_payee_verification_status.rb', line 40

def self.from_value(value, default_value = FULL_MATCH)
  return default_value if value.nil?

  str = value.to_s.strip

  case str.downcase
  when 'full_match' then FULL_MATCH
  when 'partial_match' then PARTIAL_MATCH
  when 'no_match' then NO_MATCH
  when 'error' then ERROR
  when 'check_not_possible' then CHECK_NOT_POSSIBLE
  else
    default_value
  end
end

.validate(value) ⇒ Object



34
35
36
37
38
# File 'lib/the_plaid_api/models/wallet_transaction_payee_verification_status.rb', line 34

def self.validate(value)
  return false if value.nil?

  WALLET_TRANSACTION_PAYEE_VERIFICATION_STATUS.include?(value)
end