Class: ThePlaidApi::WalletTransactionsListRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/wallet_transactions_list_request.rb

Overview

WalletTransactionListRequest defines the request schema for ‘/wallet/transaction/list`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(wallet_id:, client_id: SKIP, secret: SKIP, cursor: SKIP, count: 10, options: SKIP, additional_properties: nil) ⇒ WalletTransactionsListRequest

Returns a new instance of WalletTransactionsListRequest.



75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/the_plaid_api/models/wallet_transactions_list_request.rb', line 75

def initialize(wallet_id:, client_id: SKIP, secret: SKIP, cursor: SKIP,
               count: 10, options: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @wallet_id = wallet_id
  @cursor = cursor unless cursor == SKIP
  @count = count unless count == SKIP
  @options = options unless options == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


17
18
19
# File 'lib/the_plaid_api/models/wallet_transactions_list_request.rb', line 17

def client_id
  @client_id
end

#countInteger

The number of transactions to fetch

Returns:

  • (Integer)


39
40
41
# File 'lib/the_plaid_api/models/wallet_transactions_list_request.rb', line 39

def count
  @count
end

#cursorString

A base64 value representing the latest transaction that has already been requested. Set this to ‘next_cursor` received from the previous `/wallet/transaction/list` request. If provided, the response will only contain transactions created before that transaction. If omitted, the response will contain transactions starting from the most recent, and in descending order by the `created_at` time.

Returns:

  • (String)


35
36
37
# File 'lib/the_plaid_api/models/wallet_transactions_list_request.rb', line 35

def cursor
  @cursor
end

#optionsWalletTransactionListRequestOptions

Additional wallet transaction options



43
44
45
# File 'lib/the_plaid_api/models/wallet_transactions_list_request.rb', line 43

def options
  @options
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/wallet_transactions_list_request.rb', line 22

def secret
  @secret
end

#wallet_idString

The ID of the e-wallet to fetch transactions from

Returns:

  • (String)


26
27
28
# File 'lib/the_plaid_api/models/wallet_transactions_list_request.rb', line 26

def wallet_id
  @wallet_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/the_plaid_api/models/wallet_transactions_list_request.rb', line 90

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  wallet_id = hash.key?('wallet_id') ? hash['wallet_id'] : nil
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  cursor = hash.key?('cursor') ? hash['cursor'] : SKIP
  count = hash['count'] ||= 10
  options = WalletTransactionListRequestOptions.from_hash(hash['options']) if hash['options']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  WalletTransactionsListRequest.new(wallet_id: wallet_id,
                                    client_id: client_id,
                                    secret: secret,
                                    cursor: cursor,
                                    count: count,
                                    options: options,
                                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



46
47
48
49
50
51
52
53
54
55
# File 'lib/the_plaid_api/models/wallet_transactions_list_request.rb', line 46

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['wallet_id'] = 'wallet_id'
  @_hash['cursor'] = 'cursor'
  @_hash['count'] = 'count'
  @_hash['options'] = 'options'
  @_hash
end

.nullablesObject

An array for nullable fields



69
70
71
72
73
# File 'lib/the_plaid_api/models/wallet_transactions_list_request.rb', line 69

def self.nullables
  %w[
    options
  ]
end

.optionalsObject

An array for optional fields



58
59
60
61
62
63
64
65
66
# File 'lib/the_plaid_api/models/wallet_transactions_list_request.rb', line 58

def self.optionals
  %w[
    client_id
    secret
    cursor
    count
    options
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



127
128
129
130
131
132
# File 'lib/the_plaid_api/models/wallet_transactions_list_request.rb', line 127

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, wallet_id:"\
  " #{@wallet_id.inspect}, cursor: #{@cursor.inspect}, count: #{@count.inspect}, options:"\
  " #{@options.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



119
120
121
122
123
124
# File 'lib/the_plaid_api/models/wallet_transactions_list_request.rb', line 119

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, wallet_id: #{@wallet_id},"\
  " cursor: #{@cursor}, count: #{@count}, options: #{@options}, additional_properties:"\
  " #{@additional_properties}>"
end