Class: ThePlaidApi::WatchlistScreeningAuditTrail

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/watchlist_screening_audit_trail.rb

Overview

Information about the last change made to the parent object specifying what caused the change as well as when it occurred.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(source:, dashboard_user_id:, timestamp:, additional_properties: nil) ⇒ WatchlistScreeningAuditTrail

Returns a new instance of WatchlistScreeningAuditTrail.



49
50
51
52
53
54
55
56
57
58
# File 'lib/the_plaid_api/models/watchlist_screening_audit_trail.rb', line 49

def initialize(source:, dashboard_user_id:, timestamp:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @source = source
  @dashboard_user_id = dashboard_user_id
  @timestamp = timestamp
  @additional_properties = additional_properties
end

Instance Attribute Details

#dashboard_user_idString

ID of the associated user. To retrieve the email address or other details of the person corresponding to this id, use ‘/dashboard_user/get`.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/watchlist_screening_audit_trail.rb', line 22

def dashboard_user_id
  @dashboard_user_id
end

#sourceSource

A type indicating whether a dashboard user, an API-based user, or Plaid last touched this object.

Returns:



17
18
19
# File 'lib/the_plaid_api/models/watchlist_screening_audit_trail.rb', line 17

def source
  @source
end

#timestampDateTime

An ISO8601 formatted timestamp.

Returns:

  • (DateTime)


26
27
28
# File 'lib/the_plaid_api/models/watchlist_screening_audit_trail.rb', line 26

def timestamp
  @timestamp
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/the_plaid_api/models/watchlist_screening_audit_trail.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  source = hash.key?('source') ? hash['source'] : nil
  dashboard_user_id =
    hash.key?('dashboard_user_id') ? hash['dashboard_user_id'] : nil
  timestamp = if hash.key?('timestamp')
                (DateTimeHelper.from_rfc3339(hash['timestamp']) if hash['timestamp'])
              end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  WatchlistScreeningAuditTrail.new(source: source,
                                   dashboard_user_id: dashboard_user_id,
                                   timestamp: timestamp,
                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
# File 'lib/the_plaid_api/models/watchlist_screening_audit_trail.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['source'] = 'source'
  @_hash['dashboard_user_id'] = 'dashboard_user_id'
  @_hash['timestamp'] = 'timestamp'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
46
47
# File 'lib/the_plaid_api/models/watchlist_screening_audit_trail.rb', line 43

def self.nullables
  %w[
    dashboard_user_id
  ]
end

.optionalsObject

An array for optional fields



38
39
40
# File 'lib/the_plaid_api/models/watchlist_screening_audit_trail.rb', line 38

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



98
99
100
101
102
103
# File 'lib/the_plaid_api/models/watchlist_screening_audit_trail.rb', line 98

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} source: #{@source.inspect}, dashboard_user_id:"\
  " #{@dashboard_user_id.inspect}, timestamp: #{@timestamp.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_custom_timestampObject



86
87
88
# File 'lib/the_plaid_api/models/watchlist_screening_audit_trail.rb', line 86

def to_custom_timestamp
  DateTimeHelper.to_rfc3339(timestamp)
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
# File 'lib/the_plaid_api/models/watchlist_screening_audit_trail.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} source: #{@source}, dashboard_user_id: #{@dashboard_user_id}, timestamp:"\
  " #{@timestamp}, additional_properties: #{@additional_properties}>"
end