Class: ThePlaidApi::WatchlistScreeningEntityHitListResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/watchlist_screening_entity_hit_list_response.rb

Overview

Paginated list of entity watchlist screening hits

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(entity_watchlist_screening_hits:, next_cursor:, request_id:, additional_properties: nil) ⇒ WatchlistScreeningEntityHitListResponse

Returns a new instance of WatchlistScreeningEntityHitListResponse.



48
49
50
51
52
53
54
55
56
57
# File 'lib/the_plaid_api/models/watchlist_screening_entity_hit_list_response.rb', line 48

def initialize(entity_watchlist_screening_hits:, next_cursor:, request_id:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @entity_watchlist_screening_hits = entity_watchlist_screening_hits
  @next_cursor = next_cursor
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#entity_watchlist_screening_hitsArray[EntityWatchlistScreeningHit]

List of entity watchlist screening hits

Returns:



14
15
16
# File 'lib/the_plaid_api/models/watchlist_screening_entity_hit_list_response.rb', line 14

def entity_watchlist_screening_hits
  @entity_watchlist_screening_hits
end

#next_cursorString

An identifier that determines which page of results you receive.

Returns:

  • (String)


18
19
20
# File 'lib/the_plaid_api/models/watchlist_screening_entity_hit_list_response.rb', line 18

def next_cursor
  @next_cursor
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


24
25
26
# File 'lib/the_plaid_api/models/watchlist_screening_entity_hit_list_response.rb', line 24

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/the_plaid_api/models/watchlist_screening_entity_hit_list_response.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  entity_watchlist_screening_hits = nil
  unless hash['entity_watchlist_screening_hits'].nil?
    entity_watchlist_screening_hits = []
    hash['entity_watchlist_screening_hits'].each do |structure|
      entity_watchlist_screening_hits << (EntityWatchlistScreeningHit.from_hash(structure) if structure)
    end
  end

  entity_watchlist_screening_hits = nil unless hash.key?('entity_watchlist_screening_hits')
  next_cursor = hash.key?('next_cursor') ? hash['next_cursor'] : nil
  request_id = hash.key?('request_id') ? hash['request_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  WatchlistScreeningEntityHitListResponse.new(entity_watchlist_screening_hits: entity_watchlist_screening_hits,
                                              next_cursor: next_cursor,
                                              request_id: request_id,
                                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
34
# File 'lib/the_plaid_api/models/watchlist_screening_entity_hit_list_response.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['entity_watchlist_screening_hits'] =
    'entity_watchlist_screening_hits'
  @_hash['next_cursor'] = 'next_cursor'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



42
43
44
45
46
# File 'lib/the_plaid_api/models/watchlist_screening_entity_hit_list_response.rb', line 42

def self.nullables
  %w[
    next_cursor
  ]
end

.optionalsObject

An array for optional fields



37
38
39
# File 'lib/the_plaid_api/models/watchlist_screening_entity_hit_list_response.rb', line 37

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



100
101
102
103
104
105
# File 'lib/the_plaid_api/models/watchlist_screening_entity_hit_list_response.rb', line 100

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} entity_watchlist_screening_hits:"\
  " #{@entity_watchlist_screening_hits.inspect}, next_cursor: #{@next_cursor.inspect},"\
  " request_id: #{@request_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
97
# File 'lib/the_plaid_api/models/watchlist_screening_entity_hit_list_response.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} entity_watchlist_screening_hits: #{@entity_watchlist_screening_hits},"\
  " next_cursor: #{@next_cursor}, request_id: #{@request_id}, additional_properties:"\
  " #{@additional_properties}>"
end