Class: ThePlaidApi::WatchlistScreeningEntityListRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/watchlist_screening_entity_list_request.rb

Overview

Request input for listing entity watchlist screenings

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(entity_watchlist_program_id:, secret: SKIP, client_id: SKIP, client_user_id: SKIP, status: SKIP, assignee: SKIP, cursor: SKIP, additional_properties: nil) ⇒ WatchlistScreeningEntityListRequest

Returns a new instance of WatchlistScreeningEntityListRequest.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/the_plaid_api/models/watchlist_screening_entity_list_request.rb', line 83

def initialize(entity_watchlist_program_id:, secret: SKIP, client_id: SKIP,
               client_user_id: SKIP, status: SKIP, assignee: SKIP,
               cursor: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @secret = secret unless secret == SKIP
  @client_id = client_id unless client_id == SKIP
  @entity_watchlist_program_id = entity_watchlist_program_id
  @client_user_id = client_user_id unless client_user_id == SKIP
  @status = status unless status == SKIP
  @assignee = assignee unless assignee == SKIP
  @cursor = cursor unless cursor == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#assigneeString

ID of the associated user. To retrieve the email address or other details of the person corresponding to this id, use ‘/dashboard_user/get`.

Returns:

  • (String)


45
46
47
# File 'lib/the_plaid_api/models/watchlist_screening_entity_list_request.rb', line 45

def assignee
  @assignee
end

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/watchlist_screening_entity_list_request.rb', line 21

def client_id
  @client_id
end

#client_user_idString

A unique ID that identifies the end user in your system. Either a ‘user_id` or the `client_user_id` must be provided. This ID can also be used to associate user-specific data from other Plaid products. Financial Account Matching requires this field and the `/link/token/create` `client_user_id` to be consistent. Personally identifiable information, such as an email address or phone number, should not be used in the `client_user_id`.

Returns:

  • (String)


35
36
37
# File 'lib/the_plaid_api/models/watchlist_screening_entity_list_request.rb', line 35

def client_user_id
  @client_user_id
end

#cursorString

An identifier that determines which page of results you receive.

Returns:

  • (String)


49
50
51
# File 'lib/the_plaid_api/models/watchlist_screening_entity_list_request.rb', line 49

def cursor
  @cursor
end

#entity_watchlist_program_idString

ID of the associated entity program.

Returns:

  • (String)


25
26
27
# File 'lib/the_plaid_api/models/watchlist_screening_entity_list_request.rb', line 25

def entity_watchlist_program_id
  @entity_watchlist_program_id
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/watchlist_screening_entity_list_request.rb', line 15

def secret
  @secret
end

#statusWatchlistScreeningStatus

A status enum indicating whether a screening is still pending review, has been rejected, or has been cleared.



40
41
42
# File 'lib/the_plaid_api/models/watchlist_screening_entity_list_request.rb', line 40

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/the_plaid_api/models/watchlist_screening_entity_list_request.rb', line 100

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  entity_watchlist_program_id =
    hash.key?('entity_watchlist_program_id') ? hash['entity_watchlist_program_id'] : nil
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  client_user_id =
    hash.key?('client_user_id') ? hash['client_user_id'] : SKIP
  status = hash.key?('status') ? hash['status'] : SKIP
  assignee = hash.key?('assignee') ? hash['assignee'] : SKIP
  cursor = hash.key?('cursor') ? hash['cursor'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  WatchlistScreeningEntityListRequest.new(entity_watchlist_program_id: entity_watchlist_program_id,
                                          secret: secret,
                                          client_id: client_id,
                                          client_user_id: client_user_id,
                                          status: status,
                                          assignee: assignee,
                                          cursor: cursor,
                                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



52
53
54
55
56
57
58
59
60
61
62
# File 'lib/the_plaid_api/models/watchlist_screening_entity_list_request.rb', line 52

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['secret'] = 'secret'
  @_hash['client_id'] = 'client_id'
  @_hash['entity_watchlist_program_id'] = 'entity_watchlist_program_id'
  @_hash['client_user_id'] = 'client_user_id'
  @_hash['status'] = 'status'
  @_hash['assignee'] = 'assignee'
  @_hash['cursor'] = 'cursor'
  @_hash
end

.nullablesObject

An array for nullable fields



77
78
79
80
81
# File 'lib/the_plaid_api/models/watchlist_screening_entity_list_request.rb', line 77

def self.nullables
  %w[
    cursor
  ]
end

.optionalsObject

An array for optional fields



65
66
67
68
69
70
71
72
73
74
# File 'lib/the_plaid_api/models/watchlist_screening_entity_list_request.rb', line 65

def self.optionals
  %w[
    secret
    client_id
    client_user_id
    status
    assignee
    cursor
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



142
143
144
145
146
147
148
# File 'lib/the_plaid_api/models/watchlist_screening_entity_list_request.rb', line 142

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} secret: #{@secret.inspect}, client_id: #{@client_id.inspect},"\
  " entity_watchlist_program_id: #{@entity_watchlist_program_id.inspect}, client_user_id:"\
  " #{@client_user_id.inspect}, status: #{@status.inspect}, assignee: #{@assignee.inspect},"\
  " cursor: #{@cursor.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



133
134
135
136
137
138
139
# File 'lib/the_plaid_api/models/watchlist_screening_entity_list_request.rb', line 133

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} secret: #{@secret}, client_id: #{@client_id}, entity_watchlist_program_id:"\
  " #{@entity_watchlist_program_id}, client_user_id: #{@client_user_id}, status: #{@status},"\
  " assignee: #{@assignee}, cursor: #{@cursor}, additional_properties:"\
  " #{@additional_properties}>"
end