Class: ThePlaidApi::WatchlistScreeningEntityReviewCreateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/watchlist_screening_entity_review_create_request.rb

Overview

Request input for creating a review for an entity screening

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(confirmed_hits:, dismissed_hits:, entity_watchlist_screening_id:, comment: SKIP, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ WatchlistScreeningEntityReviewCreateRequest

Returns a new instance of WatchlistScreeningEntityReviewCreateRequest.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_create_request.rb', line 72

def initialize(confirmed_hits:, dismissed_hits:,
               entity_watchlist_screening_id:, comment: SKIP,
               client_id: SKIP, secret: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @confirmed_hits = confirmed_hits
  @dismissed_hits = dismissed_hits
  @comment = comment unless comment == SKIP
  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @entity_watchlist_screening_id = entity_watchlist_screening_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


32
33
34
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_create_request.rb', line 32

def client_id
  @client_id
end

#commentString

A comment submitted by a team member as part of reviewing a watchlist screening.

Returns:

  • (String)


26
27
28
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_create_request.rb', line 26

def comment
  @comment
end

#confirmed_hitsArray[String]

Hits to mark as a true positive after thorough manual review. These hits will never recur or be updated once dismissed. In most cases, confirmed hits indicate that the customer should be rejected.

Returns:

  • (Array[String])


16
17
18
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_create_request.rb', line 16

def confirmed_hits
  @confirmed_hits
end

#dismissed_hitsArray[String]

Hits to mark as a false positive after thorough manual review. These hits will never recur or be updated once dismissed.

Returns:

  • (Array[String])


21
22
23
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_create_request.rb', line 21

def dismissed_hits
  @dismissed_hits
end

#entity_watchlist_screening_idString

ID of the associated entity screening.

Returns:

  • (String)


41
42
43
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_create_request.rb', line 41

def entity_watchlist_screening_id
  @entity_watchlist_screening_id
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


37
38
39
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_create_request.rb', line 37

def secret
  @secret
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_create_request.rb', line 88

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  confirmed_hits =
    hash.key?('confirmed_hits') ? hash['confirmed_hits'] : nil
  dismissed_hits =
    hash.key?('dismissed_hits') ? hash['dismissed_hits'] : nil
  entity_watchlist_screening_id =
    hash.key?('entity_watchlist_screening_id') ? hash['entity_watchlist_screening_id'] : nil
  comment = hash.key?('comment') ? hash['comment'] : SKIP
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  WatchlistScreeningEntityReviewCreateRequest.new(confirmed_hits: confirmed_hits,
                                                  dismissed_hits: dismissed_hits,
                                                  entity_watchlist_screening_id: entity_watchlist_screening_id,
                                                  comment: comment,
                                                  client_id: client_id,
                                                  secret: secret,
                                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



44
45
46
47
48
49
50
51
52
53
54
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_create_request.rb', line 44

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['confirmed_hits'] = 'confirmed_hits'
  @_hash['dismissed_hits'] = 'dismissed_hits'
  @_hash['comment'] = 'comment'
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash['entity_watchlist_screening_id'] =
    'entity_watchlist_screening_id'
  @_hash
end

.nullablesObject

An array for nullable fields



66
67
68
69
70
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_create_request.rb', line 66

def self.nullables
  %w[
    comment
  ]
end

.optionalsObject

An array for optional fields



57
58
59
60
61
62
63
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_create_request.rb', line 57

def self.optionals
  %w[
    comment
    client_id
    secret
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



129
130
131
132
133
134
135
136
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_create_request.rb', line 129

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} confirmed_hits: #{@confirmed_hits.inspect}, dismissed_hits:"\
  " #{@dismissed_hits.inspect}, comment: #{@comment.inspect}, client_id:"\
  " #{@client_id.inspect}, secret: #{@secret.inspect}, entity_watchlist_screening_id:"\
  " #{@entity_watchlist_screening_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



120
121
122
123
124
125
126
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_create_request.rb', line 120

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} confirmed_hits: #{@confirmed_hits}, dismissed_hits: #{@dismissed_hits},"\
  " comment: #{@comment}, client_id: #{@client_id}, secret: #{@secret},"\
  " entity_watchlist_screening_id: #{@entity_watchlist_screening_id}, additional_properties:"\
  " #{@additional_properties}>"
end