Class: ThePlaidApi::WatchlistScreeningEntityReviewListRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/watchlist_screening_entity_review_list_request.rb

Overview

Request input for listing reviews for an entity watchlist screening

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(entity_watchlist_screening_id:, secret: SKIP, client_id: SKIP, cursor: SKIP, additional_properties: nil) ⇒ WatchlistScreeningEntityReviewListRequest

Returns a new instance of WatchlistScreeningEntityReviewListRequest.



58
59
60
61
62
63
64
65
66
67
68
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_list_request.rb', line 58

def initialize(entity_watchlist_screening_id:, secret: SKIP,
               client_id: SKIP, cursor: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @secret = secret unless secret == SKIP
  @client_id = client_id unless client_id == SKIP
  @entity_watchlist_screening_id = entity_watchlist_screening_id
  @cursor = cursor unless cursor == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_list_request.rb', line 21

def client_id
  @client_id
end

#cursorString

An identifier that determines which page of results you receive.

Returns:

  • (String)


29
30
31
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_list_request.rb', line 29

def cursor
  @cursor
end

#entity_watchlist_screening_idString

ID of the associated entity screening.

Returns:

  • (String)


25
26
27
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_list_request.rb', line 25

def entity_watchlist_screening_id
  @entity_watchlist_screening_id
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


15
16
17
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_list_request.rb', line 15

def secret
  @secret
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_list_request.rb', line 71

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  entity_watchlist_screening_id =
    hash.key?('entity_watchlist_screening_id') ? hash['entity_watchlist_screening_id'] : nil
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  cursor = hash.key?('cursor') ? hash['cursor'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  WatchlistScreeningEntityReviewListRequest.new(entity_watchlist_screening_id: entity_watchlist_screening_id,
                                                secret: secret,
                                                client_id: client_id,
                                                cursor: cursor,
                                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



32
33
34
35
36
37
38
39
40
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_list_request.rb', line 32

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['secret'] = 'secret'
  @_hash['client_id'] = 'client_id'
  @_hash['entity_watchlist_screening_id'] =
    'entity_watchlist_screening_id'
  @_hash['cursor'] = 'cursor'
  @_hash
end

.nullablesObject

An array for nullable fields



52
53
54
55
56
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_list_request.rb', line 52

def self.nullables
  %w[
    cursor
  ]
end

.optionalsObject

An array for optional fields



43
44
45
46
47
48
49
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_list_request.rb', line 43

def self.optionals
  %w[
    secret
    client_id
    cursor
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



105
106
107
108
109
110
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_list_request.rb', line 105

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} secret: #{@secret.inspect}, client_id: #{@client_id.inspect},"\
  " entity_watchlist_screening_id: #{@entity_watchlist_screening_id.inspect}, cursor:"\
  " #{@cursor.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



97
98
99
100
101
102
# File 'lib/the_plaid_api/models/watchlist_screening_entity_review_list_request.rb', line 97

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} secret: #{@secret}, client_id: #{@client_id},"\
  " entity_watchlist_screening_id: #{@entity_watchlist_screening_id}, cursor: #{@cursor},"\
  " additional_properties: #{@additional_properties}>"
end