Class: ThePlaidApi::WatchlistScreeningHitLocations

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/watchlist_screening_hit_locations.rb

Overview

Location information for the associated individual watchlist hit

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(full:, country:, additional_properties: nil) ⇒ WatchlistScreeningHitLocations

Returns a new instance of WatchlistScreeningHitLocations.



41
42
43
44
45
46
47
48
# File 'lib/the_plaid_api/models/watchlist_screening_hit_locations.rb', line 41

def initialize(full:, country:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @full = full
  @country = country
  @additional_properties = additional_properties
end

Instance Attribute Details

#countryString

Valid, capitalized, two-letter ISO code representing the country of this object. Must be in ISO 3166-1 alpha-2 form.

Returns:

  • (String)


21
22
23
# File 'lib/the_plaid_api/models/watchlist_screening_hit_locations.rb', line 21

def country
  @country
end

#fullString

The full location string, potentially including elements like street, city, postal codes and country codes. Note that this is not necessarily a complete or well-formatted address.

Returns:

  • (String)


16
17
18
# File 'lib/the_plaid_api/models/watchlist_screening_hit_locations.rb', line 16

def full
  @full
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/the_plaid_api/models/watchlist_screening_hit_locations.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  full = hash.key?('full') ? hash['full'] : nil
  country = hash.key?('country') ? hash['country'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  WatchlistScreeningHitLocations.new(full: full,
                                     country: country,
                                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
29
# File 'lib/the_plaid_api/models/watchlist_screening_hit_locations.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['full'] = 'full'
  @_hash['country'] = 'country'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/the_plaid_api/models/watchlist_screening_hit_locations.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



32
33
34
# File 'lib/the_plaid_api/models/watchlist_screening_hit_locations.rb', line 32

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/the_plaid_api/models/watchlist_screening_hit_locations.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} full: #{@full.inspect}, country: #{@country.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/the_plaid_api/models/watchlist_screening_hit_locations.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} full: #{@full}, country: #{@country}, additional_properties:"\
  " #{@additional_properties}>"
end