Class: ThePlaidApi::WatchlistScreeningIndividualCreateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/watchlist_screening_individual_create_request.rb

Overview

Request input for creating an individual watchlist screening

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(search_terms:, client_user_id: SKIP, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ WatchlistScreeningIndividualCreateRequest

Returns a new instance of WatchlistScreeningIndividualCreateRequest.



61
62
63
64
65
66
67
68
69
70
71
# File 'lib/the_plaid_api/models/watchlist_screening_individual_create_request.rb', line 61

def initialize(search_terms:, client_user_id: SKIP, client_id: SKIP,
               secret: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @search_terms = search_terms
  @client_user_id = client_user_id unless client_user_id == SKIP
  @client_id = client_id unless client_id == SKIP
  @secret = secret unless secret == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


30
31
32
# File 'lib/the_plaid_api/models/watchlist_screening_individual_create_request.rb', line 30

def client_id
  @client_id
end

#client_user_idString

A unique ID that identifies the end user in your system. Either a ‘user_id` or the `client_user_id` must be provided. This ID can also be used to associate user-specific data from other Plaid products. Financial Account Matching requires this field and the `/link/token/create` `client_user_id` to be consistent. Personally identifiable information, such as an email address or phone number, should not be used in the `client_user_id`.

Returns:

  • (String)


24
25
26
# File 'lib/the_plaid_api/models/watchlist_screening_individual_create_request.rb', line 24

def client_user_id
  @client_user_id
end

#search_termsWatchlistScreeningRequestSearchTerms

Search inputs for creating a watchlist screening



14
15
16
# File 'lib/the_plaid_api/models/watchlist_screening_individual_create_request.rb', line 14

def search_terms
  @search_terms
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


35
36
37
# File 'lib/the_plaid_api/models/watchlist_screening_individual_create_request.rb', line 35

def secret
  @secret
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/the_plaid_api/models/watchlist_screening_individual_create_request.rb', line 74

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  search_terms = WatchlistScreeningRequestSearchTerms.from_hash(hash['search_terms']) if
    hash['search_terms']
  client_user_id =
    hash.key?('client_user_id') ? hash['client_user_id'] : SKIP
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP
  secret = hash.key?('secret') ? hash['secret'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  WatchlistScreeningIndividualCreateRequest.new(search_terms: search_terms,
                                                client_user_id: client_user_id,
                                                client_id: client_id,
                                                secret: secret,
                                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



38
39
40
41
42
43
44
45
# File 'lib/the_plaid_api/models/watchlist_screening_individual_create_request.rb', line 38

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['search_terms'] = 'search_terms'
  @_hash['client_user_id'] = 'client_user_id'
  @_hash['client_id'] = 'client_id'
  @_hash['secret'] = 'secret'
  @_hash
end

.nullablesObject

An array for nullable fields



57
58
59
# File 'lib/the_plaid_api/models/watchlist_screening_individual_create_request.rb', line 57

def self.nullables
  []
end

.optionalsObject

An array for optional fields



48
49
50
51
52
53
54
# File 'lib/the_plaid_api/models/watchlist_screening_individual_create_request.rb', line 48

def self.optionals
  %w[
    client_user_id
    client_id
    secret
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



109
110
111
112
113
114
# File 'lib/the_plaid_api/models/watchlist_screening_individual_create_request.rb', line 109

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} search_terms: #{@search_terms.inspect}, client_user_id:"\
  " #{@client_user_id.inspect}, client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



101
102
103
104
105
106
# File 'lib/the_plaid_api/models/watchlist_screening_individual_create_request.rb', line 101

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} search_terms: #{@search_terms}, client_user_id: #{@client_user_id},"\
  " client_id: #{@client_id}, secret: #{@secret}, additional_properties:"\
  " #{@additional_properties}>"
end