Class: ThePlaidApi::WatchlistScreeningIndividualGetRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/watchlist_screening_individual_get_request.rb

Overview

Request input for fetching an individual watchlist screening

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(watchlist_screening_id:, secret: SKIP, client_id: SKIP, additional_properties: nil) ⇒ WatchlistScreeningIndividualGetRequest

Returns a new instance of WatchlistScreeningIndividualGetRequest.



49
50
51
52
53
54
55
56
57
58
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_request.rb', line 49

def initialize(watchlist_screening_id:, secret: SKIP, client_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @watchlist_screening_id = watchlist_screening_id
  @secret = secret unless secret == SKIP
  @client_id = client_id unless client_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_idString

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.

Returns:

  • (String)


25
26
27
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_request.rb', line 25

def client_id
  @client_id
end

#secretString

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.

Returns:

  • (String)


19
20
21
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_request.rb', line 19

def secret
  @secret
end

#watchlist_screening_idString

ID of the associated screening.

Returns:

  • (String)


14
15
16
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_request.rb', line 14

def watchlist_screening_id
  @watchlist_screening_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_request.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  watchlist_screening_id =
    hash.key?('watchlist_screening_id') ? hash['watchlist_screening_id'] : nil
  secret = hash.key?('secret') ? hash['secret'] : SKIP
  client_id = hash.key?('client_id') ? hash['client_id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  WatchlistScreeningIndividualGetRequest.new(watchlist_screening_id: watchlist_screening_id,
                                             secret: secret,
                                             client_id: client_id,
                                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



28
29
30
31
32
33
34
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_request.rb', line 28

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['watchlist_screening_id'] = 'watchlist_screening_id'
  @_hash['secret'] = 'secret'
  @_hash['client_id'] = 'client_id'
  @_hash
end

.nullablesObject

An array for nullable fields



45
46
47
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_request.rb', line 45

def self.nullables
  []
end

.optionalsObject

An array for optional fields



37
38
39
40
41
42
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_request.rb', line 37

def self.optionals
  %w[
    secret
    client_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



92
93
94
95
96
97
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_request.rb', line 92

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} watchlist_screening_id: #{@watchlist_screening_id.inspect}, secret:"\
  " #{@secret.inspect}, client_id: #{@client_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



85
86
87
88
89
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_request.rb', line 85

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} watchlist_screening_id: #{@watchlist_screening_id}, secret: #{@secret},"\
  " client_id: #{@client_id}, additional_properties: #{@additional_properties}>"
end