Class: ThePlaidApi::WatchlistScreeningIndividualGetResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::WatchlistScreeningIndividualGetResponse
- Defined in:
- lib/the_plaid_api/models/watchlist_screening_individual_get_response.rb
Overview
The screening object allows you to represent a customer in your system, update their profile, and search for them on various watchlists. Note: Rejected customers will not receive new hits, regardless of program configuration.
Instance Attribute Summary collapse
-
#assignee ⇒ String
ID of the associated user.
-
#audit_trail ⇒ WatchlistScreeningAuditTrail
Information about the last change made to the parent object specifying what caused the change as well as when it occurred.
-
#client_user_id ⇒ String
A unique ID that identifies the end user in your system.
-
#id ⇒ String
ID of the associated screening.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
-
#search_terms ⇒ WatchlistScreeningSearchTerms
Search terms for creating an individual watchlist screening.
-
#status ⇒ WatchlistScreeningStatus
A status enum indicating whether a screening is still pending review, has been rejected, or has been cleared.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id:, search_terms:, assignee:, status:, client_user_id:, audit_trail:, request_id:, additional_properties: nil) ⇒ WatchlistScreeningIndividualGetResponse
constructor
A new instance of WatchlistScreeningIndividualGetResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id:, search_terms:, assignee:, status:, client_user_id:, audit_trail:, request_id:, additional_properties: nil) ⇒ WatchlistScreeningIndividualGetResponse
Returns a new instance of WatchlistScreeningIndividualGetResponse.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_response.rb', line 80 def initialize(id:, search_terms:, assignee:, status:, client_user_id:, audit_trail:, request_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id @search_terms = search_terms @assignee = assignee @status = status @client_user_id = client_user_id @audit_trail = audit_trail @request_id = request_id @additional_properties = additional_properties end |
Instance Attribute Details
#assignee ⇒ String
ID of the associated user. To retrieve the email address or other details of the person corresponding to this id, use ‘/dashboard_user/get`.
26 27 28 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_response.rb', line 26 def assignee @assignee end |
#audit_trail ⇒ WatchlistScreeningAuditTrail
Information about the last change made to the parent object specifying what caused the change as well as when it occurred.
46 47 48 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_response.rb', line 46 def audit_trail @audit_trail end |
#client_user_id ⇒ String
A unique ID that identifies the end user in your system. Either a ‘user_id` or the `client_user_id` must be provided. This ID can also be used to associate user-specific data from other Plaid products. Financial Account Matching requires this field and the `/link/token/create` `client_user_id` to be consistent. Personally identifiable information, such as an email address or phone number, should not be used in the `client_user_id`.
41 42 43 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_response.rb', line 41 def client_user_id @client_user_id end |
#id ⇒ String
ID of the associated screening.
17 18 19 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_response.rb', line 17 def id @id end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
52 53 54 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_response.rb', line 52 def request_id @request_id end |
#search_terms ⇒ WatchlistScreeningSearchTerms
Search terms for creating an individual watchlist screening
21 22 23 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_response.rb', line 21 def search_terms @search_terms end |
#status ⇒ WatchlistScreeningStatus
A status enum indicating whether a screening is still pending review, has been rejected, or has been cleared.
31 32 33 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_response.rb', line 31 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_response.rb', line 96 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil search_terms = WatchlistScreeningSearchTerms.from_hash(hash['search_terms']) if hash['search_terms'] assignee = hash.key?('assignee') ? hash['assignee'] : nil status = hash.key?('status') ? hash['status'] : nil client_user_id = hash.key?('client_user_id') ? hash['client_user_id'] : nil audit_trail = WatchlistScreeningAuditTrail.from_hash(hash['audit_trail']) if hash['audit_trail'] request_id = hash.key?('request_id') ? hash['request_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. WatchlistScreeningIndividualGetResponse.new(id: id, search_terms: search_terms, assignee: assignee, status: status, client_user_id: client_user_id, audit_trail: audit_trail, request_id: request_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_response.rb', line 55 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['search_terms'] = 'search_terms' @_hash['assignee'] = 'assignee' @_hash['status'] = 'status' @_hash['client_user_id'] = 'client_user_id' @_hash['audit_trail'] = 'audit_trail' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
73 74 75 76 77 78 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_response.rb', line 73 def self.nullables %w[ assignee client_user_id ] end |
.optionals ⇒ Object
An array for optional fields
68 69 70 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_response.rb', line 68 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
138 139 140 141 142 143 144 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_response.rb', line 138 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, search_terms: #{@search_terms.inspect}, assignee:"\ " #{@assignee.inspect}, status: #{@status.inspect}, client_user_id:"\ " #{@client_user_id.inspect}, audit_trail: #{@audit_trail.inspect}, request_id:"\ " #{@request_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
130 131 132 133 134 135 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_get_response.rb', line 130 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, search_terms: #{@search_terms}, assignee: #{@assignee}, status:"\ " #{@status}, client_user_id: #{@client_user_id}, audit_trail: #{@audit_trail}, request_id:"\ " #{@request_id}, additional_properties: #{@additional_properties}>" end |