Class: ThePlaidApi::WatchlistScreeningIndividualListResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/watchlist_screening_individual_list_response.rb

Overview

Paginated list of individual watchlist screenings.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(watchlist_screenings:, next_cursor:, request_id:, additional_properties: nil) ⇒ WatchlistScreeningIndividualListResponse

Returns a new instance of WatchlistScreeningIndividualListResponse.



47
48
49
50
51
52
53
54
55
56
# File 'lib/the_plaid_api/models/watchlist_screening_individual_list_response.rb', line 47

def initialize(watchlist_screenings:, next_cursor:, request_id:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @watchlist_screenings = watchlist_screenings
  @next_cursor = next_cursor
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#next_cursorString

An identifier that determines which page of results you receive.

Returns:

  • (String)


18
19
20
# File 'lib/the_plaid_api/models/watchlist_screening_individual_list_response.rb', line 18

def next_cursor
  @next_cursor
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


24
25
26
# File 'lib/the_plaid_api/models/watchlist_screening_individual_list_response.rb', line 24

def request_id
  @request_id
end

#watchlist_screeningsArray[WatchlistScreeningIndividual]

List of individual watchlist screenings

Returns:



14
15
16
# File 'lib/the_plaid_api/models/watchlist_screening_individual_list_response.rb', line 14

def watchlist_screenings
  @watchlist_screenings
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/the_plaid_api/models/watchlist_screening_individual_list_response.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  watchlist_screenings = nil
  unless hash['watchlist_screenings'].nil?
    watchlist_screenings = []
    hash['watchlist_screenings'].each do |structure|
      watchlist_screenings << (WatchlistScreeningIndividual.from_hash(structure) if structure)
    end
  end

  watchlist_screenings = nil unless hash.key?('watchlist_screenings')
  next_cursor = hash.key?('next_cursor') ? hash['next_cursor'] : nil
  request_id = hash.key?('request_id') ? hash['request_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  WatchlistScreeningIndividualListResponse.new(watchlist_screenings: watchlist_screenings,
                                               next_cursor: next_cursor,
                                               request_id: request_id,
                                               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
# File 'lib/the_plaid_api/models/watchlist_screening_individual_list_response.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['watchlist_screenings'] = 'watchlist_screenings'
  @_hash['next_cursor'] = 'next_cursor'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
44
45
# File 'lib/the_plaid_api/models/watchlist_screening_individual_list_response.rb', line 41

def self.nullables
  %w[
    next_cursor
  ]
end

.optionalsObject

An array for optional fields



36
37
38
# File 'lib/the_plaid_api/models/watchlist_screening_individual_list_response.rb', line 36

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
104
# File 'lib/the_plaid_api/models/watchlist_screening_individual_list_response.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} watchlist_screenings: #{@watchlist_screenings.inspect}, next_cursor:"\
  " #{@next_cursor.inspect}, request_id: #{@request_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
96
# File 'lib/the_plaid_api/models/watchlist_screening_individual_list_response.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} watchlist_screenings: #{@watchlist_screenings}, next_cursor:"\
  " #{@next_cursor}, request_id: #{@request_id}, additional_properties:"\
  " #{@additional_properties}>"
end