Class: ThePlaidApi::WatchlistScreeningIndividualProgramListRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::WatchlistScreeningIndividualProgramListRequest
- Defined in:
- lib/the_plaid_api/models/watchlist_screening_individual_program_list_request.rb
Overview
Request input for listing watchlist screening programs for individuals
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#cursor ⇒ String
An identifier that determines which page of results you receive.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(secret: SKIP, client_id: SKIP, cursor: SKIP, additional_properties: nil) ⇒ WatchlistScreeningIndividualProgramListRequest
constructor
A new instance of WatchlistScreeningIndividualProgramListRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(secret: SKIP, client_id: SKIP, cursor: SKIP, additional_properties: nil) ⇒ WatchlistScreeningIndividualProgramListRequest
Returns a new instance of WatchlistScreeningIndividualProgramListRequest.
52 53 54 55 56 57 58 59 60 61 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_program_list_request.rb', line 52 def initialize(secret: SKIP, client_id: SKIP, cursor: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @secret = secret unless secret == SKIP @client_id = client_id unless client_id == SKIP @cursor = cursor unless cursor == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
21 22 23 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_program_list_request.rb', line 21 def client_id @client_id end |
#cursor ⇒ String
An identifier that determines which page of results you receive.
25 26 27 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_program_list_request.rb', line 25 def cursor @cursor end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
15 16 17 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_program_list_request.rb', line 15 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_program_list_request.rb', line 64 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. secret = hash.key?('secret') ? hash['secret'] : SKIP client_id = hash.key?('client_id') ? hash['client_id'] : SKIP cursor = hash.key?('cursor') ? hash['cursor'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. WatchlistScreeningIndividualProgramListRequest.new(secret: secret, client_id: client_id, cursor: cursor, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
28 29 30 31 32 33 34 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_program_list_request.rb', line 28 def self.names @_hash = {} if @_hash.nil? @_hash['secret'] = 'secret' @_hash['client_id'] = 'client_id' @_hash['cursor'] = 'cursor' @_hash end |
.nullables ⇒ Object
An array for nullable fields
46 47 48 49 50 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_program_list_request.rb', line 46 def self.nullables %w[ cursor ] end |
.optionals ⇒ Object
An array for optional fields
37 38 39 40 41 42 43 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_program_list_request.rb', line 37 def self.optionals %w[ secret client_id cursor ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
94 95 96 97 98 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_program_list_request.rb', line 94 def inspect class_name = self.class.name.split('::').last "<#{class_name} secret: #{@secret.inspect}, client_id: #{@client_id.inspect}, cursor:"\ " #{@cursor.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
87 88 89 90 91 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_program_list_request.rb', line 87 def to_s class_name = self.class.name.split('::').last "<#{class_name} secret: #{@secret}, client_id: #{@client_id}, cursor: #{@cursor},"\ " additional_properties: #{@additional_properties}>" end |