Class: ThePlaidApi::WebhookVerificationKeyGetResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/the_plaid_api/models/webhook_verification_key_get_response.rb

Overview

WebhookVerificationKeyGetResponse defines the response schema for ‘/webhook_verification_key/get`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(key:, request_id:, additional_properties: nil) ⇒ WebhookVerificationKeyGetResponse

Returns a new instance of WebhookVerificationKeyGetResponse.



42
43
44
45
46
47
48
49
# File 'lib/the_plaid_api/models/webhook_verification_key_get_response.rb', line 42

def initialize(key:, request_id:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @key = key
  @request_id = request_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#keyJwkPublicKey

A JSON Web Key (JWK) that can be used in conjunction with [JWT libraries](jwt.io/#libraries-io) to verify Plaid webhooks

Returns:



16
17
18
# File 'lib/the_plaid_api/models/webhook_verification_key_get_response.rb', line 16

def key
  @key
end

#request_idString

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

Returns:

  • (String)


22
23
24
# File 'lib/the_plaid_api/models/webhook_verification_key_get_response.rb', line 22

def request_id
  @request_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/the_plaid_api/models/webhook_verification_key_get_response.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  key = JwkPublicKey.from_hash(hash['key']) if hash['key']
  request_id = hash.key?('request_id') ? hash['request_id'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  WebhookVerificationKeyGetResponse.new(key: key,
                                        request_id: request_id,
                                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
# File 'lib/the_plaid_api/models/webhook_verification_key_get_response.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['key'] = 'key'
  @_hash['request_id'] = 'request_id'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/the_plaid_api/models/webhook_verification_key_get_response.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



33
34
35
# File 'lib/the_plaid_api/models/webhook_verification_key_get_response.rb', line 33

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/the_plaid_api/models/webhook_verification_key_get_response.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} key: #{@key.inspect}, request_id: #{@request_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/the_plaid_api/models/webhook_verification_key_get_response.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} key: #{@key}, request_id: #{@request_id}, additional_properties:"\
  " #{@additional_properties}>"
end