Class: ThePlaidApi::AamvaAnalysis
- Defined in:
- lib/the_plaid_api/models/aamva_analysis.rb
Overview
Analyzed AAMVA data for the associated hit. Note: This field is only available for U.S. driver’s licenses issued by participating states.
Instance Attribute Summary collapse
-
#city ⇒ AamvaMatchResult
The outcome of checking the particular field against state databases.
-
#date_of_birth ⇒ AamvaMatchResult
The outcome of checking the particular field against state databases.
-
#eye_color ⇒ AamvaMatchResult
The outcome of checking the particular field against state databases.
-
#first_name ⇒ AamvaDetailedMatchResult
The outcome of checking the associated hit against state databases.
-
#gender ⇒ AamvaMatchResult
The outcome of checking the particular field against state databases.
-
#height ⇒ AamvaMatchResult
The outcome of checking the particular field against state databases.
-
#id_expiration_date ⇒ AamvaMatchResult
The outcome of checking the particular field against state databases.
-
#id_issue_date ⇒ AamvaMatchResult
The outcome of checking the particular field against state databases.
-
#id_number ⇒ AamvaMatchResult
The outcome of checking the particular field against state databases.
-
#is_verified ⇒ TrueClass | FalseClass
The overall outcome of checking the associated hit against the issuing state database.
-
#last_name ⇒ AamvaDetailedMatchResult
The outcome of checking the associated hit against state databases.
-
#middle_name ⇒ AamvaDetailedMatchResult
The outcome of checking the associated hit against state databases.
-
#postal_code ⇒ AamvaDetailedMatchResult
The outcome of checking the associated hit against state databases.
-
#street ⇒ AamvaDetailedMatchResult
The outcome of checking the associated hit against state databases.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(is_verified:, id_number:, id_issue_date:, id_expiration_date:, street:, city:, postal_code:, date_of_birth:, gender:, height:, eye_color:, first_name:, middle_name:, last_name:, additional_properties: nil) ⇒ AamvaAnalysis
constructor
A new instance of AamvaAnalysis.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(is_verified:, id_number:, id_issue_date:, id_expiration_date:, street:, city:, postal_code:, date_of_birth:, gender:, height:, eye_color:, first_name:, middle_name:, last_name:, additional_properties: nil) ⇒ AamvaAnalysis
Returns a new instance of AamvaAnalysis.
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/the_plaid_api/models/aamva_analysis.rb', line 144 def initialize(is_verified:, id_number:, id_issue_date:, id_expiration_date:, street:, city:, postal_code:, date_of_birth:, gender:, height:, eye_color:, first_name:, middle_name:, last_name:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @is_verified = is_verified @id_number = id_number @id_issue_date = id_issue_date @id_expiration_date = id_expiration_date @street = street @city = city @postal_code = postal_code @date_of_birth = date_of_birth @gender = gender @height = height @eye_color = eye_color @first_name = first_name @middle_name = middle_name @last_name = last_name @additional_properties = additional_properties end |
Instance Attribute Details
#city ⇒ AamvaMatchResult
The outcome of checking the particular field against state databases. ‘match` - The field is an exact match with the state database. `no_match` - The field is not an exact match with the state database. `no_data` - The field was unable to be checked against state databases.
52 53 54 |
# File 'lib/the_plaid_api/models/aamva_analysis.rb', line 52 def city @city end |
#date_of_birth ⇒ AamvaMatchResult
The outcome of checking the particular field against state databases. ‘match` - The field is an exact match with the state database. `no_match` - The field is not an exact match with the state database. `no_data` - The field was unable to be checked against state databases.
67 68 69 |
# File 'lib/the_plaid_api/models/aamva_analysis.rb', line 67 def date_of_birth @date_of_birth end |
#eye_color ⇒ AamvaMatchResult
The outcome of checking the particular field against state databases. ‘match` - The field is an exact match with the state database. `no_match` - The field is not an exact match with the state database. `no_data` - The field was unable to be checked against state databases.
88 89 90 |
# File 'lib/the_plaid_api/models/aamva_analysis.rb', line 88 def eye_color @eye_color end |
#first_name ⇒ AamvaDetailedMatchResult
The outcome of checking the associated hit against state databases. ‘match` - The field is an exact match with the state database. `partial_match` - The field is a partial match with the state database. `no_match` - The field is not an exact match with the state database. `no_data` - The field was unable to be checked against state databases.
96 97 98 |
# File 'lib/the_plaid_api/models/aamva_analysis.rb', line 96 def first_name @first_name end |
#gender ⇒ AamvaMatchResult
The outcome of checking the particular field against state databases. ‘match` - The field is an exact match with the state database. `no_match` - The field is not an exact match with the state database. `no_data` - The field was unable to be checked against state databases.
74 75 76 |
# File 'lib/the_plaid_api/models/aamva_analysis.rb', line 74 def gender @gender end |
#height ⇒ AamvaMatchResult
The outcome of checking the particular field against state databases. ‘match` - The field is an exact match with the state database. `no_match` - The field is not an exact match with the state database. `no_data` - The field was unable to be checked against state databases.
81 82 83 |
# File 'lib/the_plaid_api/models/aamva_analysis.rb', line 81 def height @height end |
#id_expiration_date ⇒ AamvaMatchResult
The outcome of checking the particular field against state databases. ‘match` - The field is an exact match with the state database. `no_match` - The field is not an exact match with the state database. `no_data` - The field was unable to be checked against state databases.
37 38 39 |
# File 'lib/the_plaid_api/models/aamva_analysis.rb', line 37 def id_expiration_date @id_expiration_date end |
#id_issue_date ⇒ AamvaMatchResult
The outcome of checking the particular field against state databases. ‘match` - The field is an exact match with the state database. `no_match` - The field is not an exact match with the state database. `no_data` - The field was unable to be checked against state databases.
30 31 32 |
# File 'lib/the_plaid_api/models/aamva_analysis.rb', line 30 def id_issue_date @id_issue_date end |
#id_number ⇒ AamvaMatchResult
The outcome of checking the particular field against state databases. ‘match` - The field is an exact match with the state database. `no_match` - The field is not an exact match with the state database. `no_data` - The field was unable to be checked against state databases.
23 24 25 |
# File 'lib/the_plaid_api/models/aamva_analysis.rb', line 23 def id_number @id_number end |
#is_verified ⇒ TrueClass | FalseClass
The overall outcome of checking the associated hit against the issuing state database.
16 17 18 |
# File 'lib/the_plaid_api/models/aamva_analysis.rb', line 16 def is_verified @is_verified end |
#last_name ⇒ AamvaDetailedMatchResult
The outcome of checking the associated hit against state databases. ‘match` - The field is an exact match with the state database. `partial_match` - The field is a partial match with the state database. `no_match` - The field is not an exact match with the state database. `no_data` - The field was unable to be checked against state databases.
112 113 114 |
# File 'lib/the_plaid_api/models/aamva_analysis.rb', line 112 def last_name @last_name end |
#middle_name ⇒ AamvaDetailedMatchResult
The outcome of checking the associated hit against state databases. ‘match` - The field is an exact match with the state database. `partial_match` - The field is a partial match with the state database. `no_match` - The field is not an exact match with the state database. `no_data` - The field was unable to be checked against state databases.
104 105 106 |
# File 'lib/the_plaid_api/models/aamva_analysis.rb', line 104 def middle_name @middle_name end |
#postal_code ⇒ AamvaDetailedMatchResult
The outcome of checking the associated hit against state databases. ‘match` - The field is an exact match with the state database. `partial_match` - The field is a partial match with the state database. `no_match` - The field is not an exact match with the state database. `no_data` - The field was unable to be checked against state databases.
60 61 62 |
# File 'lib/the_plaid_api/models/aamva_analysis.rb', line 60 def postal_code @postal_code end |
#street ⇒ AamvaDetailedMatchResult
The outcome of checking the associated hit against state databases. ‘match` - The field is an exact match with the state database. `partial_match` - The field is a partial match with the state database. `no_match` - The field is not an exact match with the state database. `no_data` - The field was unable to be checked against state databases.
45 46 47 |
# File 'lib/the_plaid_api/models/aamva_analysis.rb', line 45 def street @street end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/the_plaid_api/models/aamva_analysis.rb', line 169 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. is_verified = hash.key?('is_verified') ? hash['is_verified'] : nil id_number = hash.key?('id_number') ? hash['id_number'] : nil id_issue_date = hash.key?('id_issue_date') ? hash['id_issue_date'] : nil id_expiration_date = hash.key?('id_expiration_date') ? hash['id_expiration_date'] : nil street = hash.key?('street') ? hash['street'] : nil city = hash.key?('city') ? hash['city'] : nil postal_code = hash.key?('postal_code') ? hash['postal_code'] : nil date_of_birth = hash.key?('date_of_birth') ? hash['date_of_birth'] : nil gender = hash.key?('gender') ? hash['gender'] : nil height = hash.key?('height') ? hash['height'] : nil eye_color = hash.key?('eye_color') ? hash['eye_color'] : nil first_name = hash.key?('first_name') ? hash['first_name'] : nil middle_name = hash.key?('middle_name') ? hash['middle_name'] : nil last_name = hash.key?('last_name') ? hash['last_name'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AamvaAnalysis.new(is_verified: is_verified, id_number: id_number, id_issue_date: id_issue_date, id_expiration_date: id_expiration_date, street: street, city: city, postal_code: postal_code, date_of_birth: date_of_birth, gender: gender, height: height, eye_color: eye_color, first_name: first_name, middle_name: middle_name, last_name: last_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/the_plaid_api/models/aamva_analysis.rb', line 115 def self.names @_hash = {} if @_hash.nil? @_hash['is_verified'] = 'is_verified' @_hash['id_number'] = 'id_number' @_hash['id_issue_date'] = 'id_issue_date' @_hash['id_expiration_date'] = 'id_expiration_date' @_hash['street'] = 'street' @_hash['city'] = 'city' @_hash['postal_code'] = 'postal_code' @_hash['date_of_birth'] = 'date_of_birth' @_hash['gender'] = 'gender' @_hash['height'] = 'height' @_hash['eye_color'] = 'eye_color' @_hash['first_name'] = 'first_name' @_hash['middle_name'] = 'middle_name' @_hash['last_name'] = 'last_name' @_hash end |
.nullables ⇒ Object
An array for nullable fields
140 141 142 |
# File 'lib/the_plaid_api/models/aamva_analysis.rb', line 140 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
135 136 137 |
# File 'lib/the_plaid_api/models/aamva_analysis.rb', line 135 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
226 227 228 229 230 231 232 233 234 235 |
# File 'lib/the_plaid_api/models/aamva_analysis.rb', line 226 def inspect class_name = self.class.name.split('::').last "<#{class_name} is_verified: #{@is_verified.inspect}, id_number: #{@id_number.inspect},"\ " id_issue_date: #{@id_issue_date.inspect}, id_expiration_date:"\ " #{@id_expiration_date.inspect}, street: #{@street.inspect}, city: #{@city.inspect},"\ " postal_code: #{@postal_code.inspect}, date_of_birth: #{@date_of_birth.inspect}, gender:"\ " #{@gender.inspect}, height: #{@height.inspect}, eye_color: #{@eye_color.inspect},"\ " first_name: #{@first_name.inspect}, middle_name: #{@middle_name.inspect}, last_name:"\ " #{@last_name.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
215 216 217 218 219 220 221 222 223 |
# File 'lib/the_plaid_api/models/aamva_analysis.rb', line 215 def to_s class_name = self.class.name.split('::').last "<#{class_name} is_verified: #{@is_verified}, id_number: #{@id_number}, id_issue_date:"\ " #{@id_issue_date}, id_expiration_date: #{@id_expiration_date}, street: #{@street}, city:"\ " #{@city}, postal_code: #{@postal_code}, date_of_birth: #{@date_of_birth}, gender:"\ " #{@gender}, height: #{@height}, eye_color: #{@eye_color}, first_name: #{@first_name},"\ " middle_name: #{@middle_name}, last_name: #{@last_name}, additional_properties:"\ " #{@additional_properties}>" end |