Class: ThePlaidApi::AccountFilter
- Defined in:
- lib/the_plaid_api/models/account_filter.rb
Overview
Enumerates the account subtypes that the application wishes for the user to be able to select from. For more details refer to Plaid documentation on account filters.
Instance Attribute Summary collapse
-
#credit ⇒ Array[String]
A list of account subtypes to be filtered.
-
#depository ⇒ Array[String]
A list of account subtypes to be filtered.
-
#investment ⇒ Array[String]
A list of account subtypes to be filtered.
-
#loan ⇒ Array[String]
A list of account subtypes to be filtered.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(depository: SKIP, credit: SKIP, loan: SKIP, investment: SKIP, additional_properties: nil) ⇒ AccountFilter
constructor
A new instance of AccountFilter.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(depository: SKIP, credit: SKIP, loan: SKIP, investment: SKIP, additional_properties: nil) ⇒ AccountFilter
Returns a new instance of AccountFilter.
55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/the_plaid_api/models/account_filter.rb', line 55 def initialize(depository: SKIP, credit: SKIP, loan: SKIP, investment: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @depository = depository unless depository == SKIP @credit = credit unless credit == SKIP @loan = loan unless loan == SKIP @investment = investment unless investment == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#credit ⇒ Array[String]
A list of account subtypes to be filtered.
20 21 22 |
# File 'lib/the_plaid_api/models/account_filter.rb', line 20 def credit @credit end |
#depository ⇒ Array[String]
A list of account subtypes to be filtered.
16 17 18 |
# File 'lib/the_plaid_api/models/account_filter.rb', line 16 def depository @depository end |
#investment ⇒ Array[String]
A list of account subtypes to be filtered.
28 29 30 |
# File 'lib/the_plaid_api/models/account_filter.rb', line 28 def investment @investment end |
#loan ⇒ Array[String]
A list of account subtypes to be filtered.
24 25 26 |
# File 'lib/the_plaid_api/models/account_filter.rb', line 24 def loan @loan end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/the_plaid_api/models/account_filter.rb', line 68 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. depository = hash.key?('depository') ? hash['depository'] : SKIP credit = hash.key?('credit') ? hash['credit'] : SKIP loan = hash.key?('loan') ? hash['loan'] : SKIP investment = hash.key?('investment') ? hash['investment'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AccountFilter.new(depository: depository, credit: credit, loan: loan, investment: investment, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
31 32 33 34 35 36 37 38 |
# File 'lib/the_plaid_api/models/account_filter.rb', line 31 def self.names @_hash = {} if @_hash.nil? @_hash['depository'] = 'depository' @_hash['credit'] = 'credit' @_hash['loan'] = 'loan' @_hash['investment'] = 'investment' @_hash end |
.nullables ⇒ Object
An array for nullable fields
51 52 53 |
# File 'lib/the_plaid_api/models/account_filter.rb', line 51 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
41 42 43 44 45 46 47 48 |
# File 'lib/the_plaid_api/models/account_filter.rb', line 41 def self.optionals %w[ depository credit loan investment ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
100 101 102 103 104 105 |
# File 'lib/the_plaid_api/models/account_filter.rb', line 100 def inspect class_name = self.class.name.split('::').last "<#{class_name} depository: #{@depository.inspect}, credit: #{@credit.inspect}, loan:"\ " #{@loan.inspect}, investment: #{@investment.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
93 94 95 96 97 |
# File 'lib/the_plaid_api/models/account_filter.rb', line 93 def to_s class_name = self.class.name.split('::').last "<#{class_name} depository: #{@depository}, credit: #{@credit}, loan: #{@loan}, investment:"\ " #{@investment}, additional_properties: #{@additional_properties}>" end |