Class: ThePlaidApi::AddressData3
- Defined in:
- lib/the_plaid_api/models/address_data3.rb
Overview
Data about the components comprising an address.
Instance Attribute Summary collapse
-
#city ⇒ String
The full city name.
-
#country ⇒ String
The ISO 3166-1 alpha-2 country code.
-
#postal_code ⇒ String
The postal code.
-
#region ⇒ String
The region or state.
-
#street ⇒ String
The full street address Example: ‘“564 Main Street, APT 15”`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(city: SKIP, country: SKIP, postal_code: SKIP, region: SKIP, street: SKIP, additional_properties: nil) ⇒ AddressData3
constructor
A new instance of AddressData3.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(city: SKIP, country: SKIP, postal_code: SKIP, region: SKIP, street: SKIP, additional_properties: nil) ⇒ AddressData3
Returns a new instance of AddressData3.
63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/the_plaid_api/models/address_data3.rb', line 63 def initialize(city: SKIP, country: SKIP, postal_code: SKIP, region: SKIP, street: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @city = city unless city == SKIP @country = country unless country == SKIP @postal_code = postal_code unless postal_code == SKIP @region = region unless region == SKIP @street = street unless street == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#city ⇒ String
The full city name
14 15 16 |
# File 'lib/the_plaid_api/models/address_data3.rb', line 14 def city @city end |
#country ⇒ String
The ISO 3166-1 alpha-2 country code
18 19 20 |
# File 'lib/the_plaid_api/models/address_data3.rb', line 18 def country @country end |
#postal_code ⇒ String
The postal code. In API versions 2018-05-22 and earlier, this field is called ‘zip`.
23 24 25 |
# File 'lib/the_plaid_api/models/address_data3.rb', line 23 def postal_code @postal_code end |
#region ⇒ String
The region or state. In API versions 2018-05-22 and earlier, this field is called ‘state`. Example: `“NC”`
29 30 31 |
# File 'lib/the_plaid_api/models/address_data3.rb', line 29 def region @region end |
#street ⇒ String
The full street address Example: ‘“564 Main Street, APT 15”`
34 35 36 |
# File 'lib/the_plaid_api/models/address_data3.rb', line 34 def street @street end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/the_plaid_api/models/address_data3.rb', line 77 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. city = hash.key?('city') ? hash['city'] : SKIP country = hash.key?('country') ? hash['country'] : SKIP postal_code = hash.key?('postal_code') ? hash['postal_code'] : SKIP region = hash.key?('region') ? hash['region'] : SKIP street = hash.key?('street') ? hash['street'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AddressData3.new(city: city, country: country, postal_code: postal_code, region: region, street: street, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 |
# File 'lib/the_plaid_api/models/address_data3.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['city'] = 'city' @_hash['country'] = 'country' @_hash['postal_code'] = 'postal_code' @_hash['region'] = 'region' @_hash['street'] = 'street' @_hash end |
.nullables ⇒ Object
An array for nullable fields
59 60 61 |
# File 'lib/the_plaid_api/models/address_data3.rb', line 59 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
48 49 50 51 52 53 54 55 56 |
# File 'lib/the_plaid_api/models/address_data3.rb', line 48 def self.optionals %w[ city country postal_code region street ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
111 112 113 114 115 116 |
# File 'lib/the_plaid_api/models/address_data3.rb', line 111 def inspect class_name = self.class.name.split('::').last "<#{class_name} city: #{@city.inspect}, country: #{@country.inspect}, postal_code:"\ " #{@postal_code.inspect}, region: #{@region.inspect}, street: #{@street.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
104 105 106 107 108 |
# File 'lib/the_plaid_api/models/address_data3.rb', line 104 def to_s class_name = self.class.name.split('::').last "<#{class_name} city: #{@city}, country: #{@country}, postal_code: #{@postal_code}, region:"\ " #{@region}, street: #{@street}, additional_properties: #{@additional_properties}>" end |