Class: ThePlaidApi::AssetReportCreateRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::AssetReportCreateRequest
- Defined in:
- lib/the_plaid_api/models/asset_report_create_request.rb
Overview
AssetReportCreateRequest defines the request schema for ‘/asset_report/create`
Instance Attribute Summary collapse
-
#access_tokens ⇒ Array[String]
An array of access tokens corresponding to the Items that will be included in the report.
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#days_requested ⇒ Integer
The maximum integer number of days of history to include in the Asset Report.
-
#options ⇒ AssetReportCreateRequestOptions
An optional object to filter ‘/asset_report/create` results.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(days_requested:, client_id: SKIP, secret: SKIP, access_tokens: SKIP, options: SKIP, additional_properties: nil) ⇒ AssetReportCreateRequest
constructor
A new instance of AssetReportCreateRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(days_requested:, client_id: SKIP, secret: SKIP, access_tokens: SKIP, options: SKIP, additional_properties: nil) ⇒ AssetReportCreateRequest
Returns a new instance of AssetReportCreateRequest.
71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/the_plaid_api/models/asset_report_create_request.rb', line 71 def initialize(days_requested:, client_id: SKIP, secret: SKIP, access_tokens: SKIP, options: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @access_tokens = access_tokens unless access_tokens == SKIP @days_requested = days_requested @options = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#access_tokens ⇒ Array[String]
An array of access tokens corresponding to the Items that will be included in the report. The ‘assets` product must have been initialized for the Items during link; the Assets product cannot be added after initialization.
29 30 31 |
# File 'lib/the_plaid_api/models/asset_report_create_request.rb', line 29 def access_tokens @access_tokens end |
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/asset_report_create_request.rb', line 17 def client_id @client_id end |
#days_requested ⇒ Integer
The maximum integer number of days of history to include in the Asset Report. If using Fannie Mae Day 1 Certainty, ‘days_requested` must be at least 61 for new originations or at least 31 for refinancings. An Asset Report requested with “Additional History” (that is, with more than 61 days of transaction history) will incur an Additional History fee.
37 38 39 |
# File 'lib/the_plaid_api/models/asset_report_create_request.rb', line 37 def days_requested @days_requested end |
#options ⇒ AssetReportCreateRequestOptions
An optional object to filter ‘/asset_report/create` results. If provided, must be non-`null`. The optional `user` object is required for the report to be eligible for Fannie Mae’s Day 1 Certainty program.
43 44 45 |
# File 'lib/the_plaid_api/models/asset_report_create_request.rb', line 43 def @options end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/the_plaid_api/models/asset_report_create_request.rb', line 22 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/the_plaid_api/models/asset_report_create_request.rb', line 86 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. days_requested = hash.key?('days_requested') ? hash['days_requested'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP access_tokens = hash.key?('access_tokens') ? hash['access_tokens'] : SKIP = AssetReportCreateRequestOptions.from_hash(hash['options']) if hash['options'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AssetReportCreateRequest.new(days_requested: days_requested, client_id: client_id, secret: secret, access_tokens: access_tokens, options: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
46 47 48 49 50 51 52 53 54 |
# File 'lib/the_plaid_api/models/asset_report_create_request.rb', line 46 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['access_tokens'] = 'access_tokens' @_hash['days_requested'] = 'days_requested' @_hash['options'] = 'options' @_hash end |
.nullables ⇒ Object
An array for nullable fields
67 68 69 |
# File 'lib/the_plaid_api/models/asset_report_create_request.rb', line 67 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
57 58 59 60 61 62 63 64 |
# File 'lib/the_plaid_api/models/asset_report_create_request.rb', line 57 def self.optionals %w[ client_id secret access_tokens options ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
122 123 124 125 126 127 |
# File 'lib/the_plaid_api/models/asset_report_create_request.rb', line 122 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\ " access_tokens: #{@access_tokens.inspect}, days_requested: #{@days_requested.inspect},"\ " options: #{@options.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
114 115 116 117 118 119 |
# File 'lib/the_plaid_api/models/asset_report_create_request.rb', line 114 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, access_tokens:"\ " #{@access_tokens}, days_requested: #{@days_requested}, options: #{@options},"\ " additional_properties: #{@additional_properties}>" end |