Class: ThePlaidApi::AuthMetadata
- Defined in:
- lib/the_plaid_api/models/auth_metadata.rb
Overview
Metadata that captures information about the Auth features of an institution.
Instance Attribute Summary collapse
-
#supported_methods ⇒ AuthSupportedMethods
Metadata specifically related to which auth methods an institution supports.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(supported_methods:, additional_properties: nil) ⇒ AuthMetadata
constructor
A new instance of AuthMetadata.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(supported_methods:, additional_properties: nil) ⇒ AuthMetadata
Returns a new instance of AuthMetadata.
37 38 39 40 41 42 43 |
# File 'lib/the_plaid_api/models/auth_metadata.rb', line 37 def initialize(supported_methods:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @supported_methods = supported_methods @additional_properties = additional_properties end |
Instance Attribute Details
#supported_methods ⇒ AuthSupportedMethods
Metadata specifically related to which auth methods an institution supports.
16 17 18 |
# File 'lib/the_plaid_api/models/auth_metadata.rb', line 16 def supported_methods @supported_methods end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/the_plaid_api/models/auth_metadata.rb', line 46 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. supported_methods = AuthSupportedMethods.from_hash(hash['supported_methods']) if hash['supported_methods'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AuthMetadata.new(supported_methods: supported_methods, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
19 20 21 22 23 |
# File 'lib/the_plaid_api/models/auth_metadata.rb', line 19 def self.names @_hash = {} if @_hash.nil? @_hash['supported_methods'] = 'supported_methods' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 34 35 |
# File 'lib/the_plaid_api/models/auth_metadata.rb', line 31 def self.nullables %w[ supported_methods ] end |
.optionals ⇒ Object
An array for optional fields
26 27 28 |
# File 'lib/the_plaid_api/models/auth_metadata.rb', line 26 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
73 74 75 76 77 |
# File 'lib/the_plaid_api/models/auth_metadata.rb', line 73 def inspect class_name = self.class.name.split('::').last "<#{class_name} supported_methods: #{@supported_methods.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 70 |
# File 'lib/the_plaid_api/models/auth_metadata.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} supported_methods: #{@supported_methods}, additional_properties:"\ " #{@additional_properties}>" end |