Class: ThePlaidApi::BankIncomeCompleteWebhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::BankIncomeCompleteWebhook
- Defined in:
- lib/the_plaid_api/models/bank_income_complete_webhook.rb
Overview
Fired when a bank income report has finished generating or failed to generate, triggered by calling ‘/credit/bank_income/get` in CRA enabled client.
Instance Attribute Summary collapse
-
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from.
-
#result ⇒ BankIncomeCompleteResult
The result of the bank income report generation ‘SUCCESS`: The bank income report was successfully generated and can be retrieved via `/credit/bank_income/get`.
-
#user_id ⇒ String
The ‘user_id` corresponding to the user the webhook has fired for.
-
#webhook_code ⇒ String
‘BANK_INCOME_COMPLETE`.
-
#webhook_type ⇒ String
‘INCOME`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, user_id:, result:, environment:, additional_properties: nil) ⇒ BankIncomeCompleteWebhook
constructor
A new instance of BankIncomeCompleteWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, user_id:, result:, environment:, additional_properties: nil) ⇒ BankIncomeCompleteWebhook
Returns a new instance of BankIncomeCompleteWebhook.
58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/the_plaid_api/models/bank_income_complete_webhook.rb', line 58 def initialize(webhook_type:, webhook_code:, user_id:, result:, environment:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @user_id = user_id @result = result @environment = environment @additional_properties = additional_properties end |
Instance Attribute Details
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from
35 36 37 |
# File 'lib/the_plaid_api/models/bank_income_complete_webhook.rb', line 35 def environment @environment end |
#result ⇒ BankIncomeCompleteResult
The result of the bank income report generation ‘SUCCESS`: The bank income report was successfully generated and can be retrieved via `/credit/bank_income/get`. `FAILURE`: The bank income report failed to be generated
31 32 33 |
# File 'lib/the_plaid_api/models/bank_income_complete_webhook.rb', line 31 def result @result end |
#user_id ⇒ String
The ‘user_id` corresponding to the user the webhook has fired for.
24 25 26 |
# File 'lib/the_plaid_api/models/bank_income_complete_webhook.rb', line 24 def user_id @user_id end |
#webhook_code ⇒ String
‘BANK_INCOME_COMPLETE`
20 21 22 |
# File 'lib/the_plaid_api/models/bank_income_complete_webhook.rb', line 20 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘INCOME`
16 17 18 |
# File 'lib/the_plaid_api/models/bank_income_complete_webhook.rb', line 16 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/the_plaid_api/models/bank_income_complete_webhook.rb', line 72 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil user_id = hash.key?('user_id') ? hash['user_id'] : nil result = hash.key?('result') ? hash['result'] : nil environment = hash.key?('environment') ? hash['environment'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BankIncomeCompleteWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, user_id: user_id, result: result, environment: environment, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
38 39 40 41 42 43 44 45 46 |
# File 'lib/the_plaid_api/models/bank_income_complete_webhook.rb', line 38 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['user_id'] = 'user_id' @_hash['result'] = 'result' @_hash['environment'] = 'environment' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 |
# File 'lib/the_plaid_api/models/bank_income_complete_webhook.rb', line 54 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 |
# File 'lib/the_plaid_api/models/bank_income_complete_webhook.rb', line 49 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
107 108 109 110 111 112 |
# File 'lib/the_plaid_api/models/bank_income_complete_webhook.rb', line 107 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, user_id: #{@user_id.inspect}, result: #{@result.inspect},"\ " environment: #{@environment.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
99 100 101 102 103 104 |
# File 'lib/the_plaid_api/models/bank_income_complete_webhook.rb', line 99 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, user_id:"\ " #{@user_id}, result: #{@result}, environment: #{@environment}, additional_properties:"\ " #{@additional_properties}>" end |