Class: ThePlaidApi::BankTransferBalanceGetResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::BankTransferBalanceGetResponse
- Defined in:
- lib/the_plaid_api/models/bank_transfer_balance_get_response.rb
Overview
Defines the response schema for ‘/bank_transfer/balance/get`
Instance Attribute Summary collapse
-
#balance ⇒ BankTransferBalance
Information about the balance of a bank transfer.
-
#origination_account_id ⇒ String
The ID of the origination account that this balance belongs to.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(balance:, origination_account_id:, request_id:, additional_properties: nil) ⇒ BankTransferBalanceGetResponse
constructor
A new instance of BankTransferBalanceGetResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(balance:, origination_account_id:, request_id:, additional_properties: nil) ⇒ BankTransferBalanceGetResponse
Returns a new instance of BankTransferBalanceGetResponse.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/the_plaid_api/models/bank_transfer_balance_get_response.rb', line 47 def initialize(balance:, origination_account_id:, request_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @balance = balance @origination_account_id = origination_account_id @request_id = request_id @additional_properties = additional_properties end |
Instance Attribute Details
#balance ⇒ BankTransferBalance
Information about the balance of a bank transfer
14 15 16 |
# File 'lib/the_plaid_api/models/bank_transfer_balance_get_response.rb', line 14 def balance @balance end |
#origination_account_id ⇒ String
The ID of the origination account that this balance belongs to.
18 19 20 |
# File 'lib/the_plaid_api/models/bank_transfer_balance_get_response.rb', line 18 def origination_account_id @origination_account_id end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
24 25 26 |
# File 'lib/the_plaid_api/models/bank_transfer_balance_get_response.rb', line 24 def request_id @request_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/the_plaid_api/models/bank_transfer_balance_get_response.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. balance = BankTransferBalance.from_hash(hash['balance']) if hash['balance'] origination_account_id = hash.key?('origination_account_id') ? hash['origination_account_id'] : nil request_id = hash.key?('request_id') ? hash['request_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BankTransferBalanceGetResponse.new(balance: balance, origination_account_id: origination_account_id, request_id: request_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
27 28 29 30 31 32 33 |
# File 'lib/the_plaid_api/models/bank_transfer_balance_get_response.rb', line 27 def self.names @_hash = {} if @_hash.nil? @_hash['balance'] = 'balance' @_hash['origination_account_id'] = 'origination_account_id' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 44 45 |
# File 'lib/the_plaid_api/models/bank_transfer_balance_get_response.rb', line 41 def self.nullables %w[ origination_account_id ] end |
.optionals ⇒ Object
An array for optional fields
36 37 38 |
# File 'lib/the_plaid_api/models/bank_transfer_balance_get_response.rb', line 36 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
90 91 92 93 94 95 |
# File 'lib/the_plaid_api/models/bank_transfer_balance_get_response.rb', line 90 def inspect class_name = self.class.name.split('::').last "<#{class_name} balance: #{@balance.inspect}, origination_account_id:"\ " #{@origination_account_id.inspect}, request_id: #{@request_id.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 87 |
# File 'lib/the_plaid_api/models/bank_transfer_balance_get_response.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} balance: #{@balance}, origination_account_id: #{@origination_account_id},"\ " request_id: #{@request_id}, additional_properties: #{@additional_properties}>" end |