Class: ThePlaidApi::BankTransferListRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::BankTransferListRequest
- Defined in:
- lib/the_plaid_api/models/bank_transfer_list_request.rb
Overview
Defines the request schema for ‘/bank_transfer/list`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#count ⇒ Integer
The maximum number of bank transfers to return.
-
#direction ⇒ BankTransferDirection
Indicates the direction of the transfer: ‘outbound` for API-initiated transfers, or `inbound` for payments received by the FBO account.
-
#end_date ⇒ DateTime
The end datetime of bank transfers to list.
-
#offset ⇒ Integer
The number of bank transfers to skip before returning results.
-
#origination_account_id ⇒ String
Filter bank transfers to only those originated through the specified origination account.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#start_date ⇒ DateTime
The start datetime of bank transfers to list.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_id: SKIP, secret: SKIP, start_date: SKIP, end_date: SKIP, count: 25, offset: 0, origination_account_id: SKIP, direction: SKIP, additional_properties: nil) ⇒ BankTransferListRequest
constructor
A new instance of BankTransferListRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_end_date ⇒ Object
- #to_custom_start_date ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_id: SKIP, secret: SKIP, start_date: SKIP, end_date: SKIP, count: 25, offset: 0, origination_account_id: SKIP, direction: SKIP, additional_properties: nil) ⇒ BankTransferListRequest
Returns a new instance of BankTransferListRequest.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/the_plaid_api/models/bank_transfer_list_request.rb', line 90 def initialize(client_id: SKIP, secret: SKIP, start_date: SKIP, end_date: SKIP, count: 25, offset: 0, origination_account_id: SKIP, direction: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @start_date = start_date unless start_date == SKIP @end_date = end_date unless end_date == SKIP @count = count unless count == SKIP @offset = offset unless offset == SKIP @origination_account_id = origination_account_id unless origination_account_id == SKIP @direction = direction unless direction == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/bank_transfer_list_request.rb', line 17 def client_id @client_id end |
#count ⇒ Integer
The maximum number of bank transfers to return.
36 37 38 |
# File 'lib/the_plaid_api/models/bank_transfer_list_request.rb', line 36 def count @count end |
#direction ⇒ BankTransferDirection
Indicates the direction of the transfer: ‘outbound` for API-initiated transfers, or `inbound` for payments received by the FBO account.
50 51 52 |
# File 'lib/the_plaid_api/models/bank_transfer_list_request.rb', line 50 def direction @direction end |
#end_date ⇒ DateTime
The end datetime of bank transfers to list. This should be in RFC 3339 format (i.e. ‘2019-12-06T22:35:49Z`)
32 33 34 |
# File 'lib/the_plaid_api/models/bank_transfer_list_request.rb', line 32 def end_date @end_date end |
#offset ⇒ Integer
The number of bank transfers to skip before returning results.
40 41 42 |
# File 'lib/the_plaid_api/models/bank_transfer_list_request.rb', line 40 def offset @offset end |
#origination_account_id ⇒ String
Filter bank transfers to only those originated through the specified origination account.
45 46 47 |
# File 'lib/the_plaid_api/models/bank_transfer_list_request.rb', line 45 def origination_account_id @origination_account_id end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/the_plaid_api/models/bank_transfer_list_request.rb', line 22 def secret @secret end |
#start_date ⇒ DateTime
The start datetime of bank transfers to list. This should be in RFC 3339 format (i.e. ‘2019-12-06T22:35:49Z`)
27 28 29 |
# File 'lib/the_plaid_api/models/bank_transfer_list_request.rb', line 27 def start_date @start_date end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/the_plaid_api/models/bank_transfer_list_request.rb', line 109 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP start_date = if hash.key?('start_date') (DateTimeHelper.from_rfc3339(hash['start_date']) if hash['start_date']) else SKIP end end_date = if hash.key?('end_date') (DateTimeHelper.from_rfc3339(hash['end_date']) if hash['end_date']) else SKIP end count = hash['count'] ||= 25 offset = hash['offset'] ||= 0 origination_account_id = hash.key?('origination_account_id') ? hash['origination_account_id'] : SKIP direction = hash.key?('direction') ? hash['direction'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BankTransferListRequest.new(client_id: client_id, secret: secret, start_date: start_date, end_date: end_date, count: count, offset: offset, origination_account_id: origination_account_id, direction: direction, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/the_plaid_api/models/bank_transfer_list_request.rb', line 53 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['start_date'] = 'start_date' @_hash['end_date'] = 'end_date' @_hash['count'] = 'count' @_hash['offset'] = 'offset' @_hash['origination_account_id'] = 'origination_account_id' @_hash['direction'] = 'direction' @_hash end |
.nullables ⇒ Object
An array for nullable fields
81 82 83 84 85 86 87 88 |
# File 'lib/the_plaid_api/models/bank_transfer_list_request.rb', line 81 def self.nullables %w[ start_date end_date origination_account_id direction ] end |
.optionals ⇒ Object
An array for optional fields
67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/the_plaid_api/models/bank_transfer_list_request.rb', line 67 def self.optionals %w[ client_id secret start_date end_date count offset origination_account_id direction ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
168 169 170 171 172 173 174 |
# File 'lib/the_plaid_api/models/bank_transfer_list_request.rb', line 168 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, start_date:"\ " #{@start_date.inspect}, end_date: #{@end_date.inspect}, count: #{@count.inspect}, offset:"\ " #{@offset.inspect}, origination_account_id: #{@origination_account_id.inspect}, direction:"\ " #{@direction.inspect}, additional_properties: #{@additional_properties}>" end |
#to_custom_end_date ⇒ Object
154 155 156 |
# File 'lib/the_plaid_api/models/bank_transfer_list_request.rb', line 154 def to_custom_end_date DateTimeHelper.to_rfc3339(end_date) end |
#to_custom_start_date ⇒ Object
150 151 152 |
# File 'lib/the_plaid_api/models/bank_transfer_list_request.rb', line 150 def to_custom_start_date DateTimeHelper.to_rfc3339(start_date) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
159 160 161 162 163 164 165 |
# File 'lib/the_plaid_api/models/bank_transfer_list_request.rb', line 159 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, start_date: #{@start_date},"\ " end_date: #{@end_date}, count: #{@count}, offset: #{@offset}, origination_account_id:"\ " #{@origination_account_id}, direction: #{@direction}, additional_properties:"\ " #{@additional_properties}>" end |