Class: ThePlaidApi::BaseReportAccountMetadata
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::BaseReportAccountMetadata
- Defined in:
- lib/the_plaid_api/models/base_report_account_metadata.rb
Overview
Metadata about the extracted account.
Instance Attribute Summary collapse
-
#end_date ⇒ Date
The end of the range of the financial institution provided data for the account, in [ISO 8601](wikipedia.org/wiki/ISO_8601) format (“yyyy-mm-dd”).
-
#start_date ⇒ Date
The beginning of the range of the financial institution provided data for the account, in [ISO 8601](wikipedia.org/wiki/ISO_8601) format (“yyyy-mm-dd”).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(start_date:, end_date:, additional_properties: nil) ⇒ BaseReportAccountMetadata
constructor
A new instance of BaseReportAccountMetadata.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(start_date:, end_date:, additional_properties: nil) ⇒ BaseReportAccountMetadata
Returns a new instance of BaseReportAccountMetadata.
45 46 47 48 49 50 51 52 |
# File 'lib/the_plaid_api/models/base_report_account_metadata.rb', line 45 def initialize(start_date:, end_date:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @start_date = start_date @end_date = end_date @additional_properties = additional_properties end |
Instance Attribute Details
#end_date ⇒ Date
The end of the range of the financial institution provided data for the account, in [ISO 8601](wikipedia.org/wiki/ISO_8601) format (“yyyy-mm-dd”).
22 23 24 |
# File 'lib/the_plaid_api/models/base_report_account_metadata.rb', line 22 def end_date @end_date end |
#start_date ⇒ Date
The beginning of the range of the financial institution provided data for the account, in [ISO 8601](wikipedia.org/wiki/ISO_8601) format (“yyyy-mm-dd”).
16 17 18 |
# File 'lib/the_plaid_api/models/base_report_account_metadata.rb', line 16 def start_date @start_date end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/the_plaid_api/models/base_report_account_metadata.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. start_date = hash.key?('start_date') ? hash['start_date'] : nil end_date = hash.key?('end_date') ? hash['end_date'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BaseReportAccountMetadata.new(start_date: start_date, end_date: end_date, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 |
# File 'lib/the_plaid_api/models/base_report_account_metadata.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['start_date'] = 'start_date' @_hash['end_date'] = 'end_date' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 41 42 43 |
# File 'lib/the_plaid_api/models/base_report_account_metadata.rb', line 38 def self.nullables %w[ start_date end_date ] end |
.optionals ⇒ Object
An array for optional fields
33 34 35 |
# File 'lib/the_plaid_api/models/base_report_account_metadata.rb', line 33 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
83 84 85 86 87 |
# File 'lib/the_plaid_api/models/base_report_account_metadata.rb', line 83 def inspect class_name = self.class.name.split('::').last "<#{class_name} start_date: #{@start_date.inspect}, end_date: #{@end_date.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
76 77 78 79 80 |
# File 'lib/the_plaid_api/models/base_report_account_metadata.rb', line 76 def to_s class_name = self.class.name.split('::').last "<#{class_name} start_date: #{@start_date}, end_date: #{@end_date}, additional_properties:"\ " #{@additional_properties}>" end |