Class: ThePlaidApi::BaseReportAverageFlowInsights
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::BaseReportAverageFlowInsights
- Defined in:
- lib/the_plaid_api/models/base_report_average_flow_insights.rb
Overview
Average dollar amount of credit or debit transactions out of the account. This field will only be included for depository accounts.
Instance Attribute Summary collapse
-
#end_date ⇒ Date
The end date of this time period.
-
#start_date ⇒ Date
The start date of this time period.
-
#total_amount ⇒ CreditAmountWithCurrency
This contains an amount, denominated in the currency specified by either ‘iso_currency_code` or `unofficial_currency_code`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(start_date:, end_date:, total_amount:, additional_properties: nil) ⇒ BaseReportAverageFlowInsights
constructor
A new instance of BaseReportAverageFlowInsights.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(start_date:, end_date:, total_amount:, additional_properties: nil) ⇒ BaseReportAverageFlowInsights
Returns a new instance of BaseReportAverageFlowInsights.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/the_plaid_api/models/base_report_average_flow_insights.rb', line 47 def initialize(start_date:, end_date:, total_amount:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @start_date = start_date @end_date = end_date @total_amount = total_amount @additional_properties = additional_properties end |
Instance Attribute Details
#end_date ⇒ Date
The end date of this time period. The date will be returned in an ISO 8601 format (YYYY-MM-DD).
21 22 23 |
# File 'lib/the_plaid_api/models/base_report_average_flow_insights.rb', line 21 def end_date @end_date end |
#start_date ⇒ Date
The start date of this time period. The date will be returned in an ISO 8601 format (YYYY-MM-DD).
16 17 18 |
# File 'lib/the_plaid_api/models/base_report_average_flow_insights.rb', line 16 def start_date @start_date end |
#total_amount ⇒ CreditAmountWithCurrency
This contains an amount, denominated in the currency specified by either ‘iso_currency_code` or `unofficial_currency_code`
26 27 28 |
# File 'lib/the_plaid_api/models/base_report_average_flow_insights.rb', line 26 def total_amount @total_amount end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/the_plaid_api/models/base_report_average_flow_insights.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. start_date = hash.key?('start_date') ? hash['start_date'] : nil end_date = hash.key?('end_date') ? hash['end_date'] : nil total_amount = CreditAmountWithCurrency.from_hash(hash['total_amount']) if hash['total_amount'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BaseReportAverageFlowInsights.new(start_date: start_date, end_date: end_date, total_amount: total_amount, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 |
# File 'lib/the_plaid_api/models/base_report_average_flow_insights.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['start_date'] = 'start_date' @_hash['end_date'] = 'end_date' @_hash['total_amount'] = 'total_amount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/the_plaid_api/models/base_report_average_flow_insights.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
38 39 40 |
# File 'lib/the_plaid_api/models/base_report_average_flow_insights.rb', line 38 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
90 91 92 93 94 |
# File 'lib/the_plaid_api/models/base_report_average_flow_insights.rb', line 90 def inspect class_name = self.class.name.split('::').last "<#{class_name} start_date: #{@start_date.inspect}, end_date: #{@end_date.inspect},"\ " total_amount: #{@total_amount.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 87 |
# File 'lib/the_plaid_api/models/base_report_average_flow_insights.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} start_date: #{@start_date}, end_date: #{@end_date}, total_amount:"\ " #{@total_amount}, additional_properties: #{@additional_properties}>" end |