Class: ThePlaidApi::BaseReportNumberFlowInsights
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::BaseReportNumberFlowInsights
- Defined in:
- lib/the_plaid_api/models/base_report_number_flow_insights.rb
Overview
The number of credits or debits out of the account. This field will only be included for depository accounts.
Instance Attribute Summary collapse
-
#count ⇒ Integer
The number of credits or debits out of the account for this time period.
-
#end_date ⇒ Date
The end date of this time period.
-
#start_date ⇒ Date
The start date of this time period.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(start_date:, end_date:, count:, additional_properties: nil) ⇒ BaseReportNumberFlowInsights
constructor
A new instance of BaseReportNumberFlowInsights.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(start_date:, end_date:, count:, additional_properties: nil) ⇒ BaseReportNumberFlowInsights
Returns a new instance of BaseReportNumberFlowInsights.
46 47 48 49 50 51 52 53 54 |
# File 'lib/the_plaid_api/models/base_report_number_flow_insights.rb', line 46 def initialize(start_date:, end_date:, count:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @start_date = start_date @end_date = end_date @count = count @additional_properties = additional_properties end |
Instance Attribute Details
#count ⇒ Integer
The number of credits or debits out of the account for this time period.
25 26 27 |
# File 'lib/the_plaid_api/models/base_report_number_flow_insights.rb', line 25 def count @count end |
#end_date ⇒ Date
The end date of this time period. The date will be returned in an ISO 8601 format (YYYY-MM-DD).
21 22 23 |
# File 'lib/the_plaid_api/models/base_report_number_flow_insights.rb', line 21 def end_date @end_date end |
#start_date ⇒ Date
The start date of this time period. The date will be returned in an ISO 8601 format (YYYY-MM-DD).
16 17 18 |
# File 'lib/the_plaid_api/models/base_report_number_flow_insights.rb', line 16 def start_date @start_date end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/the_plaid_api/models/base_report_number_flow_insights.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. start_date = hash.key?('start_date') ? hash['start_date'] : nil end_date = hash.key?('end_date') ? hash['end_date'] : nil count = hash.key?('count') ? hash['count'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BaseReportNumberFlowInsights.new(start_date: start_date, end_date: end_date, count: count, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
28 29 30 31 32 33 34 |
# File 'lib/the_plaid_api/models/base_report_number_flow_insights.rb', line 28 def self.names @_hash = {} if @_hash.nil? @_hash['start_date'] = 'start_date' @_hash['end_date'] = 'end_date' @_hash['count'] = 'count' @_hash end |
.nullables ⇒ Object
An array for nullable fields
42 43 44 |
# File 'lib/the_plaid_api/models/base_report_number_flow_insights.rb', line 42 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
37 38 39 |
# File 'lib/the_plaid_api/models/base_report_number_flow_insights.rb', line 37 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
87 88 89 90 91 |
# File 'lib/the_plaid_api/models/base_report_number_flow_insights.rb', line 87 def inspect class_name = self.class.name.split('::').last "<#{class_name} start_date: #{@start_date.inspect}, end_date: #{@end_date.inspect}, count:"\ " #{@count.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
80 81 82 83 84 |
# File 'lib/the_plaid_api/models/base_report_number_flow_insights.rb', line 80 def to_s class_name = self.class.name.split('::').last "<#{class_name} start_date: #{@start_date}, end_date: #{@end_date}, count: #{@count},"\ " additional_properties: #{@additional_properties}>" end |