Class: ThePlaidApi::BaseReportTransaction
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::BaseReportTransaction
- Defined in:
- lib/the_plaid_api/models/base_report_transaction.rb
Overview
A transaction on the Base Report
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ID of the account in which this transaction occurred.
-
#account_owner ⇒ String
The name of the account owner.
-
#amount ⇒ Float
The settled value of the transaction, denominated in the transaction’s currency, as stated in ‘iso_currency_code` or `unofficial_currency_code`.
-
#category ⇒ Array[String]
A hierarchical array of the categories to which this transaction belongs.
-
#category_id ⇒ String
The ID of the category to which this transaction belongs.
-
#check_number ⇒ String
The check number of the transaction.
-
#credit_category ⇒ CreditCategory
Information describing the intent of the transaction.
-
#date ⇒ Date
For pending transactions, the date that the transaction occurred; for posted transactions, the date that the transaction posted.
-
#date_transacted ⇒ String
The date on which the transaction took place, in IS0 8601 format.
-
#iso_currency_code ⇒ String
The ISO-4217 currency code of the transaction.
-
#location ⇒ TransactionLocation
A representation of where a transaction took place.
-
#merchant_name ⇒ String
The merchant name, as enriched by Plaid from the ‘name` field.
-
#name ⇒ String
The merchant name or transaction description.
-
#original_description ⇒ String
The string returned by the financial institution to describe the transaction.
-
#pending ⇒ TrueClass | FalseClass
When ‘true`, identifies the transaction as pending or unsettled.
-
#personal_finance_category ⇒ PersonalFinanceCategory
The ID of the category to which this transaction belongs.
-
#transaction_id ⇒ String
The unique ID of the transaction.
-
#transaction_type ⇒ BaseReportTransactionType
‘digital:` transactions that took place online.
-
#unofficial_currency_code ⇒ String
The unofficial currency code associated with the transaction.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_id:, amount:, iso_currency_code:, unofficial_currency_code:, original_description:, date:, pending:, transaction_id:, name: SKIP, credit_category: SKIP, check_number: SKIP, date_transacted: SKIP, location: SKIP, merchant_name: SKIP, account_owner: SKIP, transaction_type: SKIP, category: SKIP, category_id: SKIP, personal_finance_category: SKIP, additional_properties: nil) ⇒ BaseReportTransaction
constructor
A new instance of BaseReportTransaction.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_id:, amount:, iso_currency_code:, unofficial_currency_code:, original_description:, date:, pending:, transaction_id:, name: SKIP, credit_category: SKIP, check_number: SKIP, date_transacted: SKIP, location: SKIP, merchant_name: SKIP, account_owner: SKIP, transaction_type: SKIP, category: SKIP, category_id: SKIP, personal_finance_category: SKIP, additional_properties: nil) ⇒ BaseReportTransaction
Returns a new instance of BaseReportTransaction.
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 196 def initialize(account_id:, amount:, iso_currency_code:, unofficial_currency_code:, original_description:, date:, pending:, transaction_id:, name: SKIP, credit_category: SKIP, check_number: SKIP, date_transacted: SKIP, location: SKIP, merchant_name: SKIP, account_owner: SKIP, transaction_type: SKIP, category: SKIP, category_id: SKIP, personal_finance_category: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_id = account_id @amount = amount @iso_currency_code = iso_currency_code @unofficial_currency_code = unofficial_currency_code @name = name unless name == SKIP @original_description = original_description @credit_category = credit_category unless credit_category == SKIP @check_number = check_number unless check_number == SKIP @date = date @date_transacted = date_transacted unless date_transacted == SKIP @location = location unless location == SKIP @merchant_name = merchant_name unless merchant_name == SKIP @pending = pending @account_owner = account_owner unless account_owner == SKIP @transaction_id = transaction_id @transaction_type = transaction_type unless transaction_type == SKIP @category = category unless category == SKIP @category_id = category_id unless category_id == SKIP unless personal_finance_category == SKIP @personal_finance_category = personal_finance_category end @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
The ID of the account in which this transaction occurred.
14 15 16 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 14 def account_id @account_id end |
#account_owner ⇒ String
The name of the account owner. This field is not typically populated and only relevant when dealing with sub-accounts.
100 101 102 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 100 def account_owner @account_owner end |
#amount ⇒ Float
The settled value of the transaction, denominated in the transaction’s currency, as stated in ‘iso_currency_code` or `unofficial_currency_code`. Positive values when money moves out of the account; negative values when money moves in. For example, debit card purchases are positive; credit card payments, direct deposits, and refunds are negative.
22 23 24 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 22 def amount @amount end |
#category ⇒ Array[String]
A hierarchical array of the categories to which this transaction belongs. For a full list of categories, see [‘/categories/get`](plaid.com/docs/api/products/transactions/#cate goriesget).
119 120 121 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 119 def category @category end |
#category_id ⇒ String
The ID of the category to which this transaction belongs. For a full list of categories, see [‘/categories/get`](plaid.com/docs/api/products/transactions/#cate goriesget).
126 127 128 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 126 def category_id @category_id end |
#check_number ⇒ String
The check number of the transaction. This field is only populated for check transactions.
61 62 63 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 61 def check_number @check_number end |
#credit_category ⇒ CreditCategory
Information describing the intent of the transaction. Most relevant for credit use cases, but not limited to such use cases. See the [‘taxonomy csv file`](plaid.com/documents/credit-category-taxonomy.csv) for a full list of credit categories.
56 57 58 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 56 def credit_category @credit_category end |
#date ⇒ Date
For pending transactions, the date that the transaction occurred; for posted transactions, the date that the transaction posted. Both dates are returned in an [ISO 8601](wikipedia.org/wiki/ISO_8601) format ( ‘YYYY-MM-DD` ).
68 69 70 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 68 def date @date end |
#date_transacted ⇒ String
The date on which the transaction took place, in IS0 8601 format.
72 73 74 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 72 def date_transacted @date_transacted end |
#iso_currency_code ⇒ String
The ISO-4217 currency code of the transaction. Always ‘null` if `unofficial_currency_code` is non-null.
27 28 29 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 27 def iso_currency_code @iso_currency_code end |
#location ⇒ TransactionLocation
A representation of where a transaction took place. Location data is provided only for transactions at physical locations, not for online transactions. Location data availability depends primarily on the merchant and is most likely to be populated for transactions at large retail chains; small, local businesses are less likely to have location data available.
81 82 83 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 81 def location @location end |
#merchant_name ⇒ String
The merchant name, as enriched by Plaid from the ‘name` field. This is typically a more human-readable version of the merchant counterparty in the transaction. For some bank transactions (such as checks or account transfers) where there is no meaningful merchant name, this value will be `null`.
89 90 91 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 89 def merchant_name @merchant_name end |
#name ⇒ String
The merchant name or transaction description. Note: This is a legacy field that is not actively maintained. Use ‘merchant_name` instead for the merchant name.
43 44 45 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 43 def name @name end |
#original_description ⇒ String
The string returned by the financial institution to describe the transaction.
48 49 50 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 48 def original_description @original_description end |
#pending ⇒ TrueClass | FalseClass
When ‘true`, identifies the transaction as pending or unsettled. Pending transaction details (name, type, amount, category ID) may change before they are settled.
95 96 97 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 95 def pending @pending end |
#personal_finance_category ⇒ PersonalFinanceCategory
The ID of the category to which this transaction belongs. For a full list of categories, see [‘/categories/get`](plaid.com/docs/api/products/transactions/#cate goriesget).
133 134 135 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 133 def personal_finance_category @personal_finance_category end |
#transaction_id ⇒ String
The unique ID of the transaction. Like all Plaid identifiers, the ‘transaction_id` is case sensitive.
105 106 107 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 105 def transaction_id @transaction_id end |
#transaction_type ⇒ BaseReportTransactionType
‘digital:` transactions that took place online. `place:` transactions that were made at a physical location. `special:` transactions that relate to banks, e.g. fees or deposits. `unresolved:` transactions that do not fit into the other types.
112 113 114 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 112 def transaction_type @transaction_type end |
#unofficial_currency_code ⇒ String
The unofficial currency code associated with the transaction. Always ‘null` if `iso_currency_code` is non-`null`. Unofficial currency codes are used for currencies that do not have official ISO currency codes, such as cryptocurrencies and the currencies of certain countries. See the [currency code schema](plaid.com/docs/api/accounts#currency-code-schema) for a full listing of supported `unofficial_currency_code`s.
37 38 39 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 37 def unofficial_currency_code @unofficial_currency_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 232 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_id = hash.key?('account_id') ? hash['account_id'] : nil amount = hash.key?('amount') ? hash['amount'] : nil iso_currency_code = hash.key?('iso_currency_code') ? hash['iso_currency_code'] : nil unofficial_currency_code = hash.key?('unofficial_currency_code') ? hash['unofficial_currency_code'] : nil original_description = hash.key?('original_description') ? hash['original_description'] : nil date = hash.key?('date') ? hash['date'] : nil pending = hash.key?('pending') ? hash['pending'] : nil transaction_id = hash.key?('transaction_id') ? hash['transaction_id'] : nil name = hash.key?('name') ? hash['name'] : SKIP credit_category = CreditCategory.from_hash(hash['credit_category']) if hash['credit_category'] check_number = hash.key?('check_number') ? hash['check_number'] : SKIP date_transacted = hash.key?('date_transacted') ? hash['date_transacted'] : SKIP location = TransactionLocation.from_hash(hash['location']) if hash['location'] merchant_name = hash.key?('merchant_name') ? hash['merchant_name'] : SKIP account_owner = hash.key?('account_owner') ? hash['account_owner'] : SKIP transaction_type = hash.key?('transaction_type') ? hash['transaction_type'] : SKIP category = hash.key?('category') ? hash['category'] : SKIP category_id = hash.key?('category_id') ? hash['category_id'] : SKIP if hash['personal_finance_category'] personal_finance_category = PersonalFinanceCategory.from_hash(hash['personal_finance_category']) end # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BaseReportTransaction.new(account_id: account_id, amount: amount, iso_currency_code: iso_currency_code, unofficial_currency_code: unofficial_currency_code, original_description: original_description, date: date, pending: pending, transaction_id: transaction_id, name: name, credit_category: credit_category, check_number: check_number, date_transacted: date_transacted, location: location, merchant_name: merchant_name, account_owner: account_owner, transaction_type: transaction_type, category: category, category_id: category_id, personal_finance_category: personal_finance_category, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 136 def self.names @_hash = {} if @_hash.nil? @_hash['account_id'] = 'account_id' @_hash['amount'] = 'amount' @_hash['iso_currency_code'] = 'iso_currency_code' @_hash['unofficial_currency_code'] = 'unofficial_currency_code' @_hash['name'] = 'name' @_hash['original_description'] = 'original_description' @_hash['credit_category'] = 'credit_category' @_hash['check_number'] = 'check_number' @_hash['date'] = 'date' @_hash['date_transacted'] = 'date_transacted' @_hash['location'] = 'location' @_hash['merchant_name'] = 'merchant_name' @_hash['pending'] = 'pending' @_hash['account_owner'] = 'account_owner' @_hash['transaction_id'] = 'transaction_id' @_hash['transaction_type'] = 'transaction_type' @_hash['category'] = 'category' @_hash['category_id'] = 'category_id' @_hash['personal_finance_category'] = 'personal_finance_category' @_hash end |
.nullables ⇒ Object
An array for nullable fields
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 178 def self.nullables %w[ iso_currency_code unofficial_currency_code name original_description credit_category check_number date_transacted merchant_name account_owner transaction_type category category_id personal_finance_category ] end |
.optionals ⇒ Object
An array for optional fields
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 161 def self.optionals %w[ name credit_category check_number date_transacted location merchant_name account_owner transaction_type category category_id personal_finance_category ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 310 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_id: #{@account_id.inspect}, amount: #{@amount.inspect},"\ " iso_currency_code: #{@iso_currency_code.inspect}, unofficial_currency_code:"\ " #{@unofficial_currency_code.inspect}, name: #{@name.inspect}, original_description:"\ " #{@original_description.inspect}, credit_category: #{@credit_category.inspect},"\ " check_number: #{@check_number.inspect}, date: #{@date.inspect}, date_transacted:"\ " #{@date_transacted.inspect}, location: #{@location.inspect}, merchant_name:"\ " #{@merchant_name.inspect}, pending: #{@pending.inspect}, account_owner:"\ " #{@account_owner.inspect}, transaction_id: #{@transaction_id.inspect}, transaction_type:"\ " #{@transaction_type.inspect}, category: #{@category.inspect}, category_id:"\ " #{@category_id.inspect}, personal_finance_category: #{@personal_finance_category.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/the_plaid_api/models/base_report_transaction.rb', line 296 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_id: #{@account_id}, amount: #{@amount}, iso_currency_code:"\ " #{@iso_currency_code}, unofficial_currency_code: #{@unofficial_currency_code}, name:"\ " #{@name}, original_description: #{@original_description}, credit_category:"\ " #{@credit_category}, check_number: #{@check_number}, date: #{@date}, date_transacted:"\ " #{@date_transacted}, location: #{@location}, merchant_name: #{@merchant_name}, pending:"\ " #{@pending}, account_owner: #{@account_owner}, transaction_id: #{@transaction_id},"\ " transaction_type: #{@transaction_type}, category: #{@category}, category_id:"\ " #{@category_id}, personal_finance_category: #{@personal_finance_category},"\ " additional_properties: #{@additional_properties}>" end |