Class: ThePlaidApi::BaseReportsErrorWebhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::BaseReportsErrorWebhook
- Defined in:
- lib/the_plaid_api/models/base_reports_error_webhook.rb
Overview
Fired when Base Report generation has failed. The resulting ‘error` will have an `error_type` of `BASE_REPORT_ERROR`.
Instance Attribute Summary collapse
-
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from.
-
#error ⇒ Error
Errors are identified by ‘error_code` and categorized by `error_type`.
-
#user_id ⇒ String
The ‘user_id` corresponding to the User ID the webhook has fired for.
-
#webhook_code ⇒ String
‘ERROR`.
-
#webhook_type ⇒ String
‘BASE_REPORT`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, error:, user_id:, environment:, additional_properties: nil) ⇒ BaseReportsErrorWebhook
constructor
A new instance of BaseReportsErrorWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, error:, user_id:, environment:, additional_properties: nil) ⇒ BaseReportsErrorWebhook
Returns a new instance of BaseReportsErrorWebhook.
64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/the_plaid_api/models/base_reports_error_webhook.rb', line 64 def initialize(webhook_type:, webhook_code:, error:, user_id:, environment:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @error = error @user_id = user_id @environment = environment @additional_properties = additional_properties end |
Instance Attribute Details
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from
39 40 41 |
# File 'lib/the_plaid_api/models/base_reports_error_webhook.rb', line 39 def environment @environment end |
#error ⇒ Error
Errors are identified by ‘error_code` and categorized by `error_type`. Use these in preference to HTTP status codes to identify and handle specific errors. HTTP status codes are set and provide the broadest categorization of errors: 4xx codes are for developer- or user-related errors, and 5xx codes are for Plaid-related errors, and the status will be 2xx in non-error cases. An Item with a non-`null` error object will only be part of an API response when calling `/item/get` to view Item status. Otherwise, error fields will be `null` if no error has occurred; if an error has occurred, an error code will be returned instead.
31 32 33 |
# File 'lib/the_plaid_api/models/base_reports_error_webhook.rb', line 31 def error @error end |
#user_id ⇒ String
The ‘user_id` corresponding to the User ID the webhook has fired for.
35 36 37 |
# File 'lib/the_plaid_api/models/base_reports_error_webhook.rb', line 35 def user_id @user_id end |
#webhook_code ⇒ String
‘ERROR`
19 20 21 |
# File 'lib/the_plaid_api/models/base_reports_error_webhook.rb', line 19 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘BASE_REPORT`
15 16 17 |
# File 'lib/the_plaid_api/models/base_reports_error_webhook.rb', line 15 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/the_plaid_api/models/base_reports_error_webhook.rb', line 78 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil error = Error.from_hash(hash['error']) if hash['error'] user_id = hash.key?('user_id') ? hash['user_id'] : nil environment = hash.key?('environment') ? hash['environment'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BaseReportsErrorWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, error: error, user_id: user_id, environment: environment, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
42 43 44 45 46 47 48 49 50 |
# File 'lib/the_plaid_api/models/base_reports_error_webhook.rb', line 42 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['error'] = 'error' @_hash['user_id'] = 'user_id' @_hash['environment'] = 'environment' @_hash end |
.nullables ⇒ Object
An array for nullable fields
58 59 60 61 62 |
# File 'lib/the_plaid_api/models/base_reports_error_webhook.rb', line 58 def self.nullables %w[ error ] end |
.optionals ⇒ Object
An array for optional fields
53 54 55 |
# File 'lib/the_plaid_api/models/base_reports_error_webhook.rb', line 53 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
113 114 115 116 117 118 |
# File 'lib/the_plaid_api/models/base_reports_error_webhook.rb', line 113 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, error: #{@error.inspect}, user_id: #{@user_id.inspect},"\ " environment: #{@environment.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
105 106 107 108 109 110 |
# File 'lib/the_plaid_api/models/base_reports_error_webhook.rb', line 105 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, error:"\ " #{@error}, user_id: #{@user_id}, environment: #{@environment}, additional_properties:"\ " #{@additional_properties}>" end |