Class: ThePlaidApi::BeaconMatchSummaryAnalysis
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::BeaconMatchSummaryAnalysis
- Defined in:
- lib/the_plaid_api/models/beacon_match_summary_analysis.rb
Overview
Analysis of which fields matched between one Beacon User and another.
Instance Attribute Summary collapse
-
#address ⇒ BeaconMatchSummaryCode
An enum indicating the match type between two Beacon Users.
-
#date_of_birth ⇒ BeaconMatchSummaryCode
An enum indicating the match type between two Beacon Users.
-
#email_address ⇒ BeaconMatchSummaryCode
An enum indicating the match type between two Beacon Users.
-
#id_number ⇒ BeaconMatchSummaryCode
An enum indicating the match type between two Beacon Users.
-
#ip_address ⇒ BeaconMatchSummaryCode
An enum indicating the match type between two Beacon Users.
-
#name ⇒ BeaconMatchSummaryCode
An enum indicating the match type between two Beacon Users.
-
#phone_number ⇒ BeaconMatchSummaryCode
An enum indicating the match type between two Beacon Users.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(address:, date_of_birth:, email_address:, name:, id_number:, ip_address:, phone_number:, additional_properties: nil) ⇒ BeaconMatchSummaryAnalysis
constructor
A new instance of BeaconMatchSummaryAnalysis.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(address:, date_of_birth:, email_address:, name:, id_number:, ip_address:, phone_number:, additional_properties: nil) ⇒ BeaconMatchSummaryAnalysis
Returns a new instance of BeaconMatchSummaryAnalysis.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/the_plaid_api/models/beacon_match_summary_analysis.rb', line 126 def initialize(address:, date_of_birth:, email_address:, name:, id_number:, ip_address:, phone_number:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @address = address @date_of_birth = date_of_birth @email_address = email_address @name = name @id_number = id_number @ip_address = ip_address @phone_number = phone_number @additional_properties = additional_properties end |
Instance Attribute Details
#address ⇒ BeaconMatchSummaryCode
An enum indicating the match type between two Beacon Users. ‘match` indicates that the provided input data was a strong match against the other Beacon User. `partial_match` indicates the data approximately matched the other Beacon User. For example, “Knope” vs. “Knope-Wyatt” for last name. `no_match` indicates that Plaid was able to compare this field against the other Beacon User and it did not match the provided input data. `no_data` indicates that Plaid was unable to compare this field against the original Beacon User because the field was not present in one of the Beacon Users.
23 24 25 |
# File 'lib/the_plaid_api/models/beacon_match_summary_analysis.rb', line 23 def address @address end |
#date_of_birth ⇒ BeaconMatchSummaryCode
An enum indicating the match type between two Beacon Users. ‘match` indicates that the provided input data was a strong match against the other Beacon User. `partial_match` indicates the data approximately matched the other Beacon User. For example, “Knope” vs. “Knope-Wyatt” for last name. `no_match` indicates that Plaid was able to compare this field against the other Beacon User and it did not match the provided input data. `no_data` indicates that Plaid was unable to compare this field against the original Beacon User because the field was not present in one of the Beacon Users.
36 37 38 |
# File 'lib/the_plaid_api/models/beacon_match_summary_analysis.rb', line 36 def date_of_birth @date_of_birth end |
#email_address ⇒ BeaconMatchSummaryCode
An enum indicating the match type between two Beacon Users. ‘match` indicates that the provided input data was a strong match against the other Beacon User. `partial_match` indicates the data approximately matched the other Beacon User. For example, “Knope” vs. “Knope-Wyatt” for last name. `no_match` indicates that Plaid was able to compare this field against the other Beacon User and it did not match the provided input data. `no_data` indicates that Plaid was unable to compare this field against the original Beacon User because the field was not present in one of the Beacon Users.
49 50 51 |
# File 'lib/the_plaid_api/models/beacon_match_summary_analysis.rb', line 49 def email_address @email_address end |
#id_number ⇒ BeaconMatchSummaryCode
An enum indicating the match type between two Beacon Users. ‘match` indicates that the provided input data was a strong match against the other Beacon User. `partial_match` indicates the data approximately matched the other Beacon User. For example, “Knope” vs. “Knope-Wyatt” for last name. `no_match` indicates that Plaid was able to compare this field against the other Beacon User and it did not match the provided input data. `no_data` indicates that Plaid was unable to compare this field against the original Beacon User because the field was not present in one of the Beacon Users.
75 76 77 |
# File 'lib/the_plaid_api/models/beacon_match_summary_analysis.rb', line 75 def id_number @id_number end |
#ip_address ⇒ BeaconMatchSummaryCode
An enum indicating the match type between two Beacon Users. ‘match` indicates that the provided input data was a strong match against the other Beacon User. `partial_match` indicates the data approximately matched the other Beacon User. For example, “Knope” vs. “Knope-Wyatt” for last name. `no_match` indicates that Plaid was able to compare this field against the other Beacon User and it did not match the provided input data. `no_data` indicates that Plaid was unable to compare this field against the original Beacon User because the field was not present in one of the Beacon Users.
88 89 90 |
# File 'lib/the_plaid_api/models/beacon_match_summary_analysis.rb', line 88 def ip_address @ip_address end |
#name ⇒ BeaconMatchSummaryCode
An enum indicating the match type between two Beacon Users. ‘match` indicates that the provided input data was a strong match against the other Beacon User. `partial_match` indicates the data approximately matched the other Beacon User. For example, “Knope” vs. “Knope-Wyatt” for last name. `no_match` indicates that Plaid was able to compare this field against the other Beacon User and it did not match the provided input data. `no_data` indicates that Plaid was unable to compare this field against the original Beacon User because the field was not present in one of the Beacon Users.
62 63 64 |
# File 'lib/the_plaid_api/models/beacon_match_summary_analysis.rb', line 62 def name @name end |
#phone_number ⇒ BeaconMatchSummaryCode
An enum indicating the match type between two Beacon Users. ‘match` indicates that the provided input data was a strong match against the other Beacon User. `partial_match` indicates the data approximately matched the other Beacon User. For example, “Knope” vs. “Knope-Wyatt” for last name. `no_match` indicates that Plaid was able to compare this field against the other Beacon User and it did not match the provided input data. `no_data` indicates that Plaid was unable to compare this field against the original Beacon User because the field was not present in one of the Beacon Users.
101 102 103 |
# File 'lib/the_plaid_api/models/beacon_match_summary_analysis.rb', line 101 def phone_number @phone_number end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/the_plaid_api/models/beacon_match_summary_analysis.rb', line 142 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. address = hash.key?('address') ? hash['address'] : nil date_of_birth = hash.key?('date_of_birth') ? hash['date_of_birth'] : nil email_address = hash.key?('email_address') ? hash['email_address'] : nil name = hash.key?('name') ? hash['name'] : nil id_number = hash.key?('id_number') ? hash['id_number'] : nil ip_address = hash.key?('ip_address') ? hash['ip_address'] : nil phone_number = hash.key?('phone_number') ? hash['phone_number'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BeaconMatchSummaryAnalysis.new(address: address, date_of_birth: date_of_birth, email_address: email_address, name: name, id_number: id_number, ip_address: ip_address, phone_number: phone_number, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/the_plaid_api/models/beacon_match_summary_analysis.rb', line 104 def self.names @_hash = {} if @_hash.nil? @_hash['address'] = 'address' @_hash['date_of_birth'] = 'date_of_birth' @_hash['email_address'] = 'email_address' @_hash['name'] = 'name' @_hash['id_number'] = 'id_number' @_hash['ip_address'] = 'ip_address' @_hash['phone_number'] = 'phone_number' @_hash end |
.nullables ⇒ Object
An array for nullable fields
122 123 124 |
# File 'lib/the_plaid_api/models/beacon_match_summary_analysis.rb', line 122 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
117 118 119 |
# File 'lib/the_plaid_api/models/beacon_match_summary_analysis.rb', line 117 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
181 182 183 184 185 186 187 |
# File 'lib/the_plaid_api/models/beacon_match_summary_analysis.rb', line 181 def inspect class_name = self.class.name.split('::').last "<#{class_name} address: #{@address.inspect}, date_of_birth: #{@date_of_birth.inspect},"\ " email_address: #{@email_address.inspect}, name: #{@name.inspect}, id_number:"\ " #{@id_number.inspect}, ip_address: #{@ip_address.inspect}, phone_number:"\ " #{@phone_number.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
173 174 175 176 177 178 |
# File 'lib/the_plaid_api/models/beacon_match_summary_analysis.rb', line 173 def to_s class_name = self.class.name.split('::').last "<#{class_name} address: #{@address}, date_of_birth: #{@date_of_birth}, email_address:"\ " #{@email_address}, name: #{@name}, id_number: #{@id_number}, ip_address: #{@ip_address},"\ " phone_number: #{@phone_number}, additional_properties: #{@additional_properties}>" end |