Class: ThePlaidApi::BeaconReportCreateRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::BeaconReportCreateRequest
- Defined in:
- lib/the_plaid_api/models/beacon_report_create_request.rb
Overview
Request input for creating a Beacon Report
Instance Attribute Summary collapse
-
#beacon_user_id ⇒ String
ID of the associated Beacon User.
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#fraud_amount ⇒ FraudAmount
The amount and currency of the fraud or attempted fraud.
-
#fraud_date ⇒ Date
A date in the format YYYY-MM-DD (RFC 3339 Section 5.6).
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#type ⇒ BeaconReportCreateType
The type of Beacon Report.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(beacon_user_id:, type:, fraud_date:, fraud_amount: SKIP, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ BeaconReportCreateRequest
constructor
A new instance of BeaconReportCreateRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(beacon_user_id:, type:, fraud_date:, fraud_amount: SKIP, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ BeaconReportCreateRequest
Returns a new instance of BeaconReportCreateRequest.
75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/the_plaid_api/models/beacon_report_create_request.rb', line 75 def initialize(beacon_user_id:, type:, fraud_date:, fraud_amount: SKIP, client_id: SKIP, secret: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @beacon_user_id = beacon_user_id @type = type @fraud_date = fraud_date @fraud_amount = fraud_amount unless fraud_amount == SKIP @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#beacon_user_id ⇒ String
ID of the associated Beacon User.
14 15 16 |
# File 'lib/the_plaid_api/models/beacon_report_create_request.rb', line 14 def beacon_user_id @beacon_user_id end |
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
40 41 42 |
# File 'lib/the_plaid_api/models/beacon_report_create_request.rb', line 40 def client_id @client_id end |
#fraud_amount ⇒ FraudAmount
The amount and currency of the fraud or attempted fraud. ‘fraud_amount` should be omitted to indicate an unknown fraud amount.
34 35 36 |
# File 'lib/the_plaid_api/models/beacon_report_create_request.rb', line 34 def fraud_amount @fraud_amount end |
#fraud_date ⇒ Date
A date in the format YYYY-MM-DD (RFC 3339 Section 5.6).
29 30 31 |
# File 'lib/the_plaid_api/models/beacon_report_create_request.rb', line 29 def fraud_date @fraud_date end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
45 46 47 |
# File 'lib/the_plaid_api/models/beacon_report_create_request.rb', line 45 def secret @secret end |
#type ⇒ BeaconReportCreateType
The type of Beacon Report. ‘first_party`: If this is the same individual as the one who submitted the KYC. `stolen`: If this is a different individual from the one who submitted the KYC. `synthetic`: If this is an individual using fabricated information. `account_takeover`: If this individual’s account was compromised. ‘unknown`: If you aren’t sure who committed the fraud.
25 26 27 |
# File 'lib/the_plaid_api/models/beacon_report_create_request.rb', line 25 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/the_plaid_api/models/beacon_report_create_request.rb', line 90 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. beacon_user_id = hash.key?('beacon_user_id') ? hash['beacon_user_id'] : nil type = hash.key?('type') ? hash['type'] : nil fraud_date = hash.key?('fraud_date') ? hash['fraud_date'] : nil fraud_amount = FraudAmount.from_hash(hash['fraud_amount']) if hash['fraud_amount'] client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BeaconReportCreateRequest.new(beacon_user_id: beacon_user_id, type: type, fraud_date: fraud_date, fraud_amount: fraud_amount, client_id: client_id, secret: secret, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/the_plaid_api/models/beacon_report_create_request.rb', line 48 def self.names @_hash = {} if @_hash.nil? @_hash['beacon_user_id'] = 'beacon_user_id' @_hash['type'] = 'type' @_hash['fraud_date'] = 'fraud_date' @_hash['fraud_amount'] = 'fraud_amount' @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash end |
.nullables ⇒ Object
An array for nullable fields
69 70 71 72 73 |
# File 'lib/the_plaid_api/models/beacon_report_create_request.rb', line 69 def self.nullables %w[ fraud_amount ] end |
.optionals ⇒ Object
An array for optional fields
60 61 62 63 64 65 66 |
# File 'lib/the_plaid_api/models/beacon_report_create_request.rb', line 60 def self.optionals %w[ fraud_amount client_id secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
128 129 130 131 132 133 134 |
# File 'lib/the_plaid_api/models/beacon_report_create_request.rb', line 128 def inspect class_name = self.class.name.split('::').last "<#{class_name} beacon_user_id: #{@beacon_user_id.inspect}, type: #{@type.inspect},"\ " fraud_date: #{@fraud_date.inspect}, fraud_amount: #{@fraud_amount.inspect}, client_id:"\ " #{@client_id.inspect}, secret: #{@secret.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
120 121 122 123 124 125 |
# File 'lib/the_plaid_api/models/beacon_report_create_request.rb', line 120 def to_s class_name = self.class.name.split('::').last "<#{class_name} beacon_user_id: #{@beacon_user_id}, type: #{@type}, fraud_date:"\ " #{@fraud_date}, fraud_amount: #{@fraud_amount}, client_id: #{@client_id}, secret:"\ " #{@secret}, additional_properties: #{@additional_properties}>" end |