Class: ThePlaidApi::BeaconReportType
- Inherits:
-
Object
- Object
- ThePlaidApi::BeaconReportType
- Defined in:
- lib/the_plaid_api/models/beacon_report_type.rb
Overview
The type of Beacon Report. ‘first_party`: If this is the same individual as the one who submitted the KYC. `stolen`: If this is a different individual from the one who submitted the KYC. `synthetic`: If this is an individual using fabricated information. `account_takeover`: If this individual’s account was compromised. ‘data_breach`: If this individual’s data was compromised in a breach. ‘unknown`: If you aren’t sure who committed the fraud.
Constant Summary collapse
- BEACON_REPORT_TYPE =
[ # TODO: Write general description for FIRST_PARTY FIRST_PARTY = 'first_party'.freeze, # TODO: Write general description for STOLEN STOLEN = 'stolen'.freeze, # TODO: Write general description for SYNTHETIC SYNTHETIC = 'synthetic'.freeze, # TODO: Write general description for ACCOUNT_TAKEOVER ACCOUNT_TAKEOVER = 'account_takeover'.freeze, # TODO: Write general description for DATA_BREACH DATA_BREACH = 'data_breach'.freeze, # TODO: Write general description for UNKNOWN UNKNOWN = 'unknown'.freeze ].freeze
Class Method Summary collapse
Class Method Details
.from_value(value, default_value = FIRST_PARTY) ⇒ Object
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/the_plaid_api/models/beacon_report_type.rb', line 41 def self.from_value(value, default_value = FIRST_PARTY) return default_value if value.nil? str = value.to_s.strip case str.downcase when 'first_party' then FIRST_PARTY when 'stolen' then STOLEN when 'synthetic' then SYNTHETIC when 'account_takeover' then ACCOUNT_TAKEOVER when 'data_breach' then DATA_BREACH when 'unknown' then UNKNOWN else default_value end end |
.validate(value) ⇒ Object
35 36 37 38 39 |
# File 'lib/the_plaid_api/models/beacon_report_type.rb', line 35 def self.validate(value) return false if value.nil? BEACON_REPORT_TYPE.include?(value) end |