Class: ThePlaidApi::BetaPartnerEndCustomerWithSecrets
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::BetaPartnerEndCustomerWithSecrets
- Defined in:
- lib/the_plaid_api/models/beta_partner_end_customer_with_secrets.rb
Overview
The details for the newly created end customer, including secrets for non-Production environments.
Instance Attribute Summary collapse
-
#client_id ⇒ String
The ‘client_id` of the end customer.
-
#company_name ⇒ String
The company name associated with the end customer.
-
#product_statuses ⇒ Object
Mapping of product names to their current status.
-
#requirements_due ⇒ Array[PartnerEndCustomerRequirementDue]
A list of fields that are still required to be submitted.
-
#secrets ⇒ PartnerEndCustomerSecrets
The secrets for the newly created end customer.
-
#status ⇒ PartnerEndCustomerStatus
The status of the given end customer.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_id: SKIP, company_name: SKIP, status: SKIP, product_statuses: SKIP, requirements_due: SKIP, secrets: SKIP, additional_properties: nil) ⇒ BetaPartnerEndCustomerWithSecrets
constructor
A new instance of BetaPartnerEndCustomerWithSecrets.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_id: SKIP, company_name: SKIP, status: SKIP, product_statuses: SKIP, requirements_due: SKIP, secrets: SKIP, additional_properties: nil) ⇒ BetaPartnerEndCustomerWithSecrets
Returns a new instance of BetaPartnerEndCustomerWithSecrets.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/the_plaid_api/models/beta_partner_end_customer_with_secrets.rb', line 78 def initialize(client_id: SKIP, company_name: SKIP, status: SKIP, product_statuses: SKIP, requirements_due: SKIP, secrets: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @company_name = company_name unless company_name == SKIP @status = status unless status == SKIP @product_statuses = product_statuses unless product_statuses == SKIP @requirements_due = requirements_due unless requirements_due == SKIP @secrets = secrets unless secrets == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
The ‘client_id` of the end customer.
15 16 17 |
# File 'lib/the_plaid_api/models/beta_partner_end_customer_with_secrets.rb', line 15 def client_id @client_id end |
#company_name ⇒ String
The company name associated with the end customer.
19 20 21 |
# File 'lib/the_plaid_api/models/beta_partner_end_customer_with_secrets.rb', line 19 def company_name @company_name end |
#product_statuses ⇒ Object
Mapping of product names to their current status.
39 40 41 |
# File 'lib/the_plaid_api/models/beta_partner_end_customer_with_secrets.rb', line 39 def product_statuses @product_statuses end |
#requirements_due ⇒ Array[PartnerEndCustomerRequirementDue]
A list of fields that are still required to be submitted.
43 44 45 |
# File 'lib/the_plaid_api/models/beta_partner_end_customer_with_secrets.rb', line 43 def requirements_due @requirements_due end |
#secrets ⇒ PartnerEndCustomerSecrets
The secrets for the newly created end customer.
47 48 49 |
# File 'lib/the_plaid_api/models/beta_partner_end_customer_with_secrets.rb', line 47 def secrets @secrets end |
#status ⇒ PartnerEndCustomerStatus
The status of the given end customer. ‘UNDER_REVIEW`: The end customer has been created and enabled in the Sandbox environment. The end customer must be manually reviewed by the Plaid team before it can be enabled in Production, at which point its status will automatically transition to `PENDING_ENABLEMENT` or `DENIED`. `PENDING_ENABLEMENT`: The end customer is ready to be fully enabled in the Production environment. Call the `/partner/customer/enable` endpoint to enable the end customer in full Production. `ACTIVE`: The end customer has been fully enabled in all environments. `DENIED`: The end customer has been created and enabled in the Sandbox environment, but it did not pass review by the Plaid team and therefore cannot be enabled for Production access. Talk to your Account Manager for more information.
35 36 37 |
# File 'lib/the_plaid_api/models/beta_partner_end_customer_with_secrets.rb', line 35 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/the_plaid_api/models/beta_partner_end_customer_with_secrets.rb', line 94 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_id = hash.key?('client_id') ? hash['client_id'] : SKIP company_name = hash.key?('company_name') ? hash['company_name'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP product_statuses = hash.key?('product_statuses') ? hash['product_statuses'] : SKIP requirements_due = hash.key?('requirements_due') ? hash['requirements_due'] : SKIP secrets = PartnerEndCustomerSecrets.from_hash(hash['secrets']) if hash['secrets'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BetaPartnerEndCustomerWithSecrets.new(client_id: client_id, company_name: company_name, status: status, product_statuses: product_statuses, requirements_due: requirements_due, secrets: secrets, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
50 51 52 53 54 55 56 57 58 59 |
# File 'lib/the_plaid_api/models/beta_partner_end_customer_with_secrets.rb', line 50 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['company_name'] = 'company_name' @_hash['status'] = 'status' @_hash['product_statuses'] = 'product_statuses' @_hash['requirements_due'] = 'requirements_due' @_hash['secrets'] = 'secrets' @_hash end |
.nullables ⇒ Object
An array for nullable fields
74 75 76 |
# File 'lib/the_plaid_api/models/beta_partner_end_customer_with_secrets.rb', line 74 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
62 63 64 65 66 67 68 69 70 71 |
# File 'lib/the_plaid_api/models/beta_partner_end_customer_with_secrets.rb', line 62 def self.optionals %w[ client_id company_name status product_statuses requirements_due secrets ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
134 135 136 137 138 139 140 |
# File 'lib/the_plaid_api/models/beta_partner_end_customer_with_secrets.rb', line 134 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, company_name: #{@company_name.inspect},"\ " status: #{@status.inspect}, product_statuses: #{@product_statuses.inspect},"\ " requirements_due: #{@requirements_due.inspect}, secrets: #{@secrets.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
125 126 127 128 129 130 131 |
# File 'lib/the_plaid_api/models/beta_partner_end_customer_with_secrets.rb', line 125 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, company_name: #{@company_name}, status:"\ " #{@status}, product_statuses: #{@product_statuses}, requirements_due:"\ " #{@requirements_due}, secrets: #{@secrets}, additional_properties:"\ " #{@additional_properties}>" end |