Class: ThePlaidApi::CashflowReportTransaction
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CashflowReportTransaction
- Defined in:
- lib/the_plaid_api/models/cashflow_report_transaction.rb
Overview
A representation of a transaction returned from Cashflow Report
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ID of the account in which this transaction occurred.
-
#account_owner ⇒ String
This field is not typically populated and only relevant when dealing with sub-accounts.
-
#amount ⇒ Float
The settled value of the transaction, denominated in the transactions’s currency, as stated in ‘iso_currency_code` or `unofficial_currency_code`.
-
#authorized_date ⇒ Date
The date that the transaction was authorized.
-
#authorized_datetime ⇒ DateTime
Date and time when a transaction was authorized in [ISO 8601](wikipedia.org/wiki/ISO_8601) format ( ‘YYYY-MM-DDTHH:mm:ssZ` ).
-
#business_finance_category ⇒ BusinessFinanceCategory
Information describing the intent of the transaction.
-
#check_number ⇒ String
The check number of the transaction.
-
#counterparties ⇒ Array[Counterparty]
The counterparties present in the transaction.
-
#credit_category ⇒ CreditCategory
Information describing the intent of the transaction.
-
#date ⇒ Date
For pending transactions, the date that the transaction occurred; for posted transactions, the date that the transaction posted.
-
#datetime ⇒ DateTime
Date and time when a transaction was posted in [ISO 8601](wikipedia.org/wiki/ISO_8601) format ( ‘YYYY-MM-DDTHH:mm:ssZ` ).
-
#iso_currency_code ⇒ String
The ISO-4217 currency code of the transaction.
-
#location ⇒ TransactionLocation
A representation of where a transaction took place.
-
#logo_url ⇒ String
The URL of a logo associated with this transaction, if available.
-
#merchant_entity_id ⇒ String
A unique, stable, Plaid-generated ID that maps to the merchant.
-
#merchant_name ⇒ String
The merchant name, as enriched by Plaid from the ‘name` field.
-
#name ⇒ String
The merchant name or transaction description.
-
#original_description ⇒ String
The string returned by the financial institution to describe the transaction.
-
#payment_channel ⇒ TransactionPaymentChannel
The channel used to make a payment.
-
#payment_meta ⇒ CashflowReportPaymentMeta
Transaction information specific to inter-bank transfers.
-
#pending ⇒ TrueClass | FalseClass
When ‘true`, identifies the transaction as pending or unsettled.
-
#pending_transaction_id ⇒ String
The ID of a posted transaction’s associated pending transaction, where applicable.
-
#personal_finance_category ⇒ PersonalFinanceCategory
Information describing the intent of the transaction.
-
#personal_finance_category_icon_url ⇒ String
The URL of an icon associated with the primary personal finance category.
-
#transaction_code ⇒ TransactionCode
An identifier classifying the transaction type.
-
#transaction_id ⇒ String
The unique ID of the transaction.
-
#unofficial_currency_code ⇒ String
The unofficial currency code associated with the transaction.
-
#website ⇒ String
The website associated with this transaction, if available.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_id:, amount:, iso_currency_code:, unofficial_currency_code:, date:, location:, name:, payment_meta:, pending:, pending_transaction_id:, account_owner:, transaction_id:, authorized_date:, authorized_datetime:, datetime:, payment_channel:, transaction_code:, check_number: SKIP, merchant_name: SKIP, original_description: SKIP, logo_url: SKIP, website: SKIP, personal_finance_category: SKIP, business_finance_category: SKIP, credit_category: SKIP, personal_finance_category_icon_url: SKIP, counterparties: SKIP, merchant_entity_id: SKIP, additional_properties: nil) ⇒ CashflowReportTransaction
constructor
A new instance of CashflowReportTransaction.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_authorized_datetime ⇒ Object
- #to_custom_datetime ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_id:, amount:, iso_currency_code:, unofficial_currency_code:, date:, location:, name:, payment_meta:, pending:, pending_transaction_id:, account_owner:, transaction_id:, authorized_date:, authorized_datetime:, datetime:, payment_channel:, transaction_code:, check_number: SKIP, merchant_name: SKIP, original_description: SKIP, logo_url: SKIP, website: SKIP, personal_finance_category: SKIP, business_finance_category: SKIP, credit_category: SKIP, personal_finance_category_icon_url: SKIP, counterparties: SKIP, merchant_entity_id: SKIP, additional_properties: nil) ⇒ CashflowReportTransaction
Returns a new instance of CashflowReportTransaction.
315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 315 def initialize(account_id:, amount:, iso_currency_code:, unofficial_currency_code:, date:, location:, name:, payment_meta:, pending:, pending_transaction_id:, account_owner:, transaction_id:, authorized_date:, authorized_datetime:, datetime:, payment_channel:, transaction_code:, check_number: SKIP, merchant_name: SKIP, original_description: SKIP, logo_url: SKIP, website: SKIP, personal_finance_category: SKIP, business_finance_category: SKIP, credit_category: SKIP, personal_finance_category_icon_url: SKIP, counterparties: SKIP, merchant_entity_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_id = account_id @amount = amount @iso_currency_code = iso_currency_code @unofficial_currency_code = unofficial_currency_code @check_number = check_number unless check_number == SKIP @date = date @location = location @name = name @merchant_name = merchant_name unless merchant_name == SKIP @original_description = original_description unless original_description == SKIP @payment_meta = @pending = pending @pending_transaction_id = pending_transaction_id @account_owner = account_owner @transaction_id = transaction_id @logo_url = logo_url unless logo_url == SKIP @website = website unless website == SKIP @authorized_date = @authorized_datetime = @datetime = datetime @payment_channel = payment_channel unless personal_finance_category == SKIP @personal_finance_category = personal_finance_category end unless business_finance_category == SKIP @business_finance_category = business_finance_category end @credit_category = credit_category unless credit_category == SKIP @transaction_code = transaction_code unless personal_finance_category_icon_url == SKIP @personal_finance_category_icon_url = personal_finance_category_icon_url end @counterparties = counterparties unless counterparties == SKIP @merchant_entity_id = merchant_entity_id unless merchant_entity_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
The ID of the account in which this transaction occurred.
15 16 17 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 15 def account_id @account_id end |
#account_owner ⇒ String
This field is not typically populated and only relevant when dealing with sub-accounts. A sub-account most commonly exists in cases where a single account is linked to multiple cards, each with its own card number and card holder name; each card will be considered a sub-account. If the account does have sub-accounts, this field will typically be some combination of the sub-account owner’s name and/or the sub-account mask. The format of this field is not standardized and will vary based on institution.
115 116 117 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 115 def account_owner @account_owner end |
#amount ⇒ Float
The settled value of the transaction, denominated in the transactions’s currency, as stated in ‘iso_currency_code` or `unofficial_currency_code`. For all products except Income: Positive values when money moves out of the account; negative values when money moves in. For example, debit card purchases are positive; credit card payments, direct deposits, and refunds are negative. For Income endpoints, values are positive when representing income.
25 26 27 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 25 def amount @amount end |
#authorized_date ⇒ Date
The date that the transaction was authorized. For posted transactions, the ‘date` field will indicate the posted date, but `authorized_date` will indicate the day the transaction was authorized by the financial institution. If presenting transactions to the user in a UI, the `authorized_date`, when available, is generally preferable to use over the `date` field for posted transactions, as it will generally represent the date the user actually made the transaction. Dates are returned in an [ISO 8601](wikipedia.org/wiki/ISO_8601) format ( `YYYY-MM-DD` ).
140 141 142 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 140 def @authorized_date end |
#authorized_datetime ⇒ DateTime
Date and time when a transaction was authorized in [ISO 8601](wikipedia.org/wiki/ISO_8601) format ( ‘YYYY-MM-DDTHH:mm:ssZ` ). For posted transactions, the `datetime` field will indicate the posted date, but `authorized_datetime` will indicate the day the transaction was authorized by the financial institution. If presenting transactions to the user in a UI, the `authorized_datetime`, when available, is generally preferable to use over the `datetime` field for posted transactions, as it will generally represent the date the user actually made the transaction. This field is returned for select financial institutions and comes as provided by the institution. It may contain default time values (such as 00:00:00). This field is only populated in API version 2019-05-29 and later.
155 156 157 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 155 def @authorized_datetime end |
#business_finance_category ⇒ BusinessFinanceCategory
Information describing the intent of the transaction. Most relevant for business finance use cases, but not limited to such use cases.
188 189 190 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 188 def business_finance_category @business_finance_category end |
#check_number ⇒ String
The check number of the transaction. This field is only populated for check transactions.
45 46 47 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 45 def check_number @check_number end |
#counterparties ⇒ Array[Counterparty]
The counterparties present in the transaction. Counterparties, such as the merchant or the financial institution, are extracted by Plaid from the raw description.
228 229 230 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 228 def counterparties @counterparties end |
#credit_category ⇒ CreditCategory
Information describing the intent of the transaction. Most relevant for credit use cases, but not limited to such use cases. See the [‘taxonomy csv file`](plaid.com/documents/credit-category-taxonomy.csv) for a full list of credit categories.
196 197 198 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 196 def credit_category @credit_category end |
#date ⇒ Date
For pending transactions, the date that the transaction occurred; for posted transactions, the date that the transaction posted. Both dates are returned in an [ISO 8601](wikipedia.org/wiki/ISO_8601) format ( ‘YYYY-MM-DD` ). To receive information about the date that a posted transaction was initiated, see the `authorized_date` field.
53 54 55 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 53 def date @date end |
#datetime ⇒ DateTime
Date and time when a transaction was posted in [ISO 8601](wikipedia.org/wiki/ISO_8601) format ( ‘YYYY-MM-DDTHH:mm:ssZ` ). For the date that the transaction was initiated, rather than posted, see the `authorized_datetime` field. This field is returned for select financial institutions and comes as provided by the institution. It may contain default time values (such as 00:00:00). This field is only populated in API version 2019-05-29 and later.
166 167 168 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 166 def datetime @datetime end |
#iso_currency_code ⇒ String
The ISO-4217 currency code of the transaction. Always ‘null` if `unofficial_currency_code` is non-null.
30 31 32 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 30 def iso_currency_code @iso_currency_code end |
#location ⇒ TransactionLocation
A representation of where a transaction took place. Location data is provided only for transactions at physical locations, not for online transactions. Location data availability depends primarily on the merchant and is most likely to be populated for transactions at large retail chains; small, local businesses are less likely to have location data available.
62 63 64 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 62 def location @location end |
#logo_url ⇒ String
The URL of a logo associated with this transaction, if available. The logo will always be 100×100 pixel PNG file.
125 126 127 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 125 def logo_url @logo_url end |
#merchant_entity_id ⇒ String
A unique, stable, Plaid-generated ID that maps to the merchant. In the case of a merchant with multiple retail locations, this field will map to the broader merchant, not a specific location or store.
234 235 236 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 234 def merchant_entity_id @merchant_entity_id end |
#merchant_name ⇒ String
The merchant name, as enriched by Plaid from the ‘name` field. This is typically a more human-readable version of the merchant counterparty in the transaction. For some bank transactions (such as checks or account transfers) where there is no meaningful merchant name, this value will be `null`.
81 82 83 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 81 def merchant_name @merchant_name end |
#name ⇒ String
The merchant name or transaction description. Note: This is a legacy field that is not actively maintained. Use ‘merchant_name` instead for the merchant name. If the `transactions` object was returned by a Transactions endpoint such as `/transactions/sync` or `/transactions/get`, this field will always appear. If the `transactions` object was returned by an Assets endpoint such as `/asset_report/get/` or `/asset_report/pdf/get`, this field will only appear in an Asset Report with Insights.
73 74 75 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 73 def name @name end |
#original_description ⇒ String
The string returned by the financial institution to describe the transaction. For transactions returned by ‘/transactions/sync` or `/transactions/get`, this field will only be included if the client has set `options.include_original_description` to `true`.
88 89 90 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 88 def original_description @original_description end |
#payment_channel ⇒ TransactionPaymentChannel
The channel used to make a payment. ‘online:` transactions that took place online. `in store:` transactions that were made at a physical location. `other:` transactions that relate to banks, e.g. fees or deposits.
173 174 175 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 173 def payment_channel @payment_channel end |
#payment_meta ⇒ CashflowReportPaymentMeta
Transaction information specific to inter-bank transfers. If the transaction was not an inter-bank transfer, all fields will be ‘null`.
93 94 95 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 93 def @payment_meta end |
#pending ⇒ TrueClass | FalseClass
When ‘true`, identifies the transaction as pending or unsettled. Pending transaction details (name, type, amount, category ID) may change before they are settled. Not all institutions provide pending transactions.
99 100 101 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 99 def pending @pending end |
#pending_transaction_id ⇒ String
The ID of a posted transaction’s associated pending transaction, where applicable. Not all institutions provide pending transactions.
104 105 106 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 104 def pending_transaction_id @pending_transaction_id end |
#personal_finance_category ⇒ PersonalFinanceCategory
Information describing the intent of the transaction. Most relevant for personal finance use cases, but not limited to such use cases. See the [taxonomy CSV file](plaid.com/documents/pfc-taxonomy-all.csv) for a full list of personal finance categories. If you are migrating to personal finance categories from the legacy categories, also refer to the [migration guide](plaid.com/docs/transactions/pfc-migration/).
183 184 185 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 183 def personal_finance_category @personal_finance_category end |
#personal_finance_category_icon_url ⇒ String
The URL of an icon associated with the primary personal finance category. The icon will always be 100×100 pixel PNG file.
222 223 224 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 222 def personal_finance_category_icon_url @personal_finance_category_icon_url end |
#transaction_code ⇒ TransactionCode
An identifier classifying the transaction type. This field is only populated for European institutions. For institutions in the US and Canada, this field is set to ‘null`. `adjustment:` Bank adjustment `atm:` Cash deposit or withdrawal via an automated teller machine `bank charge:` Charge or fee levied by the institution `bill payment`: Payment of a bill `cash:` Cash deposit or withdrawal `cashback:` Cash withdrawal while making a debit card purchase `cheque:` Document ordering the payment of money to another person or organization `direct debit:` Automatic withdrawal of funds initiated by a third party at a regular interval `interest:` Interest earned or incurred `purchase:` Purchase made with a debit or credit card `standing order:` Payment instructed by the account holder to a third party at a regular interval `transfer:` Transfer of money between accounts
217 218 219 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 217 def transaction_code @transaction_code end |
#transaction_id ⇒ String
The unique ID of the transaction. Like all Plaid identifiers, the ‘transaction_id` is case sensitive.
120 121 122 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 120 def transaction_id @transaction_id end |
#unofficial_currency_code ⇒ String
The unofficial currency code associated with the transaction. Always ‘null` if `iso_currency_code` is non-`null`. Unofficial currency codes are used for currencies that do not have official ISO currency codes, such as cryptocurrencies and the currencies of certain countries. See the [currency code schema](plaid.com/docs/api/accounts#currency-code-schema) for a full listing of supported `iso_currency_code`s.
40 41 42 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 40 def unofficial_currency_code @unofficial_currency_code end |
#website ⇒ String
The website associated with this transaction, if available.
129 130 131 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 129 def website @website end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 371 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_id = hash.key?('account_id') ? hash['account_id'] : nil amount = hash.key?('amount') ? hash['amount'] : nil iso_currency_code = hash.key?('iso_currency_code') ? hash['iso_currency_code'] : nil unofficial_currency_code = hash.key?('unofficial_currency_code') ? hash['unofficial_currency_code'] : nil date = hash.key?('date') ? hash['date'] : nil location = TransactionLocation.from_hash(hash['location']) if hash['location'] name = hash.key?('name') ? hash['name'] : nil = CashflowReportPaymentMeta.from_hash(hash['payment_meta']) if hash['payment_meta'] pending = hash.key?('pending') ? hash['pending'] : nil pending_transaction_id = hash.key?('pending_transaction_id') ? hash['pending_transaction_id'] : nil account_owner = hash.key?('account_owner') ? hash['account_owner'] : nil transaction_id = hash.key?('transaction_id') ? hash['transaction_id'] : nil = hash.key?('authorized_date') ? hash['authorized_date'] : nil = if hash.key?('authorized_datetime') (DateTimeHelper.from_rfc3339(hash['authorized_datetime']) if hash['authorized_datetime']) end datetime = if hash.key?('datetime') (DateTimeHelper.from_rfc3339(hash['datetime']) if hash['datetime']) end payment_channel = hash.key?('payment_channel') ? hash['payment_channel'] : nil transaction_code = hash.key?('transaction_code') ? hash['transaction_code'] : nil check_number = hash.key?('check_number') ? hash['check_number'] : SKIP merchant_name = hash.key?('merchant_name') ? hash['merchant_name'] : SKIP original_description = hash.key?('original_description') ? hash['original_description'] : SKIP logo_url = hash.key?('logo_url') ? hash['logo_url'] : SKIP website = hash.key?('website') ? hash['website'] : SKIP if hash['personal_finance_category'] personal_finance_category = PersonalFinanceCategory.from_hash(hash['personal_finance_category']) end if hash['business_finance_category'] business_finance_category = BusinessFinanceCategory.from_hash(hash['business_finance_category']) end credit_category = CreditCategory.from_hash(hash['credit_category']) if hash['credit_category'] personal_finance_category_icon_url = hash.key?('personal_finance_category_icon_url') ? hash['personal_finance_category_icon_url'] : SKIP # Parameter is an array, so we need to iterate through it counterparties = nil unless hash['counterparties'].nil? counterparties = [] hash['counterparties'].each do |structure| counterparties << (Counterparty.from_hash(structure) if structure) end end counterparties = SKIP unless hash.key?('counterparties') merchant_entity_id = hash.key?('merchant_entity_id') ? hash['merchant_entity_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CashflowReportTransaction.new(account_id: account_id, amount: amount, iso_currency_code: iso_currency_code, unofficial_currency_code: unofficial_currency_code, date: date, location: location, name: name, payment_meta: , pending: pending, pending_transaction_id: pending_transaction_id, account_owner: account_owner, transaction_id: transaction_id, authorized_date: , authorized_datetime: , datetime: datetime, payment_channel: payment_channel, transaction_code: transaction_code, check_number: check_number, merchant_name: merchant_name, original_description: original_description, logo_url: logo_url, website: website, personal_finance_category: personal_finance_category, business_finance_category: business_finance_category, credit_category: credit_category, personal_finance_category_icon_url: personal_finance_category_icon_url, counterparties: counterparties, merchant_entity_id: merchant_entity_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 237 def self.names @_hash = {} if @_hash.nil? @_hash['account_id'] = 'account_id' @_hash['amount'] = 'amount' @_hash['iso_currency_code'] = 'iso_currency_code' @_hash['unofficial_currency_code'] = 'unofficial_currency_code' @_hash['check_number'] = 'check_number' @_hash['date'] = 'date' @_hash['location'] = 'location' @_hash['name'] = 'name' @_hash['merchant_name'] = 'merchant_name' @_hash['original_description'] = 'original_description' @_hash['payment_meta'] = 'payment_meta' @_hash['pending'] = 'pending' @_hash['pending_transaction_id'] = 'pending_transaction_id' @_hash['account_owner'] = 'account_owner' @_hash['transaction_id'] = 'transaction_id' @_hash['logo_url'] = 'logo_url' @_hash['website'] = 'website' @_hash['authorized_date'] = 'authorized_date' @_hash['authorized_datetime'] = 'authorized_datetime' @_hash['datetime'] = 'datetime' @_hash['payment_channel'] = 'payment_channel' @_hash['personal_finance_category'] = 'personal_finance_category' @_hash['business_finance_category'] = 'business_finance_category' @_hash['credit_category'] = 'credit_category' @_hash['transaction_code'] = 'transaction_code' @_hash['personal_finance_category_icon_url'] = 'personal_finance_category_icon_url' @_hash['counterparties'] = 'counterparties' @_hash['merchant_entity_id'] = 'merchant_entity_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 289 def self.nullables %w[ amount iso_currency_code unofficial_currency_code check_number name merchant_name original_description pending pending_transaction_id account_owner logo_url website authorized_date authorized_datetime datetime personal_finance_category business_finance_category credit_category transaction_code personal_finance_category_icon_url merchant_entity_id ] end |
.optionals ⇒ Object
An array for optional fields
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 272 def self.optionals %w[ check_number merchant_name original_description logo_url website personal_finance_category business_finance_category credit_category personal_finance_category_icon_url counterparties merchant_entity_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 500 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_id: #{@account_id.inspect}, amount: #{@amount.inspect},"\ " iso_currency_code: #{@iso_currency_code.inspect}, unofficial_currency_code:"\ " #{@unofficial_currency_code.inspect}, check_number: #{@check_number.inspect}, date:"\ " #{@date.inspect}, location: #{@location.inspect}, name: #{@name.inspect}, merchant_name:"\ " #{@merchant_name.inspect}, original_description: #{@original_description.inspect},"\ " payment_meta: #{@payment_meta.inspect}, pending: #{@pending.inspect},"\ " pending_transaction_id: #{@pending_transaction_id.inspect}, account_owner:"\ " #{@account_owner.inspect}, transaction_id: #{@transaction_id.inspect}, logo_url:"\ " #{@logo_url.inspect}, website: #{@website.inspect}, authorized_date:"\ " #{@authorized_date.inspect}, authorized_datetime: #{@authorized_datetime.inspect},"\ " datetime: #{@datetime.inspect}, payment_channel: #{@payment_channel.inspect},"\ " personal_finance_category: #{@personal_finance_category.inspect},"\ " business_finance_category: #{@business_finance_category.inspect}, credit_category:"\ " #{@credit_category.inspect}, transaction_code: #{@transaction_code.inspect},"\ " personal_finance_category_icon_url: #{@personal_finance_category_icon_url.inspect},"\ " counterparties: #{@counterparties.inspect}, merchant_entity_id:"\ " #{@merchant_entity_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_custom_authorized_datetime ⇒ Object
472 473 474 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 472 def DateTimeHelper.to_rfc3339() end |
#to_custom_datetime ⇒ Object
476 477 478 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 476 def to_custom_datetime DateTimeHelper.to_rfc3339(datetime) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 |
# File 'lib/the_plaid_api/models/cashflow_report_transaction.rb', line 481 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_id: #{@account_id}, amount: #{@amount}, iso_currency_code:"\ " #{@iso_currency_code}, unofficial_currency_code: #{@unofficial_currency_code},"\ " check_number: #{@check_number}, date: #{@date}, location: #{@location}, name: #{@name},"\ " merchant_name: #{@merchant_name}, original_description: #{@original_description},"\ " payment_meta: #{@payment_meta}, pending: #{@pending}, pending_transaction_id:"\ " #{@pending_transaction_id}, account_owner: #{@account_owner}, transaction_id:"\ " #{@transaction_id}, logo_url: #{@logo_url}, website: #{@website}, authorized_date:"\ " #{@authorized_date}, authorized_datetime: #{@authorized_datetime}, datetime: #{@datetime},"\ " payment_channel: #{@payment_channel}, personal_finance_category:"\ " #{@personal_finance_category}, business_finance_category: #{@business_finance_category},"\ " credit_category: #{@credit_category}, transaction_code: #{@transaction_code},"\ " personal_finance_category_icon_url: #{@personal_finance_category_icon_url},"\ " counterparties: #{@counterparties}, merchant_entity_id: #{@merchant_entity_id},"\ " additional_properties: #{@additional_properties}>" end |