Class: ThePlaidApi::CounterpartyNumbers
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CounterpartyNumbers
- Defined in:
- lib/the_plaid_api/models/counterparty_numbers.rb
Overview
Account numbers associated with the counterparty, when available. This field is currently only filled in for select financial institutions in Europe.
Instance Attribute Summary collapse
-
#bacs ⇒ CounterpartyNumbersBacs
Identifying information for a UK bank account via BACS.
-
#international ⇒ CounterpartyNumbersInternational
Account numbers using the International Bank Account Number and BIC/SWIFT code format.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(bacs: SKIP, international: SKIP, additional_properties: nil) ⇒ CounterpartyNumbers
constructor
A new instance of CounterpartyNumbers.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(bacs: SKIP, international: SKIP, additional_properties: nil) ⇒ CounterpartyNumbers
Returns a new instance of CounterpartyNumbers.
46 47 48 49 50 51 52 53 |
# File 'lib/the_plaid_api/models/counterparty_numbers.rb', line 46 def initialize(bacs: SKIP, international: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @bacs = bacs unless bacs == SKIP @international = international unless international == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#bacs ⇒ CounterpartyNumbersBacs
Identifying information for a UK bank account via BACS.
15 16 17 |
# File 'lib/the_plaid_api/models/counterparty_numbers.rb', line 15 def bacs @bacs end |
#international ⇒ CounterpartyNumbersInternational
Account numbers using the International Bank Account Number and BIC/SWIFT code format.
20 21 22 |
# File 'lib/the_plaid_api/models/counterparty_numbers.rb', line 20 def international @international end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/the_plaid_api/models/counterparty_numbers.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. bacs = CounterpartyNumbersBacs.from_hash(hash['bacs']) if hash['bacs'] international = CounterpartyNumbersInternational.from_hash(hash['international']) if hash['international'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CounterpartyNumbers.new(bacs: bacs, international: international, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/the_plaid_api/models/counterparty_numbers.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['bacs'] = 'bacs' @_hash['international'] = 'international' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 42 43 44 |
# File 'lib/the_plaid_api/models/counterparty_numbers.rb', line 39 def self.nullables %w[ bacs international ] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/the_plaid_api/models/counterparty_numbers.rb', line 31 def self.optionals %w[ bacs international ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 |
# File 'lib/the_plaid_api/models/counterparty_numbers.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} bacs: #{@bacs.inspect}, international: #{@international.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 |
# File 'lib/the_plaid_api/models/counterparty_numbers.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} bacs: #{@bacs}, international: #{@international}, additional_properties:"\ " #{@additional_properties}>" end |