Class: ThePlaidApi::CraCheckReportNetworkInsightsGetOptions
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CraCheckReportNetworkInsightsGetOptions
- Defined in:
- lib/the_plaid_api/models/cra_check_report_network_insights_get_options.rb
Overview
Defines configuration options to generate Network Insights
Instance Attribute Summary collapse
-
#network_insights_version ⇒ NetworkInsightsVersion
The version of Network Insights.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(network_insights_version: SKIP, additional_properties: nil) ⇒ CraCheckReportNetworkInsightsGetOptions
constructor
A new instance of CraCheckReportNetworkInsightsGetOptions.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(network_insights_version: SKIP, additional_properties: nil) ⇒ CraCheckReportNetworkInsightsGetOptions
Returns a new instance of CraCheckReportNetworkInsightsGetOptions.
37 38 39 40 41 42 43 |
# File 'lib/the_plaid_api/models/cra_check_report_network_insights_get_options.rb', line 37 def initialize(network_insights_version: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @network_insights_version = network_insights_version unless network_insights_version == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#network_insights_version ⇒ NetworkInsightsVersion
The version of Network Insights. Required if using Network Insights.
14 15 16 |
# File 'lib/the_plaid_api/models/cra_check_report_network_insights_get_options.rb', line 14 def network_insights_version @network_insights_version end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/the_plaid_api/models/cra_check_report_network_insights_get_options.rb', line 46 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. network_insights_version = hash.key?('network_insights_version') ? hash['network_insights_version'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CraCheckReportNetworkInsightsGetOptions.new(network_insights_version: network_insights_version, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/the_plaid_api/models/cra_check_report_network_insights_get_options.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['network_insights_version'] = 'network_insights_version' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 34 35 |
# File 'lib/the_plaid_api/models/cra_check_report_network_insights_get_options.rb', line 31 def self.nullables %w[ network_insights_version ] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/the_plaid_api/models/cra_check_report_network_insights_get_options.rb', line 24 def self.optionals %w[ network_insights_version ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
73 74 75 76 77 |
# File 'lib/the_plaid_api/models/cra_check_report_network_insights_get_options.rb', line 73 def inspect class_name = self.class.name.split('::').last "<#{class_name} network_insights_version: #{@network_insights_version.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 70 |
# File 'lib/the_plaid_api/models/cra_check_report_network_insights_get_options.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} network_insights_version: #{@network_insights_version},"\ " additional_properties: #{@additional_properties}>" end |