Class: ThePlaidApi::CraCheckReportPartnerInsightsGetRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CraCheckReportPartnerInsightsGetRequest
- Defined in:
- lib/the_plaid_api/models/cra_check_report_partner_insights_get_request.rb
Overview
CraPartnerInsightsGetRequest defines the request schema for ‘/cra/partner_insights/get`.
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#options ⇒ CraCheckReportPartnerInsightsGetOptions
Deprecated, specify ‘partner_insights.prism_versions` instead.
-
#partner_insights ⇒ CraCheckReportPartnerInsightsGetPartnerInsights
Defines configuration to generate Partner Insights.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#third_party_user_token ⇒ String
The third-party user token associated with the requested User data.
-
#user_id ⇒ String
A unique user identifier, created by ‘/user/create`.
-
#user_tier ⇒ CraUserTier
The tier of the user.
-
#user_token ⇒ String
The user token associated with the User data is being requested for.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_id: SKIP, secret: SKIP, user_id: SKIP, third_party_user_token: SKIP, user_token: SKIP, user_tier: SKIP, partner_insights: SKIP, options: SKIP, additional_properties: nil) ⇒ CraCheckReportPartnerInsightsGetRequest
constructor
A new instance of CraCheckReportPartnerInsightsGetRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_id: SKIP, secret: SKIP, user_id: SKIP, third_party_user_token: SKIP, user_token: SKIP, user_tier: SKIP, partner_insights: SKIP, options: SKIP, additional_properties: nil) ⇒ CraCheckReportPartnerInsightsGetRequest
Returns a new instance of CraCheckReportPartnerInsightsGetRequest.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/the_plaid_api/models/cra_check_report_partner_insights_get_request.rb', line 91 def initialize(client_id: SKIP, secret: SKIP, user_id: SKIP, third_party_user_token: SKIP, user_token: SKIP, user_tier: SKIP, partner_insights: SKIP, options: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @user_id = user_id unless user_id == SKIP @third_party_user_token = third_party_user_token unless third_party_user_token == SKIP @user_token = user_token unless user_token == SKIP @user_tier = user_tier unless user_tier == SKIP @partner_insights = partner_insights unless partner_insights == SKIP @options = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/cra_check_report_partner_insights_get_request.rb', line 17 def client_id @client_id end |
#options ⇒ CraCheckReportPartnerInsightsGetOptions
Deprecated, specify ‘partner_insights.prism_versions` instead.
53 54 55 |
# File 'lib/the_plaid_api/models/cra_check_report_partner_insights_get_request.rb', line 53 def @options end |
#partner_insights ⇒ CraCheckReportPartnerInsightsGetPartnerInsights
Defines configuration to generate Partner Insights
49 50 51 |
# File 'lib/the_plaid_api/models/cra_check_report_partner_insights_get_request.rb', line 49 def partner_insights @partner_insights end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/the_plaid_api/models/cra_check_report_partner_insights_get_request.rb', line 22 def secret @secret end |
#third_party_user_token ⇒ String
The third-party user token associated with the requested User data.
33 34 35 |
# File 'lib/the_plaid_api/models/cra_check_report_partner_insights_get_request.rb', line 33 def third_party_user_token @third_party_user_token end |
#user_id ⇒ String
A unique user identifier, created by ‘/user/create`. Integrations that began using `/user/create` after December 10, 2025 use this field to identify a user instead of the `user_token`. For more details, see [new user APIs](plaid.com/docs/api/users/user-apis).
29 30 31 |
# File 'lib/the_plaid_api/models/cra_check_report_partner_insights_get_request.rb', line 29 def user_id @user_id end |
#user_tier ⇒ CraUserTier
The tier of the user.
45 46 47 |
# File 'lib/the_plaid_api/models/cra_check_report_partner_insights_get_request.rb', line 45 def user_tier @user_tier end |
#user_token ⇒ String
The user token associated with the User data is being requested for. This field is used only by customers with pre-existing integrations that already use the ‘user_token` field. All other customers should use the `user_id` instead. For more details, see [New User APIs](plaid.com/docs/api/users/user-apis).
41 42 43 |
# File 'lib/the_plaid_api/models/cra_check_report_partner_insights_get_request.rb', line 41 def user_token @user_token end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/the_plaid_api/models/cra_check_report_partner_insights_get_request.rb', line 110 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP user_id = hash.key?('user_id') ? hash['user_id'] : SKIP third_party_user_token = hash.key?('third_party_user_token') ? hash['third_party_user_token'] : SKIP user_token = hash.key?('user_token') ? hash['user_token'] : SKIP user_tier = hash.key?('user_tier') ? hash['user_tier'] : SKIP if hash['partner_insights'] partner_insights = CraCheckReportPartnerInsightsGetPartnerInsights.from_hash(hash['partner_insights']) end = CraCheckReportPartnerInsightsGetOptions.from_hash(hash['options']) if hash['options'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CraCheckReportPartnerInsightsGetRequest.new(client_id: client_id, secret: secret, user_id: user_id, third_party_user_token: third_party_user_token, user_token: user_token, user_tier: user_tier, partner_insights: partner_insights, options: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/the_plaid_api/models/cra_check_report_partner_insights_get_request.rb', line 56 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['user_id'] = 'user_id' @_hash['third_party_user_token'] = 'third_party_user_token' @_hash['user_token'] = 'user_token' @_hash['user_tier'] = 'user_tier' @_hash['partner_insights'] = 'partner_insights' @_hash['options'] = 'options' @_hash end |
.nullables ⇒ Object
An array for nullable fields
84 85 86 87 88 89 |
# File 'lib/the_plaid_api/models/cra_check_report_partner_insights_get_request.rb', line 84 def self.nullables %w[ user_tier options ] end |
.optionals ⇒ Object
An array for optional fields
70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/the_plaid_api/models/cra_check_report_partner_insights_get_request.rb', line 70 def self.optionals %w[ client_id secret user_id third_party_user_token user_token user_tier partner_insights options ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
156 157 158 159 160 161 162 163 |
# File 'lib/the_plaid_api/models/cra_check_report_partner_insights_get_request.rb', line 156 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, user_id:"\ " #{@user_id.inspect}, third_party_user_token: #{@third_party_user_token.inspect},"\ " user_token: #{@user_token.inspect}, user_tier: #{@user_tier.inspect}, partner_insights:"\ " #{@partner_insights.inspect}, options: #{@options.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
147 148 149 150 151 152 153 |
# File 'lib/the_plaid_api/models/cra_check_report_partner_insights_get_request.rb', line 147 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, user_id: #{@user_id},"\ " third_party_user_token: #{@third_party_user_token}, user_token: #{@user_token}, user_tier:"\ " #{@user_tier}, partner_insights: #{@partner_insights}, options: #{@options},"\ " additional_properties: #{@additional_properties}>" end |