Class: ThePlaidApi::CraCheckReportVerificationGetRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CraCheckReportVerificationGetRequest
- Defined in:
- lib/the_plaid_api/models/cra_check_report_verification_get_request.rb
Overview
CraCheckReportVerificationGetRequest defines the request schema for ‘/cra/check_report/verification/get`.
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#employment_refresh_options ⇒ CraCheckReportVerificationGetEmploymentRefreshOptions
Defines configuration options for the Employment Refresh Report.
-
#reports_requested ⇒ Array[CraCheckReportVerificationGetReportType]
Specifies which types of home lending reports are expected in the response.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#user_id ⇒ String
A unique user identifier, created by ‘/user/create`.
-
#user_token ⇒ String
The user token associated with the User data is being requested for.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(reports_requested:, client_id: SKIP, secret: SKIP, user_id: SKIP, employment_refresh_options: SKIP, user_token: SKIP, additional_properties: nil) ⇒ CraCheckReportVerificationGetRequest
constructor
A new instance of CraCheckReportVerificationGetRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(reports_requested:, client_id: SKIP, secret: SKIP, user_id: SKIP, employment_refresh_options: SKIP, user_token: SKIP, additional_properties: nil) ⇒ CraCheckReportVerificationGetRequest
Returns a new instance of CraCheckReportVerificationGetRequest.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/the_plaid_api/models/cra_check_report_verification_get_request.rb', line 77 def initialize(reports_requested:, client_id: SKIP, secret: SKIP, user_id: SKIP, employment_refresh_options: SKIP, user_token: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @user_id = user_id unless user_id == SKIP @reports_requested = reports_requested unless == SKIP @employment_refresh_options = end @user_token = user_token unless user_token == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/cra_check_report_verification_get_request.rb', line 17 def client_id @client_id end |
#employment_refresh_options ⇒ CraCheckReportVerificationGetEmploymentRefreshOptions
Defines configuration options for the Employment Refresh Report.
37 38 39 |
# File 'lib/the_plaid_api/models/cra_check_report_verification_get_request.rb', line 37 def @employment_refresh_options end |
#reports_requested ⇒ Array[CraCheckReportVerificationGetReportType]
Specifies which types of home lending reports are expected in the response
33 34 35 |
# File 'lib/the_plaid_api/models/cra_check_report_verification_get_request.rb', line 33 def reports_requested @reports_requested end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/the_plaid_api/models/cra_check_report_verification_get_request.rb', line 22 def secret @secret end |
#user_id ⇒ String
A unique user identifier, created by ‘/user/create`. Integrations that began using `/user/create` after December 10, 2025 use this field to identify a user instead of the `user_token`. For more details, see [new user APIs](plaid.com/docs/api/users/user-apis).
29 30 31 |
# File 'lib/the_plaid_api/models/cra_check_report_verification_get_request.rb', line 29 def user_id @user_id end |
#user_token ⇒ String
The user token associated with the User data is being requested for. This field is used only by customers with pre-existing integrations that already use the ‘user_token` field. All other customers should use the `user_id` instead. For more details, see [New User APIs](plaid.com/docs/api/users/user-apis).
45 46 47 |
# File 'lib/the_plaid_api/models/cra_check_report_verification_get_request.rb', line 45 def user_token @user_token end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/the_plaid_api/models/cra_check_report_verification_get_request.rb', line 96 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. reports_requested = hash.key?('reports_requested') ? hash['reports_requested'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP user_id = hash.key?('user_id') ? hash['user_id'] : SKIP if hash['employment_refresh_options'] = CraCheckReportVerificationGetEmploymentRefreshOptions.from_hash(hash['employment_refresh_options']) end user_token = hash.key?('user_token') ? hash['user_token'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CraCheckReportVerificationGetRequest.new(reports_requested: reports_requested, client_id: client_id, secret: secret, user_id: user_id, employment_refresh_options: , user_token: user_token, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/the_plaid_api/models/cra_check_report_verification_get_request.rb', line 48 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['user_id'] = 'user_id' @_hash['reports_requested'] = 'reports_requested' @_hash['employment_refresh_options'] = 'employment_refresh_options' @_hash['user_token'] = 'user_token' @_hash end |
.nullables ⇒ Object
An array for nullable fields
71 72 73 74 75 |
# File 'lib/the_plaid_api/models/cra_check_report_verification_get_request.rb', line 71 def self.nullables %w[ employment_refresh_options ] end |
.optionals ⇒ Object
An array for optional fields
60 61 62 63 64 65 66 67 68 |
# File 'lib/the_plaid_api/models/cra_check_report_verification_get_request.rb', line 60 def self.optionals %w[ client_id secret user_id employment_refresh_options user_token ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
137 138 139 140 141 142 143 |
# File 'lib/the_plaid_api/models/cra_check_report_verification_get_request.rb', line 137 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, user_id:"\ " #{@user_id.inspect}, reports_requested: #{@reports_requested.inspect},"\ " employment_refresh_options: #{@employment_refresh_options.inspect}, user_token:"\ " #{@user_token.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
128 129 130 131 132 133 134 |
# File 'lib/the_plaid_api/models/cra_check_report_verification_get_request.rb', line 128 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, user_id: #{@user_id},"\ " reports_requested: #{@reports_requested}, employment_refresh_options:"\ " #{@employment_refresh_options}, user_token: #{@user_token}, additional_properties:"\ " #{@additional_properties}>" end |