Class: ThePlaidApi::CraIncomeCategory
- Defined in:
- lib/the_plaid_api/models/cra_income_category.rb
Overview
The income category for a given stream. The streams returned in the response will be filtered based on these primary and secondary income categories. See the [Income V2 Category Taxonomy](plaid.com/documents/income-v2-category-taxonomy.csv) for a full list of income categories.
Instance Attribute Summary collapse
-
#primary ⇒ String
A high level category that communicates the broad category of the stream.
-
#secondary ⇒ String
A granular category conveying the stream’s intent.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(primary:, secondary:, additional_properties: nil) ⇒ CraIncomeCategory
constructor
A new instance of CraIncomeCategory.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(primary:, secondary:, additional_properties: nil) ⇒ CraIncomeCategory
Returns a new instance of CraIncomeCategory.
42 43 44 45 46 47 48 49 |
# File 'lib/the_plaid_api/models/cra_income_category.rb', line 42 def initialize(primary:, secondary:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @primary = primary @secondary = secondary @additional_properties = additional_properties end |
Instance Attribute Details
#primary ⇒ String
A high level category that communicates the broad category of the stream.
18 19 20 |
# File 'lib/the_plaid_api/models/cra_income_category.rb', line 18 def primary @primary end |
#secondary ⇒ String
A granular category conveying the stream’s intent.
22 23 24 |
# File 'lib/the_plaid_api/models/cra_income_category.rb', line 22 def secondary @secondary end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/the_plaid_api/models/cra_income_category.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. primary = hash.key?('primary') ? hash['primary'] : nil secondary = hash.key?('secondary') ? hash['secondary'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CraIncomeCategory.new(primary: primary, secondary: secondary, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 |
# File 'lib/the_plaid_api/models/cra_income_category.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['primary'] = 'primary' @_hash['secondary'] = 'secondary' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/the_plaid_api/models/cra_income_category.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
33 34 35 |
# File 'lib/the_plaid_api/models/cra_income_category.rb', line 33 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
80 81 82 83 84 |
# File 'lib/the_plaid_api/models/cra_income_category.rb', line 80 def inspect class_name = self.class.name.split('::').last "<#{class_name} primary: #{@primary.inspect}, secondary: #{@secondary.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 77 |
# File 'lib/the_plaid_api/models/cra_income_category.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} primary: #{@primary}, secondary: #{@secondary}, additional_properties:"\ " #{@additional_properties}>" end |