Class: ThePlaidApi::CraUserCheckReportFailedWebhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CraUserCheckReportFailedWebhook
- Defined in:
- lib/the_plaid_api/models/cra_user_check_report_failed_webhook.rb
Overview
Fired when a Check Report has failed to generate
Instance Attribute Summary collapse
-
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from.
-
#item_ids ⇒ Array[String]
A list of ‘item_ids` included in the Check Report.
-
#user_id ⇒ String
The ‘user_id` associated with the user whose data is being requested.
-
#webhook_code ⇒ String
‘USER_CHECK_REPORT_FAILED`.
-
#webhook_type ⇒ String
‘CHECK_REPORT`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, user_id:, environment:, item_ids: SKIP, additional_properties: nil) ⇒ CraUserCheckReportFailedWebhook
constructor
A new instance of CraUserCheckReportFailedWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, user_id:, environment:, item_ids: SKIP, additional_properties: nil) ⇒ CraUserCheckReportFailedWebhook
Returns a new instance of CraUserCheckReportFailedWebhook.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/the_plaid_api/models/cra_user_check_report_failed_webhook.rb', line 59 def initialize(webhook_type:, webhook_code:, user_id:, environment:, item_ids: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @user_id = user_id @item_ids = item_ids unless item_ids == SKIP @environment = environment @additional_properties = additional_properties end |
Instance Attribute Details
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from
32 33 34 |
# File 'lib/the_plaid_api/models/cra_user_check_report_failed_webhook.rb', line 32 def environment @environment end |
#item_ids ⇒ Array[String]
A list of ‘item_ids` included in the Check Report. Access to this field is in closed beta.
28 29 30 |
# File 'lib/the_plaid_api/models/cra_user_check_report_failed_webhook.rb', line 28 def item_ids @item_ids end |
#user_id ⇒ String
The ‘user_id` associated with the user whose data is being requested. This is received by calling user/create.
23 24 25 |
# File 'lib/the_plaid_api/models/cra_user_check_report_failed_webhook.rb', line 23 def user_id @user_id end |
#webhook_code ⇒ String
‘USER_CHECK_REPORT_FAILED`
18 19 20 |
# File 'lib/the_plaid_api/models/cra_user_check_report_failed_webhook.rb', line 18 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘CHECK_REPORT`
14 15 16 |
# File 'lib/the_plaid_api/models/cra_user_check_report_failed_webhook.rb', line 14 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/the_plaid_api/models/cra_user_check_report_failed_webhook.rb', line 73 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil user_id = hash.key?('user_id') ? hash['user_id'] : nil environment = hash.key?('environment') ? hash['environment'] : nil item_ids = hash.key?('item_ids') ? hash['item_ids'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CraUserCheckReportFailedWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, user_id: user_id, environment: environment, item_ids: item_ids, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
35 36 37 38 39 40 41 42 43 |
# File 'lib/the_plaid_api/models/cra_user_check_report_failed_webhook.rb', line 35 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['user_id'] = 'user_id' @_hash['item_ids'] = 'item_ids' @_hash['environment'] = 'environment' @_hash end |
.nullables ⇒ Object
An array for nullable fields
53 54 55 56 57 |
# File 'lib/the_plaid_api/models/cra_user_check_report_failed_webhook.rb', line 53 def self.nullables %w[ item_ids ] end |
.optionals ⇒ Object
An array for optional fields
46 47 48 49 50 |
# File 'lib/the_plaid_api/models/cra_user_check_report_failed_webhook.rb', line 46 def self.optionals %w[ item_ids ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
108 109 110 111 112 113 |
# File 'lib/the_plaid_api/models/cra_user_check_report_failed_webhook.rb', line 108 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, user_id: #{@user_id.inspect}, item_ids: #{@item_ids.inspect},"\ " environment: #{@environment.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
100 101 102 103 104 105 |
# File 'lib/the_plaid_api/models/cra_user_check_report_failed_webhook.rb', line 100 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, user_id:"\ " #{@user_id}, item_ids: #{@item_ids}, environment: #{@environment}, additional_properties:"\ " #{@additional_properties}>" end |