Class: ThePlaidApi::CreditBankEmploymentGetResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CreditBankEmploymentGetResponse
- Defined in:
- lib/the_plaid_api/models/credit_bank_employment_get_response.rb
Overview
CreditBankEmploymentGetResponse defines the response schema for ‘/beta/credit/v1/bank_employment/get`.
Instance Attribute Summary collapse
-
#bank_employment_reports ⇒ Array[CreditBankEmploymentReport]
Bank Employment data.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(bank_employment_reports:, request_id:, additional_properties: nil) ⇒ CreditBankEmploymentGetResponse
constructor
A new instance of CreditBankEmploymentGetResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(bank_employment_reports:, request_id:, additional_properties: nil) ⇒ CreditBankEmploymentGetResponse
Returns a new instance of CreditBankEmploymentGetResponse.
42 43 44 45 46 47 48 49 50 |
# File 'lib/the_plaid_api/models/credit_bank_employment_get_response.rb', line 42 def initialize(bank_employment_reports:, request_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @bank_employment_reports = bank_employment_reports @request_id = request_id @additional_properties = additional_properties end |
Instance Attribute Details
#bank_employment_reports ⇒ Array[CreditBankEmploymentReport]
Bank Employment data. Each entry in the array will be a distinct bank employment report.
16 17 18 |
# File 'lib/the_plaid_api/models/credit_bank_employment_get_response.rb', line 16 def bank_employment_reports @bank_employment_reports end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
22 23 24 |
# File 'lib/the_plaid_api/models/credit_bank_employment_get_response.rb', line 22 def request_id @request_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/the_plaid_api/models/credit_bank_employment_get_response.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it bank_employment_reports = nil unless hash['bank_employment_reports'].nil? bank_employment_reports = [] hash['bank_employment_reports'].each do |structure| bank_employment_reports << (CreditBankEmploymentReport.from_hash(structure) if structure) end end bank_employment_reports = nil unless hash.key?('bank_employment_reports') request_id = hash.key?('request_id') ? hash['request_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreditBankEmploymentGetResponse.new(bank_employment_reports: bank_employment_reports, request_id: request_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 |
# File 'lib/the_plaid_api/models/credit_bank_employment_get_response.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['bank_employment_reports'] = 'bank_employment_reports' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/the_plaid_api/models/credit_bank_employment_get_response.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
33 34 35 |
# File 'lib/the_plaid_api/models/credit_bank_employment_get_response.rb', line 33 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
90 91 92 93 94 |
# File 'lib/the_plaid_api/models/credit_bank_employment_get_response.rb', line 90 def inspect class_name = self.class.name.split('::').last "<#{class_name} bank_employment_reports: #{@bank_employment_reports.inspect}, request_id:"\ " #{@request_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 87 |
# File 'lib/the_plaid_api/models/credit_bank_employment_get_response.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} bank_employment_reports: #{@bank_employment_reports}, request_id:"\ " #{@request_id}, additional_properties: #{@additional_properties}>" end |