Class: ThePlaidApi::CreditBankStatementUploadBankAccountPeriod
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CreditBankStatementUploadBankAccountPeriod
- Defined in:
- lib/the_plaid_api/models/credit_bank_statement_upload_bank_account_period.rb
Overview
An object containing data on the overall period of the statement.
Instance Attribute Summary collapse
-
#end_date ⇒ Date
The end date of the statement period in ISO 8601 format (YYYY-MM-DD).
-
#ending_balance ⇒ Float
The ending balance of the bank account for the period.
-
#start_date ⇒ Date
The start date of the statement period in ISO 8601 format (YYYY-MM-DD).
-
#starting_balance ⇒ Float
The starting balance of the bank account for the period.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(start_date:, end_date:, starting_balance:, ending_balance:, additional_properties: nil) ⇒ CreditBankStatementUploadBankAccountPeriod
constructor
A new instance of CreditBankStatementUploadBankAccountPeriod.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(start_date:, end_date:, starting_balance:, ending_balance:, additional_properties: nil) ⇒ CreditBankStatementUploadBankAccountPeriod
Returns a new instance of CreditBankStatementUploadBankAccountPeriod.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/the_plaid_api/models/credit_bank_statement_upload_bank_account_period.rb', line 53 def initialize(start_date:, end_date:, starting_balance:, ending_balance:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @start_date = start_date @end_date = end_date @starting_balance = starting_balance @ending_balance = ending_balance @additional_properties = additional_properties end |
Instance Attribute Details
#end_date ⇒ Date
The end date of the statement period in ISO 8601 format (YYYY-MM-DD).
18 19 20 |
# File 'lib/the_plaid_api/models/credit_bank_statement_upload_bank_account_period.rb', line 18 def end_date @end_date end |
#ending_balance ⇒ Float
The ending balance of the bank account for the period.
26 27 28 |
# File 'lib/the_plaid_api/models/credit_bank_statement_upload_bank_account_period.rb', line 26 def ending_balance @ending_balance end |
#start_date ⇒ Date
The start date of the statement period in ISO 8601 format (YYYY-MM-DD).
14 15 16 |
# File 'lib/the_plaid_api/models/credit_bank_statement_upload_bank_account_period.rb', line 14 def start_date @start_date end |
#starting_balance ⇒ Float
The starting balance of the bank account for the period.
22 23 24 |
# File 'lib/the_plaid_api/models/credit_bank_statement_upload_bank_account_period.rb', line 22 def starting_balance @starting_balance end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/the_plaid_api/models/credit_bank_statement_upload_bank_account_period.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. start_date = hash.key?('start_date') ? hash['start_date'] : nil end_date = hash.key?('end_date') ? hash['end_date'] : nil starting_balance = hash.key?('starting_balance') ? hash['starting_balance'] : nil ending_balance = hash.key?('ending_balance') ? hash['ending_balance'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreditBankStatementUploadBankAccountPeriod.new(start_date: start_date, end_date: end_date, starting_balance: starting_balance, ending_balance: ending_balance, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/the_plaid_api/models/credit_bank_statement_upload_bank_account_period.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['start_date'] = 'start_date' @_hash['end_date'] = 'end_date' @_hash['starting_balance'] = 'starting_balance' @_hash['ending_balance'] = 'ending_balance' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 47 48 49 50 51 |
# File 'lib/the_plaid_api/models/credit_bank_statement_upload_bank_account_period.rb', line 44 def self.nullables %w[ start_date end_date starting_balance ending_balance ] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/the_plaid_api/models/credit_bank_statement_upload_bank_account_period.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
101 102 103 104 105 106 |
# File 'lib/the_plaid_api/models/credit_bank_statement_upload_bank_account_period.rb', line 101 def inspect class_name = self.class.name.split('::').last "<#{class_name} start_date: #{@start_date.inspect}, end_date: #{@end_date.inspect},"\ " starting_balance: #{@starting_balance.inspect}, ending_balance:"\ " #{@ending_balance.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
93 94 95 96 97 98 |
# File 'lib/the_plaid_api/models/credit_bank_statement_upload_bank_account_period.rb', line 93 def to_s class_name = self.class.name.split('::').last "<#{class_name} start_date: #{@start_date}, end_date: #{@end_date}, starting_balance:"\ " #{@starting_balance}, ending_balance: #{@ending_balance}, additional_properties:"\ " #{@additional_properties}>" end |