Class: ThePlaidApi::CreditBankStatementsUploadsGetRequestOptions
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CreditBankStatementsUploadsGetRequestOptions
- Defined in:
- lib/the_plaid_api/models/credit_bank_statements_uploads_get_request_options.rb
Overview
An optional object for ‘/credit/bank_statements/uploads/get` request options.
Instance Attribute Summary collapse
-
#item_ids ⇒ Array[String]
An array of ‘item_id`s whose bank statements information is returned.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(item_ids: SKIP, additional_properties: nil) ⇒ CreditBankStatementsUploadsGetRequestOptions
constructor
A new instance of CreditBankStatementsUploadsGetRequestOptions.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(item_ids: SKIP, additional_properties: nil) ⇒ CreditBankStatementsUploadsGetRequestOptions
Returns a new instance of CreditBankStatementsUploadsGetRequestOptions.
39 40 41 42 43 44 45 |
# File 'lib/the_plaid_api/models/credit_bank_statements_uploads_get_request_options.rb', line 39 def initialize(item_ids: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @item_ids = item_ids unless item_ids == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#item_ids ⇒ Array[String]
An array of ‘item_id`s whose bank statements information is returned. Each `item_id` should uniquely identify a bank statements uploaded item. If this field is not provided, all `item_id`s associated with the `user_token` will returned in the response.
18 19 20 |
# File 'lib/the_plaid_api/models/credit_bank_statements_uploads_get_request_options.rb', line 18 def item_ids @item_ids end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/the_plaid_api/models/credit_bank_statements_uploads_get_request_options.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. item_ids = hash.key?('item_ids') ? hash['item_ids'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreditBankStatementsUploadsGetRequestOptions.new(item_ids: item_ids, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 |
# File 'lib/the_plaid_api/models/credit_bank_statements_uploads_get_request_options.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['item_ids'] = 'item_ids' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/the_plaid_api/models/credit_bank_statements_uploads_get_request_options.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
28 29 30 31 32 |
# File 'lib/the_plaid_api/models/credit_bank_statements_uploads_get_request_options.rb', line 28 def self.optionals %w[ item_ids ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
73 74 75 76 77 |
# File 'lib/the_plaid_api/models/credit_bank_statements_uploads_get_request_options.rb', line 73 def inspect class_name = self.class.name.split('::').last "<#{class_name} item_ids: #{@item_ids.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 |
# File 'lib/the_plaid_api/models/credit_bank_statements_uploads_get_request_options.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} item_ids: #{@item_ids}, additional_properties: #{@additional_properties}>" end |