Class: ThePlaidApi::CreditEmploymentItem
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CreditEmploymentItem
- Defined in:
- lib/the_plaid_api/models/credit_employment_item.rb
Overview
The object containing employment items.
Instance Attribute Summary collapse
-
#employment_report_token ⇒ String
Token to represent the underlying Employment data.
-
#employments ⇒ Array[CreditEmploymentVerification]
The ‘item_id` of the Item associated with this webhook, warning, or error.
-
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(item_id:, employments:, employment_report_token: SKIP, additional_properties: nil) ⇒ CreditEmploymentItem
constructor
A new instance of CreditEmploymentItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(item_id:, employments:, employment_report_token: SKIP, additional_properties: nil) ⇒ CreditEmploymentItem
Returns a new instance of CreditEmploymentItem.
45 46 47 48 49 50 51 52 53 54 |
# File 'lib/the_plaid_api/models/credit_employment_item.rb', line 45 def initialize(item_id:, employments:, employment_report_token: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @item_id = item_id @employments = employments @employment_report_token = employment_report_token unless employment_report_token == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#employment_report_token ⇒ String
Token to represent the underlying Employment data
22 23 24 |
# File 'lib/the_plaid_api/models/credit_employment_item.rb', line 22 def employment_report_token @employment_report_token end |
#employments ⇒ Array[CreditEmploymentVerification]
The ‘item_id` of the Item associated with this webhook, warning, or error
18 19 20 |
# File 'lib/the_plaid_api/models/credit_employment_item.rb', line 18 def employments @employments end |
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error
14 15 16 |
# File 'lib/the_plaid_api/models/credit_employment_item.rb', line 14 def item_id @item_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/the_plaid_api/models/credit_employment_item.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. item_id = hash.key?('item_id') ? hash['item_id'] : nil # Parameter is an array, so we need to iterate through it employments = nil unless hash['employments'].nil? employments = [] hash['employments'].each do |structure| employments << (CreditEmploymentVerification.from_hash(structure) if structure) end end employments = nil unless hash.key?('employments') employment_report_token = hash.key?('employment_report_token') ? hash['employment_report_token'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreditEmploymentItem.new(item_id: item_id, employments: employments, employment_report_token: employment_report_token, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/the_plaid_api/models/credit_employment_item.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['item_id'] = 'item_id' @_hash['employments'] = 'employments' @_hash['employment_report_token'] = 'employment_report_token' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/the_plaid_api/models/credit_employment_item.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 |
# File 'lib/the_plaid_api/models/credit_employment_item.rb', line 34 def self.optionals %w[ employment_report_token ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 103 |
# File 'lib/the_plaid_api/models/credit_employment_item.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} item_id: #{@item_id.inspect}, employments: #{@employments.inspect},"\ " employment_report_token: #{@employment_report_token.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
90 91 92 93 94 95 |
# File 'lib/the_plaid_api/models/credit_employment_item.rb', line 90 def to_s class_name = self.class.name.split('::').last "<#{class_name} item_id: #{@item_id}, employments: #{@employments},"\ " employment_report_token: #{@employment_report_token}, additional_properties:"\ " #{@additional_properties}>" end |