Class: ThePlaidApi::CreditFreddieMacIndividualName
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CreditFreddieMacIndividualName
- Defined in:
- lib/the_plaid_api/models/credit_freddie_mac_individual_name.rb
Overview
Documentation not found in the MISMO model viewer and not provided by Freddie Mac.
Instance Attribute Summary collapse
-
#first_name ⇒ String
The first name of the individual represented by the parent object.
-
#last_name ⇒ String
The last name of the individual represented by the parent object.
-
#middle_name ⇒ String
The middle name of the individual represented by the parent object.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(first_name:, last_name:, middle_name:, additional_properties: nil) ⇒ CreditFreddieMacIndividualName
constructor
A new instance of CreditFreddieMacIndividualName.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(first_name:, last_name:, middle_name:, additional_properties: nil) ⇒ CreditFreddieMacIndividualName
Returns a new instance of CreditFreddieMacIndividualName.
44 45 46 47 48 49 50 51 52 53 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_individual_name.rb', line 44 def initialize(first_name:, last_name:, middle_name:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @first_name = first_name @last_name = last_name @middle_name = middle_name @additional_properties = additional_properties end |
Instance Attribute Details
#first_name ⇒ String
The first name of the individual represented by the parent object.
15 16 17 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_individual_name.rb', line 15 def first_name @first_name end |
#last_name ⇒ String
The last name of the individual represented by the parent object.
19 20 21 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_individual_name.rb', line 19 def last_name @last_name end |
#middle_name ⇒ String
The middle name of the individual represented by the parent object.
23 24 25 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_individual_name.rb', line 23 def middle_name @middle_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_individual_name.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. first_name = hash.key?('FirstName') ? hash['FirstName'] : nil last_name = hash.key?('LastName') ? hash['LastName'] : nil middle_name = hash.key?('MiddleName') ? hash['MiddleName'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreditFreddieMacIndividualName.new(first_name: first_name, last_name: last_name, middle_name: middle_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_individual_name.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['first_name'] = 'FirstName' @_hash['last_name'] = 'LastName' @_hash['middle_name'] = 'MiddleName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_individual_name.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_individual_name.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_individual_name.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} first_name: #{@first_name.inspect}, last_name: #{@last_name.inspect},"\ " middle_name: #{@middle_name.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_individual_name.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} first_name: #{@first_name}, last_name: #{@last_name}, middle_name:"\ " #{@middle_name}, additional_properties: #{@additional_properties}>" end |