Class: ThePlaidApi::CreditFreddieMacService
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CreditFreddieMacService
- Defined in:
- lib/the_plaid_api/models/credit_freddie_mac_service.rb
Overview
A collection of details related to a fulfillment service or product in terms of request, process and result.
Instance Attribute Summary collapse
-
#statuses ⇒ Statuses
A collection of STATUS containers.
-
#verification_of_asset ⇒ Array[CreditFreddieMacVerificationOfAsset]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(verification_of_asset:, statuses:, additional_properties: nil) ⇒ CreditFreddieMacService
constructor
A new instance of CreditFreddieMacService.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(verification_of_asset:, statuses:, additional_properties: nil) ⇒ CreditFreddieMacService
Returns a new instance of CreditFreddieMacService.
39 40 41 42 43 44 45 46 47 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_service.rb', line 39 def initialize(verification_of_asset:, statuses:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @verification_of_asset = verification_of_asset @statuses = statuses @additional_properties = additional_properties end |
Instance Attribute Details
#statuses ⇒ Statuses
A collection of STATUS containers.
19 20 21 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_service.rb', line 19 def statuses @statuses end |
#verification_of_asset ⇒ Array[CreditFreddieMacVerificationOfAsset]
TODO: Write general description for this method
15 16 17 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_service.rb', line 15 def verification_of_asset @verification_of_asset end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_service.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it verification_of_asset = nil unless hash['VERIFICATION_OF_ASSET'].nil? verification_of_asset = [] hash['VERIFICATION_OF_ASSET'].each do |structure| verification_of_asset << (CreditFreddieMacVerificationOfAsset.from_hash(structure) if structure) end end verification_of_asset = nil unless hash.key?('VERIFICATION_OF_ASSET') statuses = Statuses.from_hash(hash['STATUSES']) if hash['STATUSES'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreditFreddieMacService.new(verification_of_asset: verification_of_asset, statuses: statuses, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_service.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['verification_of_asset'] = 'VERIFICATION_OF_ASSET' @_hash['statuses'] = 'STATUSES' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_service.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_service.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
87 88 89 90 91 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_service.rb', line 87 def inspect class_name = self.class.name.split('::').last "<#{class_name} verification_of_asset: #{@verification_of_asset.inspect}, statuses:"\ " #{@statuses.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
80 81 82 83 84 |
# File 'lib/the_plaid_api/models/credit_freddie_mac_service.rb', line 80 def to_s class_name = self.class.name.split('::').last "<#{class_name} verification_of_asset: #{@verification_of_asset}, statuses: #{@statuses},"\ " additional_properties: #{@additional_properties}>" end |