Class: ThePlaidApi::CreditRelayGetRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::CreditRelayGetRequest
- Defined in:
- lib/the_plaid_api/models/credit_relay_get_request.rb
Overview
CreditRelayGetRequest defines the request schema for ‘/credit/relay/get`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#include_insights ⇒ TrueClass | FalseClass
‘true` if you would like to retrieve the Asset Report with Insights, `false` otherwise.
-
#relay_token ⇒ String
The ‘relay_token` granting access to the report you would like to get.
-
#report_type ⇒ String
readonly
The report type.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(relay_token:, client_id: SKIP, secret: SKIP, include_insights: false, additional_properties: nil) ⇒ CreditRelayGetRequest
constructor
A new instance of CreditRelayGetRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(relay_token:, client_id: SKIP, secret: SKIP, include_insights: false, additional_properties: nil) ⇒ CreditRelayGetRequest
Returns a new instance of CreditRelayGetRequest.
62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/the_plaid_api/models/credit_relay_get_request.rb', line 62 def initialize(relay_token:, client_id: SKIP, secret: SKIP, include_insights: false, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @relay_token = relay_token @report_type = 'asset' @include_insights = include_insights unless include_insights == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/the_plaid_api/models/credit_relay_get_request.rb', line 16 def client_id @client_id end |
#include_insights ⇒ TrueClass | FalseClass
‘true` if you would like to retrieve the Asset Report with Insights, `false` otherwise. This field defaults to `false` if omitted.
35 36 37 |
# File 'lib/the_plaid_api/models/credit_relay_get_request.rb', line 35 def include_insights @include_insights end |
#relay_token ⇒ String
The ‘relay_token` granting access to the report you would like to get.
25 26 27 |
# File 'lib/the_plaid_api/models/credit_relay_get_request.rb', line 25 def relay_token @relay_token end |
#report_type ⇒ String (readonly)
The report type. It can be ‘asset`. Income report types are not yet supported.
30 31 32 |
# File 'lib/the_plaid_api/models/credit_relay_get_request.rb', line 30 def report_type @report_type end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
21 22 23 |
# File 'lib/the_plaid_api/models/credit_relay_get_request.rb', line 21 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/the_plaid_api/models/credit_relay_get_request.rb', line 76 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. relay_token = hash.key?('relay_token') ? hash['relay_token'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP include_insights = hash['include_insights'] ||= false # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreditRelayGetRequest.new(relay_token: relay_token, client_id: client_id, secret: secret, include_insights: include_insights, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
38 39 40 41 42 43 44 45 46 |
# File 'lib/the_plaid_api/models/credit_relay_get_request.rb', line 38 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['relay_token'] = 'relay_token' @_hash['report_type'] = 'report_type' @_hash['include_insights'] = 'include_insights' @_hash end |
.nullables ⇒ Object
An array for nullable fields
58 59 60 |
# File 'lib/the_plaid_api/models/credit_relay_get_request.rb', line 58 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 52 53 54 55 |
# File 'lib/the_plaid_api/models/credit_relay_get_request.rb', line 49 def self.optionals %w[ client_id secret include_insights ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
109 110 111 112 113 114 |
# File 'lib/the_plaid_api/models/credit_relay_get_request.rb', line 109 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, relay_token:"\ " #{@relay_token.inspect}, report_type: #{@report_type.inspect}, include_insights:"\ " #{@include_insights.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
101 102 103 104 105 106 |
# File 'lib/the_plaid_api/models/credit_relay_get_request.rb', line 101 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, relay_token: #{@relay_token},"\ " report_type: #{@report_type}, include_insights: #{@include_insights},"\ " additional_properties: #{@additional_properties}>" end |