Class: ThePlaidApi::DocumentRiskSummary
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::DocumentRiskSummary
- Defined in:
- lib/the_plaid_api/models/document_risk_summary.rb
Overview
A summary across all risk signals associated with a document
Instance Attribute Summary collapse
-
#risk_score ⇒ Float
A number between 0 and 100, inclusive, where a score closer to 0 indicates a document is likely to be trustworthy and a score closer to 100 indicates a document is likely to be fraudulent.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(risk_score:, additional_properties: nil) ⇒ DocumentRiskSummary
constructor
A new instance of DocumentRiskSummary.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(risk_score:, additional_properties: nil) ⇒ DocumentRiskSummary
Returns a new instance of DocumentRiskSummary.
43 44 45 46 47 48 49 |
# File 'lib/the_plaid_api/models/document_risk_summary.rb', line 43 def initialize(risk_score:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @risk_score = risk_score @additional_properties = additional_properties end |
Instance Attribute Details
#risk_score ⇒ Float
A number between 0 and 100, inclusive, where a score closer to 0 indicates a document is likely to be trustworthy and a score closer to 100 indicates a document is likely to be fraudulent. You can automatically reject documents with a high risk score, automatically accept documents with a low risk score, and manually review documents in between. We suggest starting with a threshold of 80 for auto-rejection and 20 for auto-acceptance. As you gather more data points on typical risk scores for your use case, you can tune these parameters to reduce the number of documents undergoing manual review.
22 23 24 |
# File 'lib/the_plaid_api/models/document_risk_summary.rb', line 22 def risk_score @risk_score end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/the_plaid_api/models/document_risk_summary.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. risk_score = hash.key?('risk_score') ? hash['risk_score'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DocumentRiskSummary.new(risk_score: risk_score, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 |
# File 'lib/the_plaid_api/models/document_risk_summary.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['risk_score'] = 'risk_score' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 40 41 |
# File 'lib/the_plaid_api/models/document_risk_summary.rb', line 37 def self.nullables %w[ risk_score ] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 |
# File 'lib/the_plaid_api/models/document_risk_summary.rb', line 32 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/the_plaid_api/models/document_risk_summary.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} risk_score: #{@risk_score.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/the_plaid_api/models/document_risk_summary.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} risk_score: #{@risk_score}, additional_properties:"\ " #{@additional_properties}>" end |