Class: ThePlaidApi::EwaScore
- Defined in:
- lib/the_plaid_api/models/ewa_score.rb
Overview
EwaScore represents an earned wage access score for a specific advance amount range.
Instance Attribute Summary collapse
-
#highest_amount ⇒ Float
Float value representing the upper bound (exclusive) of the advance amount range associated with a specific EWA score.
-
#lowest_amount ⇒ Float
Float value representing the lower bound (inclusive) of the advance amount range associated with a specific EWA score.
-
#score ⇒ Integer
EWA score for the corresponding amount bucket.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(lowest_amount: SKIP, highest_amount: SKIP, score: SKIP, additional_properties: nil) ⇒ EwaScore
constructor
A new instance of EwaScore.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(lowest_amount: SKIP, highest_amount: SKIP, score: SKIP, additional_properties: nil) ⇒ EwaScore
Returns a new instance of EwaScore.
51 52 53 54 55 56 57 58 59 60 |
# File 'lib/the_plaid_api/models/ewa_score.rb', line 51 def initialize(lowest_amount: SKIP, highest_amount: SKIP, score: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @lowest_amount = lowest_amount unless lowest_amount == SKIP @highest_amount = highest_amount unless highest_amount == SKIP @score = score unless score == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#highest_amount ⇒ Float
Float value representing the upper bound (exclusive) of the advance amount range associated with a specific EWA score.
21 22 23 |
# File 'lib/the_plaid_api/models/ewa_score.rb', line 21 def highest_amount @highest_amount end |
#lowest_amount ⇒ Float
Float value representing the lower bound (inclusive) of the advance amount range associated with a specific EWA score.
16 17 18 |
# File 'lib/the_plaid_api/models/ewa_score.rb', line 16 def lowest_amount @lowest_amount end |
#score ⇒ Integer
EWA score for the corresponding amount bucket. Scores range from 1-99, where a higher score indicates a higher likelihood of repayment.
26 27 28 |
# File 'lib/the_plaid_api/models/ewa_score.rb', line 26 def score @score end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/the_plaid_api/models/ewa_score.rb', line 63 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. lowest_amount = hash.key?('lowest_amount') ? hash['lowest_amount'] : SKIP highest_amount = hash.key?('highest_amount') ? hash['highest_amount'] : SKIP score = hash.key?('score') ? hash['score'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. EwaScore.new(lowest_amount: lowest_amount, highest_amount: highest_amount, score: score, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 |
# File 'lib/the_plaid_api/models/ewa_score.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['lowest_amount'] = 'lowest_amount' @_hash['highest_amount'] = 'highest_amount' @_hash['score'] = 'score' @_hash end |
.nullables ⇒ Object
An array for nullable fields
47 48 49 |
# File 'lib/the_plaid_api/models/ewa_score.rb', line 47 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
38 39 40 41 42 43 44 |
# File 'lib/the_plaid_api/models/ewa_score.rb', line 38 def self.optionals %w[ lowest_amount highest_amount score ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
94 95 96 97 98 99 |
# File 'lib/the_plaid_api/models/ewa_score.rb', line 94 def inspect class_name = self.class.name.split('::').last "<#{class_name} lowest_amount: #{@lowest_amount.inspect}, highest_amount:"\ " #{@highest_amount.inspect}, score: #{@score.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
87 88 89 90 91 |
# File 'lib/the_plaid_api/models/ewa_score.rb', line 87 def to_s class_name = self.class.name.split('::').last "<#{class_name} lowest_amount: #{@lowest_amount}, highest_amount: #{@highest_amount},"\ " score: #{@score}, additional_properties: #{@additional_properties}>" end |