Class: ThePlaidApi::HoldingsDefaultUpdateWebhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::HoldingsDefaultUpdateWebhook
- Defined in:
- lib/the_plaid_api/models/holdings_default_update_webhook.rb
Overview
Fired when new or updated holdings have been detected on an investment account. The webhook typically fires in response to any newly added holdings or price changes to existing holdings, most commonly after market close.
Instance Attribute Summary collapse
-
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from.
-
#error ⇒ Error
Errors are identified by ‘error_code` and categorized by `error_type`.
-
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error.
-
#new_holdings ⇒ Float
The number of new holdings reported since the last time this webhook was fired.
-
#updated_holdings ⇒ Float
The number of updated holdings reported since the last time this webhook was fired.
-
#user_id ⇒ String
The Plaid ‘user_id` of the User associated with this webhook, warning, or error.
-
#webhook_code ⇒ String
‘DEFAULT_UPDATE`.
-
#webhook_type ⇒ String
‘HOLDINGS`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, item_id:, new_holdings:, updated_holdings:, environment:, user_id: SKIP, error: SKIP, additional_properties: nil) ⇒ HoldingsDefaultUpdateWebhook
constructor
A new instance of HoldingsDefaultUpdateWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, item_id:, new_holdings:, updated_holdings:, environment:, user_id: SKIP, error: SKIP, additional_properties: nil) ⇒ HoldingsDefaultUpdateWebhook
Returns a new instance of HoldingsDefaultUpdateWebhook.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/the_plaid_api/models/holdings_default_update_webhook.rb', line 86 def initialize(webhook_type:, webhook_code:, item_id:, new_holdings:, updated_holdings:, environment:, user_id: SKIP, error: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @item_id = item_id @user_id = user_id unless user_id == SKIP @error = error unless error == SKIP @new_holdings = new_holdings @updated_holdings = updated_holdings @environment = environment @additional_properties = additional_properties end |
Instance Attribute Details
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from
55 56 57 |
# File 'lib/the_plaid_api/models/holdings_default_update_webhook.rb', line 55 def environment @environment end |
#error ⇒ Error
Errors are identified by ‘error_code` and categorized by `error_type`. Use these in preference to HTTP status codes to identify and handle specific errors. HTTP status codes are set and provide the broadest categorization of errors: 4xx codes are for developer- or user-related errors, and 5xx codes are for Plaid-related errors, and the status will be 2xx in non-error cases. An Item with a non-`null` error object will only be part of an API response when calling `/item/get` to view Item status. Otherwise, error fields will be `null` if no error has occurred; if an error has occurred, an error code will be returned instead.
41 42 43 |
# File 'lib/the_plaid_api/models/holdings_default_update_webhook.rb', line 41 def error @error end |
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error
24 25 26 |
# File 'lib/the_plaid_api/models/holdings_default_update_webhook.rb', line 24 def item_id @item_id end |
#new_holdings ⇒ Float
The number of new holdings reported since the last time this webhook was fired.
46 47 48 |
# File 'lib/the_plaid_api/models/holdings_default_update_webhook.rb', line 46 def new_holdings @new_holdings end |
#updated_holdings ⇒ Float
The number of updated holdings reported since the last time this webhook was fired.
51 52 53 |
# File 'lib/the_plaid_api/models/holdings_default_update_webhook.rb', line 51 def updated_holdings @updated_holdings end |
#user_id ⇒ String
The Plaid ‘user_id` of the User associated with this webhook, warning, or error.
29 30 31 |
# File 'lib/the_plaid_api/models/holdings_default_update_webhook.rb', line 29 def user_id @user_id end |
#webhook_code ⇒ String
‘DEFAULT_UPDATE`
20 21 22 |
# File 'lib/the_plaid_api/models/holdings_default_update_webhook.rb', line 20 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘HOLDINGS`
16 17 18 |
# File 'lib/the_plaid_api/models/holdings_default_update_webhook.rb', line 16 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/the_plaid_api/models/holdings_default_update_webhook.rb', line 104 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil item_id = hash.key?('item_id') ? hash['item_id'] : nil new_holdings = hash.key?('new_holdings') ? hash['new_holdings'] : nil updated_holdings = hash.key?('updated_holdings') ? hash['updated_holdings'] : nil environment = hash.key?('environment') ? hash['environment'] : nil user_id = hash.key?('user_id') ? hash['user_id'] : SKIP error = Error.from_hash(hash['error']) if hash['error'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. HoldingsDefaultUpdateWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, item_id: item_id, new_holdings: new_holdings, updated_holdings: updated_holdings, environment: environment, user_id: user_id, error: error, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/the_plaid_api/models/holdings_default_update_webhook.rb', line 58 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['item_id'] = 'item_id' @_hash['user_id'] = 'user_id' @_hash['error'] = 'error' @_hash['new_holdings'] = 'new_holdings' @_hash['updated_holdings'] = 'updated_holdings' @_hash['environment'] = 'environment' @_hash end |
.nullables ⇒ Object
An array for nullable fields
80 81 82 83 84 |
# File 'lib/the_plaid_api/models/holdings_default_update_webhook.rb', line 80 def self.nullables %w[ error ] end |
.optionals ⇒ Object
An array for optional fields
72 73 74 75 76 77 |
# File 'lib/the_plaid_api/models/holdings_default_update_webhook.rb', line 72 def self.optionals %w[ user_id error ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
147 148 149 150 151 152 153 154 |
# File 'lib/the_plaid_api/models/holdings_default_update_webhook.rb', line 147 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, item_id: #{@item_id.inspect}, user_id: #{@user_id.inspect},"\ " error: #{@error.inspect}, new_holdings: #{@new_holdings.inspect}, updated_holdings:"\ " #{@updated_holdings.inspect}, environment: #{@environment.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
138 139 140 141 142 143 144 |
# File 'lib/the_plaid_api/models/holdings_default_update_webhook.rb', line 138 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, item_id:"\ " #{@item_id}, user_id: #{@user_id}, error: #{@error}, new_holdings: #{@new_holdings},"\ " updated_holdings: #{@updated_holdings}, environment: #{@environment},"\ " additional_properties: #{@additional_properties}>" end |