Class: ThePlaidApi::HostedMmdVerificationWebhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::HostedMmdVerificationWebhook
- Defined in:
- lib/the_plaid_api/models/hosted_mmd_verification_webhook.rb
Overview
Contains the state of a SMS same-day microdeposits verification session.
Instance Attribute Summary collapse
-
#account_id ⇒ String
The external account ID of the affected account.
-
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from.
-
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error.
-
#status ⇒ String
The final status of the same-day microdeposits verification.
-
#webhook_code ⇒ String
‘SMS_MICRODEPOSITS_VERIFICATION`.
-
#webhook_type ⇒ String
‘AUTH`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, status:, item_id:, account_id:, environment: SKIP, additional_properties: nil) ⇒ HostedMmdVerificationWebhook
constructor
A new instance of HostedMmdVerificationWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, status:, item_id:, account_id:, environment: SKIP, additional_properties: nil) ⇒ HostedMmdVerificationWebhook
Returns a new instance of HostedMmdVerificationWebhook.
61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/the_plaid_api/models/hosted_mmd_verification_webhook.rb', line 61 def initialize(webhook_type:, webhook_code:, status:, item_id:, account_id:, environment: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @status = status @item_id = item_id @account_id = account_id @environment = environment unless environment == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
The external account ID of the affected account
31 32 33 |
# File 'lib/the_plaid_api/models/hosted_mmd_verification_webhook.rb', line 31 def account_id @account_id end |
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from
35 36 37 |
# File 'lib/the_plaid_api/models/hosted_mmd_verification_webhook.rb', line 35 def environment @environment end |
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error
27 28 29 |
# File 'lib/the_plaid_api/models/hosted_mmd_verification_webhook.rb', line 27 def item_id @item_id end |
#status ⇒ String
The final status of the same-day microdeposits verification. Will always be ‘MANUALLY_VERIFIED` or `VERIFICATION_FAILED`.
23 24 25 |
# File 'lib/the_plaid_api/models/hosted_mmd_verification_webhook.rb', line 23 def status @status end |
#webhook_code ⇒ String
‘SMS_MICRODEPOSITS_VERIFICATION`
18 19 20 |
# File 'lib/the_plaid_api/models/hosted_mmd_verification_webhook.rb', line 18 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘AUTH`
14 15 16 |
# File 'lib/the_plaid_api/models/hosted_mmd_verification_webhook.rb', line 14 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/the_plaid_api/models/hosted_mmd_verification_webhook.rb', line 76 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil status = hash.key?('status') ? hash['status'] : nil item_id = hash.key?('item_id') ? hash['item_id'] : nil account_id = hash.key?('account_id') ? hash['account_id'] : nil environment = hash.key?('environment') ? hash['environment'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. HostedMmdVerificationWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, status: status, item_id: item_id, account_id: account_id, environment: environment, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/the_plaid_api/models/hosted_mmd_verification_webhook.rb', line 38 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['status'] = 'status' @_hash['item_id'] = 'item_id' @_hash['account_id'] = 'account_id' @_hash['environment'] = 'environment' @_hash end |
.nullables ⇒ Object
An array for nullable fields
57 58 59 |
# File 'lib/the_plaid_api/models/hosted_mmd_verification_webhook.rb', line 57 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
50 51 52 53 54 |
# File 'lib/the_plaid_api/models/hosted_mmd_verification_webhook.rb', line 50 def self.optionals %w[ environment ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
113 114 115 116 117 118 119 |
# File 'lib/the_plaid_api/models/hosted_mmd_verification_webhook.rb', line 113 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, status: #{@status.inspect}, item_id: #{@item_id.inspect},"\ " account_id: #{@account_id.inspect}, environment: #{@environment.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
105 106 107 108 109 110 |
# File 'lib/the_plaid_api/models/hosted_mmd_verification_webhook.rb', line 105 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, status:"\ " #{@status}, item_id: #{@item_id}, account_id: #{@account_id}, environment:"\ " #{@environment}, additional_properties: #{@additional_properties}>" end |