Class: ThePlaidApi::IdentityVerificationStepSummary
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::IdentityVerificationStepSummary
- Defined in:
- lib/the_plaid_api/models/identity_verification_step_summary.rb
Overview
Each step will be one of the following values: ‘active` - This step is the user’s current step. They are either in the process of completing this step, or they recently closed their Identity Verification attempt while in the middle of this step. Only one step will be marked as ‘active` at any given point. `success` - The Identity Verification attempt has completed this step. `failed` - The user failed this step. This can either call the user to fail the session as a whole, or cause them to fallback to another step depending on how the Identity Verification template is configured. A failed step does not imply a failed session. `waiting_for_prerequisite` - The user needs to complete another step first, before they progress to this step. This step may never run, depending on if the user fails an earlier step or if the step is only run as a fallback. `not_applicable` - This step will not be run for this session. `skipped` - The retry instructions that created this Identity Verification attempt specified that this step should be skipped. `expired` - This step had not yet been completed when the Identity Verification attempt as a whole expired. `canceled` - The Identity Verification attempt was canceled before the user completed this step. `pending_review` - The Identity Verification attempt template was configured to perform a screening that had one or more hits needing review. `manually_approved` - The step was manually overridden to pass by a team member in the dashboard. `manually_rejected` - The step was manually overridden to fail by a team member in the dashboard.
Instance Attribute Summary collapse
-
#accept_tos ⇒ IdentityVerificationStepStatus
The status of a step in the Identity Verification process.
-
#documentary_verification ⇒ IdentityVerificationStepStatus
The status of a step in the Identity Verification process.
-
#kyc_check ⇒ IdentityVerificationStepStatus
The status of a step in the Identity Verification process.
-
#risk_check ⇒ IdentityVerificationStepStatus
The status of a step in the Identity Verification process.
-
#selfie_check ⇒ IdentityVerificationStepStatus
The status of a step in the Identity Verification process.
-
#verify_sms ⇒ IdentityVerificationStepStatus
The status of a step in the Identity Verification process.
-
#watchlist_screening ⇒ IdentityVerificationStepStatus
The status of a step in the Identity Verification process.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(accept_tos:, verify_sms:, kyc_check:, documentary_verification:, selfie_check:, watchlist_screening:, risk_check:, additional_properties: nil) ⇒ IdentityVerificationStepSummary
constructor
A new instance of IdentityVerificationStepSummary.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(accept_tos:, verify_sms:, kyc_check:, documentary_verification:, selfie_check:, watchlist_screening:, risk_check:, additional_properties: nil) ⇒ IdentityVerificationStepSummary
Returns a new instance of IdentityVerificationStepSummary.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/the_plaid_api/models/identity_verification_step_summary.rb', line 84 def initialize(accept_tos:, verify_sms:, kyc_check:, documentary_verification:, selfie_check:, watchlist_screening:, risk_check:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @accept_tos = accept_tos @verify_sms = verify_sms @kyc_check = kyc_check @documentary_verification = documentary_verification @selfie_check = selfie_check @watchlist_screening = watchlist_screening @risk_check = risk_check @additional_properties = additional_properties end |
Instance Attribute Details
#accept_tos ⇒ IdentityVerificationStepStatus
The status of a step in the Identity Verification process.
35 36 37 |
# File 'lib/the_plaid_api/models/identity_verification_step_summary.rb', line 35 def accept_tos @accept_tos end |
#documentary_verification ⇒ IdentityVerificationStepStatus
The status of a step in the Identity Verification process.
47 48 49 |
# File 'lib/the_plaid_api/models/identity_verification_step_summary.rb', line 47 def documentary_verification @documentary_verification end |
#kyc_check ⇒ IdentityVerificationStepStatus
The status of a step in the Identity Verification process.
43 44 45 |
# File 'lib/the_plaid_api/models/identity_verification_step_summary.rb', line 43 def kyc_check @kyc_check end |
#risk_check ⇒ IdentityVerificationStepStatus
The status of a step in the Identity Verification process.
59 60 61 |
# File 'lib/the_plaid_api/models/identity_verification_step_summary.rb', line 59 def risk_check @risk_check end |
#selfie_check ⇒ IdentityVerificationStepStatus
The status of a step in the Identity Verification process.
51 52 53 |
# File 'lib/the_plaid_api/models/identity_verification_step_summary.rb', line 51 def selfie_check @selfie_check end |
#verify_sms ⇒ IdentityVerificationStepStatus
The status of a step in the Identity Verification process.
39 40 41 |
# File 'lib/the_plaid_api/models/identity_verification_step_summary.rb', line 39 def verify_sms @verify_sms end |
#watchlist_screening ⇒ IdentityVerificationStepStatus
The status of a step in the Identity Verification process.
55 56 57 |
# File 'lib/the_plaid_api/models/identity_verification_step_summary.rb', line 55 def watchlist_screening @watchlist_screening end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/the_plaid_api/models/identity_verification_step_summary.rb', line 102 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. accept_tos = hash.key?('accept_tos') ? hash['accept_tos'] : nil verify_sms = hash.key?('verify_sms') ? hash['verify_sms'] : nil kyc_check = hash.key?('kyc_check') ? hash['kyc_check'] : nil documentary_verification = hash.key?('documentary_verification') ? hash['documentary_verification'] : nil selfie_check = hash.key?('selfie_check') ? hash['selfie_check'] : nil watchlist_screening = hash.key?('watchlist_screening') ? hash['watchlist_screening'] : nil risk_check = hash.key?('risk_check') ? hash['risk_check'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. IdentityVerificationStepSummary.new(accept_tos: accept_tos, verify_sms: verify_sms, kyc_check: kyc_check, documentary_verification: documentary_verification, selfie_check: selfie_check, watchlist_screening: watchlist_screening, risk_check: risk_check, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/the_plaid_api/models/identity_verification_step_summary.rb', line 62 def self.names @_hash = {} if @_hash.nil? @_hash['accept_tos'] = 'accept_tos' @_hash['verify_sms'] = 'verify_sms' @_hash['kyc_check'] = 'kyc_check' @_hash['documentary_verification'] = 'documentary_verification' @_hash['selfie_check'] = 'selfie_check' @_hash['watchlist_screening'] = 'watchlist_screening' @_hash['risk_check'] = 'risk_check' @_hash end |
.nullables ⇒ Object
An array for nullable fields
80 81 82 |
# File 'lib/the_plaid_api/models/identity_verification_step_summary.rb', line 80 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
75 76 77 |
# File 'lib/the_plaid_api/models/identity_verification_step_summary.rb', line 75 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
144 145 146 147 148 149 150 151 |
# File 'lib/the_plaid_api/models/identity_verification_step_summary.rb', line 144 def inspect class_name = self.class.name.split('::').last "<#{class_name} accept_tos: #{@accept_tos.inspect}, verify_sms: #{@verify_sms.inspect},"\ " kyc_check: #{@kyc_check.inspect}, documentary_verification:"\ " #{@documentary_verification.inspect}, selfie_check: #{@selfie_check.inspect},"\ " watchlist_screening: #{@watchlist_screening.inspect}, risk_check: #{@risk_check.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
135 136 137 138 139 140 141 |
# File 'lib/the_plaid_api/models/identity_verification_step_summary.rb', line 135 def to_s class_name = self.class.name.split('::').last "<#{class_name} accept_tos: #{@accept_tos}, verify_sms: #{@verify_sms}, kyc_check:"\ " #{@kyc_check}, documentary_verification: #{@documentary_verification}, selfie_check:"\ " #{@selfie_check}, watchlist_screening: #{@watchlist_screening}, risk_check:"\ " #{@risk_check}, additional_properties: #{@additional_properties}>" end |