Class: ThePlaidApi::IncomeOverride
- Defined in:
- lib/the_plaid_api/models/income_override.rb
Overview
Specify payroll data on the account.
Instance Attribute Summary collapse
-
#paystubs ⇒ Array[PaystubOverride]
A list of paystubs associated with the account.
-
#w2s ⇒ Array[W2Override]
A list of w2s associated with the account.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(paystubs: SKIP, w2s: SKIP, additional_properties: nil) ⇒ IncomeOverride
constructor
A new instance of IncomeOverride.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(paystubs: SKIP, w2s: SKIP, additional_properties: nil) ⇒ IncomeOverride
Returns a new instance of IncomeOverride.
41 42 43 44 45 46 47 48 |
# File 'lib/the_plaid_api/models/income_override.rb', line 41 def initialize(paystubs: SKIP, w2s: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @paystubs = paystubs unless paystubs == SKIP @w2s = w2s unless w2s == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#paystubs ⇒ Array[PaystubOverride]
A list of paystubs associated with the account.
14 15 16 |
# File 'lib/the_plaid_api/models/income_override.rb', line 14 def paystubs @paystubs end |
#w2s ⇒ Array[W2Override]
A list of w2s associated with the account.
18 19 20 |
# File 'lib/the_plaid_api/models/income_override.rb', line 18 def w2s @w2s end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/the_plaid_api/models/income_override.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it paystubs = nil unless hash['paystubs'].nil? paystubs = [] hash['paystubs'].each do |structure| paystubs << (PaystubOverride.from_hash(structure) if structure) end end paystubs = SKIP unless hash.key?('paystubs') # Parameter is an array, so we need to iterate through it w2s = nil unless hash['w2s'].nil? w2s = [] hash['w2s'].each do |structure| w2s << (W2Override.from_hash(structure) if structure) end end w2s = SKIP unless hash.key?('w2s') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. IncomeOverride.new(paystubs: paystubs, w2s: w2s, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/the_plaid_api/models/income_override.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['paystubs'] = 'paystubs' @_hash['w2s'] = 'w2s' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/the_plaid_api/models/income_override.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/the_plaid_api/models/income_override.rb', line 29 def self.optionals %w[ paystubs w2s ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
97 98 99 100 101 |
# File 'lib/the_plaid_api/models/income_override.rb', line 97 def inspect class_name = self.class.name.split('::').last "<#{class_name} paystubs: #{@paystubs.inspect}, w2s: #{@w2s.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
90 91 92 93 94 |
# File 'lib/the_plaid_api/models/income_override.rb', line 90 def to_s class_name = self.class.name.split('::').last "<#{class_name} paystubs: #{@paystubs}, w2s: #{@w2s}, additional_properties:"\ " #{@additional_properties}>" end |