Class: ThePlaidApi::IncomeVerificationCreateRequestOptions
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::IncomeVerificationCreateRequestOptions
- Defined in:
- lib/the_plaid_api/models/income_verification_create_request_options.rb
Overview
Optional arguments for ‘/income/verification/create`
Instance Attribute Summary collapse
-
#access_tokens ⇒ Array[String]
An array of access tokens corresponding to the Items that will be cross-referenced with the product data.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(access_tokens: SKIP, additional_properties: nil) ⇒ IncomeVerificationCreateRequestOptions
constructor
A new instance of IncomeVerificationCreateRequestOptions.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(access_tokens: SKIP, additional_properties: nil) ⇒ IncomeVerificationCreateRequestOptions
Returns a new instance of IncomeVerificationCreateRequestOptions.
39 40 41 42 43 44 45 |
# File 'lib/the_plaid_api/models/income_verification_create_request_options.rb', line 39 def initialize(access_tokens: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @access_tokens = access_tokens unless access_tokens == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#access_tokens ⇒ Array[String]
An array of access tokens corresponding to the Items that will be cross-referenced with the product data. Plaid will attempt to correlate transaction history from these Items with data from the user’s paystub, such as date and amount. If the ‘transactions` product was not initialized for the Items during Link, it will be initialized after this Link session.
18 19 20 |
# File 'lib/the_plaid_api/models/income_verification_create_request_options.rb', line 18 def access_tokens @access_tokens end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/the_plaid_api/models/income_verification_create_request_options.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. access_tokens = hash.key?('access_tokens') ? hash['access_tokens'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. IncomeVerificationCreateRequestOptions.new(access_tokens: access_tokens, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 |
# File 'lib/the_plaid_api/models/income_verification_create_request_options.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['access_tokens'] = 'access_tokens' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/the_plaid_api/models/income_verification_create_request_options.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
28 29 30 31 32 |
# File 'lib/the_plaid_api/models/income_verification_create_request_options.rb', line 28 def self.optionals %w[ access_tokens ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
74 75 76 77 78 |
# File 'lib/the_plaid_api/models/income_verification_create_request_options.rb', line 74 def inspect class_name = self.class.name.split('::').last "<#{class_name} access_tokens: #{@access_tokens.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 71 |
# File 'lib/the_plaid_api/models/income_verification_create_request_options.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} access_tokens: #{@access_tokens}, additional_properties:"\ " #{@additional_properties}>" end |