Class: ThePlaidApi::IncomeVerificationDocumentsDownloadRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::IncomeVerificationDocumentsDownloadRequest
- Defined in:
- lib/the_plaid_api/models/income_verification_documents_download_request.rb
Overview
IncomeVerificationDocumentsDownloadRequest defines the request schema for ‘/income/verification/documents/download`.
Instance Attribute Summary collapse
-
#access_token ⇒ String
The access token associated with the Item data is being requested for.
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#document_id ⇒ String
The document ID to download.
-
#income_verification_id ⇒ String
The ID of the verification.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_id: SKIP, secret: SKIP, income_verification_id: SKIP, access_token: SKIP, document_id: SKIP, additional_properties: nil) ⇒ IncomeVerificationDocumentsDownloadRequest
constructor
A new instance of IncomeVerificationDocumentsDownloadRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_id: SKIP, secret: SKIP, income_verification_id: SKIP, access_token: SKIP, document_id: SKIP, additional_properties: nil) ⇒ IncomeVerificationDocumentsDownloadRequest
Returns a new instance of IncomeVerificationDocumentsDownloadRequest.
68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/the_plaid_api/models/income_verification_documents_download_request.rb', line 68 def initialize(client_id: SKIP, secret: SKIP, income_verification_id: SKIP, access_token: SKIP, document_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @income_verification_id = income_verification_id unless income_verification_id == SKIP @access_token = access_token unless access_token == SKIP @document_id = document_id unless document_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#access_token ⇒ String
The access token associated with the Item data is being requested for.
30 31 32 |
# File 'lib/the_plaid_api/models/income_verification_documents_download_request.rb', line 30 def access_token @access_token end |
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/income_verification_documents_download_request.rb', line 17 def client_id @client_id end |
#document_id ⇒ String
The document ID to download. If passed, a single document will be returned in the resulting zip file, rather than all document
35 36 37 |
# File 'lib/the_plaid_api/models/income_verification_documents_download_request.rb', line 35 def document_id @document_id end |
#income_verification_id ⇒ String
The ID of the verification.
26 27 28 |
# File 'lib/the_plaid_api/models/income_verification_documents_download_request.rb', line 26 def income_verification_id @income_verification_id end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/the_plaid_api/models/income_verification_documents_download_request.rb', line 22 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/the_plaid_api/models/income_verification_documents_download_request.rb', line 83 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP income_verification_id = hash.key?('income_verification_id') ? hash['income_verification_id'] : SKIP access_token = hash.key?('access_token') ? hash['access_token'] : SKIP document_id = hash.key?('document_id') ? hash['document_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. IncomeVerificationDocumentsDownloadRequest.new(client_id: client_id, secret: secret, income_verification_id: income_verification_id, access_token: access_token, document_id: document_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
38 39 40 41 42 43 44 45 46 |
# File 'lib/the_plaid_api/models/income_verification_documents_download_request.rb', line 38 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['income_verification_id'] = 'income_verification_id' @_hash['access_token'] = 'access_token' @_hash['document_id'] = 'document_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
60 61 62 63 64 65 66 |
# File 'lib/the_plaid_api/models/income_verification_documents_download_request.rb', line 60 def self.nullables %w[ income_verification_id access_token document_id ] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 52 53 54 55 56 57 |
# File 'lib/the_plaid_api/models/income_verification_documents_download_request.rb', line 49 def self.optionals %w[ client_id secret income_verification_id access_token document_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
119 120 121 122 123 124 125 |
# File 'lib/the_plaid_api/models/income_verification_documents_download_request.rb', line 119 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\ " income_verification_id: #{@income_verification_id.inspect}, access_token:"\ " #{@access_token.inspect}, document_id: #{@document_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
111 112 113 114 115 116 |
# File 'lib/the_plaid_api/models/income_verification_documents_download_request.rb', line 111 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, income_verification_id:"\ " #{@income_verification_id}, access_token: #{@access_token}, document_id: #{@document_id},"\ " additional_properties: #{@additional_properties}>" end |