Class: ThePlaidApi::IndividualScreeningHitNames
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::IndividualScreeningHitNames
- Defined in:
- lib/the_plaid_api/models/individual_screening_hit_names.rb
Overview
Name information for the associated individual watchlist hit
Instance Attribute Summary collapse
-
#full ⇒ String
The full name of the individual, including all parts.
-
#is_primary ⇒ TrueClass | FalseClass
Primary names are those most commonly used to refer to this person.
-
#weak_alias_determination ⇒ WeakAliasDetermination
Names that are explicitly marked as low quality either by their ‘source` list, or by `plaid` by a series of additional checks done by Plaid.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(full:, is_primary:, weak_alias_determination:, additional_properties: nil) ⇒ IndividualScreeningHitNames
constructor
A new instance of IndividualScreeningHitNames.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(full:, is_primary:, weak_alias_determination:, additional_properties: nil) ⇒ IndividualScreeningHitNames
Returns a new instance of IndividualScreeningHitNames.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/the_plaid_api/models/individual_screening_hit_names.rb', line 47 def initialize(full:, is_primary:, weak_alias_determination:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @full = full @is_primary = is_primary @weak_alias_determination = weak_alias_determination @additional_properties = additional_properties end |
Instance Attribute Details
#full ⇒ String
The full name of the individual, including all parts.
14 15 16 |
# File 'lib/the_plaid_api/models/individual_screening_hit_names.rb', line 14 def full @full end |
#is_primary ⇒ TrueClass | FalseClass
Primary names are those most commonly used to refer to this person. Only one name will ever be marked as primary.
19 20 21 |
# File 'lib/the_plaid_api/models/individual_screening_hit_names.rb', line 19 def is_primary @is_primary end |
#weak_alias_determination ⇒ WeakAliasDetermination
Names that are explicitly marked as low quality either by their ‘source` list, or by `plaid` by a series of additional checks done by Plaid. Plaid does not ever surface a hit as a result of a weak name alone. If a name has no quality issues, this value will be `none`.
26 27 28 |
# File 'lib/the_plaid_api/models/individual_screening_hit_names.rb', line 26 def weak_alias_determination @weak_alias_determination end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/the_plaid_api/models/individual_screening_hit_names.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. full = hash.key?('full') ? hash['full'] : nil is_primary = hash.key?('is_primary') ? hash['is_primary'] : nil weak_alias_determination = hash.key?('weak_alias_determination') ? hash['weak_alias_determination'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. IndividualScreeningHitNames.new(full: full, is_primary: is_primary, weak_alias_determination: weak_alias_determination, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 |
# File 'lib/the_plaid_api/models/individual_screening_hit_names.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['full'] = 'full' @_hash['is_primary'] = 'is_primary' @_hash['weak_alias_determination'] = 'weak_alias_determination' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/the_plaid_api/models/individual_screening_hit_names.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
38 39 40 |
# File 'lib/the_plaid_api/models/individual_screening_hit_names.rb', line 38 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
90 91 92 93 94 95 |
# File 'lib/the_plaid_api/models/individual_screening_hit_names.rb', line 90 def inspect class_name = self.class.name.split('::').last "<#{class_name} full: #{@full.inspect}, is_primary: #{@is_primary.inspect},"\ " weak_alias_determination: #{@weak_alias_determination.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 87 |
# File 'lib/the_plaid_api/models/individual_screening_hit_names.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} full: #{@full}, is_primary: #{@is_primary}, weak_alias_determination:"\ " #{@weak_alias_determination}, additional_properties: #{@additional_properties}>" end |