Class: ThePlaidApi::IndividualWatchlistCode
- Inherits:
-
Object
- Object
- ThePlaidApi::IndividualWatchlistCode
- Defined in:
- lib/the_plaid_api/models/individual_watchlist_code.rb
Overview
Shorthand identifier for a specific screening list for individuals. ‘AU_CON`: Australia Department of Foreign Affairs and Trade Consolidated List `CA_CON`: Government of Canada Consolidated List of Sanctions `EU_CON`: European External Action Service Consolidated List `IZ_CIA`: CIA List of Chiefs of State and Cabinet Members `IZ_IPL`: Interpol Red Notices for Wanted Persons List `IZ_PEP`: Politically Exposed Persons List `IZ_UNC`: United Nations Consolidated Sanctions `IZ_WBK`: World Bank Listing of Ineligible Firms and Individuals `UK_HMC`: UK HM Treasury Consolidated List `US_DPL`: Bureau of Industry and Security Denied Persons List `US_DTC`: US Department of State AECA Debarred `US_FBI`: US Department of Justice FBI Wanted List `US_FSE`: US OFAC Foreign Sanctions Evaders `US_ISN`: US Department of State Nonproliferation Sanctions `US_PLC`: US OFAC Palestinian Legislative Council `US_SAM`: US System for Award Management Exclusion List `US_SDN`: US OFAC Specially Designated Nationals List `US_SSI`: US OFAC Sectoral Sanctions Identifications `SG_SOF`: Government of Singapore Terrorists and Terrorist Entities `TR_TWL`: Government of Turkey Terrorist Wanted List `TR_DFD`: Government of Turkey Domestic Freezing Decisions `TR_FOR`: Government of Turkey Foreign Freezing Requests `TR_WMD`: Government of Turkey Weapons of Mass Destruction `TR_CMB`: Government of Turkey Capital Markets Board
Constant Summary collapse
- INDIVIDUAL_WATCHLIST_CODE =
[ # TODO: Write general description for AU_CON AU_CON = 'AU_CON'.freeze, # TODO: Write general description for CA_CON CA_CON = 'CA_CON'.freeze, # TODO: Write general description for EU_CON EU_CON = 'EU_CON'.freeze, # TODO: Write general description for IZ_CIA IZ_CIA = 'IZ_CIA'.freeze, # TODO: Write general description for IZ_IPL IZ_IPL = 'IZ_IPL'.freeze, # TODO: Write general description for IZ_PEP IZ_PEP = 'IZ_PEP'.freeze, # TODO: Write general description for IZ_UNC IZ_UNC = 'IZ_UNC'.freeze, # TODO: Write general description for IZ_WBK IZ_WBK = 'IZ_WBK'.freeze, # TODO: Write general description for UK_HMC UK_HMC = 'UK_HMC'.freeze, # TODO: Write general description for US_DPL US_DPL = 'US_DPL'.freeze, # TODO: Write general description for US_DTC US_DTC = 'US_DTC'.freeze, # TODO: Write general description for US_FBI US_FBI = 'US_FBI'.freeze, # TODO: Write general description for US_FSE US_FSE = 'US_FSE'.freeze, # TODO: Write general description for US_ISN US_ISN = 'US_ISN'.freeze, # TODO: Write general description for US_MBS US_MBS = 'US_MBS'.freeze, # TODO: Write general description for US_PLC US_PLC = 'US_PLC'.freeze, # TODO: Write general description for US_SAM US_SAM = 'US_SAM'.freeze, # TODO: Write general description for US_SDN US_SDN = 'US_SDN'.freeze, # TODO: Write general description for US_SSI US_SSI = 'US_SSI'.freeze, # TODO: Write general description for SG_SOF SG_SOF = 'SG_SOF'.freeze, # TODO: Write general description for TR_TWL TR_TWL = 'TR_TWL'.freeze, # TODO: Write general description for TR_DFD TR_DFD = 'TR_DFD'.freeze, # TODO: Write general description for TR_FOR TR_FOR = 'TR_FOR'.freeze, # TODO: Write general description for TR_WMD TR_WMD = 'TR_WMD'.freeze, # TODO: Write general description for TR_CMB TR_CMB = 'TR_CMB'.freeze ].freeze
Class Method Summary collapse
Class Method Details
.from_value(value, default_value = AU_CON) ⇒ Object
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/the_plaid_api/models/individual_watchlist_code.rb', line 111 def self.from_value(value, default_value = AU_CON) return default_value if value.nil? str = value.to_s.strip case str.downcase when 'au_con' then AU_CON when 'ca_con' then CA_CON when 'eu_con' then EU_CON when 'iz_cia' then IZ_CIA when 'iz_ipl' then IZ_IPL when 'iz_pep' then IZ_PEP when 'iz_unc' then IZ_UNC when 'iz_wbk' then IZ_WBK when 'uk_hmc' then UK_HMC when 'us_dpl' then US_DPL when 'us_dtc' then US_DTC when 'us_fbi' then US_FBI when 'us_fse' then US_FSE when 'us_isn' then US_ISN when 'us_mbs' then US_MBS when 'us_plc' then US_PLC when 'us_sam' then US_SAM when 'us_sdn' then US_SDN when 'us_ssi' then US_SSI when 'sg_sof' then SG_SOF when 'tr_twl' then TR_TWL when 'tr_dfd' then TR_DFD when 'tr_for' then TR_FOR when 'tr_wmd' then TR_WMD when 'tr_cmb' then TR_CMB else default_value end end |
.validate(value) ⇒ Object
105 106 107 108 109 |
# File 'lib/the_plaid_api/models/individual_watchlist_code.rb', line 105 def self.validate(value) return false if value.nil? INDIVIDUAL_WATCHLIST_CODE.include?(value) end |