Class: ThePlaidApi::InstitutionsGetByIdRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::InstitutionsGetByIdRequest
- Defined in:
- lib/the_plaid_api/models/institutions_get_by_id_request.rb
Overview
InstitutionsGetByIdRequest defines the request schema for ‘/institutions/get_by_id`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#country_codes ⇒ Array[CountryCode]
Specify which country or countries to include institutions from, using the ISO-3166-1 alpha-2 country code standard.
-
#institution_id ⇒ String
The ID of the institution to get details about.
-
#options ⇒ InstitutionsGetByIdRequestOptions
Specifies optional parameters for ‘/institutions/get_by_id`.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(institution_id:, country_codes:, client_id: SKIP, secret: SKIP, options: SKIP, additional_properties: nil) ⇒ InstitutionsGetByIdRequest
constructor
A new instance of InstitutionsGetByIdRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(institution_id:, country_codes:, client_id: SKIP, secret: SKIP, options: SKIP, additional_properties: nil) ⇒ InstitutionsGetByIdRequest
Returns a new instance of InstitutionsGetByIdRequest.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/the_plaid_api/models/institutions_get_by_id_request.rb', line 65 def initialize(institution_id:, country_codes:, client_id: SKIP, secret: SKIP, options: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @institution_id = institution_id @country_codes = country_codes @options = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/institutions_get_by_id_request.rb', line 17 def client_id @client_id end |
#country_codes ⇒ Array[CountryCode]
Specify which country or countries to include institutions from, using the ISO-3166-1 alpha-2 country code standard. In API versions 2019-05-29 and earlier, the ‘country_codes` parameter is an optional parameter within the `options` object and will default to `[US]` if it is not supplied.
33 34 35 |
# File 'lib/the_plaid_api/models/institutions_get_by_id_request.rb', line 33 def country_codes @country_codes end |
#institution_id ⇒ String
The ID of the institution to get details about
26 27 28 |
# File 'lib/the_plaid_api/models/institutions_get_by_id_request.rb', line 26 def institution_id @institution_id end |
#options ⇒ InstitutionsGetByIdRequestOptions
Specifies optional parameters for ‘/institutions/get_by_id`. If provided, must not be `null`.
38 39 40 |
# File 'lib/the_plaid_api/models/institutions_get_by_id_request.rb', line 38 def @options end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/the_plaid_api/models/institutions_get_by_id_request.rb', line 22 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/the_plaid_api/models/institutions_get_by_id_request.rb', line 79 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. institution_id = hash.key?('institution_id') ? hash['institution_id'] : nil country_codes = hash.key?('country_codes') ? hash['country_codes'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP = InstitutionsGetByIdRequestOptions.from_hash(hash['options']) if hash['options'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InstitutionsGetByIdRequest.new(institution_id: institution_id, country_codes: country_codes, client_id: client_id, secret: secret, options: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
41 42 43 44 45 46 47 48 49 |
# File 'lib/the_plaid_api/models/institutions_get_by_id_request.rb', line 41 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['institution_id'] = 'institution_id' @_hash['country_codes'] = 'country_codes' @_hash['options'] = 'options' @_hash end |
.nullables ⇒ Object
An array for nullable fields
61 62 63 |
# File 'lib/the_plaid_api/models/institutions_get_by_id_request.rb', line 61 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
52 53 54 55 56 57 58 |
# File 'lib/the_plaid_api/models/institutions_get_by_id_request.rb', line 52 def self.optionals %w[ client_id secret options ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
115 116 117 118 119 120 |
# File 'lib/the_plaid_api/models/institutions_get_by_id_request.rb', line 115 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\ " institution_id: #{@institution_id.inspect}, country_codes: #{@country_codes.inspect},"\ " options: #{@options.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
107 108 109 110 111 112 |
# File 'lib/the_plaid_api/models/institutions_get_by_id_request.rb', line 107 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, institution_id:"\ " #{@institution_id}, country_codes: #{@country_codes}, options: #{@options},"\ " additional_properties: #{@additional_properties}>" end |