Class: ThePlaidApi::InstitutionsGetByIdRequestOptions
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::InstitutionsGetByIdRequestOptions
- Defined in:
- lib/the_plaid_api/models/institutions_get_by_id_request_options.rb
Overview
Specifies optional parameters for ‘/institutions/get_by_id`. If provided, must not be `null`.
Instance Attribute Summary collapse
-
#include_auth_metadata ⇒ TrueClass | FalseClass
When ‘true`, returns metadata related to the Auth product indicating which auth methods are supported.
-
#include_optional_metadata ⇒ TrueClass | FalseClass
When ‘true`, return an institution’s logo, brand color, and URL.
-
#include_payment_initiation_metadata ⇒ TrueClass | FalseClass
When ‘true`, returns metadata related to the Payment Initiation product indicating which payment configurations are supported.
-
#include_status ⇒ TrueClass | FalseClass
If ‘true`, the response will include status information about the institution.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(include_optional_metadata: false, include_status: false, include_auth_metadata: false, include_payment_initiation_metadata: false, additional_properties: nil) ⇒ InstitutionsGetByIdRequestOptions
constructor
A new instance of InstitutionsGetByIdRequestOptions.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(include_optional_metadata: false, include_status: false, include_auth_metadata: false, include_payment_initiation_metadata: false, additional_properties: nil) ⇒ InstitutionsGetByIdRequestOptions
Returns a new instance of InstitutionsGetByIdRequestOptions.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/the_plaid_api/models/institutions_get_by_id_request_options.rb', line 66 def initialize(include_optional_metadata: false, include_status: false, include_auth_metadata: false, include_payment_initiation_metadata: false, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? unless == SKIP @include_optional_metadata = end @include_status = include_status unless include_status == SKIP @include_auth_metadata = unless == SKIP unless == SKIP @include_payment_initiation_metadata = end @additional_properties = additional_properties end |
Instance Attribute Details
#include_auth_metadata ⇒ TrueClass | FalseClass
When ‘true`, returns metadata related to the Auth product indicating which auth methods are supported.
33 34 35 |
# File 'lib/the_plaid_api/models/institutions_get_by_id_request_options.rb', line 33 def @include_auth_metadata end |
#include_optional_metadata ⇒ TrueClass | FalseClass
When ‘true`, return an institution’s logo, brand color, and URL. When available, the bank’s logo is returned as a base64 encoded 152x152 PNG, the brand color is in hexadecimal format. The default value is ‘false`. Note that Plaid does not own any of the logos shared by the API and that by accessing or using these logos, you agree that you are doing so at your own risk and will, if necessary, obtain all required permissions from the appropriate rights holders and adhere to any applicable usage guidelines. Plaid disclaims all express or implied warranties with respect to the logos.
23 24 25 |
# File 'lib/the_plaid_api/models/institutions_get_by_id_request_options.rb', line 23 def @include_optional_metadata end |
#include_payment_initiation_metadata ⇒ TrueClass | FalseClass
When ‘true`, returns metadata related to the Payment Initiation product indicating which payment configurations are supported.
38 39 40 |
# File 'lib/the_plaid_api/models/institutions_get_by_id_request_options.rb', line 38 def @include_payment_initiation_metadata end |
#include_status ⇒ TrueClass | FalseClass
If ‘true`, the response will include status information about the institution. Default value is `false`.
28 29 30 |
# File 'lib/the_plaid_api/models/institutions_get_by_id_request_options.rb', line 28 def include_status @include_status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/the_plaid_api/models/institutions_get_by_id_request_options.rb', line 87 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. = hash['include_optional_metadata'] ||= false include_status = hash['include_status'] ||= false = hash['include_auth_metadata'] ||= false = hash['include_payment_initiation_metadata'] ||= false # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InstitutionsGetByIdRequestOptions.new(include_optional_metadata: , include_status: include_status, include_auth_metadata: , include_payment_initiation_metadata: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
41 42 43 44 45 46 47 48 49 |
# File 'lib/the_plaid_api/models/institutions_get_by_id_request_options.rb', line 41 def self.names @_hash = {} if @_hash.nil? @_hash['include_optional_metadata'] = 'include_optional_metadata' @_hash['include_status'] = 'include_status' @_hash['include_auth_metadata'] = 'include_auth_metadata' @_hash['include_payment_initiation_metadata'] = 'include_payment_initiation_metadata' @_hash end |
.nullables ⇒ Object
An array for nullable fields
62 63 64 |
# File 'lib/the_plaid_api/models/institutions_get_by_id_request_options.rb', line 62 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
52 53 54 55 56 57 58 59 |
# File 'lib/the_plaid_api/models/institutions_get_by_id_request_options.rb', line 52 def self.optionals %w[ include_optional_metadata include_status include_auth_metadata include_payment_initiation_metadata ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
122 123 124 125 126 127 128 129 |
# File 'lib/the_plaid_api/models/institutions_get_by_id_request_options.rb', line 122 def inspect class_name = self.class.name.split('::').last "<#{class_name} include_optional_metadata: #{@include_optional_metadata.inspect},"\ " include_status: #{@include_status.inspect}, include_auth_metadata:"\ " #{@include_auth_metadata.inspect}, include_payment_initiation_metadata:"\ " #{@include_payment_initiation_metadata.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
113 114 115 116 117 118 119 |
# File 'lib/the_plaid_api/models/institutions_get_by_id_request_options.rb', line 113 def to_s class_name = self.class.name.split('::').last "<#{class_name} include_optional_metadata: #{@include_optional_metadata}, include_status:"\ " #{@include_status}, include_auth_metadata: #{@include_auth_metadata},"\ " include_payment_initiation_metadata: #{@include_payment_initiation_metadata},"\ " additional_properties: #{@additional_properties}>" end |