Class: ThePlaidApi::InstitutionsGetResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::InstitutionsGetResponse
- Defined in:
- lib/the_plaid_api/models/institutions_get_response.rb
Overview
InstitutionsGetResponse defines the response schema for ‘/institutions/get`
Instance Attribute Summary collapse
-
#institutions ⇒ Array[Institution]
A list of Plaid institutions.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
-
#total ⇒ Integer
The total number of institutions available via this endpoint.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(institutions:, total:, request_id:, additional_properties: nil) ⇒ InstitutionsGetResponse
constructor
A new instance of InstitutionsGetResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(institutions:, total:, request_id:, additional_properties: nil) ⇒ InstitutionsGetResponse
Returns a new instance of InstitutionsGetResponse.
45 46 47 48 49 50 51 52 53 54 |
# File 'lib/the_plaid_api/models/institutions_get_response.rb', line 45 def initialize(institutions:, total:, request_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @institutions = institutions @total = total @request_id = request_id @additional_properties = additional_properties end |
Instance Attribute Details
#institutions ⇒ Array[Institution]
A list of Plaid institutions
14 15 16 |
# File 'lib/the_plaid_api/models/institutions_get_response.rb', line 14 def institutions @institutions end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
24 25 26 |
# File 'lib/the_plaid_api/models/institutions_get_response.rb', line 24 def request_id @request_id end |
#total ⇒ Integer
The total number of institutions available via this endpoint
18 19 20 |
# File 'lib/the_plaid_api/models/institutions_get_response.rb', line 18 def total @total end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/the_plaid_api/models/institutions_get_response.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it institutions = nil unless hash['institutions'].nil? institutions = [] hash['institutions'].each do |structure| institutions << (Institution.from_hash(structure) if structure) end end institutions = nil unless hash.key?('institutions') total = hash.key?('total') ? hash['total'] : nil request_id = hash.key?('request_id') ? hash['request_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InstitutionsGetResponse.new(institutions: institutions, total: total, request_id: request_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
27 28 29 30 31 32 33 |
# File 'lib/the_plaid_api/models/institutions_get_response.rb', line 27 def self.names @_hash = {} if @_hash.nil? @_hash['institutions'] = 'institutions' @_hash['total'] = 'total' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/the_plaid_api/models/institutions_get_response.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
36 37 38 |
# File 'lib/the_plaid_api/models/institutions_get_response.rb', line 36 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
96 97 98 99 100 |
# File 'lib/the_plaid_api/models/institutions_get_response.rb', line 96 def inspect class_name = self.class.name.split('::').last "<#{class_name} institutions: #{@institutions.inspect}, total: #{@total.inspect},"\ " request_id: #{@request_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
89 90 91 92 93 |
# File 'lib/the_plaid_api/models/institutions_get_response.rb', line 89 def to_s class_name = self.class.name.split('::').last "<#{class_name} institutions: #{@institutions}, total: #{@total}, request_id:"\ " #{@request_id}, additional_properties: #{@additional_properties}>" end |