Class: ThePlaidApi::InstitutionsSearchAccountFilter
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::InstitutionsSearchAccountFilter
- Defined in:
- lib/the_plaid_api/models/institutions_search_account_filter.rb
Overview
An account filter to apply to institutions search requests
Instance Attribute Summary collapse
-
#credit ⇒ Array[AccountSubtype]
TODO: Write general description for this method.
-
#depository ⇒ Array[AccountSubtype]
TODO: Write general description for this method.
-
#investment ⇒ Array[AccountSubtype]
TODO: Write general description for this method.
-
#loan ⇒ Array[AccountSubtype]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(loan: SKIP, depository: SKIP, credit: SKIP, investment: SKIP, additional_properties: nil) ⇒ InstitutionsSearchAccountFilter
constructor
A new instance of InstitutionsSearchAccountFilter.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(loan: SKIP, depository: SKIP, credit: SKIP, investment: SKIP, additional_properties: nil) ⇒ InstitutionsSearchAccountFilter
Returns a new instance of InstitutionsSearchAccountFilter.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/the_plaid_api/models/institutions_search_account_filter.rb', line 53 def initialize(loan: SKIP, depository: SKIP, credit: SKIP, investment: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @loan = loan unless loan == SKIP @depository = depository unless depository == SKIP @credit = credit unless credit == SKIP @investment = investment unless investment == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#credit ⇒ Array[AccountSubtype]
TODO: Write general description for this method
22 23 24 |
# File 'lib/the_plaid_api/models/institutions_search_account_filter.rb', line 22 def credit @credit end |
#depository ⇒ Array[AccountSubtype]
TODO: Write general description for this method
18 19 20 |
# File 'lib/the_plaid_api/models/institutions_search_account_filter.rb', line 18 def depository @depository end |
#investment ⇒ Array[AccountSubtype]
TODO: Write general description for this method
26 27 28 |
# File 'lib/the_plaid_api/models/institutions_search_account_filter.rb', line 26 def investment @investment end |
#loan ⇒ Array[AccountSubtype]
TODO: Write general description for this method
14 15 16 |
# File 'lib/the_plaid_api/models/institutions_search_account_filter.rb', line 14 def loan @loan end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/the_plaid_api/models/institutions_search_account_filter.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. loan = hash.key?('loan') ? hash['loan'] : SKIP depository = hash.key?('depository') ? hash['depository'] : SKIP credit = hash.key?('credit') ? hash['credit'] : SKIP investment = hash.key?('investment') ? hash['investment'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InstitutionsSearchAccountFilter.new(loan: loan, depository: depository, credit: credit, investment: investment, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/the_plaid_api/models/institutions_search_account_filter.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['loan'] = 'loan' @_hash['depository'] = 'depository' @_hash['credit'] = 'credit' @_hash['investment'] = 'investment' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/the_plaid_api/models/institutions_search_account_filter.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/the_plaid_api/models/institutions_search_account_filter.rb', line 39 def self.optionals %w[ loan depository credit investment ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 103 |
# File 'lib/the_plaid_api/models/institutions_search_account_filter.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} loan: #{@loan.inspect}, depository: #{@depository.inspect}, credit:"\ " #{@credit.inspect}, investment: #{@investment.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 95 |
# File 'lib/the_plaid_api/models/institutions_search_account_filter.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} loan: #{@loan}, depository: #{@depository}, credit: #{@credit}, investment:"\ " #{@investment}, additional_properties: #{@additional_properties}>" end |