Class: ThePlaidApi::InstitutionsSearchRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::InstitutionsSearchRequest
- Defined in:
- lib/the_plaid_api/models/institutions_search_request.rb
Overview
InstitutionsSearchRequest defines the request schema for ‘/institutions/search`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#country_codes ⇒ Array[CountryCode]
Specify which country or countries to include institutions from, using the ISO-3166-1 alpha-2 country code standard.
-
#options ⇒ InstitutionsSearchRequestOptions
An optional object to filter ‘/institutions/search` results.
-
#products ⇒ Array[Products]
Filter the Institutions based on whether they support all products listed in ‘products`.
-
#query ⇒ String
The search query.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(query:, country_codes:, client_id: SKIP, secret: SKIP, products: SKIP, options: SKIP, additional_properties: nil) ⇒ InstitutionsSearchRequest
constructor
A new instance of InstitutionsSearchRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(query:, country_codes:, client_id: SKIP, secret: SKIP, products: SKIP, options: SKIP, additional_properties: nil) ⇒ InstitutionsSearchRequest
Returns a new instance of InstitutionsSearchRequest.
78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/the_plaid_api/models/institutions_search_request.rb', line 78 def initialize(query:, country_codes:, client_id: SKIP, secret: SKIP, products: SKIP, options: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @query = query @products = products unless products == SKIP @country_codes = country_codes @options = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/institutions_search_request.rb', line 17 def client_id @client_id end |
#country_codes ⇒ Array[CountryCode]
Specify which country or countries to include institutions from, using the ISO-3166-1 alpha-2 country code standard. In API versions 2019-05-29 and earlier, the ‘country_codes` parameter is an optional parameter within the `options` object and will default to `[US]` if it is not supplied.
43 44 45 |
# File 'lib/the_plaid_api/models/institutions_search_request.rb', line 43 def country_codes @country_codes end |
#options ⇒ InstitutionsSearchRequestOptions
An optional object to filter ‘/institutions/search` results.
47 48 49 |
# File 'lib/the_plaid_api/models/institutions_search_request.rb', line 47 def @options end |
#products ⇒ Array[Products]
Filter the Institutions based on whether they support all products listed in ‘products`. Provide `null` to get institutions regardless of supported products. Note that when `auth` is specified as a product, if you are enabled for Instant Match or Automated Micro-deposits, institutions that support those products will be returned even if `auth` is not present in their product array. To search for Transfer support, use `auth`; to search for Signal Transaction Scores support, use `balance`.
36 37 38 |
# File 'lib/the_plaid_api/models/institutions_search_request.rb', line 36 def products @products end |
#query ⇒ String
The search query. Institutions with names matching the query are returned
26 27 28 |
# File 'lib/the_plaid_api/models/institutions_search_request.rb', line 26 def query @query end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/the_plaid_api/models/institutions_search_request.rb', line 22 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/the_plaid_api/models/institutions_search_request.rb', line 93 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. query = hash.key?('query') ? hash['query'] : nil country_codes = hash.key?('country_codes') ? hash['country_codes'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP products = hash.key?('products') ? hash['products'] : SKIP = InstitutionsSearchRequestOptions.from_hash(hash['options']) if hash['options'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InstitutionsSearchRequest.new(query: query, country_codes: country_codes, client_id: client_id, secret: secret, products: products, options: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
50 51 52 53 54 55 56 57 58 59 |
# File 'lib/the_plaid_api/models/institutions_search_request.rb', line 50 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['query'] = 'query' @_hash['products'] = 'products' @_hash['country_codes'] = 'country_codes' @_hash['options'] = 'options' @_hash end |
.nullables ⇒ Object
An array for nullable fields
72 73 74 75 76 |
# File 'lib/the_plaid_api/models/institutions_search_request.rb', line 72 def self.nullables %w[ products ] end |
.optionals ⇒ Object
An array for optional fields
62 63 64 65 66 67 68 69 |
# File 'lib/the_plaid_api/models/institutions_search_request.rb', line 62 def self.optionals %w[ client_id secret products options ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
130 131 132 133 134 135 136 |
# File 'lib/the_plaid_api/models/institutions_search_request.rb', line 130 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, query:"\ " #{@query.inspect}, products: #{@products.inspect}, country_codes:"\ " #{@country_codes.inspect}, options: #{@options.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
122 123 124 125 126 127 |
# File 'lib/the_plaid_api/models/institutions_search_request.rb', line 122 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, query: #{@query}, products:"\ " #{@products}, country_codes: #{@country_codes}, options: #{@options},"\ " additional_properties: #{@additional_properties}>" end |