Class: ThePlaidApi::InvestmentAccountSubtype1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::InvestmentAccountSubtype1
- Defined in:
- lib/the_plaid_api/models/investment_account_subtype1.rb
Overview
An investment account. In API versions 2018-05-22 and earlier, this type is called ‘brokerage`.
Instance Attribute Summary collapse
-
#brokerage ⇒ String
Standard brokerage account.
-
#cash_isa ⇒ String
Individual Savings Account (ISA) that pays interest tax-free (UK).
-
#crypto_exchange ⇒ String
Standard cryptocurrency exchange account.
-
#education_savings_account ⇒ String
Tax-advantaged Coverdell Education Savings Account (ESA) (US).
-
#fhsa ⇒ String
First Home Savings Account (FHSA) (Canada).
-
#fixed_annuity ⇒ String
Fixed annuity.
-
#gic ⇒ String
Guaranteed Investment Certificate (Canada).
-
#health_reimbursement_arrangement ⇒ String
Tax-advantaged Health Reimbursement Arrangement (HRA) benefit plan (US).
-
#hsa ⇒ String
Non-cash tax-advantaged medical Health Savings Account (HSA) (US).
-
#ira ⇒ String
Traditional Individual Retirement Account (IRA) (US).
-
#isa ⇒ String
Non-cash Individual Savings Account (ISA) (UK).
-
#keogh ⇒ String
Keogh self-employed retirement plan (US).
-
#lif ⇒ String
Life Income Fund (LIF) retirement account (Canada).
-
#life_insurance ⇒ String
Life insurance account.
-
#line_of_credit ⇒ String
Pre-approved line of credit.
-
#lira ⇒ String
Locked-in Retirement Account (LIRA) (Canada).
-
#lrif ⇒ String
Locked-in Retirement Income Fund (LRIF) (Canada).
-
#lrsp ⇒ String
Locked-in Retirement Savings Plan (Canada).
-
#m401a ⇒ String
Employer-sponsored money-purchase 401(a) retirement plan (US).
-
#m401k ⇒ String
Standard 401(k) retirement account (US).
-
#m403_b ⇒ String
403(b) retirement savings account for non-profits and schools (US).
-
#m457b ⇒ String
Tax-advantaged deferred-compensation 457(b) retirement plan for governments and non-profits (US).
-
#mutual_fund ⇒ String
Mutual fund account.
-
#non_custodial_wallet ⇒ String
A cryptocurrency wallet where the user controls the private key.
-
#non_taxable_brokerage_account ⇒ String
A non-taxable brokerage account that is not covered by a more specific subtype.
-
#other ⇒ String
An account whose type could not be determined.
-
#other_annuity ⇒ String
An annuity account not covered by other subtypes.
-
#other_insurance ⇒ String
An insurance account not covered by other subtypes.
-
#pension ⇒ String
Standard pension account.
-
#prif ⇒ String
Prescribed Registered Retirement Income Fund (Canada).
-
#profit_sharing_plan ⇒ String
Plan that gives employees share of company profits.
-
#qshr ⇒ String
Qualifying share account.
-
#rdsp ⇒ String
Registered Disability Savings Plan (RSDP) (Canada).
-
#resp ⇒ String
Registered Education Savings Plan (Canada).
-
#retirement ⇒ String
Retirement account not covered by other subtypes.
-
#rlif ⇒ String
Restricted Life Income Fund (RLIF) (Canada).
-
#roth ⇒ String
Roth IRA (US).
-
#roth_401k ⇒ String
Employer-sponsored Roth 401(k) plan (US).
-
#roth_403_b ⇒ String
Roth 403(b) retirement savings account for non-profits and schools (US).
-
#roth_457b ⇒ String
Roth 457(b) deferred-compensation retirement plan for governments and non-profits (US).
-
#roth_pension ⇒ String
Roth version of a standard pension account.
-
#roth_profit_sharing_plan ⇒ String
Roth version of a profit sharing plan.
-
#roth_thrift_savings_plan ⇒ String
Roth version of the Thrift Savings Plan (US).
-
#rrif ⇒ String
Registered Retirement Income Fund (RRIF) (Canada).
-
#rrsp ⇒ String
Registered Retirement Savings Plan (Canadian, similar to US 401(k)).
-
#sarsep ⇒ String
Salary Reduction Simplified Employee Pension Plan (SARSEP), discontinued retirement plan (US).
-
#sep_ira ⇒ String
Simplified Employee Pension IRA (SEP IRA), retirement plan for small businesses and self-employed (US).
-
#simple_ira ⇒ String
Savings Incentive Match Plan for Employees IRA, retirement plan for small businesses (US).
-
#sipp ⇒ String
Self-Invested Personal Pension (SIPP) (UK).
-
#stock_plan ⇒ String
Standard stock plan account.
-
#tfsa ⇒ String
Tax-Free Savings Account (TFSA), a retirement plan similar to a Roth IRA (Canada).
-
#thrift_savings_plan ⇒ String
Thrift Savings Plan, a retirement savings and investment plan for Federal employees and members of the uniformed services.
-
#trust ⇒ String
Account representing funds or assets held by a trustee for the benefit of a beneficiary.
-
#ugma ⇒ String
‘Uniform Gift to Minors Act’ (brokerage account for minors, US).
-
#utma ⇒ String
‘Uniform Transfers to Minors Act’ (brokerage account for minors, US).
-
#variable_annuity ⇒ String
Tax-deferred capital accumulation annuity contract.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(m401a:, m401k:, m403_b:, m457b:, brokerage:, cash_isa:, crypto_exchange:, education_savings_account:, fhsa:, fixed_annuity:, gic:, health_reimbursement_arrangement:, hsa:, ira:, isa:, keogh:, lif:, life_insurance:, line_of_credit:, lira:, lrif:, lrsp:, mutual_fund:, non_custodial_wallet:, non_taxable_brokerage_account:, other:, other_annuity:, other_insurance:, pension:, prif:, profit_sharing_plan:, qshr:, rdsp:, resp:, retirement:, rlif:, roth:, roth_401k:, roth_403_b:, roth_457b:, roth_pension:, roth_profit_sharing_plan:, roth_thrift_savings_plan:, rrif:, rrsp:, sarsep:, sep_ira:, simple_ira:, sipp:, stock_plan:, tfsa:, thrift_savings_plan:, trust:, ugma:, utma:, variable_annuity:, additional_properties: nil) ⇒ InvestmentAccountSubtype1
constructor
A new instance of InvestmentAccountSubtype1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(m401a:, m401k:, m403_b:, m457b:, brokerage:, cash_isa:, crypto_exchange:, education_savings_account:, fhsa:, fixed_annuity:, gic:, health_reimbursement_arrangement:, hsa:, ira:, isa:, keogh:, lif:, life_insurance:, line_of_credit:, lira:, lrif:, lrsp:, mutual_fund:, non_custodial_wallet:, non_taxable_brokerage_account:, other:, other_annuity:, other_insurance:, pension:, prif:, profit_sharing_plan:, qshr:, rdsp:, resp:, retirement:, rlif:, roth:, roth_401k:, roth_403_b:, roth_457b:, roth_pension:, roth_profit_sharing_plan:, roth_thrift_savings_plan:, rrif:, rrsp:, sarsep:, sep_ira:, simple_ira:, sipp:, stock_plan:, tfsa:, thrift_savings_plan:, trust:, ugma:, utma:, variable_annuity:, additional_properties: nil) ⇒ InvestmentAccountSubtype1
Returns a new instance of InvestmentAccountSubtype1.
320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 320 def initialize(m401a:, m401k:, m403_b:, m457b:, brokerage:, cash_isa:, crypto_exchange:, education_savings_account:, fhsa:, fixed_annuity:, gic:, health_reimbursement_arrangement:, hsa:, ira:, isa:, keogh:, lif:, life_insurance:, line_of_credit:, lira:, lrif:, lrsp:, mutual_fund:, non_custodial_wallet:, non_taxable_brokerage_account:, other:, other_annuity:, other_insurance:, pension:, prif:, profit_sharing_plan:, qshr:, rdsp:, resp:, retirement:, rlif:, roth:, roth_401k:, roth_403_b:, roth_457b:, roth_pension:, roth_profit_sharing_plan:, roth_thrift_savings_plan:, rrif:, rrsp:, sarsep:, sep_ira:, simple_ira:, sipp:, stock_plan:, tfsa:, thrift_savings_plan:, trust:, ugma:, utma:, variable_annuity:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @m401a = m401a @m401k = m401k @m403_b = m403_b @m457b = m457b @brokerage = brokerage @cash_isa = cash_isa @crypto_exchange = crypto_exchange @education_savings_account = education_savings_account @fhsa = fhsa @fixed_annuity = fixed_annuity @gic = gic @health_reimbursement_arrangement = health_reimbursement_arrangement @hsa = hsa @ira = ira @isa = isa @keogh = keogh @lif = lif @life_insurance = life_insurance @line_of_credit = line_of_credit @lira = lira @lrif = lrif @lrsp = lrsp @mutual_fund = mutual_fund @non_custodial_wallet = non_custodial_wallet @non_taxable_brokerage_account = non_taxable_brokerage_account @other = other @other_annuity = other_annuity @other_insurance = other_insurance @pension = pension @prif = prif @profit_sharing_plan = profit_sharing_plan @qshr = qshr @rdsp = rdsp @resp = resp @retirement = retirement @rlif = rlif @roth = roth @roth_401k = roth_401k @roth_403_b = roth_403_b @roth_457b = roth_457b @roth_pension = roth_pension @roth_profit_sharing_plan = roth_profit_sharing_plan @roth_thrift_savings_plan = roth_thrift_savings_plan @rrif = rrif @rrsp = rrsp @sarsep = sarsep @sep_ira = sep_ira @simple_ira = simple_ira @sipp = sipp @stock_plan = stock_plan @tfsa = tfsa @thrift_savings_plan = thrift_savings_plan @trust = trust @ugma = ugma @utma = utma @variable_annuity = variable_annuity @additional_properties = additional_properties end |
Instance Attribute Details
#brokerage ⇒ String
Standard brokerage account
32 33 34 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 32 def brokerage @brokerage end |
#cash_isa ⇒ String
Individual Savings Account (ISA) that pays interest tax-free (UK)
36 37 38 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 36 def cash_isa @cash_isa end |
#crypto_exchange ⇒ String
Standard cryptocurrency exchange account
40 41 42 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 40 def crypto_exchange @crypto_exchange end |
#education_savings_account ⇒ String
Tax-advantaged Coverdell Education Savings Account (ESA) (US)
44 45 46 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 44 def education_savings_account @education_savings_account end |
#fhsa ⇒ String
First Home Savings Account (FHSA) (Canada)
48 49 50 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 48 def fhsa @fhsa end |
#fixed_annuity ⇒ String
Fixed annuity
52 53 54 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 52 def fixed_annuity @fixed_annuity end |
#gic ⇒ String
Guaranteed Investment Certificate (Canada)
56 57 58 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 56 def gic @gic end |
#health_reimbursement_arrangement ⇒ String
Tax-advantaged Health Reimbursement Arrangement (HRA) benefit plan (US)
60 61 62 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 60 def health_reimbursement_arrangement @health_reimbursement_arrangement end |
#hsa ⇒ String
Non-cash tax-advantaged medical Health Savings Account (HSA) (US)
64 65 66 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 64 def hsa @hsa end |
#ira ⇒ String
Traditional Individual Retirement Account (IRA) (US)
68 69 70 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 68 def ira @ira end |
#isa ⇒ String
Non-cash Individual Savings Account (ISA) (UK)
72 73 74 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 72 def isa @isa end |
#keogh ⇒ String
Keogh self-employed retirement plan (US)
76 77 78 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 76 def keogh @keogh end |
#lif ⇒ String
Life Income Fund (LIF) retirement account (Canada)
80 81 82 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 80 def lif @lif end |
#life_insurance ⇒ String
Life insurance account
84 85 86 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 84 def life_insurance @life_insurance end |
#line_of_credit ⇒ String
Pre-approved line of credit
88 89 90 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 88 def line_of_credit @line_of_credit end |
#lira ⇒ String
Locked-in Retirement Account (LIRA) (Canada)
92 93 94 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 92 def lira @lira end |
#lrif ⇒ String
Locked-in Retirement Income Fund (LRIF) (Canada)
96 97 98 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 96 def lrif @lrif end |
#lrsp ⇒ String
Locked-in Retirement Savings Plan (Canada)
100 101 102 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 100 def lrsp @lrsp end |
#m401a ⇒ String
Employer-sponsored money-purchase 401(a) retirement plan (US)
15 16 17 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 15 def m401a @m401a end |
#m401k ⇒ String
Standard 401(k) retirement account (US)
19 20 21 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 19 def m401k @m401k end |
#m403_b ⇒ String
403(b) retirement savings account for non-profits and schools (US)
23 24 25 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 23 def m403_b @m403_b end |
#m457b ⇒ String
Tax-advantaged deferred-compensation 457(b) retirement plan for governments and non-profits (US)
28 29 30 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 28 def m457b @m457b end |
#mutual_fund ⇒ String
Mutual fund account
104 105 106 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 104 def mutual_fund @mutual_fund end |
#non_custodial_wallet ⇒ String
A cryptocurrency wallet where the user controls the private key
108 109 110 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 108 def non_custodial_wallet @non_custodial_wallet end |
#non_taxable_brokerage_account ⇒ String
A non-taxable brokerage account that is not covered by a more specific subtype
113 114 115 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 113 def non_taxable_brokerage_account @non_taxable_brokerage_account end |
#other ⇒ String
An account whose type could not be determined
117 118 119 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 117 def other @other end |
#other_annuity ⇒ String
An annuity account not covered by other subtypes
121 122 123 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 121 def other_annuity @other_annuity end |
#other_insurance ⇒ String
An insurance account not covered by other subtypes
125 126 127 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 125 def other_insurance @other_insurance end |
#pension ⇒ String
Standard pension account
129 130 131 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 129 def pension @pension end |
#prif ⇒ String
Prescribed Registered Retirement Income Fund (Canada)
133 134 135 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 133 def prif @prif end |
#profit_sharing_plan ⇒ String
Plan that gives employees share of company profits
137 138 139 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 137 def profit_sharing_plan @profit_sharing_plan end |
#qshr ⇒ String
Qualifying share account
141 142 143 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 141 def qshr @qshr end |
#rdsp ⇒ String
Registered Disability Savings Plan (RSDP) (Canada)
145 146 147 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 145 def rdsp @rdsp end |
#resp ⇒ String
Registered Education Savings Plan (Canada)
149 150 151 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 149 def resp @resp end |
#retirement ⇒ String
Retirement account not covered by other subtypes
153 154 155 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 153 def retirement @retirement end |
#rlif ⇒ String
Restricted Life Income Fund (RLIF) (Canada)
157 158 159 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 157 def rlif @rlif end |
#roth ⇒ String
Roth IRA (US)
161 162 163 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 161 def roth @roth end |
#roth_401k ⇒ String
Employer-sponsored Roth 401(k) plan (US)
165 166 167 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 165 def roth_401k @roth_401k end |
#roth_403_b ⇒ String
Roth 403(b) retirement savings account for non-profits and schools (US)
169 170 171 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 169 def roth_403_b @roth_403_b end |
#roth_457b ⇒ String
Roth 457(b) deferred-compensation retirement plan for governments and non-profits (US)
174 175 176 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 174 def roth_457b @roth_457b end |
#roth_pension ⇒ String
Roth version of a standard pension account
178 179 180 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 178 def roth_pension @roth_pension end |
#roth_profit_sharing_plan ⇒ String
Roth version of a profit sharing plan
182 183 184 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 182 def roth_profit_sharing_plan @roth_profit_sharing_plan end |
#roth_thrift_savings_plan ⇒ String
Roth version of the Thrift Savings Plan (US)
186 187 188 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 186 def roth_thrift_savings_plan @roth_thrift_savings_plan end |
#rrif ⇒ String
Registered Retirement Income Fund (RRIF) (Canada)
190 191 192 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 190 def rrif @rrif end |
#rrsp ⇒ String
Registered Retirement Savings Plan (Canadian, similar to US 401(k))
194 195 196 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 194 def rrsp @rrsp end |
#sarsep ⇒ String
Salary Reduction Simplified Employee Pension Plan (SARSEP), discontinued retirement plan (US)
199 200 201 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 199 def sarsep @sarsep end |
#sep_ira ⇒ String
Simplified Employee Pension IRA (SEP IRA), retirement plan for small businesses and self-employed (US)
204 205 206 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 204 def sep_ira @sep_ira end |
#simple_ira ⇒ String
Savings Incentive Match Plan for Employees IRA, retirement plan for small businesses (US)
209 210 211 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 209 def simple_ira @simple_ira end |
#sipp ⇒ String
Self-Invested Personal Pension (SIPP) (UK)
213 214 215 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 213 def sipp @sipp end |
#stock_plan ⇒ String
Standard stock plan account
217 218 219 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 217 def stock_plan @stock_plan end |
#tfsa ⇒ String
Tax-Free Savings Account (TFSA), a retirement plan similar to a Roth IRA (Canada)
222 223 224 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 222 def tfsa @tfsa end |
#thrift_savings_plan ⇒ String
Thrift Savings Plan, a retirement savings and investment plan for Federal employees and members of the uniformed services.
227 228 229 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 227 def thrift_savings_plan @thrift_savings_plan end |
#trust ⇒ String
Account representing funds or assets held by a trustee for the benefit of a beneficiary. Includes both revocable and irrevocable trusts.
232 233 234 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 232 def trust @trust end |
#ugma ⇒ String
‘Uniform Gift to Minors Act’ (brokerage account for minors, US)
236 237 238 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 236 def ugma @ugma end |
#utma ⇒ String
‘Uniform Transfers to Minors Act’ (brokerage account for minors, US)
240 241 242 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 240 def utma @utma end |
#variable_annuity ⇒ String
Tax-deferred capital accumulation annuity contract
244 245 246 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 244 def variable_annuity @variable_annuity end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 397 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. m401a = hash.key?('401a') ? hash['401a'] : nil m401k = hash.key?('401k') ? hash['401k'] : nil m403_b = hash.key?('403B') ? hash['403B'] : nil m457b = hash.key?('457b') ? hash['457b'] : nil brokerage = hash.key?('brokerage') ? hash['brokerage'] : nil cash_isa = hash.key?('cash isa') ? hash['cash isa'] : nil crypto_exchange = hash.key?('crypto exchange') ? hash['crypto exchange'] : nil education_savings_account = hash.key?('education savings account') ? hash['education savings account'] : nil fhsa = hash.key?('fhsa') ? hash['fhsa'] : nil fixed_annuity = hash.key?('fixed annuity') ? hash['fixed annuity'] : nil gic = hash.key?('gic') ? hash['gic'] : nil health_reimbursement_arrangement = hash.key?('health reimbursement arrangement') ? hash['health reimbursement arrangement'] : nil hsa = hash.key?('hsa') ? hash['hsa'] : nil ira = hash.key?('ira') ? hash['ira'] : nil isa = hash.key?('isa') ? hash['isa'] : nil keogh = hash.key?('keogh') ? hash['keogh'] : nil lif = hash.key?('lif') ? hash['lif'] : nil life_insurance = hash.key?('life insurance') ? hash['life insurance'] : nil line_of_credit = hash.key?('line of credit') ? hash['line of credit'] : nil lira = hash.key?('lira') ? hash['lira'] : nil lrif = hash.key?('lrif') ? hash['lrif'] : nil lrsp = hash.key?('lrsp') ? hash['lrsp'] : nil mutual_fund = hash.key?('mutual fund') ? hash['mutual fund'] : nil non_custodial_wallet = hash.key?('non-custodial wallet') ? hash['non-custodial wallet'] : nil non_taxable_brokerage_account = hash.key?('non-taxable brokerage account') ? hash['non-taxable brokerage account'] : nil other = hash.key?('other') ? hash['other'] : nil other_annuity = hash.key?('other annuity') ? hash['other annuity'] : nil other_insurance = hash.key?('other insurance') ? hash['other insurance'] : nil pension = hash.key?('pension') ? hash['pension'] : nil prif = hash.key?('prif') ? hash['prif'] : nil profit_sharing_plan = hash.key?('profit sharing plan') ? hash['profit sharing plan'] : nil qshr = hash.key?('qshr') ? hash['qshr'] : nil rdsp = hash.key?('rdsp') ? hash['rdsp'] : nil resp = hash.key?('resp') ? hash['resp'] : nil retirement = hash.key?('retirement') ? hash['retirement'] : nil rlif = hash.key?('rlif') ? hash['rlif'] : nil roth = hash.key?('roth') ? hash['roth'] : nil roth_401k = hash.key?('roth 401k') ? hash['roth 401k'] : nil roth_403_b = hash.key?('roth 403B') ? hash['roth 403B'] : nil roth_457b = hash.key?('roth 457b') ? hash['roth 457b'] : nil roth_pension = hash.key?('roth pension') ? hash['roth pension'] : nil roth_profit_sharing_plan = hash.key?('roth profit sharing plan') ? hash['roth profit sharing plan'] : nil roth_thrift_savings_plan = hash.key?('roth thrift savings plan') ? hash['roth thrift savings plan'] : nil rrif = hash.key?('rrif') ? hash['rrif'] : nil rrsp = hash.key?('rrsp') ? hash['rrsp'] : nil sarsep = hash.key?('sarsep') ? hash['sarsep'] : nil sep_ira = hash.key?('sep ira') ? hash['sep ira'] : nil simple_ira = hash.key?('simple ira') ? hash['simple ira'] : nil sipp = hash.key?('sipp') ? hash['sipp'] : nil stock_plan = hash.key?('stock plan') ? hash['stock plan'] : nil tfsa = hash.key?('tfsa') ? hash['tfsa'] : nil thrift_savings_plan = hash.key?('thrift savings plan') ? hash['thrift savings plan'] : nil trust = hash.key?('trust') ? hash['trust'] : nil ugma = hash.key?('ugma') ? hash['ugma'] : nil utma = hash.key?('utma') ? hash['utma'] : nil variable_annuity = hash.key?('variable annuity') ? hash['variable annuity'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InvestmentAccountSubtype1.new(m401a: m401a, m401k: m401k, m403_b: m403_b, m457b: m457b, brokerage: brokerage, cash_isa: cash_isa, crypto_exchange: crypto_exchange, education_savings_account: education_savings_account, fhsa: fhsa, fixed_annuity: fixed_annuity, gic: gic, health_reimbursement_arrangement: health_reimbursement_arrangement, hsa: hsa, ira: ira, isa: isa, keogh: keogh, lif: lif, life_insurance: life_insurance, line_of_credit: line_of_credit, lira: lira, lrif: lrif, lrsp: lrsp, mutual_fund: mutual_fund, non_custodial_wallet: non_custodial_wallet, non_taxable_brokerage_account: non_taxable_brokerage_account, other: other, other_annuity: other_annuity, other_insurance: other_insurance, pension: pension, prif: prif, profit_sharing_plan: profit_sharing_plan, qshr: qshr, rdsp: rdsp, resp: resp, retirement: retirement, rlif: rlif, roth: roth, roth_401k: roth_401k, roth_403_b: roth_403_b, roth_457b: roth_457b, roth_pension: roth_pension, roth_profit_sharing_plan: roth_profit_sharing_plan, roth_thrift_savings_plan: roth_thrift_savings_plan, rrif: rrif, rrsp: rrsp, sarsep: sarsep, sep_ira: sep_ira, simple_ira: simple_ira, sipp: sipp, stock_plan: stock_plan, tfsa: tfsa, thrift_savings_plan: thrift_savings_plan, trust: trust, ugma: ugma, utma: utma, variable_annuity: variable_annuity, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 247 def self.names @_hash = {} if @_hash.nil? @_hash['m401a'] = '401a' @_hash['m401k'] = '401k' @_hash['m403_b'] = '403B' @_hash['m457b'] = '457b' @_hash['brokerage'] = 'brokerage' @_hash['cash_isa'] = 'cash isa' @_hash['crypto_exchange'] = 'crypto exchange' @_hash['education_savings_account'] = 'education savings account' @_hash['fhsa'] = 'fhsa' @_hash['fixed_annuity'] = 'fixed annuity' @_hash['gic'] = 'gic' @_hash['health_reimbursement_arrangement'] = 'health reimbursement arrangement' @_hash['hsa'] = 'hsa' @_hash['ira'] = 'ira' @_hash['isa'] = 'isa' @_hash['keogh'] = 'keogh' @_hash['lif'] = 'lif' @_hash['life_insurance'] = 'life insurance' @_hash['line_of_credit'] = 'line of credit' @_hash['lira'] = 'lira' @_hash['lrif'] = 'lrif' @_hash['lrsp'] = 'lrsp' @_hash['mutual_fund'] = 'mutual fund' @_hash['non_custodial_wallet'] = 'non-custodial wallet' @_hash['non_taxable_brokerage_account'] = 'non-taxable brokerage account' @_hash['other'] = 'other' @_hash['other_annuity'] = 'other annuity' @_hash['other_insurance'] = 'other insurance' @_hash['pension'] = 'pension' @_hash['prif'] = 'prif' @_hash['profit_sharing_plan'] = 'profit sharing plan' @_hash['qshr'] = 'qshr' @_hash['rdsp'] = 'rdsp' @_hash['resp'] = 'resp' @_hash['retirement'] = 'retirement' @_hash['rlif'] = 'rlif' @_hash['roth'] = 'roth' @_hash['roth_401k'] = 'roth 401k' @_hash['roth_403_b'] = 'roth 403B' @_hash['roth_457b'] = 'roth 457b' @_hash['roth_pension'] = 'roth pension' @_hash['roth_profit_sharing_plan'] = 'roth profit sharing plan' @_hash['roth_thrift_savings_plan'] = 'roth thrift savings plan' @_hash['rrif'] = 'rrif' @_hash['rrsp'] = 'rrsp' @_hash['sarsep'] = 'sarsep' @_hash['sep_ira'] = 'sep ira' @_hash['simple_ira'] = 'simple ira' @_hash['sipp'] = 'sipp' @_hash['stock_plan'] = 'stock plan' @_hash['tfsa'] = 'tfsa' @_hash['thrift_savings_plan'] = 'thrift savings plan' @_hash['trust'] = 'trust' @_hash['ugma'] = 'ugma' @_hash['utma'] = 'utma' @_hash['variable_annuity'] = 'variable annuity' @_hash end |
.nullables ⇒ Object
An array for nullable fields
316 317 318 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 316 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
311 312 313 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 311 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 563 def inspect class_name = self.class.name.split('::').last "<#{class_name} m401a: #{@m401a.inspect}, m401k: #{@m401k.inspect}, m403_b:"\ " #{@m403_b.inspect}, m457b: #{@m457b.inspect}, brokerage: #{@brokerage.inspect}, cash_isa:"\ " #{@cash_isa.inspect}, crypto_exchange: #{@crypto_exchange.inspect},"\ " education_savings_account: #{@education_savings_account.inspect}, fhsa: #{@fhsa.inspect},"\ " fixed_annuity: #{@fixed_annuity.inspect}, gic: #{@gic.inspect},"\ " health_reimbursement_arrangement: #{@health_reimbursement_arrangement.inspect}, hsa:"\ " #{@hsa.inspect}, ira: #{@ira.inspect}, isa: #{@isa.inspect}, keogh: #{@keogh.inspect},"\ " lif: #{@lif.inspect}, life_insurance: #{@life_insurance.inspect}, line_of_credit:"\ " #{@line_of_credit.inspect}, lira: #{@lira.inspect}, lrif: #{@lrif.inspect}, lrsp:"\ " #{@lrsp.inspect}, mutual_fund: #{@mutual_fund.inspect}, non_custodial_wallet:"\ " #{@non_custodial_wallet.inspect}, non_taxable_brokerage_account:"\ " #{@non_taxable_brokerage_account.inspect}, other: #{@other.inspect}, other_annuity:"\ " #{@other_annuity.inspect}, other_insurance: #{@other_insurance.inspect}, pension:"\ " #{@pension.inspect}, prif: #{@prif.inspect}, profit_sharing_plan:"\ " #{@profit_sharing_plan.inspect}, qshr: #{@qshr.inspect}, rdsp: #{@rdsp.inspect}, resp:"\ " #{@resp.inspect}, retirement: #{@retirement.inspect}, rlif: #{@rlif.inspect}, roth:"\ " #{@roth.inspect}, roth_401k: #{@roth_401k.inspect}, roth_403_b: #{@roth_403_b.inspect},"\ " roth_457b: #{@roth_457b.inspect}, roth_pension: #{@roth_pension.inspect},"\ " roth_profit_sharing_plan: #{@roth_profit_sharing_plan.inspect}, roth_thrift_savings_plan:"\ " #{@roth_thrift_savings_plan.inspect}, rrif: #{@rrif.inspect}, rrsp: #{@rrsp.inspect},"\ " sarsep: #{@sarsep.inspect}, sep_ira: #{@sep_ira.inspect}, simple_ira:"\ " #{@simple_ira.inspect}, sipp: #{@sipp.inspect}, stock_plan: #{@stock_plan.inspect}, tfsa:"\ " #{@tfsa.inspect}, thrift_savings_plan: #{@thrift_savings_plan.inspect}, trust:"\ " #{@trust.inspect}, ugma: #{@ugma.inspect}, utma: #{@utma.inspect}, variable_annuity:"\ " #{@variable_annuity.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 |
# File 'lib/the_plaid_api/models/investment_account_subtype1.rb', line 539 def to_s class_name = self.class.name.split('::').last "<#{class_name} m401a: #{@m401a}, m401k: #{@m401k}, m403_b: #{@m403_b}, m457b: #{@m457b},"\ " brokerage: #{@brokerage}, cash_isa: #{@cash_isa}, crypto_exchange: #{@crypto_exchange},"\ " education_savings_account: #{@education_savings_account}, fhsa: #{@fhsa}, fixed_annuity:"\ " #{@fixed_annuity}, gic: #{@gic}, health_reimbursement_arrangement:"\ " #{@health_reimbursement_arrangement}, hsa: #{@hsa}, ira: #{@ira}, isa: #{@isa}, keogh:"\ " #{@keogh}, lif: #{@lif}, life_insurance: #{@life_insurance}, line_of_credit:"\ " #{@line_of_credit}, lira: #{@lira}, lrif: #{@lrif}, lrsp: #{@lrsp}, mutual_fund:"\ " #{@mutual_fund}, non_custodial_wallet: #{@non_custodial_wallet},"\ " non_taxable_brokerage_account: #{@non_taxable_brokerage_account}, other: #{@other},"\ " other_annuity: #{@other_annuity}, other_insurance: #{@other_insurance}, pension:"\ " #{@pension}, prif: #{@prif}, profit_sharing_plan: #{@profit_sharing_plan}, qshr: #{@qshr},"\ " rdsp: #{@rdsp}, resp: #{@resp}, retirement: #{@retirement}, rlif: #{@rlif}, roth:"\ " #{@roth}, roth_401k: #{@roth_401k}, roth_403_b: #{@roth_403_b}, roth_457b: #{@roth_457b},"\ " roth_pension: #{@roth_pension}, roth_profit_sharing_plan: #{@roth_profit_sharing_plan},"\ " roth_thrift_savings_plan: #{@roth_thrift_savings_plan}, rrif: #{@rrif}, rrsp: #{@rrsp},"\ " sarsep: #{@sarsep}, sep_ira: #{@sep_ira}, simple_ira: #{@simple_ira}, sipp: #{@sipp},"\ " stock_plan: #{@stock_plan}, tfsa: #{@tfsa}, thrift_savings_plan: #{@thrift_savings_plan},"\ " trust: #{@trust}, ugma: #{@ugma}, utma: #{@utma}, variable_annuity: #{@variable_annuity},"\ " additional_properties: #{@additional_properties}>" end |