Class: ThePlaidApi::InvestmentsAuthOwner
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::InvestmentsAuthOwner
- Defined in:
- lib/the_plaid_api/models/investments_auth_owner.rb
Overview
Information on the ownership of an investments account
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ID of the account that this identity information pertains to.
-
#names ⇒ Array[String]
A list of names associated with the account by the financial institution.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_id: SKIP, names: SKIP, additional_properties: nil) ⇒ InvestmentsAuthOwner
constructor
A new instance of InvestmentsAuthOwner.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_id: SKIP, names: SKIP, additional_properties: nil) ⇒ InvestmentsAuthOwner
Returns a new instance of InvestmentsAuthOwner.
46 47 48 49 50 51 52 53 |
# File 'lib/the_plaid_api/models/investments_auth_owner.rb', line 46 def initialize(account_id: SKIP, names: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_id = account_id unless account_id == SKIP @names = names unless names == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
The ID of the account that this identity information pertains to
14 15 16 |
# File 'lib/the_plaid_api/models/investments_auth_owner.rb', line 14 def account_id @account_id end |
#names ⇒ Array[String]
A list of names associated with the account by the financial institution. In the case of a joint account, Plaid will make a best effort to report the names of all account holders. If an Item contains multiple accounts with different owner names, some institutions will report all names associated with the Item in each account’s ‘names` array.
23 24 25 |
# File 'lib/the_plaid_api/models/investments_auth_owner.rb', line 23 def names @names end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/the_plaid_api/models/investments_auth_owner.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_id = hash.key?('account_id') ? hash['account_id'] : SKIP names = hash.key?('names') ? hash['names'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InvestmentsAuthOwner.new(account_id: account_id, names: names, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 |
# File 'lib/the_plaid_api/models/investments_auth_owner.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['account_id'] = 'account_id' @_hash['names'] = 'names' @_hash end |
.nullables ⇒ Object
An array for nullable fields
42 43 44 |
# File 'lib/the_plaid_api/models/investments_auth_owner.rb', line 42 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 |
# File 'lib/the_plaid_api/models/investments_auth_owner.rb', line 34 def self.optionals %w[ account_id names ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/the_plaid_api/models/investments_auth_owner.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_id: #{@account_id.inspect}, names: #{@names.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 81 |
# File 'lib/the_plaid_api/models/investments_auth_owner.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_id: #{@account_id}, names: #{@names}, additional_properties:"\ " #{@additional_properties}>" end |