Class: ThePlaidApi::InvestmentsTransactionsGetResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::InvestmentsTransactionsGetResponse
- Defined in:
- lib/the_plaid_api/models/investments_transactions_get_response.rb
Overview
InvestmentsTransactionsGetResponse defines the response schema for ‘/investments/transactions/get`
Instance Attribute Summary collapse
-
#accounts ⇒ Array[InvestmentAccount]
The accounts for which transaction history is being fetched.
-
#investment_transactions ⇒ Array[InvestmentTransaction]
The transactions being fetched.
-
#is_investments_fallback_item ⇒ TrueClass | FalseClass
When true, this field indicates that the Item’s portfolio was manually created with the Investments Fallback flow.
-
#item ⇒ Item
Metadata about the Item.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
-
#securities ⇒ Array[Security]
All securities for which there is a corresponding transaction being fetched.
-
#total_investment_transactions ⇒ Integer
The total number of transactions available within the date range specified.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(item:, accounts:, securities:, investment_transactions:, total_investment_transactions:, request_id:, is_investments_fallback_item: SKIP, additional_properties: nil) ⇒ InvestmentsTransactionsGetResponse
constructor
A new instance of InvestmentsTransactionsGetResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(item:, accounts:, securities:, investment_transactions:, total_investment_transactions:, request_id:, is_investments_fallback_item: SKIP, additional_properties: nil) ⇒ InvestmentsTransactionsGetResponse
Returns a new instance of InvestmentsTransactionsGetResponse.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/the_plaid_api/models/investments_transactions_get_response.rb', line 74 def initialize(item:, accounts:, securities:, investment_transactions:, total_investment_transactions:, request_id:, is_investments_fallback_item: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @item = item @accounts = accounts @securities = securities @investment_transactions = investment_transactions @total_investment_transactions = total_investment_transactions @request_id = request_id unless is_investments_fallback_item == SKIP @is_investments_fallback_item = is_investments_fallback_item end @additional_properties = additional_properties end |
Instance Attribute Details
#accounts ⇒ Array[InvestmentAccount]
The accounts for which transaction history is being fetched.
19 20 21 |
# File 'lib/the_plaid_api/models/investments_transactions_get_response.rb', line 19 def accounts @accounts end |
#investment_transactions ⇒ Array[InvestmentTransaction]
The transactions being fetched
28 29 30 |
# File 'lib/the_plaid_api/models/investments_transactions_get_response.rb', line 28 def investment_transactions @investment_transactions end |
#is_investments_fallback_item ⇒ TrueClass | FalseClass
When true, this field indicates that the Item’s portfolio was manually created with the Investments Fallback flow.
46 47 48 |
# File 'lib/the_plaid_api/models/investments_transactions_get_response.rb', line 46 def is_investments_fallback_item @is_investments_fallback_item end |
#item ⇒ Item
Metadata about the Item.
15 16 17 |
# File 'lib/the_plaid_api/models/investments_transactions_get_response.rb', line 15 def item @item end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
41 42 43 |
# File 'lib/the_plaid_api/models/investments_transactions_get_response.rb', line 41 def request_id @request_id end |
#securities ⇒ Array[Security]
All securities for which there is a corresponding transaction being fetched.
24 25 26 |
# File 'lib/the_plaid_api/models/investments_transactions_get_response.rb', line 24 def securities @securities end |
#total_investment_transactions ⇒ Integer
The total number of transactions available within the date range specified. If ‘total_investment_transactions` is larger than the size of the `transactions` array, more transactions are available and can be fetched via manipulating the `offset` parameter.
35 36 37 |
# File 'lib/the_plaid_api/models/investments_transactions_get_response.rb', line 35 def total_investment_transactions @total_investment_transactions end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/the_plaid_api/models/investments_transactions_get_response.rb', line 95 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. item = Item.from_hash(hash['item']) if hash['item'] # Parameter is an array, so we need to iterate through it accounts = nil unless hash['accounts'].nil? accounts = [] hash['accounts'].each do |structure| accounts << (InvestmentAccount.from_hash(structure) if structure) end end accounts = nil unless hash.key?('accounts') # Parameter is an array, so we need to iterate through it securities = nil unless hash['securities'].nil? securities = [] hash['securities'].each do |structure| securities << (Security.from_hash(structure) if structure) end end securities = nil unless hash.key?('securities') # Parameter is an array, so we need to iterate through it investment_transactions = nil unless hash['investment_transactions'].nil? investment_transactions = [] hash['investment_transactions'].each do |structure| investment_transactions << (InvestmentTransaction.from_hash(structure) if structure) end end investment_transactions = nil unless hash.key?('investment_transactions') total_investment_transactions = hash.key?('total_investment_transactions') ? hash['total_investment_transactions'] : nil request_id = hash.key?('request_id') ? hash['request_id'] : nil is_investments_fallback_item = hash.key?('is_investments_fallback_item') ? hash['is_investments_fallback_item'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InvestmentsTransactionsGetResponse.new(item: item, accounts: accounts, securities: securities, investment_transactions: investment_transactions, total_investment_transactions: total_investment_transactions, request_id: request_id, is_investments_fallback_item: is_investments_fallback_item, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/the_plaid_api/models/investments_transactions_get_response.rb', line 49 def self.names @_hash = {} if @_hash.nil? @_hash['item'] = 'item' @_hash['accounts'] = 'accounts' @_hash['securities'] = 'securities' @_hash['investment_transactions'] = 'investment_transactions' @_hash['total_investment_transactions'] = 'total_investment_transactions' @_hash['request_id'] = 'request_id' @_hash['is_investments_fallback_item'] = 'is_investments_fallback_item' @_hash end |
.nullables ⇒ Object
An array for nullable fields
70 71 72 |
# File 'lib/the_plaid_api/models/investments_transactions_get_response.rb', line 70 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
63 64 65 66 67 |
# File 'lib/the_plaid_api/models/investments_transactions_get_response.rb', line 63 def self.optionals %w[ is_investments_fallback_item ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
165 166 167 168 169 170 171 172 173 |
# File 'lib/the_plaid_api/models/investments_transactions_get_response.rb', line 165 def inspect class_name = self.class.name.split('::').last "<#{class_name} item: #{@item.inspect}, accounts: #{@accounts.inspect}, securities:"\ " #{@securities.inspect}, investment_transactions: #{@investment_transactions.inspect},"\ " total_investment_transactions: #{@total_investment_transactions.inspect}, request_id:"\ " #{@request_id.inspect}, is_investments_fallback_item:"\ " #{@is_investments_fallback_item.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
155 156 157 158 159 160 161 162 |
# File 'lib/the_plaid_api/models/investments_transactions_get_response.rb', line 155 def to_s class_name = self.class.name.split('::').last "<#{class_name} item: #{@item}, accounts: #{@accounts}, securities: #{@securities},"\ " investment_transactions: #{@investment_transactions}, total_investment_transactions:"\ " #{@total_investment_transactions}, request_id: #{@request_id},"\ " is_investments_fallback_item: #{@is_investments_fallback_item}, additional_properties:"\ " #{@additional_properties}>" end |