Class: ThePlaidApi::IssuesGetResponse
- Defined in:
- lib/the_plaid_api/models/issues_get_response.rb
Overview
IssuesGetResponse defines the response schema for ‘/issues/get`.
Instance Attribute Summary collapse
-
#issue ⇒ Issue
Information on an issue encountered with financial institutions interactions with financial institutions during Linking.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(issue: SKIP, request_id: SKIP, additional_properties: nil) ⇒ IssuesGetResponse
constructor
A new instance of IssuesGetResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(issue: SKIP, request_id: SKIP, additional_properties: nil) ⇒ IssuesGetResponse
Returns a new instance of IssuesGetResponse.
44 45 46 47 48 49 50 51 |
# File 'lib/the_plaid_api/models/issues_get_response.rb', line 44 def initialize(issue: SKIP, request_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @issue = issue unless issue == SKIP @request_id = request_id unless request_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#issue ⇒ Issue
Information on an issue encountered with financial institutions interactions with financial institutions during Linking.
15 16 17 |
# File 'lib/the_plaid_api/models/issues_get_response.rb', line 15 def issue @issue end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
21 22 23 |
# File 'lib/the_plaid_api/models/issues_get_response.rb', line 21 def request_id @request_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/the_plaid_api/models/issues_get_response.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. issue = Issue.from_hash(hash['issue']) if hash['issue'] request_id = hash.key?('request_id') ? hash['request_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. IssuesGetResponse.new(issue: issue, request_id: request_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/the_plaid_api/models/issues_get_response.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['issue'] = 'issue' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/the_plaid_api/models/issues_get_response.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 35 36 37 |
# File 'lib/the_plaid_api/models/issues_get_response.rb', line 32 def self.optionals %w[ issue request_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/the_plaid_api/models/issues_get_response.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} issue: #{@issue.inspect}, request_id: #{@request_id.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/the_plaid_api/models/issues_get_response.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} issue: #{@issue}, request_id: #{@request_id}, additional_properties:"\ " #{@additional_properties}>" end |