Class: ThePlaidApi::ItemActivityListRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ItemActivityListRequest
- Defined in:
- lib/the_plaid_api/models/item_activity_list_request.rb
Overview
Request to list a historical log of user consent events.
Instance Attribute Summary collapse
-
#access_token ⇒ String
The access token associated with the Item data is being requested for.
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#count ⇒ Integer
Cursor used for pagination.
-
#cursor ⇒ String
Cursor used for pagination.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_id: SKIP, secret: SKIP, access_token: SKIP, cursor: SKIP, count: 50, additional_properties: nil) ⇒ ItemActivityListRequest
constructor
A new instance of ItemActivityListRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_id: SKIP, secret: SKIP, access_token: SKIP, cursor: SKIP, count: 50, additional_properties: nil) ⇒ ItemActivityListRequest
Returns a new instance of ItemActivityListRequest.
62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/the_plaid_api/models/item_activity_list_request.rb', line 62 def initialize(client_id: SKIP, secret: SKIP, access_token: SKIP, cursor: SKIP, count: 50, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @access_token = access_token unless access_token == SKIP @cursor = cursor unless cursor == SKIP @count = count unless count == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#access_token ⇒ String
The access token associated with the Item data is being requested for.
25 26 27 |
# File 'lib/the_plaid_api/models/item_activity_list_request.rb', line 25 def access_token @access_token end |
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/the_plaid_api/models/item_activity_list_request.rb', line 16 def client_id @client_id end |
#count ⇒ Integer
Cursor used for pagination.
33 34 35 |
# File 'lib/the_plaid_api/models/item_activity_list_request.rb', line 33 def count @count end |
#cursor ⇒ String
Cursor used for pagination.
29 30 31 |
# File 'lib/the_plaid_api/models/item_activity_list_request.rb', line 29 def cursor @cursor end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
21 22 23 |
# File 'lib/the_plaid_api/models/item_activity_list_request.rb', line 21 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/the_plaid_api/models/item_activity_list_request.rb', line 76 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP access_token = hash.key?('access_token') ? hash['access_token'] : SKIP cursor = hash.key?('cursor') ? hash['cursor'] : SKIP count = hash['count'] ||= 50 # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ItemActivityListRequest.new(client_id: client_id, secret: secret, access_token: access_token, cursor: cursor, count: count, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
36 37 38 39 40 41 42 43 44 |
# File 'lib/the_plaid_api/models/item_activity_list_request.rb', line 36 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['access_token'] = 'access_token' @_hash['cursor'] = 'cursor' @_hash['count'] = 'count' @_hash end |
.nullables ⇒ Object
An array for nullable fields
58 59 60 |
# File 'lib/the_plaid_api/models/item_activity_list_request.rb', line 58 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
47 48 49 50 51 52 53 54 55 |
# File 'lib/the_plaid_api/models/item_activity_list_request.rb', line 47 def self.optionals %w[ client_id secret access_token cursor count ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
111 112 113 114 115 116 |
# File 'lib/the_plaid_api/models/item_activity_list_request.rb', line 111 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, access_token:"\ " #{@access_token.inspect}, cursor: #{@cursor.inspect}, count: #{@count.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
103 104 105 106 107 108 |
# File 'lib/the_plaid_api/models/item_activity_list_request.rb', line 103 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, access_token:"\ " #{@access_token}, cursor: #{@cursor}, count: #{@count}, additional_properties:"\ " #{@additional_properties}>" end |