Class: ThePlaidApi::ItemApplicationListResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ItemApplicationListResponse
- Defined in:
- lib/the_plaid_api/models/item_application_list_response.rb
Overview
Describes the connected application for a particular end user.
Instance Attribute Summary collapse
-
#applications ⇒ Array[ConnectedApplication]
A list of connected applications.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(applications:, request_id: SKIP, additional_properties: nil) ⇒ ItemApplicationListResponse
constructor
A new instance of ItemApplicationListResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(applications:, request_id: SKIP, additional_properties: nil) ⇒ ItemApplicationListResponse
Returns a new instance of ItemApplicationListResponse.
42 43 44 45 46 47 48 49 |
# File 'lib/the_plaid_api/models/item_application_list_response.rb', line 42 def initialize(applications:, request_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @request_id = request_id unless request_id == SKIP @applications = applications @additional_properties = additional_properties end |
Instance Attribute Details
#applications ⇒ Array[ConnectedApplication]
A list of connected applications.
20 21 22 |
# File 'lib/the_plaid_api/models/item_application_list_response.rb', line 20 def applications @applications end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
16 17 18 |
# File 'lib/the_plaid_api/models/item_application_list_response.rb', line 16 def request_id @request_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/the_plaid_api/models/item_application_list_response.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it applications = nil unless hash['applications'].nil? applications = [] hash['applications'].each do |structure| applications << (ConnectedApplication.from_hash(structure) if structure) end end applications = nil unless hash.key?('applications') request_id = hash.key?('request_id') ? hash['request_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ItemApplicationListResponse.new(applications: applications, request_id: request_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/the_plaid_api/models/item_application_list_response.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['request_id'] = 'request_id' @_hash['applications'] = 'applications' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/the_plaid_api/models/item_application_list_response.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 |
# File 'lib/the_plaid_api/models/item_application_list_response.rb', line 31 def self.optionals %w[ request_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/the_plaid_api/models/item_application_list_response.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} request_id: #{@request_id.inspect}, applications: #{@applications.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/the_plaid_api/models/item_application_list_response.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} request_id: #{@request_id}, applications: #{@applications},"\ " additional_properties: #{@additional_properties}>" end |