Class: ThePlaidApi::ItemAuthMethod
- Inherits:
-
Object
- Object
- ThePlaidApi::ItemAuthMethod
- Defined in:
- lib/the_plaid_api/models/item_auth_method.rb
Overview
The method used to populate Auth data for the Item. This field is only populated for Items that have had Auth numbers data set on at least one of its accounts, and will be ‘null` otherwise. For info about the various flows, see our [Auth coverage documentation](plaid.com/docs/auth/coverage/). `INSTANT_AUTH`: The Item’s Auth data was provided directly by the user’s institution connection. ‘INSTANT_MATCH`: The Item’s Auth data was provided via the Instant Match fallback flow. ‘AUTOMATED_MICRODEPOSITS`: The Item’s Auth data was provided via the Automated Micro-deposits flow. ‘SAME_DAY_MICRODEPOSITS`: The Item’s Auth data was provided via the Same Day Micro-deposits flow. ‘INSTANT_MICRODEPOSITS`: The Item’s Auth data was provided via the Instant Micro-deposits flow. ‘DATABASE_MATCH`: The Item’s Auth data was provided via the Database Match flow. ‘DATABASE_INSIGHTS`: The Item’s Auth data was provided via the Database Insights flow. ‘TRANSFER_MIGRATED`: The Item’s Auth data was provided via [‘/transfer/migrate_account`](plaid.com/docs/api/products/transfer/a ccount-linking/#migrate-account-into-transfers). `INVESTMENTS_FALLBACK`: The Item’s Auth data for Investments Move was provided via a [fallback flow](plaid.com/docs/investments-move/#fallback-flows).
Constant Summary collapse
- ITEM_AUTH_METHOD =
[ # TODO: Write general description for INSTANT_AUTH INSTANT_AUTH = 'INSTANT_AUTH'.freeze, # TODO: Write general description for INSTANT_MATCH INSTANT_MATCH = 'INSTANT_MATCH'.freeze, # TODO: Write general description for AUTOMATED_MICRODEPOSITS AUTOMATED_MICRODEPOSITS = 'AUTOMATED_MICRODEPOSITS'.freeze, # TODO: Write general description for SAME_DAY_MICRODEPOSITS SAME_DAY_MICRODEPOSITS = 'SAME_DAY_MICRODEPOSITS'.freeze, # TODO: Write general description for INSTANT_MICRODEPOSITS INSTANT_MICRODEPOSITS = 'INSTANT_MICRODEPOSITS'.freeze, # TODO: Write general description for DATABASE_MATCH DATABASE_MATCH = 'DATABASE_MATCH'.freeze, # TODO: Write general description for DATABASE_INSIGHTS DATABASE_INSIGHTS = 'DATABASE_INSIGHTS'.freeze, # TODO: Write general description for TRANSFER_MIGRATED TRANSFER_MIGRATED = 'TRANSFER_MIGRATED'.freeze, # TODO: Write general description for INVESTMENTS_FALLBACK INVESTMENTS_FALLBACK = 'INVESTMENTS_FALLBACK'.freeze ].freeze
Class Method Summary collapse
Class Method Details
.from_value(value, default_value = INSTANT_AUTH) ⇒ Object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/the_plaid_api/models/item_auth_method.rb', line 62 def self.from_value(value, default_value = INSTANT_AUTH) return default_value if value.nil? str = value.to_s.strip case str.downcase when 'instant_auth' then INSTANT_AUTH when 'instant_match' then INSTANT_MATCH when 'automated_microdeposits' then AUTOMATED_MICRODEPOSITS when 'same_day_microdeposits' then SAME_DAY_MICRODEPOSITS when 'instant_microdeposits' then INSTANT_MICRODEPOSITS when 'database_match' then DATABASE_MATCH when 'database_insights' then DATABASE_INSIGHTS when 'transfer_migrated' then TRANSFER_MIGRATED when 'investments_fallback' then INVESTMENTS_FALLBACK else default_value end end |
.validate(value) ⇒ Object
56 57 58 59 60 |
# File 'lib/the_plaid_api/models/item_auth_method.rb', line 56 def self.validate(value) return false if value.nil? ITEM_AUTH_METHOD.include?(value) end |