Class: ThePlaidApi::ItemProductReadyWebhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ItemProductReadyWebhook
- Defined in:
- lib/the_plaid_api/models/item_product_ready_webhook.rb
Overview
Fired once Plaid calculates income from an Item.
Instance Attribute Summary collapse
-
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from.
-
#error ⇒ Error
Errors are identified by ‘error_code` and categorized by `error_type`.
-
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error.
-
#webhook_code ⇒ String
‘PRODUCT_READY`.
-
#webhook_type ⇒ String
‘INCOME`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, item_id:, environment:, error: SKIP, additional_properties: nil) ⇒ ItemProductReadyWebhook
constructor
A new instance of ItemProductReadyWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, item_id:, environment:, error: SKIP, additional_properties: nil) ⇒ ItemProductReadyWebhook
Returns a new instance of ItemProductReadyWebhook.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/the_plaid_api/models/item_product_ready_webhook.rb', line 65 def initialize(webhook_type:, webhook_code:, item_id:, environment:, error: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @item_id = item_id @error = error unless error == SKIP @environment = environment @additional_properties = additional_properties end |
Instance Attribute Details
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from
38 39 40 |
# File 'lib/the_plaid_api/models/item_product_ready_webhook.rb', line 38 def environment @environment end |
#error ⇒ Error
Errors are identified by ‘error_code` and categorized by `error_type`. Use these in preference to HTTP status codes to identify and handle specific errors. HTTP status codes are set and provide the broadest categorization of errors: 4xx codes are for developer- or user-related errors, and 5xx codes are for Plaid-related errors, and the status will be 2xx in non-error cases. An Item with a non-`null` error object will only be part of an API response when calling `/item/get` to view Item status. Otherwise, error fields will be `null` if no error has occurred; if an error has occurred, an error code will be returned instead.
34 35 36 |
# File 'lib/the_plaid_api/models/item_product_ready_webhook.rb', line 34 def error @error end |
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error
22 23 24 |
# File 'lib/the_plaid_api/models/item_product_ready_webhook.rb', line 22 def item_id @item_id end |
#webhook_code ⇒ String
‘PRODUCT_READY`
18 19 20 |
# File 'lib/the_plaid_api/models/item_product_ready_webhook.rb', line 18 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘INCOME`
14 15 16 |
# File 'lib/the_plaid_api/models/item_product_ready_webhook.rb', line 14 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/the_plaid_api/models/item_product_ready_webhook.rb', line 79 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil item_id = hash.key?('item_id') ? hash['item_id'] : nil environment = hash.key?('environment') ? hash['environment'] : nil error = Error.from_hash(hash['error']) if hash['error'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ItemProductReadyWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, item_id: item_id, environment: environment, error: error, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
41 42 43 44 45 46 47 48 49 |
# File 'lib/the_plaid_api/models/item_product_ready_webhook.rb', line 41 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['item_id'] = 'item_id' @_hash['error'] = 'error' @_hash['environment'] = 'environment' @_hash end |
.nullables ⇒ Object
An array for nullable fields
59 60 61 62 63 |
# File 'lib/the_plaid_api/models/item_product_ready_webhook.rb', line 59 def self.nullables %w[ error ] end |
.optionals ⇒ Object
An array for optional fields
52 53 54 55 56 |
# File 'lib/the_plaid_api/models/item_product_ready_webhook.rb', line 52 def self.optionals %w[ error ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
114 115 116 117 118 119 |
# File 'lib/the_plaid_api/models/item_product_ready_webhook.rb', line 114 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, item_id: #{@item_id.inspect}, error: #{@error.inspect},"\ " environment: #{@environment.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
106 107 108 109 110 111 |
# File 'lib/the_plaid_api/models/item_product_ready_webhook.rb', line 106 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, item_id:"\ " #{@item_id}, error: #{@error}, environment: #{@environment}, additional_properties:"\ " #{@additional_properties}>" end |