Class: ThePlaidApi::ItemProductsTerminateRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ItemProductsTerminateRequest
- Defined in:
- lib/the_plaid_api/models/item_products_terminate_request.rb
Overview
ItemProductsTerminateRequest defines the request schema for ‘/item/products/terminate`
Instance Attribute Summary collapse
-
#access_token ⇒ String
The access token associated with the Item data is being requested for.
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#reason_code ⇒ String
readonly
The reason for terminating products on the Item.
-
#reason_note ⇒ String
Additional context or details about the reason for terminating products on the Item.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(access_token:, client_id: SKIP, secret: SKIP, reason_note: SKIP, additional_properties: nil) ⇒ ItemProductsTerminateRequest
constructor
A new instance of ItemProductsTerminateRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(access_token:, client_id: SKIP, secret: SKIP, reason_note: SKIP, additional_properties: nil) ⇒ ItemProductsTerminateRequest
Returns a new instance of ItemProductsTerminateRequest.
67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/the_plaid_api/models/item_products_terminate_request.rb', line 67 def initialize(access_token:, client_id: SKIP, secret: SKIP, reason_note: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @access_token = access_token @reason_code = 'OTHER' @reason_note = reason_note unless reason_note == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#access_token ⇒ String
The access token associated with the Item data is being requested for.
26 27 28 |
# File 'lib/the_plaid_api/models/item_products_terminate_request.rb', line 26 def access_token @access_token end |
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/item_products_terminate_request.rb', line 17 def client_id @client_id end |
#reason_code ⇒ String (readonly)
The reason for terminating products on the Item. ‘OTHER`: Any other reason for terminating products not covered by the above categories
32 33 34 |
# File 'lib/the_plaid_api/models/item_products_terminate_request.rb', line 32 def reason_code @reason_code end |
#reason_note ⇒ String
Additional context or details about the reason for terminating products on the Item. Personally identifiable information, such as an email address or phone number, should not be included in the ‘reason_note`.
38 39 40 |
# File 'lib/the_plaid_api/models/item_products_terminate_request.rb', line 38 def reason_note @reason_note end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/the_plaid_api/models/item_products_terminate_request.rb', line 22 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/the_plaid_api/models/item_products_terminate_request.rb', line 81 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. access_token = hash.key?('access_token') ? hash['access_token'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP reason_note = hash.key?('reason_note') ? hash['reason_note'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ItemProductsTerminateRequest.new(access_token: access_token, client_id: client_id, secret: secret, reason_note: reason_note, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
41 42 43 44 45 46 47 48 49 |
# File 'lib/the_plaid_api/models/item_products_terminate_request.rb', line 41 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['access_token'] = 'access_token' @_hash['reason_code'] = 'reason_code' @_hash['reason_note'] = 'reason_note' @_hash end |
.nullables ⇒ Object
An array for nullable fields
61 62 63 64 65 |
# File 'lib/the_plaid_api/models/item_products_terminate_request.rb', line 61 def self.nullables %w[ reason_note ] end |
.optionals ⇒ Object
An array for optional fields
52 53 54 55 56 57 58 |
# File 'lib/the_plaid_api/models/item_products_terminate_request.rb', line 52 def self.optionals %w[ client_id secret reason_note ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
114 115 116 117 118 119 |
# File 'lib/the_plaid_api/models/item_products_terminate_request.rb', line 114 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, access_token:"\ " #{@access_token.inspect}, reason_code: #{@reason_code.inspect}, reason_note:"\ " #{@reason_note.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
106 107 108 109 110 111 |
# File 'lib/the_plaid_api/models/item_products_terminate_request.rb', line 106 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, access_token:"\ " #{@access_token}, reason_code: #{@reason_code}, reason_note: #{@reason_note},"\ " additional_properties: #{@additional_properties}>" end |