Class: ThePlaidApi::ItemRemoveReasonCode
- Inherits:
-
Object
- Object
- ThePlaidApi::ItemRemoveReasonCode
- Defined in:
- lib/the_plaid_api/models/item_remove_reason_code.rb
Overview
The reason for removing the item ‘FRAUD_FIRST_PARTY`: The end user who owns the connected bank account committed fraud `FRAUD_FALSE_IDENTITY`: The end user created the connection using false identity information or stolen credentials `FRAUD_ABUSE`: The end user is abusing the client’s service or platform through their connected account ‘FRAUD_OTHER`: Other fraud-related reasons involving the end user not covered by the specific fraud categories `CONNECTION_IS_NON_FUNCTIONAL`: The connection to the end user’s financial institution is broken and cannot be restored ‘OTHER`: Any other reason for removing the connection not covered by the above categories
Constant Summary collapse
- ITEM_REMOVE_REASON_CODE =
[ # TODO: Write general description for FRAUD_FIRST_PARTY FRAUD_FIRST_PARTY = 'FRAUD_FIRST_PARTY'.freeze, # TODO: Write general description for FRAUD_FALSE_IDENTITY FRAUD_FALSE_IDENTITY = 'FRAUD_FALSE_IDENTITY'.freeze, # TODO: Write general description for FRAUD_ABUSE FRAUD_ABUSE = 'FRAUD_ABUSE'.freeze, # TODO: Write general description for FRAUD_OTHER FRAUD_OTHER = 'FRAUD_OTHER'.freeze, # TODO: Write general description for CONNECTION_IS_NON_FUNCTIONAL CONNECTION_IS_NON_FUNCTIONAL = 'CONNECTION_IS_NON_FUNCTIONAL'.freeze, # TODO: Write general description for OTHER OTHER = 'OTHER'.freeze ].freeze
Class Method Summary collapse
Class Method Details
.from_value(value, default_value = FRAUD_FIRST_PARTY) ⇒ Object
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/the_plaid_api/models/item_remove_reason_code.rb', line 43 def self.from_value(value, default_value = FRAUD_FIRST_PARTY) return default_value if value.nil? str = value.to_s.strip case str.downcase when 'fraud_first_party' then FRAUD_FIRST_PARTY when 'fraud_false_identity' then FRAUD_FALSE_IDENTITY when 'fraud_abuse' then FRAUD_ABUSE when 'fraud_other' then FRAUD_OTHER when 'connection_is_non_functional' then CONNECTION_IS_NON_FUNCTIONAL when 'other' then OTHER else default_value end end |
.validate(value) ⇒ Object
37 38 39 40 41 |
# File 'lib/the_plaid_api/models/item_remove_reason_code.rb', line 37 def self.validate(value) return false if value.nil? ITEM_REMOVE_REASON_CODE.include?(value) end |