Class: ThePlaidApi::KycCheckDateOfBirthSummary
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::KycCheckDateOfBirthSummary
- Defined in:
- lib/the_plaid_api/models/kyc_check_date_of_birth_summary.rb
Overview
Result summary object specifying how the ‘date_of_birth` field matched.
Instance Attribute Summary collapse
-
#day ⇒ MatchSummaryCode1
An enum indicating the match type between data provided by user and data checked against an external data source.
-
#month ⇒ MatchSummaryCode1
An enum indicating the match type between data provided by user and data checked against an external data source.
-
#summary ⇒ MatchSummaryCode1
An enum indicating the match type between data provided by user and data checked against an external data source.
-
#year ⇒ MatchSummaryCode1
An enum indicating the match type between data provided by user and data checked against an external data source.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(summary:, day: SKIP, month: SKIP, year: SKIP, additional_properties: nil) ⇒ KycCheckDateOfBirthSummary
constructor
A new instance of KycCheckDateOfBirthSummary.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(summary:, day: SKIP, month: SKIP, year: SKIP, additional_properties: nil) ⇒ KycCheckDateOfBirthSummary
Returns a new instance of KycCheckDateOfBirthSummary.
96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/the_plaid_api/models/kyc_check_date_of_birth_summary.rb', line 96 def initialize(summary:, day: SKIP, month: SKIP, year: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @summary = summary @day = day unless day == SKIP @month = month unless month == SKIP @year = year unless year == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#day ⇒ MatchSummaryCode1
An enum indicating the match type between data provided by user and data checked against an external data source. ‘match` indicates that the provided input data was a strong match against external data. `partial_match` indicates the data approximately matched against external data. For example, “Knope” vs. “Knope-Wyatt” for last name. `no_match` indicates that Plaid was able to perform a check against an external data source and it did not match the provided input data. `no_data` indicates that Plaid was unable to find external data to compare against the provided input data. `no_input` indicates that Plaid was unable to perform a check because no information was provided for this field by the end user.
40 41 42 |
# File 'lib/the_plaid_api/models/kyc_check_date_of_birth_summary.rb', line 40 def day @day end |
#month ⇒ MatchSummaryCode1
An enum indicating the match type between data provided by user and data checked against an external data source. ‘match` indicates that the provided input data was a strong match against external data. `partial_match` indicates the data approximately matched against external data. For example, “Knope” vs. “Knope-Wyatt” for last name. `no_match` indicates that Plaid was able to perform a check against an external data source and it did not match the provided input data. `no_data` indicates that Plaid was unable to find external data to compare against the provided input data. `no_input` indicates that Plaid was unable to perform a check because no information was provided for this field by the end user.
55 56 57 |
# File 'lib/the_plaid_api/models/kyc_check_date_of_birth_summary.rb', line 55 def month @month end |
#summary ⇒ MatchSummaryCode1
An enum indicating the match type between data provided by user and data checked against an external data source. ‘match` indicates that the provided input data was a strong match against external data. `partial_match` indicates the data approximately matched against external data. For example, “Knope” vs. “Knope-Wyatt” for last name. `no_match` indicates that Plaid was able to perform a check against an external data source and it did not match the provided input data. `no_data` indicates that Plaid was unable to find external data to compare against the provided input data. `no_input` indicates that Plaid was unable to perform a check because no information was provided for this field by the end user.
25 26 27 |
# File 'lib/the_plaid_api/models/kyc_check_date_of_birth_summary.rb', line 25 def summary @summary end |
#year ⇒ MatchSummaryCode1
An enum indicating the match type between data provided by user and data checked against an external data source. ‘match` indicates that the provided input data was a strong match against external data. `partial_match` indicates the data approximately matched against external data. For example, “Knope” vs. “Knope-Wyatt” for last name. `no_match` indicates that Plaid was able to perform a check against an external data source and it did not match the provided input data. `no_data` indicates that Plaid was unable to find external data to compare against the provided input data. `no_input` indicates that Plaid was unable to perform a check because no information was provided for this field by the end user.
70 71 72 |
# File 'lib/the_plaid_api/models/kyc_check_date_of_birth_summary.rb', line 70 def year @year end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/the_plaid_api/models/kyc_check_date_of_birth_summary.rb', line 109 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. summary = hash.key?('summary') ? hash['summary'] : nil day = hash.key?('day') ? hash['day'] : SKIP month = hash.key?('month') ? hash['month'] : SKIP year = hash.key?('year') ? hash['year'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. KycCheckDateOfBirthSummary.new(summary: summary, day: day, month: month, year: year, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
73 74 75 76 77 78 79 80 |
# File 'lib/the_plaid_api/models/kyc_check_date_of_birth_summary.rb', line 73 def self.names @_hash = {} if @_hash.nil? @_hash['summary'] = 'summary' @_hash['day'] = 'day' @_hash['month'] = 'month' @_hash['year'] = 'year' @_hash end |
.nullables ⇒ Object
An array for nullable fields
92 93 94 |
# File 'lib/the_plaid_api/models/kyc_check_date_of_birth_summary.rb', line 92 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
83 84 85 86 87 88 89 |
# File 'lib/the_plaid_api/models/kyc_check_date_of_birth_summary.rb', line 83 def self.optionals %w[ day month year ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
141 142 143 144 145 146 |
# File 'lib/the_plaid_api/models/kyc_check_date_of_birth_summary.rb', line 141 def inspect class_name = self.class.name.split('::').last "<#{class_name} summary: #{@summary.inspect}, day: #{@day.inspect}, month:"\ " #{@month.inspect}, year: #{@year.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
134 135 136 137 138 |
# File 'lib/the_plaid_api/models/kyc_check_date_of_birth_summary.rb', line 134 def to_s class_name = self.class.name.split('::').last "<#{class_name} summary: #{@summary}, day: #{@day}, month: #{@month}, year: #{@year},"\ " additional_properties: #{@additional_properties}>" end |