Class: ThePlaidApi::KycCheckNameSummary
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::KycCheckNameSummary
- Defined in:
- lib/the_plaid_api/models/kyc_check_name_summary.rb
Overview
Result summary object specifying how the ‘name` field matched.
Instance Attribute Summary collapse
-
#family_name ⇒ MatchSummaryCode1
An enum indicating the match type between data provided by user and data checked against an external data source.
-
#given_name ⇒ MatchSummaryCode1
An enum indicating the match type between data provided by user and data checked against an external data source.
-
#summary ⇒ MatchSummaryCode1
An enum indicating the match type between data provided by user and data checked against an external data source.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(summary:, given_name: SKIP, family_name: SKIP, additional_properties: nil) ⇒ KycCheckNameSummary
constructor
A new instance of KycCheckNameSummary.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(summary:, given_name: SKIP, family_name: SKIP, additional_properties: nil) ⇒ KycCheckNameSummary
Returns a new instance of KycCheckNameSummary.
79 80 81 82 83 84 85 86 87 88 |
# File 'lib/the_plaid_api/models/kyc_check_name_summary.rb', line 79 def initialize(summary:, given_name: SKIP, family_name: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @summary = summary @given_name = given_name unless given_name == SKIP @family_name = family_name unless family_name == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#family_name ⇒ MatchSummaryCode1
An enum indicating the match type between data provided by user and data checked against an external data source. ‘match` indicates that the provided input data was a strong match against external data. `partial_match` indicates the data approximately matched against external data. For example, “Knope” vs. “Knope-Wyatt” for last name. `no_match` indicates that Plaid was able to perform a check against an external data source and it did not match the provided input data. `no_data` indicates that Plaid was unable to find external data to compare against the provided input data. `no_input` indicates that Plaid was unable to perform a check because no information was provided for this field by the end user.
55 56 57 |
# File 'lib/the_plaid_api/models/kyc_check_name_summary.rb', line 55 def family_name @family_name end |
#given_name ⇒ MatchSummaryCode1
An enum indicating the match type between data provided by user and data checked against an external data source. ‘match` indicates that the provided input data was a strong match against external data. `partial_match` indicates the data approximately matched against external data. For example, “Knope” vs. “Knope-Wyatt” for last name. `no_match` indicates that Plaid was able to perform a check against an external data source and it did not match the provided input data. `no_data` indicates that Plaid was unable to find external data to compare against the provided input data. `no_input` indicates that Plaid was unable to perform a check because no information was provided for this field by the end user.
40 41 42 |
# File 'lib/the_plaid_api/models/kyc_check_name_summary.rb', line 40 def given_name @given_name end |
#summary ⇒ MatchSummaryCode1
An enum indicating the match type between data provided by user and data checked against an external data source. ‘match` indicates that the provided input data was a strong match against external data. `partial_match` indicates the data approximately matched against external data. For example, “Knope” vs. “Knope-Wyatt” for last name. `no_match` indicates that Plaid was able to perform a check against an external data source and it did not match the provided input data. `no_data` indicates that Plaid was unable to find external data to compare against the provided input data. `no_input` indicates that Plaid was unable to perform a check because no information was provided for this field by the end user.
25 26 27 |
# File 'lib/the_plaid_api/models/kyc_check_name_summary.rb', line 25 def summary @summary end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/the_plaid_api/models/kyc_check_name_summary.rb', line 91 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. summary = hash.key?('summary') ? hash['summary'] : nil given_name = hash.key?('given_name') ? hash['given_name'] : SKIP family_name = hash.key?('family_name') ? hash['family_name'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. KycCheckNameSummary.new(summary: summary, given_name: given_name, family_name: family_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
58 59 60 61 62 63 64 |
# File 'lib/the_plaid_api/models/kyc_check_name_summary.rb', line 58 def self.names @_hash = {} if @_hash.nil? @_hash['summary'] = 'summary' @_hash['given_name'] = 'given_name' @_hash['family_name'] = 'family_name' @_hash end |
.nullables ⇒ Object
An array for nullable fields
75 76 77 |
# File 'lib/the_plaid_api/models/kyc_check_name_summary.rb', line 75 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
67 68 69 70 71 72 |
# File 'lib/the_plaid_api/models/kyc_check_name_summary.rb', line 67 def self.optionals %w[ given_name family_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
121 122 123 124 125 |
# File 'lib/the_plaid_api/models/kyc_check_name_summary.rb', line 121 def inspect class_name = self.class.name.split('::').last "<#{class_name} summary: #{@summary.inspect}, given_name: #{@given_name.inspect},"\ " family_name: #{@family_name.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
114 115 116 117 118 |
# File 'lib/the_plaid_api/models/kyc_check_name_summary.rb', line 114 def to_s class_name = self.class.name.split('::').last "<#{class_name} summary: #{@summary}, given_name: #{@given_name}, family_name:"\ " #{@family_name}, additional_properties: #{@additional_properties}>" end |