Class: ThePlaidApi::LinkDeliveryCallbackWebhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::LinkDeliveryCallbackWebhook
- Defined in:
- lib/the_plaid_api/models/link_delivery_callback_webhook.rb
Overview
Webhook containing metadata proxied over from Link callback e.g ‘onEvent`, `onExit`, `onSuccess`.
Instance Attribute Summary collapse
-
#error ⇒ Error
Errors are identified by ‘error_code` and categorized by `error_type`.
-
#link_callback_metadata ⇒ LinkCallbackMetadata
Information related to the callback from the Hosted Link session.
-
#link_delivery_session_id ⇒ String
The ID of the Hosted Link session.
-
#timestamp ⇒ String
Timestamp in [ISO 8601](wikipedia.org/wiki/ISO_8601) format.
-
#webhook_code ⇒ String
‘LINK_CALLBACK`.
-
#webhook_type ⇒ String
‘LINK_DELIVERY`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, link_delivery_session_id:, timestamp:, link_callback_metadata:, error: SKIP, additional_properties: nil) ⇒ LinkDeliveryCallbackWebhook
constructor
A new instance of LinkDeliveryCallbackWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, link_delivery_session_id:, timestamp:, link_callback_metadata:, error: SKIP, additional_properties: nil) ⇒ LinkDeliveryCallbackWebhook
Returns a new instance of LinkDeliveryCallbackWebhook.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/the_plaid_api/models/link_delivery_callback_webhook.rb', line 71 def initialize(webhook_type:, webhook_code:, link_delivery_session_id:, timestamp:, link_callback_metadata:, error: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @link_delivery_session_id = link_delivery_session_id @timestamp = @error = error unless error == SKIP @link_callback_metadata = @additional_properties = additional_properties end |
Instance Attribute Details
#error ⇒ Error
Errors are identified by ‘error_code` and categorized by `error_type`. Use these in preference to HTTP status codes to identify and handle specific errors. HTTP status codes are set and provide the broadest categorization of errors: 4xx codes are for developer- or user-related errors, and 5xx codes are for Plaid-related errors, and the status will be 2xx in non-error cases. An Item with a non-`null` error object will only be part of an API response when calling `/item/get` to view Item status. Otherwise, error fields will be `null` if no error has occurred; if an error has occurred, an error code will be returned instead.
39 40 41 |
# File 'lib/the_plaid_api/models/link_delivery_callback_webhook.rb', line 39 def error @error end |
#link_callback_metadata ⇒ LinkCallbackMetadata
Information related to the callback from the Hosted Link session.
43 44 45 |
# File 'lib/the_plaid_api/models/link_delivery_callback_webhook.rb', line 43 def @link_callback_metadata end |
#link_delivery_session_id ⇒ String
The ID of the Hosted Link session.
23 24 25 |
# File 'lib/the_plaid_api/models/link_delivery_callback_webhook.rb', line 23 def link_delivery_session_id @link_delivery_session_id end |
#timestamp ⇒ String
Timestamp in [ISO 8601](wikipedia.org/wiki/ISO_8601) format.
27 28 29 |
# File 'lib/the_plaid_api/models/link_delivery_callback_webhook.rb', line 27 def @timestamp end |
#webhook_code ⇒ String
‘LINK_CALLBACK`
19 20 21 |
# File 'lib/the_plaid_api/models/link_delivery_callback_webhook.rb', line 19 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘LINK_DELIVERY`
15 16 17 |
# File 'lib/the_plaid_api/models/link_delivery_callback_webhook.rb', line 15 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/the_plaid_api/models/link_delivery_callback_webhook.rb', line 87 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil link_delivery_session_id = hash.key?('link_delivery_session_id') ? hash['link_delivery_session_id'] : nil = hash.key?('timestamp') ? hash['timestamp'] : nil = LinkCallbackMetadata.from_hash(hash['link_callback_metadata']) if hash['link_callback_metadata'] error = Error.from_hash(hash['error']) if hash['error'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LinkDeliveryCallbackWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, link_delivery_session_id: link_delivery_session_id, timestamp: , link_callback_metadata: , error: error, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/the_plaid_api/models/link_delivery_callback_webhook.rb', line 46 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['link_delivery_session_id'] = 'link_delivery_session_id' @_hash['timestamp'] = 'timestamp' @_hash['error'] = 'error' @_hash['link_callback_metadata'] = 'link_callback_metadata' @_hash end |
.nullables ⇒ Object
An array for nullable fields
65 66 67 68 69 |
# File 'lib/the_plaid_api/models/link_delivery_callback_webhook.rb', line 65 def self.nullables %w[ error ] end |
.optionals ⇒ Object
An array for optional fields
58 59 60 61 62 |
# File 'lib/the_plaid_api/models/link_delivery_callback_webhook.rb', line 58 def self.optionals %w[ error ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
127 128 129 130 131 132 133 |
# File 'lib/the_plaid_api/models/link_delivery_callback_webhook.rb', line 127 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, link_delivery_session_id: #{@link_delivery_session_id.inspect},"\ " timestamp: #{@timestamp.inspect}, error: #{@error.inspect}, link_callback_metadata:"\ " #{@link_callback_metadata.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
118 119 120 121 122 123 124 |
# File 'lib/the_plaid_api/models/link_delivery_callback_webhook.rb', line 118 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code},"\ " link_delivery_session_id: #{@link_delivery_session_id}, timestamp: #{@timestamp}, error:"\ " #{@error}, link_callback_metadata: #{@link_callback_metadata}, additional_properties:"\ " #{@additional_properties}>" end |