Class: ThePlaidApi::LinkDeliveryMetadata
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::LinkDeliveryMetadata
- Defined in:
- lib/the_plaid_api/models/link_delivery_metadata.rb
Overview
Information related to the related to the delivery of the link session to users
Instance Attribute Summary collapse
-
#communication_method ⇒ LinkDeliveryWebhookCommunicationMethod
The communication method used to deliver the Hosted Link session.
-
#delivery_status ⇒ LinkDeliveryWebhookDeliveryStatus
The status of the delivery of the Hosted Link to the user.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(communication_method: SKIP, delivery_status: SKIP, additional_properties: nil) ⇒ LinkDeliveryMetadata
constructor
A new instance of LinkDeliveryMetadata.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(communication_method: SKIP, delivery_status: SKIP, additional_properties: nil) ⇒ LinkDeliveryMetadata
Returns a new instance of LinkDeliveryMetadata.
42 43 44 45 46 47 48 49 50 |
# File 'lib/the_plaid_api/models/link_delivery_metadata.rb', line 42 def initialize(communication_method: SKIP, delivery_status: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @communication_method = communication_method unless communication_method == SKIP @delivery_status = delivery_status unless delivery_status == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#communication_method ⇒ LinkDeliveryWebhookCommunicationMethod
The communication method used to deliver the Hosted Link session
15 16 17 |
# File 'lib/the_plaid_api/models/link_delivery_metadata.rb', line 15 def communication_method @communication_method end |
#delivery_status ⇒ LinkDeliveryWebhookDeliveryStatus
The status of the delivery of the Hosted Link to the user
19 20 21 |
# File 'lib/the_plaid_api/models/link_delivery_metadata.rb', line 19 def delivery_status @delivery_status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/the_plaid_api/models/link_delivery_metadata.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. communication_method = hash.key?('communication_method') ? hash['communication_method'] : SKIP delivery_status = hash.key?('delivery_status') ? hash['delivery_status'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LinkDeliveryMetadata.new(communication_method: communication_method, delivery_status: delivery_status, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/the_plaid_api/models/link_delivery_metadata.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['communication_method'] = 'communication_method' @_hash['delivery_status'] = 'delivery_status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/the_plaid_api/models/link_delivery_metadata.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/the_plaid_api/models/link_delivery_metadata.rb', line 30 def self.optionals %w[ communication_method delivery_status ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
83 84 85 86 87 |
# File 'lib/the_plaid_api/models/link_delivery_metadata.rb', line 83 def inspect class_name = self.class.name.split('::').last "<#{class_name} communication_method: #{@communication_method.inspect}, delivery_status:"\ " #{@delivery_status.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
76 77 78 79 80 |
# File 'lib/the_plaid_api/models/link_delivery_metadata.rb', line 76 def to_s class_name = self.class.name.split('::').last "<#{class_name} communication_method: #{@communication_method}, delivery_status:"\ " #{@delivery_status}, additional_properties: #{@additional_properties}>" end |