Class: ThePlaidApi::LinkEvent
- Defined in:
- lib/the_plaid_api/models/link_event.rb
Overview
An event that occurred while the user was going through Link
Instance Attribute Summary collapse
-
#event_id ⇒ String
UUID that can be used to deduplicate events.
-
#event_metadata ⇒ LinkEventMetadata
Metadata about an event that occurred while the user was going through Link.
-
#event_name ⇒ String
Event name.
-
#timestamp ⇒ String
Timestamp in [ISO 8601](wikipedia.org/wiki/ISO_8601) format.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(event_name:, timestamp:, event_id:, event_metadata:, additional_properties: nil) ⇒ LinkEvent
constructor
A new instance of LinkEvent.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(event_name:, timestamp:, event_id:, event_metadata:, additional_properties: nil) ⇒ LinkEvent
Returns a new instance of LinkEvent.
49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/the_plaid_api/models/link_event.rb', line 49 def initialize(event_name:, timestamp:, event_id:, event_metadata:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @event_name = event_name @timestamp = @event_id = event_id @event_metadata = @additional_properties = additional_properties end |
Instance Attribute Details
#event_id ⇒ String
UUID that can be used to deduplicate events
22 23 24 |
# File 'lib/the_plaid_api/models/link_event.rb', line 22 def event_id @event_id end |
#event_metadata ⇒ LinkEventMetadata
Metadata about an event that occurred while the user was going through Link
27 28 29 |
# File 'lib/the_plaid_api/models/link_event.rb', line 27 def @event_metadata end |
#event_name ⇒ String
Event name
14 15 16 |
# File 'lib/the_plaid_api/models/link_event.rb', line 14 def event_name @event_name end |
#timestamp ⇒ String
Timestamp in [ISO 8601](wikipedia.org/wiki/ISO_8601) format.
18 19 20 |
# File 'lib/the_plaid_api/models/link_event.rb', line 18 def @timestamp end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/the_plaid_api/models/link_event.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. event_name = hash.key?('event_name') ? hash['event_name'] : nil = hash.key?('timestamp') ? hash['timestamp'] : nil event_id = hash.key?('event_id') ? hash['event_id'] : nil = LinkEventMetadata.from_hash(hash['event_metadata']) if hash['event_metadata'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LinkEvent.new(event_name: event_name, timestamp: , event_id: event_id, event_metadata: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
30 31 32 33 34 35 36 37 |
# File 'lib/the_plaid_api/models/link_event.rb', line 30 def self.names @_hash = {} if @_hash.nil? @_hash['event_name'] = 'event_name' @_hash['timestamp'] = 'timestamp' @_hash['event_id'] = 'event_id' @_hash['event_metadata'] = 'event_metadata' @_hash end |
.nullables ⇒ Object
An array for nullable fields
45 46 47 |
# File 'lib/the_plaid_api/models/link_event.rb', line 45 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
40 41 42 |
# File 'lib/the_plaid_api/models/link_event.rb', line 40 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
96 97 98 99 100 101 |
# File 'lib/the_plaid_api/models/link_event.rb', line 96 def inspect class_name = self.class.name.split('::').last "<#{class_name} event_name: #{@event_name.inspect}, timestamp: #{@timestamp.inspect},"\ " event_id: #{@event_id.inspect}, event_metadata: #{@event_metadata.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
88 89 90 91 92 93 |
# File 'lib/the_plaid_api/models/link_event.rb', line 88 def to_s class_name = self.class.name.split('::').last "<#{class_name} event_name: #{@event_name}, timestamp: #{@timestamp}, event_id:"\ " #{@event_id}, event_metadata: #{@event_metadata}, additional_properties:"\ " #{@additional_properties}>" end |