Class: ThePlaidApi::LinkTokenCreateRequestDepositSwitch
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::LinkTokenCreateRequestDepositSwitch
- Defined in:
- lib/the_plaid_api/models/link_token_create_request_deposit_switch.rb
Overview
(Deprecated) Specifies options for initializing Link for use with the Deposit Switch (beta) product. This field is required if ‘deposit_switch` is included in the `products` array.
Instance Attribute Summary collapse
-
#deposit_switch_id ⇒ String
The ‘deposit_switch_id` provided by the `/deposit_switch/create` endpoint.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(deposit_switch_id:, additional_properties: nil) ⇒ LinkTokenCreateRequestDepositSwitch
constructor
A new instance of LinkTokenCreateRequestDepositSwitch.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(deposit_switch_id:, additional_properties: nil) ⇒ LinkTokenCreateRequestDepositSwitch
Returns a new instance of LinkTokenCreateRequestDepositSwitch.
35 36 37 38 39 40 41 |
# File 'lib/the_plaid_api/models/link_token_create_request_deposit_switch.rb', line 35 def initialize(deposit_switch_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @deposit_switch_id = deposit_switch_id @additional_properties = additional_properties end |
Instance Attribute Details
#deposit_switch_id ⇒ String
The ‘deposit_switch_id` provided by the `/deposit_switch/create` endpoint.
16 17 18 |
# File 'lib/the_plaid_api/models/link_token_create_request_deposit_switch.rb', line 16 def deposit_switch_id @deposit_switch_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/the_plaid_api/models/link_token_create_request_deposit_switch.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. deposit_switch_id = hash.key?('deposit_switch_id') ? hash['deposit_switch_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LinkTokenCreateRequestDepositSwitch.new(deposit_switch_id: deposit_switch_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
19 20 21 22 23 |
# File 'lib/the_plaid_api/models/link_token_create_request_deposit_switch.rb', line 19 def self.names @_hash = {} if @_hash.nil? @_hash['deposit_switch_id'] = 'deposit_switch_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/the_plaid_api/models/link_token_create_request_deposit_switch.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
26 27 28 |
# File 'lib/the_plaid_api/models/link_token_create_request_deposit_switch.rb', line 26 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
71 72 73 74 75 |
# File 'lib/the_plaid_api/models/link_token_create_request_deposit_switch.rb', line 71 def inspect class_name = self.class.name.split('::').last "<#{class_name} deposit_switch_id: #{@deposit_switch_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
64 65 66 67 68 |
# File 'lib/the_plaid_api/models/link_token_create_request_deposit_switch.rb', line 64 def to_s class_name = self.class.name.split('::').last "<#{class_name} deposit_switch_id: #{@deposit_switch_id}, additional_properties:"\ " #{@additional_properties}>" end |