Class: ThePlaidApi::LinkTokenCreateRequestPaymentConfiguration
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::LinkTokenCreateRequestPaymentConfiguration
- Defined in:
- lib/the_plaid_api/models/link_token_create_request_payment_configuration.rb
Overview
Specifies options for initializing Link for use with the Pay By Bank flow. This is an optional field to configure the user experience, and currently requires the amount field to be set.
Instance Attribute Summary collapse
-
#amount ⇒ String
The amount of the transfer (decimal string with two digits of precision e.g. “10.00”).
-
#description ⇒ String
The description of the transfer that provides the payment context.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(amount:, description: SKIP, additional_properties: nil) ⇒ LinkTokenCreateRequestPaymentConfiguration
constructor
A new instance of LinkTokenCreateRequestPaymentConfiguration.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(amount:, description: SKIP, additional_properties: nil) ⇒ LinkTokenCreateRequestPaymentConfiguration
Returns a new instance of LinkTokenCreateRequestPaymentConfiguration.
44 45 46 47 48 49 50 51 |
# File 'lib/the_plaid_api/models/link_token_create_request_payment_configuration.rb', line 44 def initialize(amount:, description: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @amount = amount @description = description unless description == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#amount ⇒ String
The amount of the transfer (decimal string with two digits of precision e.g. “10.00”).
17 18 19 |
# File 'lib/the_plaid_api/models/link_token_create_request_payment_configuration.rb', line 17 def amount @amount end |
#description ⇒ String
The description of the transfer that provides the payment context. The max length is 256.
22 23 24 |
# File 'lib/the_plaid_api/models/link_token_create_request_payment_configuration.rb', line 22 def description @description end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/the_plaid_api/models/link_token_create_request_payment_configuration.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. amount = hash.key?('amount') ? hash['amount'] : nil description = hash.key?('description') ? hash['description'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LinkTokenCreateRequestPaymentConfiguration.new(amount: amount, description: description, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 |
# File 'lib/the_plaid_api/models/link_token_create_request_payment_configuration.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['amount'] = 'amount' @_hash['description'] = 'description' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/the_plaid_api/models/link_token_create_request_payment_configuration.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
33 34 35 36 37 |
# File 'lib/the_plaid_api/models/link_token_create_request_payment_configuration.rb', line 33 def self.optionals %w[ description ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/the_plaid_api/models/link_token_create_request_payment_configuration.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} amount: #{@amount.inspect}, description: #{@description.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/the_plaid_api/models/link_token_create_request_payment_configuration.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} amount: #{@amount}, description: #{@description}, additional_properties:"\ " #{@additional_properties}>" end |