Class: ThePlaidApi::LinkTokenCreateRequestTransfer
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::LinkTokenCreateRequestTransfer
- Defined in:
- lib/the_plaid_api/models/link_token_create_request_transfer.rb
Overview
Specifies options for initializing Link for use with the Transfer product.
Instance Attribute Summary collapse
-
#authorization_id ⇒ String
The ‘id` returned by the `/transfer/authorization/create` endpoint.
-
#intent_id ⇒ String
The ‘id` returned by the `/transfer/intent/create` endpoint.
-
#payment_profile_token ⇒ String
The ‘payment_profile_token` returned by the `/payment_profile/create` endpoint.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(intent_id: SKIP, authorization_id: SKIP, payment_profile_token: SKIP, additional_properties: nil) ⇒ LinkTokenCreateRequestTransfer
constructor
A new instance of LinkTokenCreateRequestTransfer.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(intent_id: SKIP, authorization_id: SKIP, payment_profile_token: SKIP, additional_properties: nil) ⇒ LinkTokenCreateRequestTransfer
Returns a new instance of LinkTokenCreateRequestTransfer.
50 51 52 53 54 55 56 57 58 59 |
# File 'lib/the_plaid_api/models/link_token_create_request_transfer.rb', line 50 def initialize(intent_id: SKIP, authorization_id: SKIP, payment_profile_token: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @intent_id = intent_id unless intent_id == SKIP @authorization_id = unless == SKIP @payment_profile_token = payment_profile_token unless payment_profile_token == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#authorization_id ⇒ String
The ‘id` returned by the `/transfer/authorization/create` endpoint. Used to indicate Link session to complete required user action in order to make a decision for the authorization. If set, `access_token` can be omitted.
20 21 22 |
# File 'lib/the_plaid_api/models/link_token_create_request_transfer.rb', line 20 def @authorization_id end |
#intent_id ⇒ String
The ‘id` returned by the `/transfer/intent/create` endpoint.
14 15 16 |
# File 'lib/the_plaid_api/models/link_token_create_request_transfer.rb', line 14 def intent_id @intent_id end |
#payment_profile_token ⇒ String
The ‘payment_profile_token` returned by the `/payment_profile/create` endpoint.
25 26 27 |
# File 'lib/the_plaid_api/models/link_token_create_request_transfer.rb', line 25 def payment_profile_token @payment_profile_token end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/the_plaid_api/models/link_token_create_request_transfer.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. intent_id = hash.key?('intent_id') ? hash['intent_id'] : SKIP = hash.key?('authorization_id') ? hash['authorization_id'] : SKIP payment_profile_token = hash.key?('payment_profile_token') ? hash['payment_profile_token'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LinkTokenCreateRequestTransfer.new(intent_id: intent_id, authorization_id: , payment_profile_token: payment_profile_token, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
28 29 30 31 32 33 34 |
# File 'lib/the_plaid_api/models/link_token_create_request_transfer.rb', line 28 def self.names @_hash = {} if @_hash.nil? @_hash['intent_id'] = 'intent_id' @_hash['authorization_id'] = 'authorization_id' @_hash['payment_profile_token'] = 'payment_profile_token' @_hash end |
.nullables ⇒ Object
An array for nullable fields
46 47 48 |
# File 'lib/the_plaid_api/models/link_token_create_request_transfer.rb', line 46 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
37 38 39 40 41 42 43 |
# File 'lib/the_plaid_api/models/link_token_create_request_transfer.rb', line 37 def self.optionals %w[ intent_id authorization_id payment_profile_token ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
95 96 97 98 99 100 |
# File 'lib/the_plaid_api/models/link_token_create_request_transfer.rb', line 95 def inspect class_name = self.class.name.split('::').last "<#{class_name} intent_id: #{@intent_id.inspect}, authorization_id:"\ " #{@authorization_id.inspect}, payment_profile_token: #{@payment_profile_token.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
87 88 89 90 91 92 |
# File 'lib/the_plaid_api/models/link_token_create_request_transfer.rb', line 87 def to_s class_name = self.class.name.split('::').last "<#{class_name} intent_id: #{@intent_id}, authorization_id: #{@authorization_id},"\ " payment_profile_token: #{@payment_profile_token}, additional_properties:"\ " #{@additional_properties}>" end |