Class: ThePlaidApi::LinkTokenInvestmentsAuth
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::LinkTokenInvestmentsAuth
- Defined in:
- lib/the_plaid_api/models/link_token_investments_auth.rb
Overview
Configuration parameters for the Investments Move product
Instance Attribute Summary collapse
-
#manual_entry_enabled ⇒ TrueClass | FalseClass
If ‘true`, show institutions that use the manual entry fallback flow.
-
#masked_number_match_enabled ⇒ TrueClass | FalseClass
If ‘true`, show institutions that use the masked number match fallback flow.
-
#rollover_401k_enabled ⇒ TrueClass | FalseClass
If ‘true`, the fee and contribution details for 401k accounts will be returned.
-
#stated_account_number_enabled ⇒ TrueClass | FalseClass
If ‘true`, show institutions that use the stated account number fallback flow.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(manual_entry_enabled: false, masked_number_match_enabled: false, stated_account_number_enabled: false, rollover_401k_enabled: false, additional_properties: nil) ⇒ LinkTokenInvestmentsAuth
constructor
A new instance of LinkTokenInvestmentsAuth.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(manual_entry_enabled: false, masked_number_match_enabled: false, stated_account_number_enabled: false, rollover_401k_enabled: false, additional_properties: nil) ⇒ LinkTokenInvestmentsAuth
Returns a new instance of LinkTokenInvestmentsAuth.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/the_plaid_api/models/link_token_investments_auth.rb', line 62 def initialize(manual_entry_enabled: false, masked_number_match_enabled: false, stated_account_number_enabled: false, rollover_401k_enabled: false, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @manual_entry_enabled = manual_entry_enabled unless manual_entry_enabled == SKIP unless masked_number_match_enabled == SKIP @masked_number_match_enabled = masked_number_match_enabled end unless stated_account_number_enabled == SKIP @stated_account_number_enabled = stated_account_number_enabled end @rollover_401k_enabled = rollover_401k_enabled unless rollover_401k_enabled == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#manual_entry_enabled ⇒ TrueClass | FalseClass
If ‘true`, show institutions that use the manual entry fallback flow.
14 15 16 |
# File 'lib/the_plaid_api/models/link_token_investments_auth.rb', line 14 def manual_entry_enabled @manual_entry_enabled end |
#masked_number_match_enabled ⇒ TrueClass | FalseClass
If ‘true`, show institutions that use the masked number match fallback flow.
19 20 21 |
# File 'lib/the_plaid_api/models/link_token_investments_auth.rb', line 19 def masked_number_match_enabled @masked_number_match_enabled end |
#rollover_401k_enabled ⇒ TrueClass | FalseClass
If ‘true`, the fee and contribution details for 401k accounts will be returned.
29 30 31 |
# File 'lib/the_plaid_api/models/link_token_investments_auth.rb', line 29 def rollover_401k_enabled @rollover_401k_enabled end |
#stated_account_number_enabled ⇒ TrueClass | FalseClass
If ‘true`, show institutions that use the stated account number fallback flow.
24 25 26 |
# File 'lib/the_plaid_api/models/link_token_investments_auth.rb', line 24 def stated_account_number_enabled @stated_account_number_enabled end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/the_plaid_api/models/link_token_investments_auth.rb', line 83 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. manual_entry_enabled = hash['manual_entry_enabled'] ||= false masked_number_match_enabled = hash['masked_number_match_enabled'] ||= false stated_account_number_enabled = hash['stated_account_number_enabled'] ||= false rollover_401k_enabled = hash['rollover_401k_enabled'] ||= false # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LinkTokenInvestmentsAuth.new(manual_entry_enabled: manual_entry_enabled, masked_number_match_enabled: masked_number_match_enabled, stated_account_number_enabled: stated_account_number_enabled, rollover_401k_enabled: rollover_401k_enabled, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
32 33 34 35 36 37 38 39 40 |
# File 'lib/the_plaid_api/models/link_token_investments_auth.rb', line 32 def self.names @_hash = {} if @_hash.nil? @_hash['manual_entry_enabled'] = 'manual_entry_enabled' @_hash['masked_number_match_enabled'] = 'masked_number_match_enabled' @_hash['stated_account_number_enabled'] = 'stated_account_number_enabled' @_hash['rollover_401k_enabled'] = 'rollover_401k_enabled' @_hash end |
.nullables ⇒ Object
An array for nullable fields
53 54 55 56 57 58 59 60 |
# File 'lib/the_plaid_api/models/link_token_investments_auth.rb', line 53 def self.nullables %w[ manual_entry_enabled masked_number_match_enabled stated_account_number_enabled rollover_401k_enabled ] end |
.optionals ⇒ Object
An array for optional fields
43 44 45 46 47 48 49 50 |
# File 'lib/the_plaid_api/models/link_token_investments_auth.rb', line 43 def self.optionals %w[ manual_entry_enabled masked_number_match_enabled stated_account_number_enabled rollover_401k_enabled ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
119 120 121 122 123 124 125 126 |
# File 'lib/the_plaid_api/models/link_token_investments_auth.rb', line 119 def inspect class_name = self.class.name.split('::').last "<#{class_name} manual_entry_enabled: #{@manual_entry_enabled.inspect},"\ " masked_number_match_enabled: #{@masked_number_match_enabled.inspect},"\ " stated_account_number_enabled: #{@stated_account_number_enabled.inspect},"\ " rollover_401k_enabled: #{@rollover_401k_enabled.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
110 111 112 113 114 115 116 |
# File 'lib/the_plaid_api/models/link_token_investments_auth.rb', line 110 def to_s class_name = self.class.name.split('::').last "<#{class_name} manual_entry_enabled: #{@manual_entry_enabled},"\ " masked_number_match_enabled: #{@masked_number_match_enabled},"\ " stated_account_number_enabled: #{@stated_account_number_enabled}, rollover_401k_enabled:"\ " #{@rollover_401k_enabled}, additional_properties: #{@additional_properties}>" end |