Class: ThePlaidApi::LinkTokenTransactions
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::LinkTokenTransactions
- Defined in:
- lib/the_plaid_api/models/link_token_transactions.rb
Overview
Configuration parameters for the Transactions product
Instance Attribute Summary collapse
-
#days_requested ⇒ Integer
The maximum number of days of transaction history to request for the Transactions product.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(days_requested: 90, additional_properties: nil) ⇒ LinkTokenTransactions
constructor
A new instance of LinkTokenTransactions.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(days_requested: 90, additional_properties: nil) ⇒ LinkTokenTransactions
Returns a new instance of LinkTokenTransactions.
44 45 46 47 48 49 50 |
# File 'lib/the_plaid_api/models/link_token_transactions.rb', line 44 def initialize(days_requested: 90, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @days_requested = days_requested unless days_requested == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#days_requested ⇒ Integer
The maximum number of days of transaction history to request for the Transactions product. The more transaction history is requested, the longer the historical update poll will take. The default value is 90 days. In Production, if a value under 30 is provided, a minimum of 30 days of history will be requested. Once Transactions has been added to an Item, this value cannot be updated. Customers using [Recurring Transactions](plaid.com/docs/api/products/transactions/#transactio nsrecurringget) should request at least 180 days of history for optimal results.
23 24 25 |
# File 'lib/the_plaid_api/models/link_token_transactions.rb', line 23 def days_requested @days_requested end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/the_plaid_api/models/link_token_transactions.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. days_requested = hash['days_requested'] ||= 90 # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LinkTokenTransactions.new(days_requested: days_requested, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 |
# File 'lib/the_plaid_api/models/link_token_transactions.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['days_requested'] = 'days_requested' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/the_plaid_api/models/link_token_transactions.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
33 34 35 36 37 |
# File 'lib/the_plaid_api/models/link_token_transactions.rb', line 33 def self.optionals %w[ days_requested ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/the_plaid_api/models/link_token_transactions.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} days_requested: #{@days_requested.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/the_plaid_api/models/link_token_transactions.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} days_requested: #{@days_requested}, additional_properties:"\ " #{@additional_properties}>" end |