Class: ThePlaidApi::LinkUserDeliveryStatusWebhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::LinkUserDeliveryStatusWebhook
- Defined in:
- lib/the_plaid_api/models/link_user_delivery_status_webhook.rb
Overview
Webhook indicating that the status of the delivery of the Hosted Link session to a user
Instance Attribute Summary collapse
-
#link_delivery_metadata ⇒ LinkDeliveryMetadata
Information related to the related to the delivery of the link session to users.
-
#link_delivery_session_id ⇒ String
The ID of the Hosted Link session.
-
#timestamp ⇒ String
Timestamp in [ISO 8601](wikipedia.org/wiki/ISO_8601) format.
-
#webhook_code ⇒ String
‘DELIVERY_STATUS`.
-
#webhook_type ⇒ String
‘LINK_DELIVERY`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, link_delivery_session_id:, timestamp:, link_delivery_metadata:, additional_properties: nil) ⇒ LinkUserDeliveryStatusWebhook
constructor
A new instance of LinkUserDeliveryStatusWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, link_delivery_session_id:, timestamp:, link_delivery_metadata:, additional_properties: nil) ⇒ LinkUserDeliveryStatusWebhook
Returns a new instance of LinkUserDeliveryStatusWebhook.
55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/the_plaid_api/models/link_user_delivery_status_webhook.rb', line 55 def initialize(webhook_type:, webhook_code:, link_delivery_session_id:, timestamp:, link_delivery_metadata:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @link_delivery_session_id = link_delivery_session_id @timestamp = @link_delivery_metadata = @additional_properties = additional_properties end |
Instance Attribute Details
#link_delivery_metadata ⇒ LinkDeliveryMetadata
Information related to the related to the delivery of the link session to users
32 33 34 |
# File 'lib/the_plaid_api/models/link_user_delivery_status_webhook.rb', line 32 def @link_delivery_metadata end |
#link_delivery_session_id ⇒ String
The ID of the Hosted Link session.
23 24 25 |
# File 'lib/the_plaid_api/models/link_user_delivery_status_webhook.rb', line 23 def link_delivery_session_id @link_delivery_session_id end |
#timestamp ⇒ String
Timestamp in [ISO 8601](wikipedia.org/wiki/ISO_8601) format.
27 28 29 |
# File 'lib/the_plaid_api/models/link_user_delivery_status_webhook.rb', line 27 def @timestamp end |
#webhook_code ⇒ String
‘DELIVERY_STATUS`
19 20 21 |
# File 'lib/the_plaid_api/models/link_user_delivery_status_webhook.rb', line 19 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘LINK_DELIVERY`
15 16 17 |
# File 'lib/the_plaid_api/models/link_user_delivery_status_webhook.rb', line 15 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/the_plaid_api/models/link_user_delivery_status_webhook.rb', line 70 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil link_delivery_session_id = hash.key?('link_delivery_session_id') ? hash['link_delivery_session_id'] : nil = hash.key?('timestamp') ? hash['timestamp'] : nil = LinkDeliveryMetadata.from_hash(hash['link_delivery_metadata']) if hash['link_delivery_metadata'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LinkUserDeliveryStatusWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, link_delivery_session_id: link_delivery_session_id, timestamp: , link_delivery_metadata: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
35 36 37 38 39 40 41 42 43 |
# File 'lib/the_plaid_api/models/link_user_delivery_status_webhook.rb', line 35 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['link_delivery_session_id'] = 'link_delivery_session_id' @_hash['timestamp'] = 'timestamp' @_hash['link_delivery_metadata'] = 'link_delivery_metadata' @_hash end |
.nullables ⇒ Object
An array for nullable fields
51 52 53 |
# File 'lib/the_plaid_api/models/link_user_delivery_status_webhook.rb', line 51 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
46 47 48 |
# File 'lib/the_plaid_api/models/link_user_delivery_status_webhook.rb', line 46 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
108 109 110 111 112 113 114 |
# File 'lib/the_plaid_api/models/link_user_delivery_status_webhook.rb', line 108 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, link_delivery_session_id: #{@link_delivery_session_id.inspect},"\ " timestamp: #{@timestamp.inspect}, link_delivery_metadata:"\ " #{@link_delivery_metadata.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
99 100 101 102 103 104 105 |
# File 'lib/the_plaid_api/models/link_user_delivery_status_webhook.rb', line 99 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code},"\ " link_delivery_session_id: #{@link_delivery_session_id}, timestamp: #{@timestamp},"\ " link_delivery_metadata: #{@link_delivery_metadata}, additional_properties:"\ " #{@additional_properties}>" end |