Class: ThePlaidApi::Loan
- Defined in:
- lib/the_plaid_api/models/loan.rb
Overview
Information specific to a mortgage loan agreement between one or more borrowers and a mortgage lender.
Instance Attribute Summary collapse
-
#loan_identifiers ⇒ LoanIdentifiers
Collection of current and previous identifiers for this loan.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(loan_identifiers:, additional_properties: nil) ⇒ Loan
constructor
A new instance of Loan.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(loan_identifiers:, additional_properties: nil) ⇒ Loan
Returns a new instance of Loan.
34 35 36 37 38 39 40 |
# File 'lib/the_plaid_api/models/loan.rb', line 34 def initialize(loan_identifiers:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @loan_identifiers = loan_identifiers @additional_properties = additional_properties end |
Instance Attribute Details
#loan_identifiers ⇒ LoanIdentifiers
Collection of current and previous identifiers for this loan.
15 16 17 |
# File 'lib/the_plaid_api/models/loan.rb', line 15 def loan_identifiers @loan_identifiers end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/the_plaid_api/models/loan.rb', line 43 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. loan_identifiers = LoanIdentifiers.from_hash(hash['LOAN_IDENTIFIERS']) if hash['LOAN_IDENTIFIERS'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Loan.new(loan_identifiers: loan_identifiers, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/the_plaid_api/models/loan.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['loan_identifiers'] = 'LOAN_IDENTIFIERS' @_hash end |
.nullables ⇒ Object
An array for nullable fields
30 31 32 |
# File 'lib/the_plaid_api/models/loan.rb', line 30 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 |
# File 'lib/the_plaid_api/models/loan.rb', line 25 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
70 71 72 73 74 |
# File 'lib/the_plaid_api/models/loan.rb', line 70 def inspect class_name = self.class.name.split('::').last "<#{class_name} loan_identifiers: #{@loan_identifiers.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
63 64 65 66 67 |
# File 'lib/the_plaid_api/models/loan.rb', line 63 def to_s class_name = self.class.name.split('::').last "<#{class_name} loan_identifiers: #{@loan_identifiers}, additional_properties:"\ " #{@additional_properties}>" end |