Class: ThePlaidApi::MonthlySummary
- Defined in:
- lib/the_plaid_api/models/monthly_summary.rb
Overview
Monthly summary of transactions within a specific time period, showing aggregated amounts.
Instance Attribute Summary collapse
-
#end_date ⇒ Date
The end date of the month for the given report time window.
-
#start_date ⇒ Date
The start date of the month for the given report time window.
-
#total_amount ⇒ AmountWithCurrency
A monetary amount with its associated currency information, supporting both official and unofficial currency codes.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(start_date: SKIP, end_date: SKIP, total_amount: SKIP, additional_properties: nil) ⇒ MonthlySummary
constructor
A new instance of MonthlySummary.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(start_date: SKIP, end_date: SKIP, total_amount: SKIP, additional_properties: nil) ⇒ MonthlySummary
Returns a new instance of MonthlySummary.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/the_plaid_api/models/monthly_summary.rb', line 57 def initialize(start_date: SKIP, end_date: SKIP, total_amount: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @start_date = start_date unless start_date == SKIP @end_date = end_date unless end_date == SKIP @total_amount = total_amount unless total_amount == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#end_date ⇒ Date
The end date of the month for the given report time window. Will be provided in [ISO 8601](wikipedia.org/wiki/ISO_8601) format (YYYY-MM-DD).
23 24 25 |
# File 'lib/the_plaid_api/models/monthly_summary.rb', line 23 def end_date @end_date end |
#start_date ⇒ Date
The start date of the month for the given report time window. Will be provided in [ISO 8601](wikipedia.org/wiki/ISO_8601) format (YYYY-MM-DD).
17 18 19 |
# File 'lib/the_plaid_api/models/monthly_summary.rb', line 17 def start_date @start_date end |
#total_amount ⇒ AmountWithCurrency
A monetary amount with its associated currency information, supporting both official and unofficial currency codes.
28 29 30 |
# File 'lib/the_plaid_api/models/monthly_summary.rb', line 28 def total_amount @total_amount end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/the_plaid_api/models/monthly_summary.rb', line 69 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. start_date = hash.key?('start_date') ? hash['start_date'] : SKIP end_date = hash.key?('end_date') ? hash['end_date'] : SKIP total_amount = AmountWithCurrency.from_hash(hash['total_amount']) if hash['total_amount'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. MonthlySummary.new(start_date: start_date, end_date: end_date, total_amount: total_amount, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
31 32 33 34 35 36 37 |
# File 'lib/the_plaid_api/models/monthly_summary.rb', line 31 def self.names @_hash = {} if @_hash.nil? @_hash['start_date'] = 'start_date' @_hash['end_date'] = 'end_date' @_hash['total_amount'] = 'total_amount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 52 53 54 55 |
# File 'lib/the_plaid_api/models/monthly_summary.rb', line 49 def self.nullables %w[ start_date end_date total_amount ] end |
.optionals ⇒ Object
An array for optional fields
40 41 42 43 44 45 46 |
# File 'lib/the_plaid_api/models/monthly_summary.rb', line 40 def self.optionals %w[ start_date end_date total_amount ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 |
# File 'lib/the_plaid_api/models/monthly_summary.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} start_date: #{@start_date.inspect}, end_date: #{@end_date.inspect},"\ " total_amount: #{@total_amount.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 |
# File 'lib/the_plaid_api/models/monthly_summary.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} start_date: #{@start_date}, end_date: #{@end_date}, total_amount:"\ " #{@total_amount}, additional_properties: #{@additional_properties}>" end |