Class: ThePlaidApi::Name2
- Defined in:
- lib/the_plaid_api/models/name2.rb
Overview
Documentation not found in the MISMO model viewer and not provided by Freddie Mac.
Instance Attribute Summary collapse
-
#full_name ⇒ String
The unparsed name of either an individual or a legal entity.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(full_name:, additional_properties: nil) ⇒ Name2
constructor
A new instance of Name2.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(full_name:, additional_properties: nil) ⇒ Name2
Returns a new instance of Name2.
34 35 36 37 38 39 40 |
# File 'lib/the_plaid_api/models/name2.rb', line 34 def initialize(full_name:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @full_name = full_name @additional_properties = additional_properties end |
Instance Attribute Details
#full_name ⇒ String
The unparsed name of either an individual or a legal entity.
15 16 17 |
# File 'lib/the_plaid_api/models/name2.rb', line 15 def full_name @full_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/the_plaid_api/models/name2.rb', line 43 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. full_name = hash.key?('FullName') ? hash['FullName'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Name2.new(full_name: full_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/the_plaid_api/models/name2.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['full_name'] = 'FullName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
30 31 32 |
# File 'lib/the_plaid_api/models/name2.rb', line 30 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 |
# File 'lib/the_plaid_api/models/name2.rb', line 25 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
69 70 71 72 73 |
# File 'lib/the_plaid_api/models/name2.rb', line 69 def inspect class_name = self.class.name.split('::').last "<#{class_name} full_name: #{@full_name.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
62 63 64 65 66 |
# File 'lib/the_plaid_api/models/name2.rb', line 62 def to_s class_name = self.class.name.split('::').last "<#{class_name} full_name: #{@full_name}, additional_properties:"\ " #{@additional_properties}>" end |