Class: ThePlaidApi::NetworkStatusGetResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::NetworkStatusGetResponse
- Defined in:
- lib/the_plaid_api/models/network_status_get_response.rb
Overview
NetworkStatusGetResponse defines the response schema for ‘/network/status/get`
Instance Attribute Summary collapse
-
#layer ⇒ NetworkStatusGetResponseLayer
An object representing Layer-related metadata for the requested user.
-
#network_status ⇒ NetworkStatusGetResponseNetworkStatus
Enum representing the overall network status of the user.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(network_status:, request_id:, layer: SKIP, additional_properties: nil) ⇒ NetworkStatusGetResponse
constructor
A new instance of NetworkStatusGetResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(network_status:, request_id:, layer: SKIP, additional_properties: nil) ⇒ NetworkStatusGetResponse
Returns a new instance of NetworkStatusGetResponse.
50 51 52 53 54 55 56 57 58 59 |
# File 'lib/the_plaid_api/models/network_status_get_response.rb', line 50 def initialize(network_status:, request_id:, layer: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @network_status = network_status @layer = layer unless layer == SKIP @request_id = request_id @additional_properties = additional_properties end |
Instance Attribute Details
#layer ⇒ NetworkStatusGetResponseLayer
An object representing Layer-related metadata for the requested user.
19 20 21 |
# File 'lib/the_plaid_api/models/network_status_get_response.rb', line 19 def layer @layer end |
#network_status ⇒ NetworkStatusGetResponseNetworkStatus
Enum representing the overall network status of the user.
15 16 17 |
# File 'lib/the_plaid_api/models/network_status_get_response.rb', line 15 def network_status @network_status end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
25 26 27 |
# File 'lib/the_plaid_api/models/network_status_get_response.rb', line 25 def request_id @request_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/the_plaid_api/models/network_status_get_response.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. network_status = hash.key?('network_status') ? hash['network_status'] : nil request_id = hash.key?('request_id') ? hash['request_id'] : nil layer = NetworkStatusGetResponseLayer.from_hash(hash['layer']) if hash['layer'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. NetworkStatusGetResponse.new(network_status: network_status, request_id: request_id, layer: layer, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
28 29 30 31 32 33 34 |
# File 'lib/the_plaid_api/models/network_status_get_response.rb', line 28 def self.names @_hash = {} if @_hash.nil? @_hash['network_status'] = 'network_status' @_hash['layer'] = 'layer' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 47 48 |
# File 'lib/the_plaid_api/models/network_status_get_response.rb', line 44 def self.nullables %w[ layer ] end |
.optionals ⇒ Object
An array for optional fields
37 38 39 40 41 |
# File 'lib/the_plaid_api/models/network_status_get_response.rb', line 37 def self.optionals %w[ layer ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 |
# File 'lib/the_plaid_api/models/network_status_get_response.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} network_status: #{@network_status.inspect}, layer: #{@layer.inspect},"\ " request_id: #{@request_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 |
# File 'lib/the_plaid_api/models/network_status_get_response.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} network_status: #{@network_status}, layer: #{@layer}, request_id:"\ " #{@request_id}, additional_properties: #{@additional_properties}>" end |