Class: ThePlaidApi::NotificationPayloadEntity
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::NotificationPayloadEntity
- Defined in:
- lib/the_plaid_api/models/notification_payload_entity.rb
Overview
Custom key-value pairs payload for a notification
Instance Attribute Summary collapse
-
#event ⇒ FdxLifecycleEventEntity
Details of consent or payment network identifier or other entity’s revocation request or other lifecycle status change event.
-
#id ⇒ String
ID for the origination entity related to the notification.
-
#id_type ⇒ NotificationPayloadIdType
Type of entity causing origination of a notification.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id: SKIP, id_type: SKIP, event: SKIP, additional_properties: nil) ⇒ NotificationPayloadEntity
constructor
A new instance of NotificationPayloadEntity.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id: SKIP, id_type: SKIP, event: SKIP, additional_properties: nil) ⇒ NotificationPayloadEntity
Returns a new instance of NotificationPayloadEntity.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/the_plaid_api/models/notification_payload_entity.rb', line 48 def initialize(id: SKIP, id_type: SKIP, event: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id unless id == SKIP @id_type = id_type unless id_type == SKIP @event = event unless event == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#event ⇒ FdxLifecycleEventEntity
Details of consent or payment network identifier or other entity’s revocation request or other lifecycle status change event
23 24 25 |
# File 'lib/the_plaid_api/models/notification_payload_entity.rb', line 23 def event @event end |
#id ⇒ String
ID for the origination entity related to the notification
14 15 16 |
# File 'lib/the_plaid_api/models/notification_payload_entity.rb', line 14 def id @id end |
#id_type ⇒ NotificationPayloadIdType
Type of entity causing origination of a notification
18 19 20 |
# File 'lib/the_plaid_api/models/notification_payload_entity.rb', line 18 def id_type @id_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/the_plaid_api/models/notification_payload_entity.rb', line 60 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : SKIP id_type = hash.key?('idType') ? hash['idType'] : SKIP event = FdxLifecycleEventEntity.from_hash(hash['event']) if hash['event'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. NotificationPayloadEntity.new(id: id, id_type: id_type, event: event, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/the_plaid_api/models/notification_payload_entity.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['id_type'] = 'idType' @_hash['event'] = 'event' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/the_plaid_api/models/notification_payload_entity.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 40 41 |
# File 'lib/the_plaid_api/models/notification_payload_entity.rb', line 35 def self.optionals %w[ id id_type event ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
90 91 92 93 94 |
# File 'lib/the_plaid_api/models/notification_payload_entity.rb', line 90 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, id_type: #{@id_type.inspect}, event: #{@event.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 87 |
# File 'lib/the_plaid_api/models/notification_payload_entity.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, id_type: #{@id_type}, event: #{@event}, additional_properties:"\ " #{@additional_properties}>" end |