Class: ThePlaidApi::NumbersAcats
- Defined in:
- lib/the_plaid_api/models/numbers_acats.rb
Overview
Identifying information for transferring holdings to an investments account via ACATS.
Instance Attribute Summary collapse
-
#account ⇒ String
The full account number for the account.
-
#account_id ⇒ String
The Plaid account ID associated with the account numbers.
-
#dtc_numbers ⇒ Array[String]
Identifiers for the clearinghouses that are associated with the account in order of relevance.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_id:, account:, dtc_numbers:, additional_properties: nil) ⇒ NumbersAcats
constructor
A new instance of NumbersAcats.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_id:, account:, dtc_numbers:, additional_properties: nil) ⇒ NumbersAcats
Returns a new instance of NumbersAcats.
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/the_plaid_api/models/numbers_acats.rb', line 46 def initialize(account_id:, account:, dtc_numbers:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_id = account_id @account = account @dtc_numbers = dtc_numbers @additional_properties = additional_properties end |
Instance Attribute Details
#account ⇒ String
The full account number for the account
19 20 21 |
# File 'lib/the_plaid_api/models/numbers_acats.rb', line 19 def account @account end |
#account_id ⇒ String
The Plaid account ID associated with the account numbers
15 16 17 |
# File 'lib/the_plaid_api/models/numbers_acats.rb', line 15 def account_id @account_id end |
#dtc_numbers ⇒ Array[String]
Identifiers for the clearinghouses that are associated with the account in order of relevance. If this array is empty, call ‘/institutions/get_by_id` with the `item.institution_id` to get the DTC number.
25 26 27 |
# File 'lib/the_plaid_api/models/numbers_acats.rb', line 25 def dtc_numbers @dtc_numbers end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/the_plaid_api/models/numbers_acats.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_id = hash.key?('account_id') ? hash['account_id'] : nil account = hash.key?('account') ? hash['account'] : nil dtc_numbers = hash.key?('dtc_numbers') ? hash['dtc_numbers'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. NumbersAcats.new(account_id: account_id, account: account, dtc_numbers: dtc_numbers, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
28 29 30 31 32 33 34 |
# File 'lib/the_plaid_api/models/numbers_acats.rb', line 28 def self.names @_hash = {} if @_hash.nil? @_hash['account_id'] = 'account_id' @_hash['account'] = 'account' @_hash['dtc_numbers'] = 'dtc_numbers' @_hash end |
.nullables ⇒ Object
An array for nullable fields
42 43 44 |
# File 'lib/the_plaid_api/models/numbers_acats.rb', line 42 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
37 38 39 |
# File 'lib/the_plaid_api/models/numbers_acats.rb', line 37 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
88 89 90 91 92 |
# File 'lib/the_plaid_api/models/numbers_acats.rb', line 88 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_id: #{@account_id.inspect}, account: #{@account.inspect},"\ " dtc_numbers: #{@dtc_numbers.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
81 82 83 84 85 |
# File 'lib/the_plaid_api/models/numbers_acats.rb', line 81 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_id: #{@account_id}, account: #{@account}, dtc_numbers:"\ " #{@dtc_numbers}, additional_properties: #{@additional_properties}>" end |