Class: ThePlaidApi::Originator1
- Defined in:
- lib/the_plaid_api/models/originator1.rb
Overview
Originator and their status.
Instance Attribute Summary collapse
-
#client_id ⇒ String
Originator’s client ID.
-
#transfer_diligence_status ⇒ TransferDiligenceStatus
Originator’s diligence status.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_id:, transfer_diligence_status:, additional_properties: nil) ⇒ Originator1
constructor
A new instance of Originator1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_id:, transfer_diligence_status:, additional_properties: nil) ⇒ Originator1
Returns a new instance of Originator1.
38 39 40 41 42 43 44 45 46 |
# File 'lib/the_plaid_api/models/originator1.rb', line 38 def initialize(client_id:, transfer_diligence_status:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id @transfer_diligence_status = transfer_diligence_status @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Originator’s client ID.
14 15 16 |
# File 'lib/the_plaid_api/models/originator1.rb', line 14 def client_id @client_id end |
#transfer_diligence_status ⇒ TransferDiligenceStatus
Originator’s diligence status.
18 19 20 |
# File 'lib/the_plaid_api/models/originator1.rb', line 18 def transfer_diligence_status @transfer_diligence_status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/the_plaid_api/models/originator1.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_id = hash.key?('client_id') ? hash['client_id'] : nil transfer_diligence_status = hash.key?('transfer_diligence_status') ? hash['transfer_diligence_status'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Originator1.new(client_id: client_id, transfer_diligence_status: transfer_diligence_status, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/the_plaid_api/models/originator1.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['transfer_diligence_status'] = 'transfer_diligence_status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/the_plaid_api/models/originator1.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/the_plaid_api/models/originator1.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/the_plaid_api/models/originator1.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, transfer_diligence_status:"\ " #{@transfer_diligence_status.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/the_plaid_api/models/originator1.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, transfer_diligence_status:"\ " #{@transfer_diligence_status}, additional_properties: #{@additional_properties}>" end |