Class: ThePlaidApi::PartnerEndCustomerCraQuestionnaire
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::PartnerEndCustomerCraQuestionnaire
- Defined in:
- lib/the_plaid_api/models/partner_end_customer_cra_questionnaire.rb
Overview
The CRA questionnaire for the end customer.
Instance Attribute Summary collapse
-
#is_technical_service_provider_involved ⇒ TrueClass | FalseClass
Denotes whether the technical service provider is involved.
-
#is_third_party_involved ⇒ TrueClass | FalseClass
Denotes whether the third party is involved.
-
#purposes ⇒ PartnerEndCustomerCraPurposes
A map of permissible purposes to their corresponding use cases.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(purposes: SKIP, is_third_party_involved: SKIP, is_technical_service_provider_involved: SKIP, additional_properties: nil) ⇒ PartnerEndCustomerCraQuestionnaire
constructor
A new instance of PartnerEndCustomerCraQuestionnaire.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(purposes: SKIP, is_third_party_involved: SKIP, is_technical_service_provider_involved: SKIP, additional_properties: nil) ⇒ PartnerEndCustomerCraQuestionnaire
Returns a new instance of PartnerEndCustomerCraQuestionnaire.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/the_plaid_api/models/partner_end_customer_cra_questionnaire.rb', line 48 def initialize(purposes: SKIP, is_third_party_involved: SKIP, is_technical_service_provider_involved: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @purposes = purposes unless purposes == SKIP @is_third_party_involved = is_third_party_involved unless is_third_party_involved == SKIP unless is_technical_service_provider_involved == SKIP @is_technical_service_provider_involved = is_technical_service_provider_involved end @additional_properties = additional_properties end |
Instance Attribute Details
#is_technical_service_provider_involved ⇒ TrueClass | FalseClass
Denotes whether the technical service provider is involved.
22 23 24 |
# File 'lib/the_plaid_api/models/partner_end_customer_cra_questionnaire.rb', line 22 def is_technical_service_provider_involved @is_technical_service_provider_involved end |
#is_third_party_involved ⇒ TrueClass | FalseClass
Denotes whether the third party is involved.
18 19 20 |
# File 'lib/the_plaid_api/models/partner_end_customer_cra_questionnaire.rb', line 18 def is_third_party_involved @is_third_party_involved end |
#purposes ⇒ PartnerEndCustomerCraPurposes
A map of permissible purposes to their corresponding use cases.
14 15 16 |
# File 'lib/the_plaid_api/models/partner_end_customer_cra_questionnaire.rb', line 14 def purposes @purposes end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/the_plaid_api/models/partner_end_customer_cra_questionnaire.rb', line 64 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. purposes = PartnerEndCustomerCraPurposes.from_hash(hash['purposes']) if hash['purposes'] is_third_party_involved = hash.key?('is_third_party_involved') ? hash['is_third_party_involved'] : SKIP is_technical_service_provider_involved = hash.key?('is_technical_service_provider_involved') ? hash['is_technical_service_provider_involved'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PartnerEndCustomerCraQuestionnaire.new(purposes: purposes, is_third_party_involved: is_third_party_involved, is_technical_service_provider_involved: is_technical_service_provider_involved, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 32 |
# File 'lib/the_plaid_api/models/partner_end_customer_cra_questionnaire.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['purposes'] = 'purposes' @_hash['is_third_party_involved'] = 'is_third_party_involved' @_hash['is_technical_service_provider_involved'] = 'is_technical_service_provider_involved' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/the_plaid_api/models/partner_end_customer_cra_questionnaire.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 40 41 |
# File 'lib/the_plaid_api/models/partner_end_customer_cra_questionnaire.rb', line 35 def self.optionals %w[ purposes is_third_party_involved is_technical_service_provider_involved ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 103 104 |
# File 'lib/the_plaid_api/models/partner_end_customer_cra_questionnaire.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} purposes: #{@purposes.inspect}, is_third_party_involved:"\ " #{@is_third_party_involved.inspect}, is_technical_service_provider_involved:"\ " #{@is_technical_service_provider_involved.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
89 90 91 92 93 94 95 |
# File 'lib/the_plaid_api/models/partner_end_customer_cra_questionnaire.rb', line 89 def to_s class_name = self.class.name.split('::').last "<#{class_name} purposes: #{@purposes}, is_third_party_involved:"\ " #{@is_third_party_involved}, is_technical_service_provider_involved:"\ " #{@is_technical_service_provider_involved}, additional_properties:"\ " #{@additional_properties}>" end |