Class: ThePlaidApi::PartnerEndCustomerCustomerSupportInfo
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::PartnerEndCustomerCustomerSupportInfo
- Defined in:
- lib/the_plaid_api/models/partner_end_customer_customer_support_info.rb
Overview
This information is public. Users of your app will see this information when managing connections between your app and their bank accounts in Plaid Portal. Defaults to partner’s customer support info if omitted. This field is mandatory for partners whose Plaid accounts were created after November 26, 2024 and will be mandatory for all partners by the 1033 compliance deadline.
Instance Attribute Summary collapse
-
#contact_url ⇒ String
This field is mandatory for partners whose Plaid accounts were created after November 26, 2024 and will be mandatory for all partners by the 1033 compliance deadline.
-
#email ⇒ String
This field is mandatory for partners whose Plaid accounts were created after November 26, 2024 and will be mandatory for all partners by the 1033 compliance deadline.
-
#link_update_url ⇒ String
This field is mandatory for partners whose Plaid accounts were created after November 26, 2024 and will be mandatory for all partners by the 1033 compliance deadline.
-
#phone_number ⇒ String
This field is mandatory for partners whose Plaid accounts were created after November 26, 2024 and will be mandatory for all partners by the 1033 compliance deadline.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(email: SKIP, phone_number: SKIP, contact_url: SKIP, link_update_url: SKIP, additional_properties: nil) ⇒ PartnerEndCustomerCustomerSupportInfo
constructor
A new instance of PartnerEndCustomerCustomerSupportInfo.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(email: SKIP, phone_number: SKIP, contact_url: SKIP, link_update_url: SKIP, additional_properties: nil) ⇒ PartnerEndCustomerCustomerSupportInfo
Returns a new instance of PartnerEndCustomerCustomerSupportInfo.
66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/the_plaid_api/models/partner_end_customer_customer_support_info.rb', line 66 def initialize(email: SKIP, phone_number: SKIP, contact_url: SKIP, link_update_url: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @email = email unless email == SKIP @phone_number = phone_number unless phone_number == SKIP @contact_url = contact_url unless contact_url == SKIP @link_update_url = link_update_url unless link_update_url == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#contact_url ⇒ String
This field is mandatory for partners whose Plaid accounts were created after November 26, 2024 and will be mandatory for all partners by the 1033 compliance deadline.
33 34 35 |
# File 'lib/the_plaid_api/models/partner_end_customer_customer_support_info.rb', line 33 def contact_url @contact_url end |
#email ⇒ String
This field is mandatory for partners whose Plaid accounts were created after November 26, 2024 and will be mandatory for all partners by the 1033 compliance deadline.
21 22 23 |
# File 'lib/the_plaid_api/models/partner_end_customer_customer_support_info.rb', line 21 def email @email end |
#link_update_url ⇒ String
This field is mandatory for partners whose Plaid accounts were created after November 26, 2024 and will be mandatory for all partners by the 1033 compliance deadline.
39 40 41 |
# File 'lib/the_plaid_api/models/partner_end_customer_customer_support_info.rb', line 39 def link_update_url @link_update_url end |
#phone_number ⇒ String
This field is mandatory for partners whose Plaid accounts were created after November 26, 2024 and will be mandatory for all partners by the 1033 compliance deadline.
27 28 29 |
# File 'lib/the_plaid_api/models/partner_end_customer_customer_support_info.rb', line 27 def phone_number @phone_number end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/the_plaid_api/models/partner_end_customer_customer_support_info.rb', line 79 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. email = hash.key?('email') ? hash['email'] : SKIP phone_number = hash.key?('phone_number') ? hash['phone_number'] : SKIP contact_url = hash.key?('contact_url') ? hash['contact_url'] : SKIP link_update_url = hash.key?('link_update_url') ? hash['link_update_url'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PartnerEndCustomerCustomerSupportInfo.new(email: email, phone_number: phone_number, contact_url: contact_url, link_update_url: link_update_url, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
42 43 44 45 46 47 48 49 |
# File 'lib/the_plaid_api/models/partner_end_customer_customer_support_info.rb', line 42 def self.names @_hash = {} if @_hash.nil? @_hash['email'] = 'email' @_hash['phone_number'] = 'phone_number' @_hash['contact_url'] = 'contact_url' @_hash['link_update_url'] = 'link_update_url' @_hash end |
.nullables ⇒ Object
An array for nullable fields
62 63 64 |
# File 'lib/the_plaid_api/models/partner_end_customer_customer_support_info.rb', line 62 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
52 53 54 55 56 57 58 59 |
# File 'lib/the_plaid_api/models/partner_end_customer_customer_support_info.rb', line 52 def self.optionals %w[ email phone_number contact_url link_update_url ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
113 114 115 116 117 118 |
# File 'lib/the_plaid_api/models/partner_end_customer_customer_support_info.rb', line 113 def inspect class_name = self.class.name.split('::').last "<#{class_name} email: #{@email.inspect}, phone_number: #{@phone_number.inspect},"\ " contact_url: #{@contact_url.inspect}, link_update_url: #{@link_update_url.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
105 106 107 108 109 110 |
# File 'lib/the_plaid_api/models/partner_end_customer_customer_support_info.rb', line 105 def to_s class_name = self.class.name.split('::').last "<#{class_name} email: #{@email}, phone_number: #{@phone_number}, contact_url:"\ " #{@contact_url}, link_update_url: #{@link_update_url}, additional_properties:"\ " #{@additional_properties}>" end |