Class: ThePlaidApi::PartyRoleType
- Inherits:
-
Object
- Object
- ThePlaidApi::PartyRoleType
- Defined in:
- lib/the_plaid_api/models/party_role_type.rb
Overview
A value from a MISMO defined list that identifies the role that the party plays in the transaction. Parties may be either a person or legal entity. A party may play multiple roles in a transaction.A value from a MISMO defined list that identifies the role that the party plays in the transaction. Parties may be either a person or legal entity. A party may play multiple roles in a transaction.
Constant Summary collapse
- PARTY_ROLE_TYPE =
[ # TODO: Write general description for BORROWER BORROWER = 'Borrower'.freeze ].freeze
Class Method Summary collapse
Class Method Details
.from_value(value, default_value = BORROWER) ⇒ Object
25 26 27 28 29 |
# File 'lib/the_plaid_api/models/party_role_type.rb', line 25 def self.from_value(value, default_value = BORROWER) return default_value if value.nil? default_value end |
.validate(value) ⇒ Object
19 20 21 22 23 |
# File 'lib/the_plaid_api/models/party_role_type.rb', line 19 def self.validate(value) return false if value.nil? PARTY_ROLE_TYPE.include?(value) end |