Class: ThePlaidApi::PaymentInitiationPaymentListRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::PaymentInitiationPaymentListRequest
- Defined in:
- lib/the_plaid_api/models/payment_initiation_payment_list_request.rb
Overview
PaymentInitiationPaymentListRequest defines the request schema for ‘/payment_initiation/payment/list`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#consent_id ⇒ String
The consent ID.
-
#count ⇒ Integer
The maximum number of payments to return.
-
#cursor ⇒ DateTime
A string in RFC 3339 format (i.e. “2019-12-06T22:35:49Z”).
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_id: SKIP, secret: SKIP, count: 10, cursor: SKIP, consent_id: SKIP, additional_properties: nil) ⇒ PaymentInitiationPaymentListRequest
constructor
A new instance of PaymentInitiationPaymentListRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_cursor ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_id: SKIP, secret: SKIP, count: 10, cursor: SKIP, consent_id: SKIP, additional_properties: nil) ⇒ PaymentInitiationPaymentListRequest
Returns a new instance of PaymentInitiationPaymentListRequest.
72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_list_request.rb', line 72 def initialize(client_id: SKIP, secret: SKIP, count: 10, cursor: SKIP, consent_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @count = count unless count == SKIP @cursor = cursor unless cursor == SKIP @consent_id = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
18 19 20 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_list_request.rb', line 18 def client_id @client_id end |
#consent_id ⇒ String
The consent ID. If specified, only payments, executed using this consent, will be returned.
39 40 41 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_list_request.rb', line 39 def @consent_id end |
#count ⇒ Integer
The maximum number of payments to return. If ‘count` is not specified, a maximum of 10 payments will be returned, beginning with the most recent payment before the cursor (if specified).
29 30 31 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_list_request.rb', line 29 def count @count end |
#cursor ⇒ DateTime
A string in RFC 3339 format (i.e. “2019-12-06T22:35:49Z”). Only payments created before the cursor will be returned.
34 35 36 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_list_request.rb', line 34 def cursor @cursor end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
23 24 25 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_list_request.rb', line 23 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_list_request.rb', line 86 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP count = hash['count'] ||= 10 cursor = if hash.key?('cursor') (DateTimeHelper.from_rfc3339(hash['cursor']) if hash['cursor']) else SKIP end = hash.key?('consent_id') ? hash['consent_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PaymentInitiationPaymentListRequest.new(client_id: client_id, secret: secret, count: count, cursor: cursor, consent_id: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
42 43 44 45 46 47 48 49 50 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_list_request.rb', line 42 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['count'] = 'count' @_hash['cursor'] = 'cursor' @_hash['consent_id'] = 'consent_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
64 65 66 67 68 69 70 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_list_request.rb', line 64 def self.nullables %w[ count cursor consent_id ] end |
.optionals ⇒ Object
An array for optional fields
53 54 55 56 57 58 59 60 61 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_list_request.rb', line 53 def self.optionals %w[ client_id secret count cursor consent_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
128 129 130 131 132 133 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_list_request.rb', line 128 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, count:"\ " #{@count.inspect}, cursor: #{@cursor.inspect}, consent_id: #{@consent_id.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_custom_cursor ⇒ Object
116 117 118 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_list_request.rb', line 116 def to_custom_cursor DateTimeHelper.to_rfc3339(cursor) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
121 122 123 124 125 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_list_request.rb', line 121 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, count: #{@count}, cursor:"\ " #{@cursor}, consent_id: #{@consent_id}, additional_properties: #{@additional_properties}>" end |