Class: ThePlaidApi::PaymentInitiationPaymentTokenCreateResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::PaymentInitiationPaymentTokenCreateResponse
- Defined in:
- lib/the_plaid_api/models/payment_initiation_payment_token_create_response.rb
Overview
PaymentInitiationPaymentTokenCreateResponse defines the response schema for ‘/payment_initiation/payment/token/create`
Instance Attribute Summary collapse
-
#payment_token ⇒ String
A ‘payment_token` that can be provided to Link initialization to enter the payment initiation flow.
-
#payment_token_expiration_time ⇒ DateTime
The date and time at which the token will expire, in [ISO 8601](wikipedia.org/wiki/ISO_8601) format.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(payment_token:, payment_token_expiration_time:, request_id:, additional_properties: nil) ⇒ PaymentInitiationPaymentTokenCreateResponse
constructor
A new instance of PaymentInitiationPaymentTokenCreateResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_payment_token_expiration_time ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(payment_token:, payment_token_expiration_time:, request_id:, additional_properties: nil) ⇒ PaymentInitiationPaymentTokenCreateResponse
Returns a new instance of PaymentInitiationPaymentTokenCreateResponse.
51 52 53 54 55 56 57 58 59 60 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_token_create_response.rb', line 51 def initialize(payment_token:, payment_token_expiration_time:, request_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @payment_token = payment_token @payment_token_expiration_time = payment_token_expiration_time @request_id = request_id @additional_properties = additional_properties end |
Instance Attribute Details
#payment_token ⇒ String
A ‘payment_token` that can be provided to Link initialization to enter the payment initiation flow
17 18 19 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_token_create_response.rb', line 17 def payment_token @payment_token end |
#payment_token_expiration_time ⇒ DateTime
The date and time at which the token will expire, in [ISO 8601](wikipedia.org/wiki/ISO_8601) format. A ‘payment_token` expires after 15 minutes.
23 24 25 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_token_create_response.rb', line 23 def payment_token_expiration_time @payment_token_expiration_time end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
29 30 31 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_token_create_response.rb', line 29 def request_id @request_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_token_create_response.rb', line 63 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. payment_token = hash.key?('payment_token') ? hash['payment_token'] : nil payment_token_expiration_time = if hash.key?('payment_token_expiration_time') (DateTimeHelper.from_rfc3339(hash['payment_token_expiration_time']) if hash['payment_token_expiration_time']) end request_id = hash.key?('request_id') ? hash['request_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PaymentInitiationPaymentTokenCreateResponse.new(payment_token: payment_token, payment_token_expiration_time: payment_token_expiration_time, request_id: request_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
32 33 34 35 36 37 38 39 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_token_create_response.rb', line 32 def self.names @_hash = {} if @_hash.nil? @_hash['payment_token'] = 'payment_token' @_hash['payment_token_expiration_time'] = 'payment_token_expiration_time' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
47 48 49 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_token_create_response.rb', line 47 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
42 43 44 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_token_create_response.rb', line 42 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
100 101 102 103 104 105 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_token_create_response.rb', line 100 def inspect class_name = self.class.name.split('::').last "<#{class_name} payment_token: #{@payment_token.inspect}, payment_token_expiration_time:"\ " #{@payment_token_expiration_time.inspect}, request_id: #{@request_id.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_custom_payment_token_expiration_time ⇒ Object
87 88 89 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_token_create_response.rb', line 87 def to_custom_payment_token_expiration_time DateTimeHelper.to_rfc3339(payment_token_expiration_time) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 97 |
# File 'lib/the_plaid_api/models/payment_initiation_payment_token_create_response.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} payment_token: #{@payment_token}, payment_token_expiration_time:"\ " #{@payment_token_expiration_time}, request_id: #{@request_id}, additional_properties:"\ " #{@additional_properties}>" end |