Class: ThePlaidApi::PoBoxStatus
- Inherits:
-
Object
- Object
- ThePlaidApi::PoBoxStatus
- Defined in:
- lib/the_plaid_api/models/po_box_status.rb
Overview
Field describing whether the associated address is a post office box. Will be ‘yes` when a P.O. box is detected, `no` when Plaid confirmed the address is not a P.O. box, and `no_data` when Plaid was not able to determine if the address is a P.O. box.
Constant Summary collapse
- PO_BOX_STATUS =
[ # TODO: Write general description for YES YES = 'yes'.freeze, # TODO: Write general description for NO NO = 'no'.freeze, # TODO: Write general description for NO_DATA NO_DATA = 'no_data'.freeze ].freeze
Class Method Summary collapse
Class Method Details
.from_value(value, default_value = YES) ⇒ Object
29 30 31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/the_plaid_api/models/po_box_status.rb', line 29 def self.from_value(value, default_value = YES) return default_value if value.nil? str = value.to_s.strip case str.downcase when 'yes' then YES when 'no' then NO when 'no_data' then NO_DATA else default_value end end |
.validate(value) ⇒ Object
23 24 25 26 27 |
# File 'lib/the_plaid_api/models/po_box_status.rb', line 23 def self.validate(value) return false if value.nil? PO_BOX_STATUS.include?(value) end |