Class: ThePlaidApi::ProcessorInvestmentsTransactionsGetRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ProcessorInvestmentsTransactionsGetRequest
- Defined in:
- lib/the_plaid_api/models/processor_investments_transactions_get_request.rb
Overview
ProcessorInvestmentsTransactionsGetRequest defines the request schema for ‘/processor/investments/transactions/get`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#end_date ⇒ Date
The latest date for which data should be returned.
-
#options ⇒ InvestmentsTransactionsGetRequestOptions
An optional object to filter ‘/investments/transactions/get` results.
-
#processor_token ⇒ String
The processor token obtained from the Plaid integration partner.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#start_date ⇒ Date
The earliest date for which data should be returned.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(processor_token:, start_date:, end_date:, client_id: SKIP, options: SKIP, secret: SKIP, additional_properties: nil) ⇒ ProcessorInvestmentsTransactionsGetRequest
constructor
A new instance of ProcessorInvestmentsTransactionsGetRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(processor_token:, start_date:, end_date:, client_id: SKIP, options: SKIP, secret: SKIP, additional_properties: nil) ⇒ ProcessorInvestmentsTransactionsGetRequest
Returns a new instance of ProcessorInvestmentsTransactionsGetRequest.
70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/the_plaid_api/models/processor_investments_transactions_get_request.rb', line 70 def initialize(processor_token:, start_date:, end_date:, client_id: SKIP, options: SKIP, secret: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @options = unless == SKIP @processor_token = processor_token @secret = secret unless secret == SKIP @start_date = start_date @end_date = end_date @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/processor_investments_transactions_get_request.rb', line 17 def client_id @client_id end |
#end_date ⇒ Date
The latest date for which data should be returned. Dates should be formatted as YYYY-MM-DD.
42 43 44 |
# File 'lib/the_plaid_api/models/processor_investments_transactions_get_request.rb', line 42 def end_date @end_date end |
#options ⇒ InvestmentsTransactionsGetRequestOptions
An optional object to filter ‘/investments/transactions/get` results. If provided, must be non-`null`.
22 23 24 |
# File 'lib/the_plaid_api/models/processor_investments_transactions_get_request.rb', line 22 def @options end |
#processor_token ⇒ String
The processor token obtained from the Plaid integration partner. Processor tokens are in the format: ‘processor-<environment>-<identifier>`
27 28 29 |
# File 'lib/the_plaid_api/models/processor_investments_transactions_get_request.rb', line 27 def processor_token @processor_token end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
32 33 34 |
# File 'lib/the_plaid_api/models/processor_investments_transactions_get_request.rb', line 32 def secret @secret end |
#start_date ⇒ Date
The earliest date for which data should be returned. Dates should be formatted as YYYY-MM-DD.
37 38 39 |
# File 'lib/the_plaid_api/models/processor_investments_transactions_get_request.rb', line 37 def start_date @start_date end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/the_plaid_api/models/processor_investments_transactions_get_request.rb', line 85 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. processor_token = hash.key?('processor_token') ? hash['processor_token'] : nil start_date = hash.key?('start_date') ? hash['start_date'] : nil end_date = hash.key?('end_date') ? hash['end_date'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP = InvestmentsTransactionsGetRequestOptions.from_hash(hash['options']) if hash['options'] secret = hash.key?('secret') ? hash['secret'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProcessorInvestmentsTransactionsGetRequest.new(processor_token: processor_token, start_date: start_date, end_date: end_date, client_id: client_id, options: , secret: secret, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
45 46 47 48 49 50 51 52 53 54 |
# File 'lib/the_plaid_api/models/processor_investments_transactions_get_request.rb', line 45 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['options'] = 'options' @_hash['processor_token'] = 'processor_token' @_hash['secret'] = 'secret' @_hash['start_date'] = 'start_date' @_hash['end_date'] = 'end_date' @_hash end |
.nullables ⇒ Object
An array for nullable fields
66 67 68 |
# File 'lib/the_plaid_api/models/processor_investments_transactions_get_request.rb', line 66 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
57 58 59 60 61 62 63 |
# File 'lib/the_plaid_api/models/processor_investments_transactions_get_request.rb', line 57 def self.optionals %w[ client_id options secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
124 125 126 127 128 129 130 |
# File 'lib/the_plaid_api/models/processor_investments_transactions_get_request.rb', line 124 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, options: #{@options.inspect},"\ " processor_token: #{@processor_token.inspect}, secret: #{@secret.inspect}, start_date:"\ " #{@start_date.inspect}, end_date: #{@end_date.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
116 117 118 119 120 121 |
# File 'lib/the_plaid_api/models/processor_investments_transactions_get_request.rb', line 116 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, options: #{@options}, processor_token:"\ " #{@processor_token}, secret: #{@secret}, start_date: #{@start_date}, end_date:"\ " #{@end_date}, additional_properties: #{@additional_properties}>" end |