Class: ThePlaidApi::ProcessorRecurringTransactionsUpdateWebhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ProcessorRecurringTransactionsUpdateWebhook
- Defined in:
- lib/the_plaid_api/models/processor_recurring_transactions_update_webhook.rb
Overview
This webhook is only sent to [Plaid processor partners](plaid.com/docs/auth/partnerships/). Fired when recurring transactions data is updated. This includes when a new recurring stream is detected or when a new transaction is added to an existing recurring stream. The ‘RECURRING_TRANSACTIONS_UPDATE` webhook will also fire when one or more attributes of the recurring stream changes, which is usually a result of the addition, update, or removal of transactions to the stream. After receipt of this webhook, the updated data can be fetched from `/processor/transactions/recurring/get`.
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ID of the account.
-
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from.
-
#webhook_code ⇒ String
‘RECURRING_TRANSACTIONS_UPDATE`.
-
#webhook_type ⇒ String
‘TRANSACTIONS`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, account_id:, environment:, additional_properties: nil) ⇒ ProcessorRecurringTransactionsUpdateWebhook
constructor
A new instance of ProcessorRecurringTransactionsUpdateWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, account_id:, environment:, additional_properties: nil) ⇒ ProcessorRecurringTransactionsUpdateWebhook
Returns a new instance of ProcessorRecurringTransactionsUpdateWebhook.
56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/the_plaid_api/models/processor_recurring_transactions_update_webhook.rb', line 56 def initialize(webhook_type:, webhook_code:, account_id:, environment:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @account_id = account_id @environment = environment @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
The ID of the account.
30 31 32 |
# File 'lib/the_plaid_api/models/processor_recurring_transactions_update_webhook.rb', line 30 def account_id @account_id end |
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from
34 35 36 |
# File 'lib/the_plaid_api/models/processor_recurring_transactions_update_webhook.rb', line 34 def environment @environment end |
#webhook_code ⇒ String
‘RECURRING_TRANSACTIONS_UPDATE`
26 27 28 |
# File 'lib/the_plaid_api/models/processor_recurring_transactions_update_webhook.rb', line 26 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘TRANSACTIONS`
22 23 24 |
# File 'lib/the_plaid_api/models/processor_recurring_transactions_update_webhook.rb', line 22 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/the_plaid_api/models/processor_recurring_transactions_update_webhook.rb', line 69 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil account_id = hash.key?('account_id') ? hash['account_id'] : nil environment = hash.key?('environment') ? hash['environment'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProcessorRecurringTransactionsUpdateWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, account_id: account_id, environment: environment, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 |
# File 'lib/the_plaid_api/models/processor_recurring_transactions_update_webhook.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['account_id'] = 'account_id' @_hash['environment'] = 'environment' @_hash end |
.nullables ⇒ Object
An array for nullable fields
52 53 54 |
# File 'lib/the_plaid_api/models/processor_recurring_transactions_update_webhook.rb', line 52 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
47 48 49 |
# File 'lib/the_plaid_api/models/processor_recurring_transactions_update_webhook.rb', line 47 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
102 103 104 105 106 107 |
# File 'lib/the_plaid_api/models/processor_recurring_transactions_update_webhook.rb', line 102 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, account_id: #{@account_id.inspect}, environment:"\ " #{@environment.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
94 95 96 97 98 99 |
# File 'lib/the_plaid_api/models/processor_recurring_transactions_update_webhook.rb', line 94 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, account_id:"\ " #{@account_id}, environment: #{@environment}, additional_properties:"\ " #{@additional_properties}>" end |