Class: ThePlaidApi::ProcessorTokenPermissionsGetResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ProcessorTokenPermissionsGetResponse
- Defined in:
- lib/the_plaid_api/models/processor_token_permissions_get_response.rb
Overview
ProcessorTokenPermissionsGetResponse defines the response schema for ‘/processor/token/permissions/get`
Instance Attribute Summary collapse
-
#products ⇒ Array[Products]
A list of products the processor token should have access to.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(request_id:, products:, additional_properties: nil) ⇒ ProcessorTokenPermissionsGetResponse
constructor
A new instance of ProcessorTokenPermissionsGetResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(request_id:, products:, additional_properties: nil) ⇒ ProcessorTokenPermissionsGetResponse
Returns a new instance of ProcessorTokenPermissionsGetResponse.
43 44 45 46 47 48 49 50 |
# File 'lib/the_plaid_api/models/processor_token_permissions_get_response.rb', line 43 def initialize(request_id:, products:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @request_id = request_id @products = products @additional_properties = additional_properties end |
Instance Attribute Details
#products ⇒ Array[Products]
A list of products the processor token should have access to. An empty list means that the processor has access to all available products, including future products.
23 24 25 |
# File 'lib/the_plaid_api/models/processor_token_permissions_get_response.rb', line 23 def products @products end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
17 18 19 |
# File 'lib/the_plaid_api/models/processor_token_permissions_get_response.rb', line 17 def request_id @request_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/the_plaid_api/models/processor_token_permissions_get_response.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. request_id = hash.key?('request_id') ? hash['request_id'] : nil products = hash.key?('products') ? hash['products'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProcessorTokenPermissionsGetResponse.new(request_id: request_id, products: products, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 |
# File 'lib/the_plaid_api/models/processor_token_permissions_get_response.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['request_id'] = 'request_id' @_hash['products'] = 'products' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/the_plaid_api/models/processor_token_permissions_get_response.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/the_plaid_api/models/processor_token_permissions_get_response.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/the_plaid_api/models/processor_token_permissions_get_response.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} request_id: #{@request_id.inspect}, products: #{@products.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/the_plaid_api/models/processor_token_permissions_get_response.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} request_id: #{@request_id}, products: #{@products}, additional_properties:"\ " #{@additional_properties}>" end |