Class: ThePlaidApi::ProcessorTransactionsSyncRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ProcessorTransactionsSyncRequest
- Defined in:
- lib/the_plaid_api/models/processor_transactions_sync_request.rb
Overview
ProcessorTransactionsSyncRequest defines the request schema for ‘/processor/transactions/sync`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#count ⇒ Integer
The number of transaction updates to fetch.
-
#cursor ⇒ String
The cursor value represents the last update requested.
-
#options ⇒ TransactionsSyncRequestOptions
An optional object to be used with the request.
-
#processor_token ⇒ String
The processor token obtained from the Plaid integration partner.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(processor_token:, client_id: SKIP, secret: SKIP, cursor: SKIP, count: 100, options: SKIP, additional_properties: nil) ⇒ ProcessorTransactionsSyncRequest
constructor
A new instance of ProcessorTransactionsSyncRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(processor_token:, client_id: SKIP, secret: SKIP, cursor: SKIP, count: 100, options: SKIP, additional_properties: nil) ⇒ ProcessorTransactionsSyncRequest
Returns a new instance of ProcessorTransactionsSyncRequest.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/the_plaid_api/models/processor_transactions_sync_request.rb', line 74 def initialize(processor_token:, client_id: SKIP, secret: SKIP, cursor: SKIP, count: 100, options: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @processor_token = processor_token @secret = secret unless secret == SKIP @cursor = cursor unless cursor == SKIP @count = count unless count == SKIP @options = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/processor_transactions_sync_request.rb', line 17 def client_id @client_id end |
#count ⇒ Integer
The number of transaction updates to fetch.
39 40 41 |
# File 'lib/the_plaid_api/models/processor_transactions_sync_request.rb', line 39 def count @count end |
#cursor ⇒ String
The cursor value represents the last update requested. Providing it will cause the response to only return changes after this update. If omitted, the entire history of updates will be returned, starting with the first-added transactions on the item. Note: The upper-bound length of this cursor is 256 characters of base64.
35 36 37 |
# File 'lib/the_plaid_api/models/processor_transactions_sync_request.rb', line 35 def cursor @cursor end |
#options ⇒ TransactionsSyncRequestOptions
An optional object to be used with the request. If specified, ‘options` must not be `null`.
44 45 46 |
# File 'lib/the_plaid_api/models/processor_transactions_sync_request.rb', line 44 def @options end |
#processor_token ⇒ String
The processor token obtained from the Plaid integration partner. Processor tokens are in the format: ‘processor-<environment>-<identifier>`
22 23 24 |
# File 'lib/the_plaid_api/models/processor_transactions_sync_request.rb', line 22 def processor_token @processor_token end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
27 28 29 |
# File 'lib/the_plaid_api/models/processor_transactions_sync_request.rb', line 27 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/the_plaid_api/models/processor_transactions_sync_request.rb', line 90 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. processor_token = hash.key?('processor_token') ? hash['processor_token'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP cursor = hash.key?('cursor') ? hash['cursor'] : SKIP count = hash['count'] ||= 100 = TransactionsSyncRequestOptions.from_hash(hash['options']) if hash['options'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProcessorTransactionsSyncRequest.new(processor_token: processor_token, client_id: client_id, secret: secret, cursor: cursor, count: count, options: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/the_plaid_api/models/processor_transactions_sync_request.rb', line 47 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['processor_token'] = 'processor_token' @_hash['secret'] = 'secret' @_hash['cursor'] = 'cursor' @_hash['count'] = 'count' @_hash['options'] = 'options' @_hash end |
.nullables ⇒ Object
An array for nullable fields
70 71 72 |
# File 'lib/the_plaid_api/models/processor_transactions_sync_request.rb', line 70 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
59 60 61 62 63 64 65 66 67 |
# File 'lib/the_plaid_api/models/processor_transactions_sync_request.rb', line 59 def self.optionals %w[ client_id secret cursor count options ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
128 129 130 131 132 133 134 |
# File 'lib/the_plaid_api/models/processor_transactions_sync_request.rb', line 128 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, processor_token:"\ " #{@processor_token.inspect}, secret: #{@secret.inspect}, cursor: #{@cursor.inspect},"\ " count: #{@count.inspect}, options: #{@options.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
120 121 122 123 124 125 |
# File 'lib/the_plaid_api/models/processor_transactions_sync_request.rb', line 120 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, processor_token: #{@processor_token}, secret:"\ " #{@secret}, cursor: #{@cursor}, count: #{@count}, options: #{@options},"\ " additional_properties: #{@additional_properties}>" end |