Class: ThePlaidApi::ProtectComputeRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ProtectComputeRequest
- Defined in:
- lib/the_plaid_api/models/protect_compute_request.rb
Overview
Request object for /protect/compute
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#model ⇒ String
The name of the Trust Index model to use for calculating the Trust Index Score, with a major.minor version suffix.
-
#model_inputs ⇒ ProtectModelInputs
Inputs for the Trust Index model.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#user ⇒ ProtectUser
Represents an end user for /protect/compute requests.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(model:, user:, client_id: SKIP, secret: SKIP, model_inputs: SKIP, additional_properties: nil) ⇒ ProtectComputeRequest
constructor
A new instance of ProtectComputeRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(model:, user:, client_id: SKIP, secret: SKIP, model_inputs: SKIP, additional_properties: nil) ⇒ ProtectComputeRequest
Returns a new instance of ProtectComputeRequest.
68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/the_plaid_api/models/protect_compute_request.rb', line 68 def initialize(model:, user:, client_id: SKIP, secret: SKIP, model_inputs: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @model = model @user = user @model_inputs = model_inputs unless model_inputs == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/the_plaid_api/models/protect_compute_request.rb', line 16 def client_id @client_id end |
#model ⇒ String
The name of the Trust Index model to use for calculating the Trust Index Score, with a major.minor version suffix. Examples include ‘ti-link-session-2.0` and `ti-identity-2.0`. The model specified may require certain fields within `model_inputs`. For example, `ti-link-session-2.0` requires the `link` field to be provided in `model_inputs`.
30 31 32 |
# File 'lib/the_plaid_api/models/protect_compute_request.rb', line 30 def model @model end |
#model_inputs ⇒ ProtectModelInputs
Inputs for the Trust Index model. The ‘link` field is required for any link session model type.
39 40 41 |
# File 'lib/the_plaid_api/models/protect_compute_request.rb', line 39 def model_inputs @model_inputs end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
21 22 23 |
# File 'lib/the_plaid_api/models/protect_compute_request.rb', line 21 def secret @secret end |
#user ⇒ ProtectUser
Represents an end user for /protect/compute requests.
34 35 36 |
# File 'lib/the_plaid_api/models/protect_compute_request.rb', line 34 def user @user end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/the_plaid_api/models/protect_compute_request.rb', line 82 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. model = hash.key?('model') ? hash['model'] : nil user = ProtectUser.from_hash(hash['user']) if hash['user'] client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP model_inputs = ProtectModelInputs.from_hash(hash['model_inputs']) if hash['model_inputs'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProtectComputeRequest.new(model: model, user: user, client_id: client_id, secret: secret, model_inputs: model_inputs, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
42 43 44 45 46 47 48 49 50 |
# File 'lib/the_plaid_api/models/protect_compute_request.rb', line 42 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['model'] = 'model' @_hash['user'] = 'user' @_hash['model_inputs'] = 'model_inputs' @_hash end |
.nullables ⇒ Object
An array for nullable fields
62 63 64 65 66 |
# File 'lib/the_plaid_api/models/protect_compute_request.rb', line 62 def self.nullables %w[ model_inputs ] end |
.optionals ⇒ Object
An array for optional fields
53 54 55 56 57 58 59 |
# File 'lib/the_plaid_api/models/protect_compute_request.rb', line 53 def self.optionals %w[ client_id secret model_inputs ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
117 118 119 120 121 122 |
# File 'lib/the_plaid_api/models/protect_compute_request.rb', line 117 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, model:"\ " #{@model.inspect}, user: #{@user.inspect}, model_inputs: #{@model_inputs.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
109 110 111 112 113 114 |
# File 'lib/the_plaid_api/models/protect_compute_request.rb', line 109 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, model: #{@model}, user:"\ " #{@user}, model_inputs: #{@model_inputs}, additional_properties:"\ " #{@additional_properties}>" end |