Class: ThePlaidApi::ProtectEventGetResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ProtectEventGetResponse
- Defined in:
- lib/the_plaid_api/models/protect_event_get_response.rb
Overview
Response object for /protect/event/get
Instance Attribute Summary collapse
-
#event_id ⇒ String
The event ID.
-
#fraud_attributes ⇒ Object
Event fraud attributes as an arbitrary set of key-value pairs.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
-
#timestamp ⇒ DateTime
The timestamp of the event, in [ISO 8601](wikipedia.org/wiki/ISO_8601) format, e.g.
-
#trust_index ⇒ TrustIndex
Represents a calculated Trust Index Score.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(event_id:, timestamp:, request_id:, trust_index: SKIP, fraud_attributes: SKIP, additional_properties: nil) ⇒ ProtectEventGetResponse
constructor
A new instance of ProtectEventGetResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_timestamp ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(event_id:, timestamp:, request_id:, trust_index: SKIP, fraud_attributes: SKIP, additional_properties: nil) ⇒ ProtectEventGetResponse
Returns a new instance of ProtectEventGetResponse.
64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/the_plaid_api/models/protect_event_get_response.rb', line 64 def initialize(event_id:, timestamp:, request_id:, trust_index: SKIP, fraud_attributes: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @event_id = event_id @timestamp = @trust_index = trust_index unless trust_index == SKIP @fraud_attributes = fraud_attributes unless fraud_attributes == SKIP @request_id = request_id @additional_properties = additional_properties end |
Instance Attribute Details
#event_id ⇒ String
The event ID.
15 16 17 |
# File 'lib/the_plaid_api/models/protect_event_get_response.rb', line 15 def event_id @event_id end |
#fraud_attributes ⇒ Object
Event fraud attributes as an arbitrary set of key-value pairs.
29 30 31 |
# File 'lib/the_plaid_api/models/protect_event_get_response.rb', line 29 def fraud_attributes @fraud_attributes end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
35 36 37 |
# File 'lib/the_plaid_api/models/protect_event_get_response.rb', line 35 def request_id @request_id end |
#timestamp ⇒ DateTime
The timestamp of the event, in [ISO 8601](wikipedia.org/wiki/ISO_8601) format, e.g. āā2017-09-14T14:42:19.350Zā`
21 22 23 |
# File 'lib/the_plaid_api/models/protect_event_get_response.rb', line 21 def @timestamp end |
#trust_index ⇒ TrustIndex
Represents a calculated Trust Index Score.
25 26 27 |
# File 'lib/the_plaid_api/models/protect_event_get_response.rb', line 25 def trust_index @trust_index end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/the_plaid_api/models/protect_event_get_response.rb', line 78 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. event_id = hash.key?('event_id') ? hash['event_id'] : nil = if hash.key?('timestamp') (DateTimeHelper.from_rfc3339(hash['timestamp']) if hash['timestamp']) end request_id = hash.key?('request_id') ? hash['request_id'] : nil trust_index = TrustIndex.from_hash(hash['trust_index']) if hash['trust_index'] fraud_attributes = hash.key?('fraud_attributes') ? hash['fraud_attributes'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProtectEventGetResponse.new(event_id: event_id, timestamp: , request_id: request_id, trust_index: trust_index, fraud_attributes: fraud_attributes, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
38 39 40 41 42 43 44 45 46 |
# File 'lib/the_plaid_api/models/protect_event_get_response.rb', line 38 def self.names @_hash = {} if @_hash.nil? @_hash['event_id'] = 'event_id' @_hash['timestamp'] = 'timestamp' @_hash['trust_index'] = 'trust_index' @_hash['fraud_attributes'] = 'fraud_attributes' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
57 58 59 60 61 62 |
# File 'lib/the_plaid_api/models/protect_event_get_response.rb', line 57 def self.nullables %w[ trust_index fraud_attributes ] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 52 53 54 |
# File 'lib/the_plaid_api/models/protect_event_get_response.rb', line 49 def self.optionals %w[ trust_index fraud_attributes ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
120 121 122 123 124 125 |
# File 'lib/the_plaid_api/models/protect_event_get_response.rb', line 120 def inspect class_name = self.class.name.split('::').last "<#{class_name} event_id: #{@event_id.inspect}, timestamp: #{@timestamp.inspect},"\ " trust_index: #{@trust_index.inspect}, fraud_attributes: #{@fraud_attributes.inspect},"\ " request_id: #{@request_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_custom_timestamp ⇒ Object
107 108 109 |
# File 'lib/the_plaid_api/models/protect_event_get_response.rb', line 107 def DateTimeHelper.to_rfc3339() end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
112 113 114 115 116 117 |
# File 'lib/the_plaid_api/models/protect_event_get_response.rb', line 112 def to_s class_name = self.class.name.split('::').last "<#{class_name} event_id: #{@event_id}, timestamp: #{@timestamp}, trust_index:"\ " #{@trust_index}, fraud_attributes: #{@fraud_attributes}, request_id: #{@request_id},"\ " additional_properties: #{@additional_properties}>" end |