Class: ThePlaidApi::ProtectEventSendRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ProtectEventSendRequest
- Defined in:
- lib/the_plaid_api/models/protect_event_send_request.rb
Overview
Request object for /protect/event/send
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#event ⇒ ProtectEvent
Event data for Protect events.
-
#protect_session_id ⇒ String
Protect Session ID should be provided for any event correlated with a frontend user session started via the Protect SDK.
-
#request_trust_index ⇒ TrueClass | FalseClass
Whether this event should be scored with Trust Index.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#timestamp ⇒ DateTime
Timestamp of the event.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(event:, client_id: SKIP, secret: SKIP, timestamp: SKIP, protect_session_id: SKIP, request_trust_index: SKIP, additional_properties: nil) ⇒ ProtectEventSendRequest
constructor
A new instance of ProtectEventSendRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_timestamp ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(event:, client_id: SKIP, secret: SKIP, timestamp: SKIP, protect_session_id: SKIP, request_trust_index: SKIP, additional_properties: nil) ⇒ ProtectEventSendRequest
Returns a new instance of ProtectEventSendRequest.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/the_plaid_api/models/protect_event_send_request.rb', line 74 def initialize(event:, client_id: SKIP, secret: SKIP, timestamp: SKIP, protect_session_id: SKIP, request_trust_index: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @timestamp = unless == SKIP @event = event @protect_session_id = protect_session_id unless protect_session_id == SKIP @request_trust_index = request_trust_index unless request_trust_index == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/protect_event_send_request.rb', line 17 def client_id @client_id end |
#event ⇒ ProtectEvent
Event data for Protect events.
32 33 34 |
# File 'lib/the_plaid_api/models/protect_event_send_request.rb', line 32 def event @event end |
#protect_session_id ⇒ String
Protect Session ID should be provided for any event correlated with a frontend user session started via the Protect SDK.
37 38 39 |
# File 'lib/the_plaid_api/models/protect_event_send_request.rb', line 37 def protect_session_id @protect_session_id end |
#request_trust_index ⇒ TrueClass | FalseClass
Whether this event should be scored with Trust Index. The default is false.
42 43 44 |
# File 'lib/the_plaid_api/models/protect_event_send_request.rb', line 42 def request_trust_index @request_trust_index end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/the_plaid_api/models/protect_event_send_request.rb', line 22 def secret @secret end |
#timestamp ⇒ DateTime
Timestamp of the event. Might be the current moment or a time in the past. In [ISO 8601](wikipedia.org/wiki/ISO_8601) format, e.g. ‘“2017-09-14T14:42:19.350Z”`
28 29 30 |
# File 'lib/the_plaid_api/models/protect_event_send_request.rb', line 28 def @timestamp end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/the_plaid_api/models/protect_event_send_request.rb', line 90 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. event = ProtectEvent.from_hash(hash['event']) if hash['event'] client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP = if hash.key?('timestamp') (DateTimeHelper.from_rfc3339(hash['timestamp']) if hash['timestamp']) else SKIP end protect_session_id = hash.key?('protect_session_id') ? hash['protect_session_id'] : SKIP request_trust_index = hash.key?('request_trust_index') ? hash['request_trust_index'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProtectEventSendRequest.new(event: event, client_id: client_id, secret: secret, timestamp: , protect_session_id: protect_session_id, request_trust_index: request_trust_index, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
45 46 47 48 49 50 51 52 53 54 |
# File 'lib/the_plaid_api/models/protect_event_send_request.rb', line 45 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['timestamp'] = 'timestamp' @_hash['event'] = 'event' @_hash['protect_session_id'] = 'protect_session_id' @_hash['request_trust_index'] = 'request_trust_index' @_hash end |
.nullables ⇒ Object
An array for nullable fields
68 69 70 71 72 |
# File 'lib/the_plaid_api/models/protect_event_send_request.rb', line 68 def self.nullables %w[ event ] end |
.optionals ⇒ Object
An array for optional fields
57 58 59 60 61 62 63 64 65 |
# File 'lib/the_plaid_api/models/protect_event_send_request.rb', line 57 def self.optionals %w[ client_id secret timestamp protect_session_id request_trust_index ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
137 138 139 140 141 142 143 |
# File 'lib/the_plaid_api/models/protect_event_send_request.rb', line 137 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, timestamp:"\ " #{@timestamp.inspect}, event: #{@event.inspect}, protect_session_id:"\ " #{@protect_session_id.inspect}, request_trust_index: #{@request_trust_index.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_custom_timestamp ⇒ Object
124 125 126 |
# File 'lib/the_plaid_api/models/protect_event_send_request.rb', line 124 def DateTimeHelper.to_rfc3339() end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
129 130 131 132 133 134 |
# File 'lib/the_plaid_api/models/protect_event_send_request.rb', line 129 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, timestamp: #{@timestamp},"\ " event: #{@event}, protect_session_id: #{@protect_session_id}, request_trust_index:"\ " #{@request_trust_index}, additional_properties: #{@additional_properties}>" end |