Class: ThePlaidApi::ProtectEventSendResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ProtectEventSendResponse
- Defined in:
- lib/the_plaid_api/models/protect_event_send_response.rb
Overview
Response object for /protect/event/send
Instance Attribute Summary collapse
-
#event_id ⇒ String
The id of the recorded event.
-
#fraud_attributes ⇒ Object
Event fraud attributes as an arbitrary set of key-value pairs.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
-
#trust_index ⇒ TrustIndex
Represents a calculated Trust Index Score.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(event_id:, request_id:, trust_index: SKIP, fraud_attributes: SKIP, additional_properties: nil) ⇒ ProtectEventSendResponse
constructor
A new instance of ProtectEventSendResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(event_id:, request_id:, trust_index: SKIP, fraud_attributes: SKIP, additional_properties: nil) ⇒ ProtectEventSendResponse
Returns a new instance of ProtectEventSendResponse.
56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/the_plaid_api/models/protect_event_send_response.rb', line 56 def initialize(event_id:, request_id:, trust_index: SKIP, fraud_attributes: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @event_id = event_id @trust_index = trust_index unless trust_index == SKIP @fraud_attributes = fraud_attributes unless fraud_attributes == SKIP @request_id = request_id @additional_properties = additional_properties end |
Instance Attribute Details
#event_id ⇒ String
The id of the recorded event.
14 15 16 |
# File 'lib/the_plaid_api/models/protect_event_send_response.rb', line 14 def event_id @event_id end |
#fraud_attributes ⇒ Object
Event fraud attributes as an arbitrary set of key-value pairs.
22 23 24 |
# File 'lib/the_plaid_api/models/protect_event_send_response.rb', line 22 def fraud_attributes @fraud_attributes end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
28 29 30 |
# File 'lib/the_plaid_api/models/protect_event_send_response.rb', line 28 def request_id @request_id end |
#trust_index ⇒ TrustIndex
Represents a calculated Trust Index Score.
18 19 20 |
# File 'lib/the_plaid_api/models/protect_event_send_response.rb', line 18 def trust_index @trust_index end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/the_plaid_api/models/protect_event_send_response.rb', line 69 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. event_id = hash.key?('event_id') ? hash['event_id'] : nil request_id = hash.key?('request_id') ? hash['request_id'] : nil trust_index = TrustIndex.from_hash(hash['trust_index']) if hash['trust_index'] fraud_attributes = hash.key?('fraud_attributes') ? hash['fraud_attributes'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProtectEventSendResponse.new(event_id: event_id, request_id: request_id, trust_index: trust_index, fraud_attributes: fraud_attributes, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
31 32 33 34 35 36 37 38 |
# File 'lib/the_plaid_api/models/protect_event_send_response.rb', line 31 def self.names @_hash = {} if @_hash.nil? @_hash['event_id'] = 'event_id' @_hash['trust_index'] = 'trust_index' @_hash['fraud_attributes'] = 'fraud_attributes' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 52 53 54 |
# File 'lib/the_plaid_api/models/protect_event_send_response.rb', line 49 def self.nullables %w[ trust_index fraud_attributes ] end |
.optionals ⇒ Object
An array for optional fields
41 42 43 44 45 46 |
# File 'lib/the_plaid_api/models/protect_event_send_response.rb', line 41 def self.optionals %w[ trust_index fraud_attributes ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
103 104 105 106 107 108 |
# File 'lib/the_plaid_api/models/protect_event_send_response.rb', line 103 def inspect class_name = self.class.name.split('::').last "<#{class_name} event_id: #{@event_id.inspect}, trust_index: #{@trust_index.inspect},"\ " fraud_attributes: #{@fraud_attributes.inspect}, request_id: #{@request_id.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
95 96 97 98 99 100 |
# File 'lib/the_plaid_api/models/protect_event_send_response.rb', line 95 def to_s class_name = self.class.name.split('::').last "<#{class_name} event_id: #{@event_id}, trust_index: #{@trust_index}, fraud_attributes:"\ " #{@fraud_attributes}, request_id: #{@request_id}, additional_properties:"\ " #{@additional_properties}>" end |