Class: ThePlaidApi::ProtectIncidentAmount
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ProtectIncidentAmount
- Defined in:
- lib/the_plaid_api/models/protect_incident_amount.rb
Overview
The monetary amount associated with the incident.
Instance Attribute Summary collapse
-
#iso_currency_code ⇒ String
The ISO-4217 currency code of the incident amount.
-
#value ⇒ Float
The monetary value of the incident amount.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(value:, iso_currency_code: 'USD', additional_properties: nil) ⇒ ProtectIncidentAmount
constructor
A new instance of ProtectIncidentAmount.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(value:, iso_currency_code: 'USD', additional_properties: nil) ⇒ ProtectIncidentAmount
Returns a new instance of ProtectIncidentAmount.
43 44 45 46 47 48 49 50 |
# File 'lib/the_plaid_api/models/protect_incident_amount.rb', line 43 def initialize(value:, iso_currency_code: 'USD', additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @iso_currency_code = iso_currency_code unless iso_currency_code == SKIP @value = value @additional_properties = additional_properties end |
Instance Attribute Details
#iso_currency_code ⇒ String
The ISO-4217 currency code of the incident amount. Defaults to ‘USD` if not specified.
15 16 17 |
# File 'lib/the_plaid_api/models/protect_incident_amount.rb', line 15 def iso_currency_code @iso_currency_code end |
#value ⇒ Float
The monetary value of the incident amount.
19 20 21 |
# File 'lib/the_plaid_api/models/protect_incident_amount.rb', line 19 def value @value end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/the_plaid_api/models/protect_incident_amount.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. value = hash.key?('value') ? hash['value'] : nil iso_currency_code = hash['iso_currency_code'] ||= 'USD' # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProtectIncidentAmount.new(value: value, iso_currency_code: iso_currency_code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/the_plaid_api/models/protect_incident_amount.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['iso_currency_code'] = 'iso_currency_code' @_hash['value'] = 'value' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 40 41 |
# File 'lib/the_plaid_api/models/protect_incident_amount.rb', line 37 def self.nullables %w[ iso_currency_code ] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 |
# File 'lib/the_plaid_api/models/protect_incident_amount.rb', line 30 def self.optionals %w[ iso_currency_code ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/the_plaid_api/models/protect_incident_amount.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} iso_currency_code: #{@iso_currency_code.inspect}, value: #{@value.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/the_plaid_api/models/protect_incident_amount.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} iso_currency_code: #{@iso_currency_code}, value: #{@value},"\ " additional_properties: #{@additional_properties}>" end |