Class: ThePlaidApi::RiskCheckBehaviorFraudRingDetectedLabel
- Inherits:
-
Object
- Object
- ThePlaidApi::RiskCheckBehaviorFraudRingDetectedLabel
- Defined in:
- lib/the_plaid_api/models/risk_check_behavior_fraud_ring_detected_label.rb
Overview
Field describing the outcome of a fraud ring behavior risk check. ‘yes` indicates that fraud ring activity was detected. `no` indicates that fraud ring activity was not detected. `no_data` indicates there was not enough information available to give an accurate signal.
Constant Summary collapse
- RISK_CHECK_BEHAVIOR_FRAUD_RING_DETECTED_LABEL =
[ # TODO: Write general description for YES YES = 'yes'.freeze, # TODO: Write general description for NO NO = 'no'.freeze, # TODO: Write general description for NO_DATA NO_DATA = 'no_data'.freeze ].freeze
Class Method Summary collapse
Class Method Details
.from_value(value, default_value = YES) ⇒ Object
29 30 31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/the_plaid_api/models/risk_check_behavior_fraud_ring_detected_label.rb', line 29 def self.from_value(value, default_value = YES) return default_value if value.nil? str = value.to_s.strip case str.downcase when 'yes' then YES when 'no' then NO when 'no_data' then NO_DATA else default_value end end |
.validate(value) ⇒ Object
23 24 25 26 27 |
# File 'lib/the_plaid_api/models/risk_check_behavior_fraud_ring_detected_label.rb', line 23 def self.validate(value) return false if value.nil? RISK_CHECK_BEHAVIOR_FRAUD_RING_DETECTED_LABEL.include?(value) end |