Class: ThePlaidApi::RiskCheckBehaviorUserInteractionsLabel
- Inherits:
-
Object
- Object
- ThePlaidApi::RiskCheckBehaviorUserInteractionsLabel
- Defined in:
- lib/the_plaid_api/models/risk_check_behavior_user_interactions_label.rb
Overview
Field describing the overall user interaction signals of a behavior risk check. This value represents how familiar the user is with the personal data they provide, based on a number of signals that are collected during their session. ‘genuine` indicates the user has high familiarity with the data they are providing, and that fraud is unlikely. `neutral` indicates some signals are present in between `risky` and `genuine`, but there are not enough clear signals to determine an outcome. `risky` indicates the user has low familiarity with the data they are providing, and that fraud is likely. `no_data` indicates there is not sufficient information to give an accurate signal.
Constant Summary collapse
- RISK_CHECK_BEHAVIOR_USER_INTERACTIONS_LABEL =
[ # TODO: Write general description for GENUINE GENUINE = 'genuine'.freeze, # TODO: Write general description for NEUTRAL NEUTRAL = 'neutral'.freeze, # TODO: Write general description for RISKY RISKY = 'risky'.freeze, # TODO: Write general description for NO_DATA NO_DATA = 'no_data'.freeze ].freeze
Class Method Summary collapse
Class Method Details
.from_value(value, default_value = GENUINE) ⇒ Object
38 39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/the_plaid_api/models/risk_check_behavior_user_interactions_label.rb', line 38 def self.from_value(value, default_value = GENUINE) return default_value if value.nil? str = value.to_s.strip case str.downcase when 'genuine' then GENUINE when 'neutral' then NEUTRAL when 'risky' then RISKY when 'no_data' then NO_DATA else default_value end end |
.validate(value) ⇒ Object
32 33 34 35 36 |
# File 'lib/the_plaid_api/models/risk_check_behavior_user_interactions_label.rb', line 32 def self.validate(value) return false if value.nil? RISK_CHECK_BEHAVIOR_USER_INTERACTIONS_LABEL.include?(value) end |