Class: ThePlaidApi::RiskCheckEmailTopLevelDomainIsSuspicious
- Inherits:
-
Object
- Object
- ThePlaidApi::RiskCheckEmailTopLevelDomainIsSuspicious
- Defined in:
- lib/the_plaid_api/models/risk_check_email_top_level_domain_is_suspicious.rb
Overview
Indicates whether the email address top level domain, which is the last part of the domain, is fraudulent or risky if known. In most cases, a suspicious top level domain is also associated with a disposable or high-risk domain.
Constant Summary collapse
- RISK_CHECK_EMAIL_TOP_LEVEL_DOMAIN_IS_SUSPICIOUS =
[ # TODO: Write general description for YES YES = 'yes'.freeze, # TODO: Write general description for NO NO = 'no'.freeze, # TODO: Write general description for NO_DATA NO_DATA = 'no_data'.freeze ].freeze
Class Method Summary collapse
Class Method Details
.from_value(value, default_value = YES) ⇒ Object
28 29 30 31 32 33 34 35 36 37 38 39 40 |
# File 'lib/the_plaid_api/models/risk_check_email_top_level_domain_is_suspicious.rb', line 28 def self.from_value(value, default_value = YES) return default_value if value.nil? str = value.to_s.strip case str.downcase when 'yes' then YES when 'no' then NO when 'no_data' then NO_DATA else default_value end end |
.validate(value) ⇒ Object
22 23 24 25 26 |
# File 'lib/the_plaid_api/models/risk_check_email_top_level_domain_is_suspicious.rb', line 22 def self.validate(value) return false if value.nil? RISK_CHECK_EMAIL_TOP_LEVEL_DOMAIN_IS_SUSPICIOUS.include?(value) end |