Class: ThePlaidApi::RiskCheckIdentityAbuseSignals
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::RiskCheckIdentityAbuseSignals
- Defined in:
- lib/the_plaid_api/models/risk_check_identity_abuse_signals.rb
Overview
Result summary object capturing abuse signals related to ‘identity abuse`, e.g. stolen and synthetic identity fraud. These attributes are only available for US identities and some signals may not be available depending on what information was collected.
Instance Attribute Summary collapse
-
#stolen_identity ⇒ RiskCheckStolenIdentity
Field containing the data used in determining the outcome of the stolen identity risk check.
-
#synthetic_identity ⇒ RiskCheckSyntheticIdentity
Field containing the data used in determining the outcome of the synthetic identity risk check.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(synthetic_identity:, stolen_identity:, additional_properties: nil) ⇒ RiskCheckIdentityAbuseSignals
constructor
A new instance of RiskCheckIdentityAbuseSignals.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(synthetic_identity:, stolen_identity:, additional_properties: nil) ⇒ RiskCheckIdentityAbuseSignals
Returns a new instance of RiskCheckIdentityAbuseSignals.
52 53 54 55 56 57 58 59 60 |
# File 'lib/the_plaid_api/models/risk_check_identity_abuse_signals.rb', line 52 def initialize(synthetic_identity:, stolen_identity:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @synthetic_identity = synthetic_identity @stolen_identity = stolen_identity @additional_properties = additional_properties end |
Instance Attribute Details
#stolen_identity ⇒ RiskCheckStolenIdentity
Field containing the data used in determining the outcome of the stolen identity risk check. Contains the following fields: ‘score` - A score from 0 to 100 indicating the likelihood that the user is a stolen identity.
29 30 31 |
# File 'lib/the_plaid_api/models/risk_check_identity_abuse_signals.rb', line 29 def stolen_identity @stolen_identity end |
#synthetic_identity ⇒ RiskCheckSyntheticIdentity
Field containing the data used in determining the outcome of the synthetic identity risk check. Contains the following fields: ‘score` - A score from 0 to 100 indicating the likelihood that the user is a synthetic identity.
21 22 23 |
# File 'lib/the_plaid_api/models/risk_check_identity_abuse_signals.rb', line 21 def synthetic_identity @synthetic_identity end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/the_plaid_api/models/risk_check_identity_abuse_signals.rb', line 63 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. synthetic_identity = RiskCheckSyntheticIdentity.from_hash(hash['synthetic_identity']) if hash['synthetic_identity'] stolen_identity = RiskCheckStolenIdentity.from_hash(hash['stolen_identity']) if hash['stolen_identity'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. RiskCheckIdentityAbuseSignals.new(synthetic_identity: synthetic_identity, stolen_identity: stolen_identity, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
32 33 34 35 36 37 |
# File 'lib/the_plaid_api/models/risk_check_identity_abuse_signals.rb', line 32 def self.names @_hash = {} if @_hash.nil? @_hash['synthetic_identity'] = 'synthetic_identity' @_hash['stolen_identity'] = 'stolen_identity' @_hash end |
.nullables ⇒ Object
An array for nullable fields
45 46 47 48 49 50 |
# File 'lib/the_plaid_api/models/risk_check_identity_abuse_signals.rb', line 45 def self.nullables %w[ synthetic_identity stolen_identity ] end |
.optionals ⇒ Object
An array for optional fields
40 41 42 |
# File 'lib/the_plaid_api/models/risk_check_identity_abuse_signals.rb', line 40 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 |
# File 'lib/the_plaid_api/models/risk_check_identity_abuse_signals.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} synthetic_identity: #{@synthetic_identity.inspect}, stolen_identity:"\ " #{@stolen_identity.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 |
# File 'lib/the_plaid_api/models/risk_check_identity_abuse_signals.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} synthetic_identity: #{@synthetic_identity}, stolen_identity:"\ " #{@stolen_identity}, additional_properties: #{@additional_properties}>" end |