Class: ThePlaidApi::RiskCheckPhone
- Defined in:
- lib/the_plaid_api/models/risk_check_phone.rb
Overview
Result summary object specifying values for ‘phone` attributes of risk check.
Instance Attribute Summary collapse
-
#factors ⇒ Array[String]
List of factors, when available, that contribute towards the risk level of the given risk check type.
-
#linked_services ⇒ Array[RiskCheckLinkedService]
A list of online services where this phone number has been detected to have accounts or other activity.
-
#risk_level ⇒ RiskLevel
Risk level for the given risk check type.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(linked_services:, risk_level: SKIP, factors: SKIP, additional_properties: nil) ⇒ RiskCheckPhone
constructor
A new instance of RiskCheckPhone.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(linked_services:, risk_level: SKIP, factors: SKIP, additional_properties: nil) ⇒ RiskCheckPhone
Returns a new instance of RiskCheckPhone.
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/the_plaid_api/models/risk_check_phone.rb', line 49 def initialize(linked_services:, risk_level: SKIP, factors: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @linked_services = linked_services @risk_level = risk_level unless risk_level == SKIP @factors = factors unless factors == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#factors ⇒ Array[String]
List of factors, when available, that contribute towards the risk level of the given risk check type.
25 26 27 |
# File 'lib/the_plaid_api/models/risk_check_phone.rb', line 25 def factors @factors end |
#linked_services ⇒ Array[RiskCheckLinkedService]
A list of online services where this phone number has been detected to have accounts or other activity.
16 17 18 |
# File 'lib/the_plaid_api/models/risk_check_phone.rb', line 16 def linked_services @linked_services end |
#risk_level ⇒ RiskLevel
Risk level for the given risk check type.
20 21 22 |
# File 'lib/the_plaid_api/models/risk_check_phone.rb', line 20 def risk_level @risk_level end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/the_plaid_api/models/risk_check_phone.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. linked_services = hash.key?('linked_services') ? hash['linked_services'] : nil risk_level = hash.key?('risk_level') ? hash['risk_level'] : SKIP factors = hash.key?('factors') ? hash['factors'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. RiskCheckPhone.new(linked_services: linked_services, risk_level: risk_level, factors: factors, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
28 29 30 31 32 33 34 |
# File 'lib/the_plaid_api/models/risk_check_phone.rb', line 28 def self.names @_hash = {} if @_hash.nil? @_hash['linked_services'] = 'linked_services' @_hash['risk_level'] = 'risk_level' @_hash['factors'] = 'factors' @_hash end |
.nullables ⇒ Object
An array for nullable fields
45 46 47 |
# File 'lib/the_plaid_api/models/risk_check_phone.rb', line 45 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
37 38 39 40 41 42 |
# File 'lib/the_plaid_api/models/risk_check_phone.rb', line 37 def self.optionals %w[ risk_level factors ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
92 93 94 95 96 97 |
# File 'lib/the_plaid_api/models/risk_check_phone.rb', line 92 def inspect class_name = self.class.name.split('::').last "<#{class_name} linked_services: #{@linked_services.inspect}, risk_level:"\ " #{@risk_level.inspect}, factors: #{@factors.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
85 86 87 88 89 |
# File 'lib/the_plaid_api/models/risk_check_phone.rb', line 85 def to_s class_name = self.class.name.split('::').last "<#{class_name} linked_services: #{@linked_services}, risk_level: #{@risk_level}, factors:"\ " #{@factors}, additional_properties: #{@additional_properties}>" end |