Class: ThePlaidApi::RiskCheckStolenIdentity
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::RiskCheckStolenIdentity
- Defined in:
- lib/the_plaid_api/models/risk_check_stolen_identity.rb
Overview
Field containing the data used in determining the outcome of the stolen identity risk check. Contains the following fields: ‘score` - A score from 0 to 100 indicating the likelihood that the user is a stolen identity.
Instance Attribute Summary collapse
-
#risk_level ⇒ RiskLevel
Risk level for the given risk check type.
-
#score ⇒ Integer
A score from 0 to 100 indicating the likelihood that the user is a stolen identity.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(score:, risk_level: SKIP, additional_properties: nil) ⇒ RiskCheckStolenIdentity
constructor
A new instance of RiskCheckStolenIdentity.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(score:, risk_level: SKIP, additional_properties: nil) ⇒ RiskCheckStolenIdentity
Returns a new instance of RiskCheckStolenIdentity.
43 44 45 46 47 48 49 50 |
# File 'lib/the_plaid_api/models/risk_check_stolen_identity.rb', line 43 def initialize(score:, risk_level: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @score = score @risk_level = risk_level unless risk_level == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#risk_level ⇒ RiskLevel
Risk level for the given risk check type.
21 22 23 |
# File 'lib/the_plaid_api/models/risk_check_stolen_identity.rb', line 21 def risk_level @risk_level end |
#score ⇒ Integer
A score from 0 to 100 indicating the likelihood that the user is a stolen identity.
17 18 19 |
# File 'lib/the_plaid_api/models/risk_check_stolen_identity.rb', line 17 def score @score end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/the_plaid_api/models/risk_check_stolen_identity.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. score = hash.key?('score') ? hash['score'] : nil risk_level = hash.key?('risk_level') ? hash['risk_level'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. RiskCheckStolenIdentity.new(score: score, risk_level: risk_level, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/the_plaid_api/models/risk_check_stolen_identity.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['score'] = 'score' @_hash['risk_level'] = 'risk_level' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/the_plaid_api/models/risk_check_stolen_identity.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 35 36 |
# File 'lib/the_plaid_api/models/risk_check_stolen_identity.rb', line 32 def self.optionals %w[ risk_level ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/the_plaid_api/models/risk_check_stolen_identity.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} score: #{@score.inspect}, risk_level: #{@risk_level.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/the_plaid_api/models/risk_check_stolen_identity.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} score: #{@score}, risk_level: #{@risk_level}, additional_properties:"\ " #{@additional_properties}>" end |