Class: ThePlaidApi::SandboxItemFireWebhookRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::SandboxItemFireWebhookRequest
- Defined in:
- lib/the_plaid_api/models/sandbox_item_fire_webhook_request.rb
Overview
SandboxItemFireWebhookRequest defines the request schema for ‘/sandbox/item/fire_webhook`
Instance Attribute Summary collapse
-
#access_token ⇒ String
The access token associated with the Item data is being requested for.
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#webhook_code ⇒ WebhookCode
The webhook codes that can be fired by this test endpoint.
-
#webhook_type ⇒ WebhookType
The webhook types that can be fired by this test endpoint.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(access_token:, webhook_code:, client_id: SKIP, secret: SKIP, webhook_type: SKIP, additional_properties: nil) ⇒ SandboxItemFireWebhookRequest
constructor
A new instance of SandboxItemFireWebhookRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(access_token:, webhook_code:, client_id: SKIP, secret: SKIP, webhook_type: SKIP, additional_properties: nil) ⇒ SandboxItemFireWebhookRequest
Returns a new instance of SandboxItemFireWebhookRequest.
61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/the_plaid_api/models/sandbox_item_fire_webhook_request.rb', line 61 def initialize(access_token:, webhook_code:, client_id: SKIP, secret: SKIP, webhook_type: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @access_token = access_token @webhook_type = webhook_type unless webhook_type == SKIP @webhook_code = webhook_code @additional_properties = additional_properties end |
Instance Attribute Details
#access_token ⇒ String
The access token associated with the Item data is being requested for.
26 27 28 |
# File 'lib/the_plaid_api/models/sandbox_item_fire_webhook_request.rb', line 26 def access_token @access_token end |
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/sandbox_item_fire_webhook_request.rb', line 17 def client_id @client_id end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/the_plaid_api/models/sandbox_item_fire_webhook_request.rb', line 22 def secret @secret end |
#webhook_code ⇒ WebhookCode
The webhook codes that can be fired by this test endpoint.
34 35 36 |
# File 'lib/the_plaid_api/models/sandbox_item_fire_webhook_request.rb', line 34 def webhook_code @webhook_code end |
#webhook_type ⇒ WebhookType
The webhook types that can be fired by this test endpoint.
30 31 32 |
# File 'lib/the_plaid_api/models/sandbox_item_fire_webhook_request.rb', line 30 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/the_plaid_api/models/sandbox_item_fire_webhook_request.rb', line 75 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. access_token = hash.key?('access_token') ? hash['access_token'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SandboxItemFireWebhookRequest.new(access_token: access_token, webhook_code: webhook_code, client_id: client_id, secret: secret, webhook_type: webhook_type, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 |
# File 'lib/the_plaid_api/models/sandbox_item_fire_webhook_request.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['access_token'] = 'access_token' @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash end |
.nullables ⇒ Object
An array for nullable fields
57 58 59 |
# File 'lib/the_plaid_api/models/sandbox_item_fire_webhook_request.rb', line 57 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
48 49 50 51 52 53 54 |
# File 'lib/the_plaid_api/models/sandbox_item_fire_webhook_request.rb', line 48 def self.optionals %w[ client_id secret webhook_type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
110 111 112 113 114 115 |
# File 'lib/the_plaid_api/models/sandbox_item_fire_webhook_request.rb', line 110 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, access_token:"\ " #{@access_token.inspect}, webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
102 103 104 105 106 107 |
# File 'lib/the_plaid_api/models/sandbox_item_fire_webhook_request.rb', line 102 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, access_token:"\ " #{@access_token}, webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code},"\ " additional_properties: #{@additional_properties}>" end |