Class: ThePlaidApi::SandboxTransferRefundSimulateRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::SandboxTransferRefundSimulateRequest
- Defined in:
- lib/the_plaid_api/models/sandbox_transfer_refund_simulate_request.rb
Overview
Defines the request schema for ‘/sandbox/transfer/refund/simulate`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#event_type ⇒ String
The asynchronous event to be simulated.
-
#failure_reason ⇒ TransferFailure
The failure reason if the event type for a transfer is ‘“failed”` or `“returned”`.
-
#refund_id ⇒ String
Plaid’s unique identifier for a refund.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#test_clock_id ⇒ String
Plaid’s unique identifier for a test clock.
-
#webhook ⇒ String
The webhook URL to which a ‘TRANSFER_EVENTS_UPDATE` webhook should be sent.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(refund_id:, event_type:, client_id: SKIP, secret: SKIP, test_clock_id: SKIP, failure_reason: SKIP, webhook: SKIP, additional_properties: nil) ⇒ SandboxTransferRefundSimulateRequest
constructor
A new instance of SandboxTransferRefundSimulateRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(refund_id:, event_type:, client_id: SKIP, secret: SKIP, test_clock_id: SKIP, failure_reason: SKIP, webhook: SKIP, additional_properties: nil) ⇒ SandboxTransferRefundSimulateRequest
Returns a new instance of SandboxTransferRefundSimulateRequest.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/the_plaid_api/models/sandbox_transfer_refund_simulate_request.rb', line 89 def initialize(refund_id:, event_type:, client_id: SKIP, secret: SKIP, test_clock_id: SKIP, failure_reason: SKIP, webhook: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @refund_id = refund_id @test_clock_id = test_clock_id unless test_clock_id == SKIP @event_type = event_type @failure_reason = failure_reason unless failure_reason == SKIP @webhook = webhook unless webhook == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/the_plaid_api/models/sandbox_transfer_refund_simulate_request.rb', line 16 def client_id @client_id end |
#event_type ⇒ String
The asynchronous event to be simulated. May be: ‘refund.posted`, `refund.settled`, `refund.failed`, or `refund.returned`. An error will be returned if the event type is incompatible with the current refund status. Compatible status –> event type transitions include: `refund.pending` –> `refund.failed` `refund.pending` –> `refund.posted` `refund.posted` –> `refund.returned` `refund.posted` –> `refund.settled` `refund.posted` events can only be simulated if the refunded transfer has been transitioned to settled. This mimics the ordering of events in Production.
45 46 47 |
# File 'lib/the_plaid_api/models/sandbox_transfer_refund_simulate_request.rb', line 45 def event_type @event_type end |
#failure_reason ⇒ TransferFailure
The failure reason if the event type for a transfer is ‘“failed”` or `“returned”`. Null value otherwise.
50 51 52 |
# File 'lib/the_plaid_api/models/sandbox_transfer_refund_simulate_request.rb', line 50 def failure_reason @failure_reason end |
#refund_id ⇒ String
Plaid’s unique identifier for a refund.
25 26 27 |
# File 'lib/the_plaid_api/models/sandbox_transfer_refund_simulate_request.rb', line 25 def refund_id @refund_id end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
21 22 23 |
# File 'lib/the_plaid_api/models/sandbox_transfer_refund_simulate_request.rb', line 21 def secret @secret end |
#test_clock_id ⇒ String
Plaid’s unique identifier for a test clock. If provided, the event to be simulated is created at the ‘virtual_time` on the provided `test_clock`.
30 31 32 |
# File 'lib/the_plaid_api/models/sandbox_transfer_refund_simulate_request.rb', line 30 def test_clock_id @test_clock_id end |
#webhook ⇒ String
The webhook URL to which a ‘TRANSFER_EVENTS_UPDATE` webhook should be sent.
55 56 57 |
# File 'lib/the_plaid_api/models/sandbox_transfer_refund_simulate_request.rb', line 55 def webhook @webhook end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/the_plaid_api/models/sandbox_transfer_refund_simulate_request.rb', line 106 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. refund_id = hash.key?('refund_id') ? hash['refund_id'] : nil event_type = hash.key?('event_type') ? hash['event_type'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP test_clock_id = hash.key?('test_clock_id') ? hash['test_clock_id'] : SKIP failure_reason = TransferFailure.from_hash(hash['failure_reason']) if hash['failure_reason'] webhook = hash.key?('webhook') ? hash['webhook'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SandboxTransferRefundSimulateRequest.new(refund_id: refund_id, event_type: event_type, client_id: client_id, secret: secret, test_clock_id: test_clock_id, failure_reason: failure_reason, webhook: webhook, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/the_plaid_api/models/sandbox_transfer_refund_simulate_request.rb', line 58 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['refund_id'] = 'refund_id' @_hash['test_clock_id'] = 'test_clock_id' @_hash['event_type'] = 'event_type' @_hash['failure_reason'] = 'failure_reason' @_hash['webhook'] = 'webhook' @_hash end |
.nullables ⇒ Object
An array for nullable fields
82 83 84 85 86 87 |
# File 'lib/the_plaid_api/models/sandbox_transfer_refund_simulate_request.rb', line 82 def self.nullables %w[ test_clock_id failure_reason ] end |
.optionals ⇒ Object
An array for optional fields
71 72 73 74 75 76 77 78 79 |
# File 'lib/the_plaid_api/models/sandbox_transfer_refund_simulate_request.rb', line 71 def self.optionals %w[ client_id secret test_clock_id failure_reason webhook ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
146 147 148 149 150 151 152 |
# File 'lib/the_plaid_api/models/sandbox_transfer_refund_simulate_request.rb', line 146 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, refund_id:"\ " #{@refund_id.inspect}, test_clock_id: #{@test_clock_id.inspect}, event_type:"\ " #{@event_type.inspect}, failure_reason: #{@failure_reason.inspect}, webhook:"\ " #{@webhook.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
137 138 139 140 141 142 143 |
# File 'lib/the_plaid_api/models/sandbox_transfer_refund_simulate_request.rb', line 137 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, refund_id: #{@refund_id},"\ " test_clock_id: #{@test_clock_id}, event_type: #{@event_type}, failure_reason:"\ " #{@failure_reason}, webhook: #{@webhook}, additional_properties:"\ " #{@additional_properties}>" end |