Class: ThePlaidApi::SandboxTransferTestClockAdvanceRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::SandboxTransferTestClockAdvanceRequest
- Defined in:
- lib/the_plaid_api/models/sandbox_transfer_test_clock_advance_request.rb
Overview
Defines the request schema for ‘/sandbox/transfer/test_clock/advance`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#new_virtual_time ⇒ DateTime
The virtual timestamp on the test clock.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#test_clock_id ⇒ String
Plaid’s unique identifier for a test clock.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(test_clock_id:, new_virtual_time:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ SandboxTransferTestClockAdvanceRequest
constructor
A new instance of SandboxTransferTestClockAdvanceRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_new_virtual_time ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(test_clock_id:, new_virtual_time:, client_id: SKIP, secret: SKIP, additional_properties: nil) ⇒ SandboxTransferTestClockAdvanceRequest
Returns a new instance of SandboxTransferTestClockAdvanceRequest.
61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_advance_request.rb', line 61 def initialize(test_clock_id:, new_virtual_time:, client_id: SKIP, secret: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @test_clock_id = test_clock_id @new_virtual_time = new_virtual_time @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_advance_request.rb', line 17 def client_id @client_id end |
#new_virtual_time ⇒ DateTime
The virtual timestamp on the test clock. This will be of the form ‘2006-01-02T15:04:05Z`.
36 37 38 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_advance_request.rb', line 36 def new_virtual_time @new_virtual_time end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_advance_request.rb', line 22 def secret @secret end |
#test_clock_id ⇒ String
Plaid’s unique identifier for a test clock. This field is only populated in the Sandbox environment, and only if a ‘test_clock_id` was included in the `/transfer/recurring/create` request. For more details, see [Simulating recurring transfers](plaid.com/docs/transfer/sandbox/#simulating-recurring-t ransfers).
31 32 33 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_advance_request.rb', line 31 def test_clock_id @test_clock_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_advance_request.rb', line 74 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. test_clock_id = hash.key?('test_clock_id') ? hash['test_clock_id'] : nil new_virtual_time = if hash.key?('new_virtual_time') (DateTimeHelper.from_rfc3339(hash['new_virtual_time']) if hash['new_virtual_time']) end client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SandboxTransferTestClockAdvanceRequest.new(test_clock_id: test_clock_id, new_virtual_time: new_virtual_time, client_id: client_id, secret: secret, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
39 40 41 42 43 44 45 46 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_advance_request.rb', line 39 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['test_clock_id'] = 'test_clock_id' @_hash['new_virtual_time'] = 'new_virtual_time' @_hash end |
.nullables ⇒ Object
An array for nullable fields
57 58 59 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_advance_request.rb', line 57 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 52 53 54 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_advance_request.rb', line 49 def self.optionals %w[ client_id secret ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
113 114 115 116 117 118 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_advance_request.rb', line 113 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\ " test_clock_id: #{@test_clock_id.inspect}, new_virtual_time: #{@new_virtual_time.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_custom_new_virtual_time ⇒ Object
100 101 102 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_advance_request.rb', line 100 def to_custom_new_virtual_time DateTimeHelper.to_rfc3339(new_virtual_time) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
105 106 107 108 109 110 |
# File 'lib/the_plaid_api/models/sandbox_transfer_test_clock_advance_request.rb', line 105 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, test_clock_id:"\ " #{@test_clock_id}, new_virtual_time: #{@new_virtual_time}, additional_properties:"\ " #{@additional_properties}>" end |