Class: ThePlaidApi::SelfieAnalysisLivenessCheck
- Inherits:
-
Object
- Object
- ThePlaidApi::SelfieAnalysisLivenessCheck
- Defined in:
- lib/the_plaid_api/models/selfie_analysis_liveness_check.rb
Overview
Assessment of whether the selfie capture is of a real human being, as opposed to a picture of a human on a screen, a picture of a paper cut out, someone wearing a mask, or a deepfake.
Constant Summary collapse
- SELFIE_ANALYSIS_LIVENESS_CHECK =
[ # TODO: Write general description for SUCCESS SUCCESS = 'success'.freeze, # TODO: Write general description for FAILED FAILED = 'failed'.freeze ].freeze
Class Method Summary collapse
Class Method Details
.from_value(value, default_value = SUCCESS) ⇒ Object
25 26 27 28 29 30 31 32 33 34 35 36 |
# File 'lib/the_plaid_api/models/selfie_analysis_liveness_check.rb', line 25 def self.from_value(value, default_value = SUCCESS) return default_value if value.nil? str = value.to_s.strip case str.downcase when 'success' then SUCCESS when 'failed' then FAILED else default_value end end |
.validate(value) ⇒ Object
19 20 21 22 23 |
# File 'lib/the_plaid_api/models/selfie_analysis_liveness_check.rb', line 19 def self.validate(value) return false if value.nil? SELFIE_ANALYSIS_LIVENESS_CHECK.include?(value) end |