Class: ThePlaidApi::SelfieCapture
- Defined in:
- lib/the_plaid_api/models/selfie_capture.rb
Overview
The image or video capture of a selfie. Only one of image or video URL will be populated per selfie.
Instance Attribute Summary collapse
-
#image_url ⇒ String
Temporary URL for downloading an image selfie capture.
-
#video_url ⇒ String
Temporary URL for downloading a video selfie capture.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(image_url:, video_url:, additional_properties: nil) ⇒ SelfieCapture
constructor
A new instance of SelfieCapture.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(image_url:, video_url:, additional_properties: nil) ⇒ SelfieCapture
Returns a new instance of SelfieCapture.
42 43 44 45 46 47 48 49 |
# File 'lib/the_plaid_api/models/selfie_capture.rb', line 42 def initialize(image_url:, video_url:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @image_url = image_url @video_url = video_url @additional_properties = additional_properties end |
Instance Attribute Details
#image_url ⇒ String
Temporary URL for downloading an image selfie capture.
15 16 17 |
# File 'lib/the_plaid_api/models/selfie_capture.rb', line 15 def image_url @image_url end |
#video_url ⇒ String
Temporary URL for downloading a video selfie capture.
19 20 21 |
# File 'lib/the_plaid_api/models/selfie_capture.rb', line 19 def video_url @video_url end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/the_plaid_api/models/selfie_capture.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. image_url = hash.key?('image_url') ? hash['image_url'] : nil video_url = hash.key?('video_url') ? hash['video_url'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SelfieCapture.new(image_url: image_url, video_url: video_url, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/the_plaid_api/models/selfie_capture.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['image_url'] = 'image_url' @_hash['video_url'] = 'video_url' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 38 39 40 |
# File 'lib/the_plaid_api/models/selfie_capture.rb', line 35 def self.nullables %w[ image_url video_url ] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/the_plaid_api/models/selfie_capture.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
80 81 82 83 84 |
# File 'lib/the_plaid_api/models/selfie_capture.rb', line 80 def inspect class_name = self.class.name.split('::').last "<#{class_name} image_url: #{@image_url.inspect}, video_url: #{@video_url.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 77 |
# File 'lib/the_plaid_api/models/selfie_capture.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} image_url: #{@image_url}, video_url: #{@video_url}, additional_properties:"\ " #{@additional_properties}>" end |