Class: ThePlaidApi::ServiceProductFulfillmentDetail
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::ServiceProductFulfillmentDetail
- Defined in:
- lib/the_plaid_api/models/service_product_fulfillment_detail.rb
Overview
Documentation not found in the MISMO model viewer and not provided by Freddie Mac.
Instance Attribute Summary collapse
-
#service_product_fulfillment_identifier ⇒ ServiceProductFulfillmentIdentifier
Documentation not found in the MISMO model viewer and not provided by Freddie Mac.
-
#vendor_order_identifier ⇒ String
A string that uniquely identifies a type of order Verification of Asset.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(vendor_order_identifier:, service_product_fulfillment_identifier:, additional_properties: nil) ⇒ ServiceProductFulfillmentDetail
constructor
A new instance of ServiceProductFulfillmentDetail.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(vendor_order_identifier:, service_product_fulfillment_identifier:, additional_properties: nil) ⇒ ServiceProductFulfillmentDetail
Returns a new instance of ServiceProductFulfillmentDetail.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/the_plaid_api/models/service_product_fulfillment_detail.rb', line 43 def initialize(vendor_order_identifier:, service_product_fulfillment_identifier:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @vendor_order_identifier = vendor_order_identifier @service_product_fulfillment_identifier = service_product_fulfillment_identifier @additional_properties = additional_properties end |
Instance Attribute Details
#service_product_fulfillment_identifier ⇒ ServiceProductFulfillmentIdentifier
Documentation not found in the MISMO model viewer and not provided by Freddie Mac.
20 21 22 |
# File 'lib/the_plaid_api/models/service_product_fulfillment_detail.rb', line 20 def service_product_fulfillment_identifier @service_product_fulfillment_identifier end |
#vendor_order_identifier ⇒ String
A string that uniquely identifies a type of order Verification of Asset.
15 16 17 |
# File 'lib/the_plaid_api/models/service_product_fulfillment_detail.rb', line 15 def vendor_order_identifier @vendor_order_identifier end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/the_plaid_api/models/service_product_fulfillment_detail.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. vendor_order_identifier = hash.key?('VendorOrderIdentifier') ? hash['VendorOrderIdentifier'] : nil service_product_fulfillment_identifier = hash.key?('ServiceProductFulfillmentIdentifier') ? hash['ServiceProductFulfillmentIdentifier'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ServiceProductFulfillmentDetail.new(vendor_order_identifier: vendor_order_identifier, service_product_fulfillment_identifier: service_product_fulfillment_identifier, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 29 |
# File 'lib/the_plaid_api/models/service_product_fulfillment_detail.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['vendor_order_identifier'] = 'VendorOrderIdentifier' @_hash['service_product_fulfillment_identifier'] = 'ServiceProductFulfillmentIdentifier' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 40 41 |
# File 'lib/the_plaid_api/models/service_product_fulfillment_detail.rb', line 37 def self.nullables %w[ vendor_order_identifier ] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 |
# File 'lib/the_plaid_api/models/service_product_fulfillment_detail.rb', line 32 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 91 92 |
# File 'lib/the_plaid_api/models/service_product_fulfillment_detail.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} vendor_order_identifier: #{@vendor_order_identifier.inspect},"\ ' service_product_fulfillment_identifier:'\ " #{@service_product_fulfillment_identifier.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 82 83 |
# File 'lib/the_plaid_api/models/service_product_fulfillment_detail.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} vendor_order_identifier: #{@vendor_order_identifier},"\ " service_product_fulfillment_identifier: #{@service_product_fulfillment_identifier},"\ " additional_properties: #{@additional_properties}>" end |