Class: ThePlaidApi::TaxpayerIdentifier
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TaxpayerIdentifier
- Defined in:
- lib/the_plaid_api/models/taxpayer_identifier.rb
Overview
Information about the Taxpayer identification values assigned to the individual or legal entity.
Instance Attribute Summary collapse
-
#taxpayer_identifier_type ⇒ TaxpayerIdentifierType
A value from a MISMO prescribed list that classifies identification numbers used by the Internal Revenue Service (IRS) in the administration of tax laws.
-
#taxpayer_identifier_value ⇒ String
The value of the taxpayer identifier as assigned by the IRS to the individual or legal entity.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(taxpayer_identifier_type:, taxpayer_identifier_value:, additional_properties: nil) ⇒ TaxpayerIdentifier
constructor
A new instance of TaxpayerIdentifier.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(taxpayer_identifier_type:, taxpayer_identifier_value:, additional_properties: nil) ⇒ TaxpayerIdentifier
Returns a new instance of TaxpayerIdentifier.
46 47 48 49 50 51 52 53 54 |
# File 'lib/the_plaid_api/models/taxpayer_identifier.rb', line 46 def initialize(taxpayer_identifier_type:, taxpayer_identifier_value:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @taxpayer_identifier_type = taxpayer_identifier_type @taxpayer_identifier_value = taxpayer_identifier_value @additional_properties = additional_properties end |
Instance Attribute Details
#taxpayer_identifier_type ⇒ TaxpayerIdentifierType
A value from a MISMO prescribed list that classifies identification numbers used by the Internal Revenue Service (IRS) in the administration of tax laws. A Social Security number (SSN) is issued by the SSA; all other taxpayer identification numbers are issued by the IRS.
18 19 20 |
# File 'lib/the_plaid_api/models/taxpayer_identifier.rb', line 18 def taxpayer_identifier_type @taxpayer_identifier_type end |
#taxpayer_identifier_value ⇒ String
The value of the taxpayer identifier as assigned by the IRS to the individual or legal entity.
23 24 25 |
# File 'lib/the_plaid_api/models/taxpayer_identifier.rb', line 23 def taxpayer_identifier_value @taxpayer_identifier_value end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/the_plaid_api/models/taxpayer_identifier.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. taxpayer_identifier_type = hash.key?('TaxpayerIdentifierType') ? hash['TaxpayerIdentifierType'] : nil taxpayer_identifier_value = hash.key?('TaxpayerIdentifierValue') ? hash['TaxpayerIdentifierValue'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TaxpayerIdentifier.new(taxpayer_identifier_type: taxpayer_identifier_type, taxpayer_identifier_value: taxpayer_identifier_value, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 |
# File 'lib/the_plaid_api/models/taxpayer_identifier.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['taxpayer_identifier_type'] = 'TaxpayerIdentifierType' @_hash['taxpayer_identifier_value'] = 'TaxpayerIdentifierValue' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 42 43 44 |
# File 'lib/the_plaid_api/models/taxpayer_identifier.rb', line 39 def self.nullables %w[ taxpayer_identifier_type taxpayer_identifier_value ] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/the_plaid_api/models/taxpayer_identifier.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
88 89 90 91 92 93 |
# File 'lib/the_plaid_api/models/taxpayer_identifier.rb', line 88 def inspect class_name = self.class.name.split('::').last "<#{class_name} taxpayer_identifier_type: #{@taxpayer_identifier_type.inspect},"\ " taxpayer_identifier_value: #{@taxpayer_identifier_value.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
80 81 82 83 84 85 |
# File 'lib/the_plaid_api/models/taxpayer_identifier.rb', line 80 def to_s class_name = self.class.name.split('::').last "<#{class_name} taxpayer_identifier_type: #{@taxpayer_identifier_type},"\ " taxpayer_identifier_value: #{@taxpayer_identifier_value}, additional_properties:"\ " #{@additional_properties}>" end |