Class: ThePlaidApi::TransactionsEnrichRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TransactionsEnrichRequest
- Defined in:
- lib/the_plaid_api/models/transactions_enrich_request.rb
Overview
TransactionsEnrichRequest defines the request schema for ‘/transactions/enrich`.
Instance Attribute Summary collapse
-
#account_type ⇒ String
The account type for the requested transactions (either ‘depository` or `credit`).
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#options ⇒ TransactionsEnrichRequestOptions
An optional object to be used with the request.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#transactions ⇒ Array[ClientProvidedTransaction]
An array of transaction objects to be enriched by Plaid.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_type:, transactions:, client_id: SKIP, secret: SKIP, options: SKIP, additional_properties: nil) ⇒ TransactionsEnrichRequest
constructor
A new instance of TransactionsEnrichRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_type:, transactions:, client_id: SKIP, secret: SKIP, options: SKIP, additional_properties: nil) ⇒ TransactionsEnrichRequest
Returns a new instance of TransactionsEnrichRequest.
63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/the_plaid_api/models/transactions_enrich_request.rb', line 63 def initialize(account_type:, transactions:, client_id: SKIP, secret: SKIP, options: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @account_type = account_type @transactions = transactions @options = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_type ⇒ String
The account type for the requested transactions (either ‘depository` or `credit`).
27 28 29 |
# File 'lib/the_plaid_api/models/transactions_enrich_request.rb', line 27 def account_type @account_type end |
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/transactions_enrich_request.rb', line 17 def client_id @client_id end |
#options ⇒ TransactionsEnrichRequestOptions
An optional object to be used with the request.
36 37 38 |
# File 'lib/the_plaid_api/models/transactions_enrich_request.rb', line 36 def @options end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/the_plaid_api/models/transactions_enrich_request.rb', line 22 def secret @secret end |
#transactions ⇒ Array[ClientProvidedTransaction]
An array of transaction objects to be enriched by Plaid. Maximum of 100 transactions per request.
32 33 34 |
# File 'lib/the_plaid_api/models/transactions_enrich_request.rb', line 32 def transactions @transactions end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/the_plaid_api/models/transactions_enrich_request.rb', line 77 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_type = hash.key?('account_type') ? hash['account_type'] : nil # Parameter is an array, so we need to iterate through it transactions = nil unless hash['transactions'].nil? transactions = [] hash['transactions'].each do |structure| transactions << (ClientProvidedTransaction.from_hash(structure) if structure) end end transactions = nil unless hash.key?('transactions') client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP = TransactionsEnrichRequestOptions.from_hash(hash['options']) if hash['options'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransactionsEnrichRequest.new(account_type: account_type, transactions: transactions, client_id: client_id, secret: secret, options: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
39 40 41 42 43 44 45 46 47 |
# File 'lib/the_plaid_api/models/transactions_enrich_request.rb', line 39 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['account_type'] = 'account_type' @_hash['transactions'] = 'transactions' @_hash['options'] = 'options' @_hash end |
.nullables ⇒ Object
An array for nullable fields
59 60 61 |
# File 'lib/the_plaid_api/models/transactions_enrich_request.rb', line 59 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
50 51 52 53 54 55 56 |
# File 'lib/the_plaid_api/models/transactions_enrich_request.rb', line 50 def self.optionals %w[ client_id secret options ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
121 122 123 124 125 126 |
# File 'lib/the_plaid_api/models/transactions_enrich_request.rb', line 121 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, account_type:"\ " #{@account_type.inspect}, transactions: #{@transactions.inspect}, options:"\ " #{@options.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
113 114 115 116 117 118 |
# File 'lib/the_plaid_api/models/transactions_enrich_request.rb', line 113 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, account_type:"\ " #{@account_type}, transactions: #{@transactions}, options: #{@options},"\ " additional_properties: #{@additional_properties}>" end |