Class: ThePlaidApi::TransactionsGetResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TransactionsGetResponse
- Defined in:
- lib/the_plaid_api/models/transactions_get_response.rb
Overview
TransactionsGetResponse defines the response schema for ‘/transactions/get`
Instance Attribute Summary collapse
-
#accounts ⇒ Array[Account]
An array containing the ‘accounts` associated with the Item for which transactions are being returned.
-
#item ⇒ Item
Metadata about the Item.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
-
#total_transactions ⇒ Integer
The total number of transactions available within the date range specified.
-
#transactions ⇒ Array[Transaction]
An array containing transactions from the account.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(accounts:, transactions:, total_transactions:, item:, request_id:, additional_properties: nil) ⇒ TransactionsGetResponse
constructor
A new instance of TransactionsGetResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(accounts:, transactions:, total_transactions:, item:, request_id:, additional_properties: nil) ⇒ TransactionsGetResponse
Returns a new instance of TransactionsGetResponse.
63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/the_plaid_api/models/transactions_get_response.rb', line 63 def initialize(accounts:, transactions:, total_transactions:, item:, request_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @accounts = accounts @transactions = transactions @total_transactions = total_transactions @item = item @request_id = request_id @additional_properties = additional_properties end |
Instance Attribute Details
#accounts ⇒ Array[Account]
An array containing the ‘accounts` associated with the Item for which transactions are being returned. Each transaction can be mapped to its corresponding account via the `account_id` field.
16 17 18 |
# File 'lib/the_plaid_api/models/transactions_get_response.rb', line 16 def accounts @accounts end |
#item ⇒ Item
Metadata about the Item.
34 35 36 |
# File 'lib/the_plaid_api/models/transactions_get_response.rb', line 34 def item @item end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
40 41 42 |
# File 'lib/the_plaid_api/models/transactions_get_response.rb', line 40 def request_id @request_id end |
#total_transactions ⇒ Integer
The total number of transactions available within the date range specified. If ‘total_transactions` is larger than the size of the `transactions` array, more transactions are available and can be fetched via manipulating the `offset` parameter.
30 31 32 |
# File 'lib/the_plaid_api/models/transactions_get_response.rb', line 30 def total_transactions @total_transactions end |
#transactions ⇒ Array[Transaction]
An array containing transactions from the account. Transactions are returned in reverse chronological order, with the most recent at the beginning of the array. The maximum number of transactions returned is determined by the ‘count` parameter.
23 24 25 |
# File 'lib/the_plaid_api/models/transactions_get_response.rb', line 23 def transactions @transactions end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/the_plaid_api/models/transactions_get_response.rb', line 77 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it accounts = nil unless hash['accounts'].nil? accounts = [] hash['accounts'].each do |structure| accounts << (Account.from_hash(structure) if structure) end end accounts = nil unless hash.key?('accounts') # Parameter is an array, so we need to iterate through it transactions = nil unless hash['transactions'].nil? transactions = [] hash['transactions'].each do |structure| transactions << (Transaction.from_hash(structure) if structure) end end transactions = nil unless hash.key?('transactions') total_transactions = hash.key?('total_transactions') ? hash['total_transactions'] : nil item = Item.from_hash(hash['item']) if hash['item'] request_id = hash.key?('request_id') ? hash['request_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransactionsGetResponse.new(accounts: accounts, transactions: transactions, total_transactions: total_transactions, item: item, request_id: request_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
43 44 45 46 47 48 49 50 51 |
# File 'lib/the_plaid_api/models/transactions_get_response.rb', line 43 def self.names @_hash = {} if @_hash.nil? @_hash['accounts'] = 'accounts' @_hash['transactions'] = 'transactions' @_hash['total_transactions'] = 'total_transactions' @_hash['item'] = 'item' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
59 60 61 |
# File 'lib/the_plaid_api/models/transactions_get_response.rb', line 59 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
54 55 56 |
# File 'lib/the_plaid_api/models/transactions_get_response.rb', line 54 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
131 132 133 134 135 136 |
# File 'lib/the_plaid_api/models/transactions_get_response.rb', line 131 def inspect class_name = self.class.name.split('::').last "<#{class_name} accounts: #{@accounts.inspect}, transactions: #{@transactions.inspect},"\ " total_transactions: #{@total_transactions.inspect}, item: #{@item.inspect}, request_id:"\ " #{@request_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
123 124 125 126 127 128 |
# File 'lib/the_plaid_api/models/transactions_get_response.rb', line 123 def to_s class_name = self.class.name.split('::').last "<#{class_name} accounts: #{@accounts}, transactions: #{@transactions}, total_transactions:"\ " #{@total_transactions}, item: #{@item}, request_id: #{@request_id}, additional_properties:"\ " #{@additional_properties}>" end |