Class: ThePlaidApi::TransactionsSyncRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TransactionsSyncRequest
- Defined in:
- lib/the_plaid_api/models/transactions_sync_request.rb
Overview
TransactionsSyncRequest defines the request schema for ‘/transactions/sync`
Instance Attribute Summary collapse
-
#access_token ⇒ String
The access token associated with the Item data is being requested for.
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#count ⇒ Integer
The number of transaction updates to fetch.
-
#cursor ⇒ String
The cursor value represents the last update requested.
-
#options ⇒ TransactionsSyncRequestOptions
An optional object to be used with the request.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(access_token:, client_id: SKIP, secret: SKIP, cursor: SKIP, count: 100, options: SKIP, additional_properties: nil) ⇒ TransactionsSyncRequest
constructor
A new instance of TransactionsSyncRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(access_token:, client_id: SKIP, secret: SKIP, cursor: SKIP, count: 100, options: SKIP, additional_properties: nil) ⇒ TransactionsSyncRequest
Returns a new instance of TransactionsSyncRequest.
78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/the_plaid_api/models/transactions_sync_request.rb', line 78 def initialize(access_token:, client_id: SKIP, secret: SKIP, cursor: SKIP, count: 100, options: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @access_token = access_token @secret = secret unless secret == SKIP @cursor = cursor unless cursor == SKIP @count = count unless count == SKIP @options = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#access_token ⇒ String
The access token associated with the Item data is being requested for.
20 21 22 |
# File 'lib/the_plaid_api/models/transactions_sync_request.rb', line 20 def access_token @access_token end |
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/the_plaid_api/models/transactions_sync_request.rb', line 16 def client_id @client_id end |
#count ⇒ Integer
The number of transaction updates to fetch.
43 44 45 |
# File 'lib/the_plaid_api/models/transactions_sync_request.rb', line 43 def count @count end |
#cursor ⇒ String
The cursor value represents the last update requested. Providing it will cause the response to only return changes after this update. If omitted, the entire history of updates will be returned, starting with the first-added transactions on the Item. The cursor also accepts the special value of ‘“now”`, which can be used to fast-forward the cursor as part of migrating an existing Item from `/transactions/get` to `/transactions/sync`. For more information, see the [Transactions sync migration guide](plaid.com/docs/transactions/sync-migration/). Note that using the `“now”` value is not supported for any use case other than migrating existing Items from `/transactions/get`. The upper-bound length of this cursor is 256 characters of base64.
39 40 41 |
# File 'lib/the_plaid_api/models/transactions_sync_request.rb', line 39 def cursor @cursor end |
#options ⇒ TransactionsSyncRequestOptions
An optional object to be used with the request. If specified, ‘options` must not be `null`.
48 49 50 |
# File 'lib/the_plaid_api/models/transactions_sync_request.rb', line 48 def @options end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
25 26 27 |
# File 'lib/the_plaid_api/models/transactions_sync_request.rb', line 25 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/the_plaid_api/models/transactions_sync_request.rb', line 93 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. access_token = hash.key?('access_token') ? hash['access_token'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP cursor = hash.key?('cursor') ? hash['cursor'] : SKIP count = hash['count'] ||= 100 = TransactionsSyncRequestOptions.from_hash(hash['options']) if hash['options'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransactionsSyncRequest.new(access_token: access_token, client_id: client_id, secret: secret, cursor: cursor, count: count, options: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
51 52 53 54 55 56 57 58 59 60 |
# File 'lib/the_plaid_api/models/transactions_sync_request.rb', line 51 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['access_token'] = 'access_token' @_hash['secret'] = 'secret' @_hash['cursor'] = 'cursor' @_hash['count'] = 'count' @_hash['options'] = 'options' @_hash end |
.nullables ⇒ Object
An array for nullable fields
74 75 76 |
# File 'lib/the_plaid_api/models/transactions_sync_request.rb', line 74 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
63 64 65 66 67 68 69 70 71 |
# File 'lib/the_plaid_api/models/transactions_sync_request.rb', line 63 def self.optionals %w[ client_id secret cursor count options ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
130 131 132 133 134 135 |
# File 'lib/the_plaid_api/models/transactions_sync_request.rb', line 130 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, access_token: #{@access_token.inspect},"\ " secret: #{@secret.inspect}, cursor: #{@cursor.inspect}, count: #{@count.inspect}, options:"\ " #{@options.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
122 123 124 125 126 127 |
# File 'lib/the_plaid_api/models/transactions_sync_request.rb', line 122 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, access_token: #{@access_token}, secret:"\ " #{@secret}, cursor: #{@cursor}, count: #{@count}, options: #{@options},"\ " additional_properties: #{@additional_properties}>" end |