Class: ThePlaidApi::TransferAuthorizationGuaranteeDecisionRationale
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TransferAuthorizationGuaranteeDecisionRationale
- Defined in:
- lib/the_plaid_api/models/transfer_authorization_guarantee_decision_rationale.rb
Overview
The rationale for Plaid’s decision to not guarantee a transfer. Will be ‘null` unless `guarantee_decision` is `NOT_GUARANTEED`.
Instance Attribute Summary collapse
-
#code ⇒ TransferAuthorizationGuaranteeDecisionRationaleCode
A code representing the reason Plaid declined to guarantee this transfer: ‘RETURN_BANK`: The risk of a bank-initiated return (for example, an R01/NSF) is too high to guarantee this transfer.
-
#description ⇒ String
A human-readable description of why the transfer cannot be guaranteed.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(code:, description:, additional_properties: nil) ⇒ TransferAuthorizationGuaranteeDecisionRationale
constructor
A new instance of TransferAuthorizationGuaranteeDecisionRationale.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(code:, description:, additional_properties: nil) ⇒ TransferAuthorizationGuaranteeDecisionRationale
Returns a new instance of TransferAuthorizationGuaranteeDecisionRationale.
48 49 50 51 52 53 54 55 |
# File 'lib/the_plaid_api/models/transfer_authorization_guarantee_decision_rationale.rb', line 48 def initialize(code:, description:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @code = code @description = description @additional_properties = additional_properties end |
Instance Attribute Details
#code ⇒ TransferAuthorizationGuaranteeDecisionRationaleCode
A code representing the reason Plaid declined to guarantee this transfer: ‘RETURN_BANK`: The risk of a bank-initiated return (for example, an R01/NSF) is too high to guarantee this transfer. `RETURN_CUSTOMER`: The risk of a customer-initiated return (for example, a R10/Unauthorized) is too high to guarantee this transfer. `GUARANTEE_LIMIT_REACHED`: This transfer is low-risk, but Guarantee has exhausted an internal limit on the number or rate of guarantees that applies to this transfer. `RISK_ESTIMATE_UNAVAILABLE`: A risk estimate is unavailable for this Item. `REQUIRED_PARAM_MISSING`: Required fields are missing.
24 25 26 |
# File 'lib/the_plaid_api/models/transfer_authorization_guarantee_decision_rationale.rb', line 24 def code @code end |
#description ⇒ String
A human-readable description of why the transfer cannot be guaranteed.
28 29 30 |
# File 'lib/the_plaid_api/models/transfer_authorization_guarantee_decision_rationale.rb', line 28 def description @description end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/the_plaid_api/models/transfer_authorization_guarantee_decision_rationale.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. code = hash.key?('code') ? hash['code'] : nil description = hash.key?('description') ? hash['description'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransferAuthorizationGuaranteeDecisionRationale.new(code: code, description: description, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
31 32 33 34 35 36 |
# File 'lib/the_plaid_api/models/transfer_authorization_guarantee_decision_rationale.rb', line 31 def self.names @_hash = {} if @_hash.nil? @_hash['code'] = 'code' @_hash['description'] = 'description' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/the_plaid_api/models/transfer_authorization_guarantee_decision_rationale.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/the_plaid_api/models/transfer_authorization_guarantee_decision_rationale.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 |
# File 'lib/the_plaid_api/models/transfer_authorization_guarantee_decision_rationale.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} code: #{@code.inspect}, description: #{@description.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/the_plaid_api/models/transfer_authorization_guarantee_decision_rationale.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} code: #{@code}, description: #{@description}, additional_properties:"\ " #{@additional_properties}>" end |