Class: ThePlaidApi::TransferCancelRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TransferCancelRequest
- Defined in:
- lib/the_plaid_api/models/transfer_cancel_request.rb
Overview
Defines the request schema for ‘/transfer/cancel`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#originator_client_id ⇒ String
The Plaid client ID of the transfer originator.
-
#reason_code ⇒ ReasonCode
Specifies the reason for cancelling transfer.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#transfer_id ⇒ String
Plaid’s unique identifier for a transfer.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(transfer_id:, client_id: SKIP, secret: SKIP, originator_client_id: SKIP, reason_code: SKIP, additional_properties: nil) ⇒ TransferCancelRequest
constructor
A new instance of TransferCancelRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(transfer_id:, client_id: SKIP, secret: SKIP, originator_client_id: SKIP, reason_code: SKIP, additional_properties: nil) ⇒ TransferCancelRequest
Returns a new instance of TransferCancelRequest.
80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/the_plaid_api/models/transfer_cancel_request.rb', line 80 def initialize(transfer_id:, client_id: SKIP, secret: SKIP, originator_client_id: SKIP, reason_code: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @transfer_id = transfer_id @originator_client_id = originator_client_id unless originator_client_id == SKIP @reason_code = reason_code unless reason_code == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/the_plaid_api/models/transfer_cancel_request.rb', line 16 def client_id @client_id end |
#originator_client_id ⇒ String
The Plaid client ID of the transfer originator. Should only be present if ‘client_id` is a third-party sender (TPS).
30 31 32 |
# File 'lib/the_plaid_api/models/transfer_cancel_request.rb', line 30 def originator_client_id @originator_client_id end |
#reason_code ⇒ ReasonCode
Specifies the reason for cancelling transfer. This is required for RfP transfers, and will be ignored for other networks. ‘“AC03”` - Invalid Creditor Account Number `“AM09”` - Incorrect Amount `“CUST”` - Requested By Customer - Cancellation requested `“DUPL”` - Duplicate Payment `“FRAD”` - Fraudulent Payment - Unauthorized or fraudulently induced `“TECH”` - Technical Problem - Cancellation due to system issues `“UPAY”` - Undue Payment - Payment was made through another channel `“AC14”` - Invalid or Missing Creditor Account Type `“AM06”` - Amount Too Low `“BE05”` - Unrecognized Initiating Party `“FOCR”` - Following Refund Request `“MS02”` - No Specified Reason - Customer `“MS03”` - No Specified Reason - Agent `“RR04”` - Regulatory Reason `“RUTA”` - Return Upon Unable To Apply
50 51 52 |
# File 'lib/the_plaid_api/models/transfer_cancel_request.rb', line 50 def reason_code @reason_code end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
21 22 23 |
# File 'lib/the_plaid_api/models/transfer_cancel_request.rb', line 21 def secret @secret end |
#transfer_id ⇒ String
Plaid’s unique identifier for a transfer.
25 26 27 |
# File 'lib/the_plaid_api/models/transfer_cancel_request.rb', line 25 def transfer_id @transfer_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/the_plaid_api/models/transfer_cancel_request.rb', line 95 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. transfer_id = hash.key?('transfer_id') ? hash['transfer_id'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP originator_client_id = hash.key?('originator_client_id') ? hash['originator_client_id'] : SKIP reason_code = hash.key?('reason_code') ? hash['reason_code'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransferCancelRequest.new(transfer_id: transfer_id, client_id: client_id, secret: secret, originator_client_id: originator_client_id, reason_code: reason_code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
53 54 55 56 57 58 59 60 61 |
# File 'lib/the_plaid_api/models/transfer_cancel_request.rb', line 53 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['transfer_id'] = 'transfer_id' @_hash['originator_client_id'] = 'originator_client_id' @_hash['reason_code'] = 'reason_code' @_hash end |
.nullables ⇒ Object
An array for nullable fields
74 75 76 77 78 |
# File 'lib/the_plaid_api/models/transfer_cancel_request.rb', line 74 def self.nullables %w[ originator_client_id ] end |
.optionals ⇒ Object
An array for optional fields
64 65 66 67 68 69 70 71 |
# File 'lib/the_plaid_api/models/transfer_cancel_request.rb', line 64 def self.optionals %w[ client_id secret originator_client_id reason_code ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
131 132 133 134 135 136 |
# File 'lib/the_plaid_api/models/transfer_cancel_request.rb', line 131 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, transfer_id:"\ " #{@transfer_id.inspect}, originator_client_id: #{@originator_client_id.inspect},"\ " reason_code: #{@reason_code.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
123 124 125 126 127 128 |
# File 'lib/the_plaid_api/models/transfer_cancel_request.rb', line 123 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, transfer_id: #{@transfer_id},"\ " originator_client_id: #{@originator_client_id}, reason_code: #{@reason_code},"\ " additional_properties: #{@additional_properties}>" end |