Class: ThePlaidApi::TransferGetRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TransferGetRequest
- Defined in:
- lib/the_plaid_api/models/transfer_get_request.rb
Overview
Defines the request schema for ‘/transfer/get`
Instance Attribute Summary collapse
-
#authorization_id ⇒ String
Plaid’s unique identifier for a transfer authorization.
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#originator_client_id ⇒ String
The Plaid client ID of the transfer originator.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#transfer_id ⇒ String
Plaid’s unique identifier for a transfer.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_id: SKIP, secret: SKIP, transfer_id: SKIP, authorization_id: SKIP, originator_client_id: SKIP, additional_properties: nil) ⇒ TransferGetRequest
constructor
A new instance of TransferGetRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_id: SKIP, secret: SKIP, transfer_id: SKIP, authorization_id: SKIP, originator_client_id: SKIP, additional_properties: nil) ⇒ TransferGetRequest
Returns a new instance of TransferGetRequest.
65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/the_plaid_api/models/transfer_get_request.rb', line 65 def initialize(client_id: SKIP, secret: SKIP, transfer_id: SKIP, authorization_id: SKIP, originator_client_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @transfer_id = transfer_id unless transfer_id == SKIP @authorization_id = unless == SKIP @originator_client_id = originator_client_id unless originator_client_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#authorization_id ⇒ String
Plaid’s unique identifier for a transfer authorization.
29 30 31 |
# File 'lib/the_plaid_api/models/transfer_get_request.rb', line 29 def @authorization_id end |
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/the_plaid_api/models/transfer_get_request.rb', line 16 def client_id @client_id end |
#originator_client_id ⇒ String
The Plaid client ID of the transfer originator. Should only be present if ‘client_id` is a third-party sender (TPS).
34 35 36 |
# File 'lib/the_plaid_api/models/transfer_get_request.rb', line 34 def originator_client_id @originator_client_id end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
21 22 23 |
# File 'lib/the_plaid_api/models/transfer_get_request.rb', line 21 def secret @secret end |
#transfer_id ⇒ String
Plaid’s unique identifier for a transfer.
25 26 27 |
# File 'lib/the_plaid_api/models/transfer_get_request.rb', line 25 def transfer_id @transfer_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/the_plaid_api/models/transfer_get_request.rb', line 80 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP transfer_id = hash.key?('transfer_id') ? hash['transfer_id'] : SKIP = hash.key?('authorization_id') ? hash['authorization_id'] : SKIP originator_client_id = hash.key?('originator_client_id') ? hash['originator_client_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransferGetRequest.new(client_id: client_id, secret: secret, transfer_id: transfer_id, authorization_id: , originator_client_id: originator_client_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 |
# File 'lib/the_plaid_api/models/transfer_get_request.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['transfer_id'] = 'transfer_id' @_hash['authorization_id'] = 'authorization_id' @_hash['originator_client_id'] = 'originator_client_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
59 60 61 62 63 |
# File 'lib/the_plaid_api/models/transfer_get_request.rb', line 59 def self.nullables %w[ originator_client_id ] end |
.optionals ⇒ Object
An array for optional fields
48 49 50 51 52 53 54 55 56 |
# File 'lib/the_plaid_api/models/transfer_get_request.rb', line 48 def self.optionals %w[ client_id secret transfer_id authorization_id originator_client_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
117 118 119 120 121 122 123 |
# File 'lib/the_plaid_api/models/transfer_get_request.rb', line 117 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, transfer_id:"\ " #{@transfer_id.inspect}, authorization_id: #{@authorization_id.inspect},"\ " originator_client_id: #{@originator_client_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
109 110 111 112 113 114 |
# File 'lib/the_plaid_api/models/transfer_get_request.rb', line 109 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, transfer_id: #{@transfer_id},"\ " authorization_id: #{@authorization_id}, originator_client_id: #{@originator_client_id},"\ " additional_properties: #{@additional_properties}>" end |