Class: ThePlaidApi::TransferLedgerBalance
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TransferLedgerBalance
- Defined in:
- lib/the_plaid_api/models/transfer_ledger_balance.rb
Overview
Information about the balance of the ledger held with Plaid.
Instance Attribute Summary collapse
-
#available ⇒ String
The amount of this balance available for use (decimal string with two digits of precision e.g. “10.00”).
-
#pending ⇒ String
The amount of pending funds that are in processing (decimal string with two digits of precision e.g. “10.00”).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(available:, pending:, additional_properties: nil) ⇒ TransferLedgerBalance
constructor
A new instance of TransferLedgerBalance.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(available:, pending:, additional_properties: nil) ⇒ TransferLedgerBalance
Returns a new instance of TransferLedgerBalance.
40 41 42 43 44 45 46 47 |
# File 'lib/the_plaid_api/models/transfer_ledger_balance.rb', line 40 def initialize(available:, pending:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @available = available @pending = pending @additional_properties = additional_properties end |
Instance Attribute Details
#available ⇒ String
The amount of this balance available for use (decimal string with two digits of precision e.g. “10.00”).
15 16 17 |
# File 'lib/the_plaid_api/models/transfer_ledger_balance.rb', line 15 def available @available end |
#pending ⇒ String
The amount of pending funds that are in processing (decimal string with two digits of precision e.g. “10.00”).
20 21 22 |
# File 'lib/the_plaid_api/models/transfer_ledger_balance.rb', line 20 def pending @pending end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/the_plaid_api/models/transfer_ledger_balance.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. available = hash.key?('available') ? hash['available'] : nil pending = hash.key?('pending') ? hash['pending'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransferLedgerBalance.new(available: available, pending: pending, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/the_plaid_api/models/transfer_ledger_balance.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['available'] = 'available' @_hash['pending'] = 'pending' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/the_plaid_api/models/transfer_ledger_balance.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 |
# File 'lib/the_plaid_api/models/transfer_ledger_balance.rb', line 31 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/the_plaid_api/models/transfer_ledger_balance.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} available: #{@available.inspect}, pending: #{@pending.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/the_plaid_api/models/transfer_ledger_balance.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} available: #{@available}, pending: #{@pending}, additional_properties:"\ " #{@additional_properties}>" end |