Class: ThePlaidApi::TransferLedgerDistributeRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TransferLedgerDistributeRequest
- Defined in:
- lib/the_plaid_api/models/transfer_ledger_distribute_request.rb
Overview
Defines the request schema for ‘/transfer/ledger/distribute`
Instance Attribute Summary collapse
-
#amount ⇒ String
The amount to move (decimal string with two digits of precision e.g. “10.00”).
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#description ⇒ String
An optional description for the ledger distribute operation.
-
#from_ledger_id ⇒ String
The Ledger to pull money from.
-
#idempotency_key ⇒ String
A unique key provided by the client, per unique ledger distribute.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#to_ledger_id ⇒ String
The Ledger to credit money to.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(from_ledger_id:, to_ledger_id:, amount:, idempotency_key:, client_id: SKIP, secret: SKIP, description: SKIP, additional_properties: nil) ⇒ TransferLedgerDistributeRequest
constructor
A new instance of TransferLedgerDistributeRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(from_ledger_id:, to_ledger_id:, amount:, idempotency_key:, client_id: SKIP, secret: SKIP, description: SKIP, additional_properties: nil) ⇒ TransferLedgerDistributeRequest
Returns a new instance of TransferLedgerDistributeRequest.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/the_plaid_api/models/transfer_ledger_distribute_request.rb', line 77 def initialize(from_ledger_id:, to_ledger_id:, amount:, idempotency_key:, client_id: SKIP, secret: SKIP, description: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @from_ledger_id = from_ledger_id @to_ledger_id = to_ledger_id @amount = amount @idempotency_key = idempotency_key @description = description unless description == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#amount ⇒ String
The amount to move (decimal string with two digits of precision e.g. “10.00”). Amount must be positive.
34 35 36 |
# File 'lib/the_plaid_api/models/transfer_ledger_distribute_request.rb', line 34 def amount @amount end |
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/the_plaid_api/models/transfer_ledger_distribute_request.rb', line 16 def client_id @client_id end |
#description ⇒ String
An optional description for the ledger distribute operation.
48 49 50 |
# File 'lib/the_plaid_api/models/transfer_ledger_distribute_request.rb', line 48 def description @description end |
#from_ledger_id ⇒ String
The Ledger to pull money from.
25 26 27 |
# File 'lib/the_plaid_api/models/transfer_ledger_distribute_request.rb', line 25 def from_ledger_id @from_ledger_id end |
#idempotency_key ⇒ String
A unique key provided by the client, per unique ledger distribute. Maximum of 50 characters. The API supports idempotency for safely retrying the request without accidentally performing the same operation twice. For example, if a request to create a ledger distribute fails due to a network connection error, you can retry the request with the same idempotency key to guarantee that only a single distribute is created.
44 45 46 |
# File 'lib/the_plaid_api/models/transfer_ledger_distribute_request.rb', line 44 def idempotency_key @idempotency_key end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
21 22 23 |
# File 'lib/the_plaid_api/models/transfer_ledger_distribute_request.rb', line 21 def secret @secret end |
#to_ledger_id ⇒ String
The Ledger to credit money to.
29 30 31 |
# File 'lib/the_plaid_api/models/transfer_ledger_distribute_request.rb', line 29 def to_ledger_id @to_ledger_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/the_plaid_api/models/transfer_ledger_distribute_request.rb', line 94 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. from_ledger_id = hash.key?('from_ledger_id') ? hash['from_ledger_id'] : nil to_ledger_id = hash.key?('to_ledger_id') ? hash['to_ledger_id'] : nil amount = hash.key?('amount') ? hash['amount'] : nil idempotency_key = hash.key?('idempotency_key') ? hash['idempotency_key'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP description = hash.key?('description') ? hash['description'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransferLedgerDistributeRequest.new(from_ledger_id: from_ledger_id, to_ledger_id: to_ledger_id, amount: amount, idempotency_key: idempotency_key, client_id: client_id, secret: secret, description: description, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/the_plaid_api/models/transfer_ledger_distribute_request.rb', line 51 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['from_ledger_id'] = 'from_ledger_id' @_hash['to_ledger_id'] = 'to_ledger_id' @_hash['amount'] = 'amount' @_hash['idempotency_key'] = 'idempotency_key' @_hash['description'] = 'description' @_hash end |
.nullables ⇒ Object
An array for nullable fields
73 74 75 |
# File 'lib/the_plaid_api/models/transfer_ledger_distribute_request.rb', line 73 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
64 65 66 67 68 69 70 |
# File 'lib/the_plaid_api/models/transfer_ledger_distribute_request.rb', line 64 def self.optionals %w[ client_id secret description ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
136 137 138 139 140 141 142 |
# File 'lib/the_plaid_api/models/transfer_ledger_distribute_request.rb', line 136 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect},"\ " from_ledger_id: #{@from_ledger_id.inspect}, to_ledger_id: #{@to_ledger_id.inspect},"\ " amount: #{@amount.inspect}, idempotency_key: #{@idempotency_key.inspect}, description:"\ " #{@description.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
127 128 129 130 131 132 133 |
# File 'lib/the_plaid_api/models/transfer_ledger_distribute_request.rb', line 127 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, from_ledger_id:"\ " #{@from_ledger_id}, to_ledger_id: #{@to_ledger_id}, amount: #{@amount}, idempotency_key:"\ " #{@idempotency_key}, description: #{@description}, additional_properties:"\ " #{@additional_properties}>" end |