Class: ThePlaidApi::TransferLedgerGetResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TransferLedgerGetResponse
- Defined in:
- lib/the_plaid_api/models/transfer_ledger_get_response.rb
Overview
Defines the response schema for ‘/transfer/ledger/get`
Instance Attribute Summary collapse
-
#balance ⇒ TransferLedgerBalance
Information about the balance of the ledger held with Plaid.
-
#is_default ⇒ TrueClass | FalseClass
Whether this Ledger is the client’s default ledger.
-
#ledger_id ⇒ String
The unique identifier of the Ledger that was returned.
-
#name ⇒ String
The name of the Ledger.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(ledger_id:, balance:, name:, is_default:, request_id:, additional_properties: nil) ⇒ TransferLedgerGetResponse
constructor
A new instance of TransferLedgerGetResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(ledger_id:, balance:, name:, is_default:, request_id:, additional_properties: nil) ⇒ TransferLedgerGetResponse
Returns a new instance of TransferLedgerGetResponse.
55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/the_plaid_api/models/transfer_ledger_get_response.rb', line 55 def initialize(ledger_id:, balance:, name:, is_default:, request_id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @ledger_id = ledger_id @balance = balance @name = name @is_default = is_default @request_id = request_id @additional_properties = additional_properties end |
Instance Attribute Details
#balance ⇒ TransferLedgerBalance
Information about the balance of the ledger held with Plaid.
18 19 20 |
# File 'lib/the_plaid_api/models/transfer_ledger_get_response.rb', line 18 def balance @balance end |
#is_default ⇒ TrueClass | FalseClass
Whether this Ledger is the client’s default ledger.
26 27 28 |
# File 'lib/the_plaid_api/models/transfer_ledger_get_response.rb', line 26 def is_default @is_default end |
#ledger_id ⇒ String
The unique identifier of the Ledger that was returned.
14 15 16 |
# File 'lib/the_plaid_api/models/transfer_ledger_get_response.rb', line 14 def ledger_id @ledger_id end |
#name ⇒ String
The name of the Ledger
22 23 24 |
# File 'lib/the_plaid_api/models/transfer_ledger_get_response.rb', line 22 def name @name end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
32 33 34 |
# File 'lib/the_plaid_api/models/transfer_ledger_get_response.rb', line 32 def request_id @request_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/the_plaid_api/models/transfer_ledger_get_response.rb', line 69 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. ledger_id = hash.key?('ledger_id') ? hash['ledger_id'] : nil balance = TransferLedgerBalance.from_hash(hash['balance']) if hash['balance'] name = hash.key?('name') ? hash['name'] : nil is_default = hash.key?('is_default') ? hash['is_default'] : nil request_id = hash.key?('request_id') ? hash['request_id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransferLedgerGetResponse.new(ledger_id: ledger_id, balance: balance, name: name, is_default: is_default, request_id: request_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
35 36 37 38 39 40 41 42 43 |
# File 'lib/the_plaid_api/models/transfer_ledger_get_response.rb', line 35 def self.names @_hash = {} if @_hash.nil? @_hash['ledger_id'] = 'ledger_id' @_hash['balance'] = 'balance' @_hash['name'] = 'name' @_hash['is_default'] = 'is_default' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
51 52 53 |
# File 'lib/the_plaid_api/models/transfer_ledger_get_response.rb', line 51 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
46 47 48 |
# File 'lib/the_plaid_api/models/transfer_ledger_get_response.rb', line 46 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
104 105 106 107 108 109 |
# File 'lib/the_plaid_api/models/transfer_ledger_get_response.rb', line 104 def inspect class_name = self.class.name.split('::').last "<#{class_name} ledger_id: #{@ledger_id.inspect}, balance: #{@balance.inspect}, name:"\ " #{@name.inspect}, is_default: #{@is_default.inspect}, request_id: #{@request_id.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
96 97 98 99 100 101 |
# File 'lib/the_plaid_api/models/transfer_ledger_get_response.rb', line 96 def to_s class_name = self.class.name.split('::').last "<#{class_name} ledger_id: #{@ledger_id}, balance: #{@balance}, name: #{@name}, is_default:"\ " #{@is_default}, request_id: #{@request_id}, additional_properties:"\ " #{@additional_properties}>" end |