Class: ThePlaidApi::TransferOriginatorListRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::TransferOriginatorListRequest
- Defined in:
- lib/the_plaid_api/models/transfer_originator_list_request.rb
Overview
Defines the request schema for ‘/transfer/originator/list`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#count ⇒ Integer
The maximum number of originators to return.
-
#offset ⇒ Integer
The number of originators to skip before returning results.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_id: SKIP, secret: SKIP, count: 25, offset: 0, additional_properties: nil) ⇒ TransferOriginatorListRequest
constructor
A new instance of TransferOriginatorListRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_id: SKIP, secret: SKIP, count: 25, offset: 0, additional_properties: nil) ⇒ TransferOriginatorListRequest
Returns a new instance of TransferOriginatorListRequest.
59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/the_plaid_api/models/transfer_originator_list_request.rb', line 59 def initialize(client_id: SKIP, secret: SKIP, count: 25, offset: 0, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @count = count unless count == SKIP @offset = offset unless offset == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/the_plaid_api/models/transfer_originator_list_request.rb', line 16 def client_id @client_id end |
#count ⇒ Integer
The maximum number of originators to return.
25 26 27 |
# File 'lib/the_plaid_api/models/transfer_originator_list_request.rb', line 25 def count @count end |
#offset ⇒ Integer
The number of originators to skip before returning results.
29 30 31 |
# File 'lib/the_plaid_api/models/transfer_originator_list_request.rb', line 29 def offset @offset end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
21 22 23 |
# File 'lib/the_plaid_api/models/transfer_originator_list_request.rb', line 21 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/the_plaid_api/models/transfer_originator_list_request.rb', line 72 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP count = hash['count'] ||= 25 offset = hash['offset'] ||= 0 # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransferOriginatorListRequest.new(client_id: client_id, secret: secret, count: count, offset: offset, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
32 33 34 35 36 37 38 39 |
# File 'lib/the_plaid_api/models/transfer_originator_list_request.rb', line 32 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['count'] = 'count' @_hash['offset'] = 'offset' @_hash end |
.nullables ⇒ Object
An array for nullable fields
52 53 54 55 56 57 |
# File 'lib/the_plaid_api/models/transfer_originator_list_request.rb', line 52 def self.nullables %w[ count offset ] end |
.optionals ⇒ Object
An array for optional fields
42 43 44 45 46 47 48 49 |
# File 'lib/the_plaid_api/models/transfer_originator_list_request.rb', line 42 def self.optionals %w[ client_id secret count offset ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
104 105 106 107 108 109 |
# File 'lib/the_plaid_api/models/transfer_originator_list_request.rb', line 104 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, count:"\ " #{@count.inspect}, offset: #{@offset.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
97 98 99 100 101 |
# File 'lib/the_plaid_api/models/transfer_originator_list_request.rb', line 97 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, count: #{@count}, offset:"\ " #{@offset}, additional_properties: #{@additional_properties}>" end |