Class: ThePlaidApi::TrustIndex
- Defined in:
- lib/the_plaid_api/models/trust_index.rb
Overview
Represents a calculated Trust Index Score.
Instance Attribute Summary collapse
-
#model ⇒ String
The versioned name of the Trust Index model used for scoring.
-
#score ⇒ Integer
The overall trust index score.
-
#subscores ⇒ TrustIndexSubscores
Contains sub-score metadata.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(score:, model:, subscores:, additional_properties: nil) ⇒ TrustIndex
constructor
A new instance of TrustIndex.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(score:, model:, subscores:, additional_properties: nil) ⇒ TrustIndex
Returns a new instance of TrustIndex.
45 46 47 48 49 50 51 52 53 |
# File 'lib/the_plaid_api/models/trust_index.rb', line 45 def initialize(score:, model:, subscores:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @score = score @model = model @subscores = subscores @additional_properties = additional_properties end |
Instance Attribute Details
#model ⇒ String
The versioned name of the Trust Index model used for scoring.
18 19 20 |
# File 'lib/the_plaid_api/models/trust_index.rb', line 18 def model @model end |
#score ⇒ Integer
The overall trust index score.
14 15 16 |
# File 'lib/the_plaid_api/models/trust_index.rb', line 14 def score @score end |
#subscores ⇒ TrustIndexSubscores
Contains sub-score metadata.
22 23 24 |
# File 'lib/the_plaid_api/models/trust_index.rb', line 22 def subscores @subscores end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/the_plaid_api/models/trust_index.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. score = hash.key?('score') ? hash['score'] : nil model = hash.key?('model') ? hash['model'] : nil subscores = TrustIndexSubscores.from_hash(hash['subscores']) if hash['subscores'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TrustIndex.new(score: score, model: model, subscores: subscores, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/the_plaid_api/models/trust_index.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['score'] = 'score' @_hash['model'] = 'model' @_hash['subscores'] = 'subscores' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 42 43 |
# File 'lib/the_plaid_api/models/trust_index.rb', line 39 def self.nullables %w[ subscores ] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/the_plaid_api/models/trust_index.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
86 87 88 89 90 |
# File 'lib/the_plaid_api/models/trust_index.rb', line 86 def inspect class_name = self.class.name.split('::').last "<#{class_name} score: #{@score.inspect}, model: #{@model.inspect}, subscores:"\ " #{@subscores.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 |
# File 'lib/the_plaid_api/models/trust_index.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} score: #{@score}, model: #{@model}, subscores: #{@subscores},"\ " additional_properties: #{@additional_properties}>" end |