Class: ThePlaidApi::UserAccountRevokedWebhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::UserAccountRevokedWebhook
- Defined in:
- lib/the_plaid_api/models/user_account_revoked_webhook.rb
Overview
The ‘USER_ACCOUNT_REVOKED` webhook is fired when an end user has revoked access to their account on the Data Provider’s portal. This webhook is currently sent only for PNC Items, but may be sent in the future for other financial institutions that allow account-level permissions revocation through their portals. Upon receiving this webhook, it is recommended to delete any Plaid-derived data you have stored that is associated with the revoked account. If you are using Auth and receive this webhook, this webhook indicates that the TAN associated with the revoked account is no longer valid and cannot be used to create new transfers. You should not create new ACH transfers for the account that was revoked until access has been re-granted. You can request the user to re-grant access to their account by sending them through [update mode](plaid.com/docs/link/update-mode). Alternatively, they may re-grant access directly through the Data Provider’s portal. After the user has re-granted access, Auth customers should call the auth endpoint again to obtain the new TAN.
Instance Attribute Summary collapse
-
#account_id ⇒ String
The external account ID of the affected account.
-
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from.
-
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error.
-
#user_id ⇒ String
The Plaid ‘user_id` of the User associated with this webhook, warning, or error.
-
#webhook_code ⇒ String
‘USER_ACCOUNT_REVOKED`.
-
#webhook_type ⇒ String
‘ITEM`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, item_id:, account_id:, environment:, user_id: SKIP, additional_properties: nil) ⇒ UserAccountRevokedWebhook
constructor
A new instance of UserAccountRevokedWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, item_id:, account_id:, environment:, user_id: SKIP, additional_properties: nil) ⇒ UserAccountRevokedWebhook
Returns a new instance of UserAccountRevokedWebhook.
76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/the_plaid_api/models/user_account_revoked_webhook.rb', line 76 def initialize(webhook_type:, webhook_code:, item_id:, account_id:, environment:, user_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @item_id = item_id @user_id = user_id unless user_id == SKIP @account_id = account_id @environment = environment @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
The external account ID of the affected account
46 47 48 |
# File 'lib/the_plaid_api/models/user_account_revoked_webhook.rb', line 46 def account_id @account_id end |
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from
50 51 52 |
# File 'lib/the_plaid_api/models/user_account_revoked_webhook.rb', line 50 def environment @environment end |
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error
37 38 39 |
# File 'lib/the_plaid_api/models/user_account_revoked_webhook.rb', line 37 def item_id @item_id end |
#user_id ⇒ String
The Plaid ‘user_id` of the User associated with this webhook, warning, or error.
42 43 44 |
# File 'lib/the_plaid_api/models/user_account_revoked_webhook.rb', line 42 def user_id @user_id end |
#webhook_code ⇒ String
‘USER_ACCOUNT_REVOKED`
33 34 35 |
# File 'lib/the_plaid_api/models/user_account_revoked_webhook.rb', line 33 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘ITEM`
29 30 31 |
# File 'lib/the_plaid_api/models/user_account_revoked_webhook.rb', line 29 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/the_plaid_api/models/user_account_revoked_webhook.rb', line 91 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil item_id = hash.key?('item_id') ? hash['item_id'] : nil account_id = hash.key?('account_id') ? hash['account_id'] : nil environment = hash.key?('environment') ? hash['environment'] : nil user_id = hash.key?('user_id') ? hash['user_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UserAccountRevokedWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, item_id: item_id, account_id: account_id, environment: environment, user_id: user_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
53 54 55 56 57 58 59 60 61 62 |
# File 'lib/the_plaid_api/models/user_account_revoked_webhook.rb', line 53 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['item_id'] = 'item_id' @_hash['user_id'] = 'user_id' @_hash['account_id'] = 'account_id' @_hash['environment'] = 'environment' @_hash end |
.nullables ⇒ Object
An array for nullable fields
72 73 74 |
# File 'lib/the_plaid_api/models/user_account_revoked_webhook.rb', line 72 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
65 66 67 68 69 |
# File 'lib/the_plaid_api/models/user_account_revoked_webhook.rb', line 65 def self.optionals %w[ user_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
128 129 130 131 132 133 134 |
# File 'lib/the_plaid_api/models/user_account_revoked_webhook.rb', line 128 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, item_id: #{@item_id.inspect}, user_id: #{@user_id.inspect},"\ " account_id: #{@account_id.inspect}, environment: #{@environment.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
120 121 122 123 124 125 |
# File 'lib/the_plaid_api/models/user_account_revoked_webhook.rb', line 120 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, item_id:"\ " #{@item_id}, user_id: #{@user_id}, account_id: #{@account_id}, environment:"\ " #{@environment}, additional_properties: #{@additional_properties}>" end |