Class: ThePlaidApi::UserAccountSessionEvent
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::UserAccountSessionEvent
- Defined in:
- lib/the_plaid_api/models/user_account_session_event.rb
Overview
Event data for user account session tracking
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the event.
-
#outcome ⇒ String
Optional outcome of the event.
-
#timestamp ⇒ DateTime
The timestamp when the event occurred in ISO 8601 format.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name:, timestamp:, outcome: SKIP, additional_properties: nil) ⇒ UserAccountSessionEvent
constructor
A new instance of UserAccountSessionEvent.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_timestamp ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name:, timestamp:, outcome: SKIP, additional_properties: nil) ⇒ UserAccountSessionEvent
Returns a new instance of UserAccountSessionEvent.
46 47 48 49 50 51 52 53 54 |
# File 'lib/the_plaid_api/models/user_account_session_event.rb', line 46 def initialize(name:, timestamp:, outcome: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name @timestamp = @outcome = outcome unless outcome == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#name ⇒ String
The name of the event.
15 16 17 |
# File 'lib/the_plaid_api/models/user_account_session_event.rb', line 15 def name @name end |
#outcome ⇒ String
Optional outcome of the event.
23 24 25 |
# File 'lib/the_plaid_api/models/user_account_session_event.rb', line 23 def outcome @outcome end |
#timestamp ⇒ DateTime
The timestamp when the event occurred in ISO 8601 format.
19 20 21 |
# File 'lib/the_plaid_api/models/user_account_session_event.rb', line 19 def @timestamp end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/the_plaid_api/models/user_account_session_event.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : nil = if hash.key?('timestamp') (DateTimeHelper.from_rfc3339(hash['timestamp']) if hash['timestamp']) end outcome = hash.key?('outcome') ? hash['outcome'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UserAccountSessionEvent.new(name: name, timestamp: , outcome: outcome, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/the_plaid_api/models/user_account_session_event.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['timestamp'] = 'timestamp' @_hash['outcome'] = 'outcome' @_hash end |
.nullables ⇒ Object
An array for nullable fields
42 43 44 |
# File 'lib/the_plaid_api/models/user_account_session_event.rb', line 42 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 |
# File 'lib/the_plaid_api/models/user_account_session_event.rb', line 35 def self.optionals %w[ outcome ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 |
# File 'lib/the_plaid_api/models/user_account_session_event.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, timestamp: #{@timestamp.inspect}, outcome:"\ " #{@outcome.inspect}, additional_properties: #{@additional_properties}>" end |
#to_custom_timestamp ⇒ Object
81 82 83 |
# File 'lib/the_plaid_api/models/user_account_session_event.rb', line 81 def DateTimeHelper.to_rfc3339() end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 |
# File 'lib/the_plaid_api/models/user_account_session_event.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, timestamp: #{@timestamp}, outcome: #{@outcome},"\ " additional_properties: #{@additional_properties}>" end |