Class: ThePlaidApi::UserAccountSessionEventSendRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::UserAccountSessionEventSendRequest
- Defined in:
- lib/the_plaid_api/models/user_account_session_event_send_request.rb
Overview
UserAccountSessionEventSendRequest defines the request schema for ‘/user_account/session/event/send`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#cohort_id ⇒ String
Optional cohort identifier for the user session.
-
#event ⇒ UserAccountSessionEvent
Event data for user account session tracking.
-
#link_session_id ⇒ String
The Link session identifier.
-
#secret ⇒ String
Your Plaid API ‘secret`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(link_session_id:, event:, client_id: SKIP, secret: SKIP, cohort_id: SKIP, additional_properties: nil) ⇒ UserAccountSessionEventSendRequest
constructor
A new instance of UserAccountSessionEventSendRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(link_session_id:, event:, client_id: SKIP, secret: SKIP, cohort_id: SKIP, additional_properties: nil) ⇒ UserAccountSessionEventSendRequest
Returns a new instance of UserAccountSessionEventSendRequest.
61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/the_plaid_api/models/user_account_session_event_send_request.rb', line 61 def initialize(link_session_id:, event:, client_id: SKIP, secret: SKIP, cohort_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @cohort_id = cohort_id unless cohort_id == SKIP @link_session_id = link_session_id @event = event @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
17 18 19 |
# File 'lib/the_plaid_api/models/user_account_session_event_send_request.rb', line 17 def client_id @client_id end |
#cohort_id ⇒ String
Optional cohort identifier for the user session.
26 27 28 |
# File 'lib/the_plaid_api/models/user_account_session_event_send_request.rb', line 26 def cohort_id @cohort_id end |
#event ⇒ UserAccountSessionEvent
Event data for user account session tracking
34 35 36 |
# File 'lib/the_plaid_api/models/user_account_session_event_send_request.rb', line 34 def event @event end |
#link_session_id ⇒ String
The Link session identifier.
30 31 32 |
# File 'lib/the_plaid_api/models/user_account_session_event_send_request.rb', line 30 def link_session_id @link_session_id end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
22 23 24 |
# File 'lib/the_plaid_api/models/user_account_session_event_send_request.rb', line 22 def secret @secret end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/the_plaid_api/models/user_account_session_event_send_request.rb', line 75 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. link_session_id = hash.key?('link_session_id') ? hash['link_session_id'] : nil event = UserAccountSessionEvent.from_hash(hash['event']) if hash['event'] client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP cohort_id = hash.key?('cohort_id') ? hash['cohort_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UserAccountSessionEventSendRequest.new(link_session_id: link_session_id, event: event, client_id: client_id, secret: secret, cohort_id: cohort_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 |
# File 'lib/the_plaid_api/models/user_account_session_event_send_request.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['cohort_id'] = 'cohort_id' @_hash['link_session_id'] = 'link_session_id' @_hash['event'] = 'event' @_hash end |
.nullables ⇒ Object
An array for nullable fields
57 58 59 |
# File 'lib/the_plaid_api/models/user_account_session_event_send_request.rb', line 57 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
48 49 50 51 52 53 54 |
# File 'lib/the_plaid_api/models/user_account_session_event_send_request.rb', line 48 def self.optionals %w[ client_id secret cohort_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
111 112 113 114 115 116 |
# File 'lib/the_plaid_api/models/user_account_session_event_send_request.rb', line 111 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, cohort_id:"\ " #{@cohort_id.inspect}, link_session_id: #{@link_session_id.inspect}, event:"\ " #{@event.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
103 104 105 106 107 108 |
# File 'lib/the_plaid_api/models/user_account_session_event_send_request.rb', line 103 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, cohort_id: #{@cohort_id},"\ " link_session_id: #{@link_session_id}, event: #{@event}, additional_properties:"\ " #{@additional_properties}>" end |