Class: ThePlaidApi::UserItemsRemoveRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::UserItemsRemoveRequest
- Defined in:
- lib/the_plaid_api/models/user_items_remove_request.rb
Overview
UserItemsRemoveRequest defines the request schema for ‘/user/items/remove`
Instance Attribute Summary collapse
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#item_ids ⇒ Array[String]
An array of ‘item_id`s to be deleted.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#user_id ⇒ String
A unique user identifier, created by ‘/user/create`.
-
#user_token ⇒ String
The user token associated with the User data is being requested for.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(item_ids:, client_id: SKIP, secret: SKIP, user_token: SKIP, user_id: SKIP, additional_properties: nil) ⇒ UserItemsRemoveRequest
constructor
A new instance of UserItemsRemoveRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(item_ids:, client_id: SKIP, secret: SKIP, user_token: SKIP, user_id: SKIP, additional_properties: nil) ⇒ UserItemsRemoveRequest
Returns a new instance of UserItemsRemoveRequest.
70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/the_plaid_api/models/user_items_remove_request.rb', line 70 def initialize(item_ids:, client_id: SKIP, secret: SKIP, user_token: SKIP, user_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @user_token = user_token unless user_token == SKIP @user_id = user_id unless user_id == SKIP @item_ids = item_ids @additional_properties = additional_properties end |
Instance Attribute Details
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
16 17 18 |
# File 'lib/the_plaid_api/models/user_items_remove_request.rb', line 16 def client_id @client_id end |
#item_ids ⇒ Array[String]
An array of ‘item_id`s to be deleted. All Items for removal must be currently associated with the provided `user_id` or `user_token`. Otherwise, the entire operation will error and no Items will be deleted.
42 43 44 |
# File 'lib/the_plaid_api/models/user_items_remove_request.rb', line 42 def item_ids @item_ids end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
21 22 23 |
# File 'lib/the_plaid_api/models/user_items_remove_request.rb', line 21 def secret @secret end |
#user_id ⇒ String
A unique user identifier, created by ‘/user/create`. Integrations that began using `/user/create` after December 10, 2025 use this field to identify a user instead of the `user_token`. For more details, see [new user APIs](plaid.com/docs/api/users/user-apis).
36 37 38 |
# File 'lib/the_plaid_api/models/user_items_remove_request.rb', line 36 def user_id @user_id end |
#user_token ⇒ String
The user token associated with the User data is being requested for. This field is used only by customers with pre-existing integrations that already use the ‘user_token` field. All other customers should use the `user_id` instead. For more details, see [New User APIs](plaid.com/docs/api/users/user-apis).
29 30 31 |
# File 'lib/the_plaid_api/models/user_items_remove_request.rb', line 29 def user_token @user_token end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/the_plaid_api/models/user_items_remove_request.rb', line 84 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. item_ids = hash.key?('item_ids') ? hash['item_ids'] : nil client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP user_token = hash.key?('user_token') ? hash['user_token'] : SKIP user_id = hash.key?('user_id') ? hash['user_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UserItemsRemoveRequest.new(item_ids: item_ids, client_id: client_id, secret: secret, user_token: user_token, user_id: user_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
45 46 47 48 49 50 51 52 53 |
# File 'lib/the_plaid_api/models/user_items_remove_request.rb', line 45 def self.names @_hash = {} if @_hash.nil? @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['user_token'] = 'user_token' @_hash['user_id'] = 'user_id' @_hash['item_ids'] = 'item_ids' @_hash end |
.nullables ⇒ Object
An array for nullable fields
66 67 68 |
# File 'lib/the_plaid_api/models/user_items_remove_request.rb', line 66 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
56 57 58 59 60 61 62 63 |
# File 'lib/the_plaid_api/models/user_items_remove_request.rb', line 56 def self.optionals %w[ client_id secret user_token user_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
119 120 121 122 123 124 |
# File 'lib/the_plaid_api/models/user_items_remove_request.rb', line 119 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id.inspect}, secret: #{@secret.inspect}, user_token:"\ " #{@user_token.inspect}, user_id: #{@user_id.inspect}, item_ids: #{@item_ids.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
111 112 113 114 115 116 |
# File 'lib/the_plaid_api/models/user_items_remove_request.rb', line 111 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_id: #{@client_id}, secret: #{@secret}, user_token: #{@user_token},"\ " user_id: #{@user_id}, item_ids: #{@item_ids}, additional_properties:"\ " #{@additional_properties}>" end |