Class: ThePlaidApi::VerificationExpiredWebhook
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::VerificationExpiredWebhook
- Defined in:
- lib/the_plaid_api/models/verification_expired_webhook.rb
Overview
Fired when an Item was not verified via automated micro-deposits after seven days since the automated micro-deposit was made.
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ‘account_id` of the account associated with the webhook.
-
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from.
-
#error ⇒ Error
Errors are identified by ‘error_code` and categorized by `error_type`.
-
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error.
-
#webhook_code ⇒ String
‘VERIFICATION_EXPIRED`.
-
#webhook_type ⇒ String
‘AUTH`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(webhook_type:, webhook_code:, item_id:, account_id:, environment:, error: SKIP, additional_properties: nil) ⇒ VerificationExpiredWebhook
constructor
A new instance of VerificationExpiredWebhook.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(webhook_type:, webhook_code:, item_id:, account_id:, environment:, error: SKIP, additional_properties: nil) ⇒ VerificationExpiredWebhook
Returns a new instance of VerificationExpiredWebhook.
71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/the_plaid_api/models/verification_expired_webhook.rb', line 71 def initialize(webhook_type:, webhook_code:, item_id:, account_id:, environment:, error: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @webhook_type = webhook_type @webhook_code = webhook_code @item_id = item_id @account_id = account_id @environment = environment @error = error unless error == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
The ‘account_id` of the account associated with the webhook
27 28 29 |
# File 'lib/the_plaid_api/models/verification_expired_webhook.rb', line 27 def account_id @account_id end |
#environment ⇒ WebhookEnvironmentValues
The Plaid environment the webhook was sent from
31 32 33 |
# File 'lib/the_plaid_api/models/verification_expired_webhook.rb', line 31 def environment @environment end |
#error ⇒ Error
Errors are identified by ‘error_code` and categorized by `error_type`. Use these in preference to HTTP status codes to identify and handle specific errors. HTTP status codes are set and provide the broadest categorization of errors: 4xx codes are for developer- or user-related errors, and 5xx codes are for Plaid-related errors, and the status will be 2xx in non-error cases. An Item with a non-`null` error object will only be part of an API response when calling `/item/get` to view Item status. Otherwise, error fields will be `null` if no error has occurred; if an error has occurred, an error code will be returned instead.
43 44 45 |
# File 'lib/the_plaid_api/models/verification_expired_webhook.rb', line 43 def error @error end |
#item_id ⇒ String
The ‘item_id` of the Item associated with this webhook, warning, or error
23 24 25 |
# File 'lib/the_plaid_api/models/verification_expired_webhook.rb', line 23 def item_id @item_id end |
#webhook_code ⇒ String
‘VERIFICATION_EXPIRED`
19 20 21 |
# File 'lib/the_plaid_api/models/verification_expired_webhook.rb', line 19 def webhook_code @webhook_code end |
#webhook_type ⇒ String
‘AUTH`
15 16 17 |
# File 'lib/the_plaid_api/models/verification_expired_webhook.rb', line 15 def webhook_type @webhook_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/the_plaid_api/models/verification_expired_webhook.rb', line 86 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. webhook_type = hash.key?('webhook_type') ? hash['webhook_type'] : nil webhook_code = hash.key?('webhook_code') ? hash['webhook_code'] : nil item_id = hash.key?('item_id') ? hash['item_id'] : nil account_id = hash.key?('account_id') ? hash['account_id'] : nil environment = hash.key?('environment') ? hash['environment'] : nil error = Error.from_hash(hash['error']) if hash['error'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. VerificationExpiredWebhook.new(webhook_type: webhook_type, webhook_code: webhook_code, item_id: item_id, account_id: account_id, environment: environment, error: error, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/the_plaid_api/models/verification_expired_webhook.rb', line 46 def self.names @_hash = {} if @_hash.nil? @_hash['webhook_type'] = 'webhook_type' @_hash['webhook_code'] = 'webhook_code' @_hash['item_id'] = 'item_id' @_hash['account_id'] = 'account_id' @_hash['environment'] = 'environment' @_hash['error'] = 'error' @_hash end |
.nullables ⇒ Object
An array for nullable fields
65 66 67 68 69 |
# File 'lib/the_plaid_api/models/verification_expired_webhook.rb', line 65 def self.nullables %w[ error ] end |
.optionals ⇒ Object
An array for optional fields
58 59 60 61 62 |
# File 'lib/the_plaid_api/models/verification_expired_webhook.rb', line 58 def self.optionals %w[ error ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
123 124 125 126 127 128 129 |
# File 'lib/the_plaid_api/models/verification_expired_webhook.rb', line 123 def inspect class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type.inspect}, webhook_code:"\ " #{@webhook_code.inspect}, item_id: #{@item_id.inspect}, account_id:"\ " #{@account_id.inspect}, environment: #{@environment.inspect}, error: #{@error.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
115 116 117 118 119 120 |
# File 'lib/the_plaid_api/models/verification_expired_webhook.rb', line 115 def to_s class_name = self.class.name.split('::').last "<#{class_name} webhook_type: #{@webhook_type}, webhook_code: #{@webhook_code}, item_id:"\ " #{@item_id}, account_id: #{@account_id}, environment: #{@environment}, error: #{@error},"\ " additional_properties: #{@additional_properties}>" end |