Class: ThePlaidApi::VerificationInsightsNetworkStatus
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::VerificationInsightsNetworkStatus
- Defined in:
- lib/the_plaid_api/models/verification_insights_network_status.rb
Overview
Status information about the account and routing number in the Plaid network.
Instance Attribute Summary collapse
-
#has_numbers_match ⇒ TrueClass | FalseClass
Indicates whether we found at least one matching account for the ACH account and routing number.
-
#is_numbers_match_verified ⇒ TrueClass | FalseClass
Indicates if at least one matching account for the ACH account and routing number is already verified.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(has_numbers_match:, is_numbers_match_verified:, additional_properties: nil) ⇒ VerificationInsightsNetworkStatus
constructor
A new instance of VerificationInsightsNetworkStatus.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(has_numbers_match:, is_numbers_match_verified:, additional_properties: nil) ⇒ VerificationInsightsNetworkStatus
Returns a new instance of VerificationInsightsNetworkStatus.
41 42 43 44 45 46 47 48 49 |
# File 'lib/the_plaid_api/models/verification_insights_network_status.rb', line 41 def initialize(has_numbers_match:, is_numbers_match_verified:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @has_numbers_match = has_numbers_match @is_numbers_match_verified = is_numbers_match_verified @additional_properties = additional_properties end |
Instance Attribute Details
#has_numbers_match ⇒ TrueClass | FalseClass
Indicates whether we found at least one matching account for the ACH account and routing number.
16 17 18 |
# File 'lib/the_plaid_api/models/verification_insights_network_status.rb', line 16 def has_numbers_match @has_numbers_match end |
#is_numbers_match_verified ⇒ TrueClass | FalseClass
Indicates if at least one matching account for the ACH account and routing number is already verified.
21 22 23 |
# File 'lib/the_plaid_api/models/verification_insights_network_status.rb', line 21 def is_numbers_match_verified @is_numbers_match_verified end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/the_plaid_api/models/verification_insights_network_status.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. has_numbers_match = hash.key?('has_numbers_match') ? hash['has_numbers_match'] : nil is_numbers_match_verified = hash.key?('is_numbers_match_verified') ? hash['is_numbers_match_verified'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. VerificationInsightsNetworkStatus.new(has_numbers_match: has_numbers_match, is_numbers_match_verified: is_numbers_match_verified, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/the_plaid_api/models/verification_insights_network_status.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['has_numbers_match'] = 'has_numbers_match' @_hash['is_numbers_match_verified'] = 'is_numbers_match_verified' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/the_plaid_api/models/verification_insights_network_status.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 |
# File 'lib/the_plaid_api/models/verification_insights_network_status.rb', line 32 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 87 |
# File 'lib/the_plaid_api/models/verification_insights_network_status.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} has_numbers_match: #{@has_numbers_match.inspect},"\ " is_numbers_match_verified: #{@is_numbers_match_verified.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/the_plaid_api/models/verification_insights_network_status.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} has_numbers_match: #{@has_numbers_match}, is_numbers_match_verified:"\ " #{@is_numbers_match_verified}, additional_properties: #{@additional_properties}>" end |