Class: ThePlaidApi::VerificationStatus3
- Inherits:
-
Object
- Object
- ThePlaidApi::VerificationStatus3
- Defined in:
- lib/the_plaid_api/models/verification_status3.rb
Overview
‘VERIFICATION_STATUS_PROCESSING_COMPLETE`: The income verification status processing has completed. If the user uploaded multiple documents, this webhook will fire when all documents have finished processing. Call the `/income/verification/paystubs/get` endpoint and check the document metadata to see which documents were successfully parsed. `VERIFICATION_STATUS_PROCESSING_FAILED`: A failure occurred when attempting to process the verification documentation. `VERIFICATION_STATUS_PENDING_APPROVAL`: (deprecated) The income verification has been sent to the user for review.
Constant Summary collapse
- VERIFICATION_STATUS3 =
[ # TODO: Write general description for # VERIFICATION_STATUS_PROCESSING_COMPLETE VERIFICATION_STATUS_PROCESSING_COMPLETE = 'VERIFICATION_STATUS_PROCESSING_COMPLETE'.freeze, # TODO: Write general description for # VERIFICATION_STATUS_PROCESSING_FAILED VERIFICATION_STATUS_PROCESSING_FAILED = 'VERIFICATION_STATUS_PROCESSING_FAILED'.freeze, # TODO: Write general description for VERIFICATION_STATUS_PENDING_APPROVAL VERIFICATION_STATUS_PENDING_APPROVAL = 'VERIFICATION_STATUS_PENDING_APPROVAL'.freeze ].freeze
Class Method Summary collapse
- .from_value(value, default_value = VERIFICATION_STATUS_PROCESSING_COMPLETE) ⇒ Object
- .validate(value) ⇒ Object
Class Method Details
.from_value(value, default_value = VERIFICATION_STATUS_PROCESSING_COMPLETE) ⇒ Object
36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/the_plaid_api/models/verification_status3.rb', line 36 def self.from_value(value, default_value = VERIFICATION_STATUS_PROCESSING_COMPLETE) return default_value if value.nil? str = value.to_s.strip case str.downcase when 'verification_status_processing_complete' then VERIFICATION_STATUS_PROCESSING_COMPLETE when 'verification_status_processing_failed' then VERIFICATION_STATUS_PROCESSING_FAILED when 'verification_status_pending_approval' then VERIFICATION_STATUS_PENDING_APPROVAL else default_value end end |
.validate(value) ⇒ Object
30 31 32 33 34 |
# File 'lib/the_plaid_api/models/verification_status3.rb', line 30 def self.validate(value) return false if value.nil? VERIFICATION_STATUS3.include?(value) end |