Class: ThePlaidApi::WalletBalance
- Defined in:
- lib/the_plaid_api/models/wallet_balance.rb
Overview
An object representing the e-wallet balance
Instance Attribute Summary collapse
-
#available ⇒ Float
The total amount of funds in the account after subtracting pending debit transaction amounts.
-
#current ⇒ Float
The total amount of funds in the account.
-
#iso_currency_code ⇒ String
The ISO-4217 currency code of the balance.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(iso_currency_code:, current:, available:, additional_properties: nil) ⇒ WalletBalance
constructor
A new instance of WalletBalance.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(iso_currency_code:, current:, available:, additional_properties: nil) ⇒ WalletBalance
Returns a new instance of WalletBalance.
44 45 46 47 48 49 50 51 52 53 |
# File 'lib/the_plaid_api/models/wallet_balance.rb', line 44 def initialize(iso_currency_code:, current:, available:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @iso_currency_code = iso_currency_code @current = current @available = available @additional_properties = additional_properties end |
Instance Attribute Details
#available ⇒ Float
The total amount of funds in the account after subtracting pending debit transaction amounts
23 24 25 |
# File 'lib/the_plaid_api/models/wallet_balance.rb', line 23 def available @available end |
#current ⇒ Float
The total amount of funds in the account
18 19 20 |
# File 'lib/the_plaid_api/models/wallet_balance.rb', line 18 def current @current end |
#iso_currency_code ⇒ String
The ISO-4217 currency code of the balance
14 15 16 |
# File 'lib/the_plaid_api/models/wallet_balance.rb', line 14 def iso_currency_code @iso_currency_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/the_plaid_api/models/wallet_balance.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. iso_currency_code = hash.key?('iso_currency_code') ? hash['iso_currency_code'] : nil current = hash.key?('current') ? hash['current'] : nil available = hash.key?('available') ? hash['available'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. WalletBalance.new(iso_currency_code: iso_currency_code, current: current, available: available, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/the_plaid_api/models/wallet_balance.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['iso_currency_code'] = 'iso_currency_code' @_hash['current'] = 'current' @_hash['available'] = 'available' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/the_plaid_api/models/wallet_balance.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/the_plaid_api/models/wallet_balance.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
87 88 89 90 91 92 |
# File 'lib/the_plaid_api/models/wallet_balance.rb', line 87 def inspect class_name = self.class.name.split('::').last "<#{class_name} iso_currency_code: #{@iso_currency_code.inspect}, current:"\ " #{@current.inspect}, available: #{@available.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
80 81 82 83 84 |
# File 'lib/the_plaid_api/models/wallet_balance.rb', line 80 def to_s class_name = self.class.name.split('::').last "<#{class_name} iso_currency_code: #{@iso_currency_code}, current: #{@current}, available:"\ " #{@available}, additional_properties: #{@additional_properties}>" end |