Class: ThePlaidApi::WalletTransactionAmount
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::WalletTransactionAmount
- Defined in:
- lib/the_plaid_api/models/wallet_transaction_amount.rb
Overview
The amount and currency of a transaction
Instance Attribute Summary collapse
-
#iso_currency_code ⇒ IsoCurrencyCode
An ISO-4217 currency code, used with e-wallets and transactions.
-
#value ⇒ Float
The amount of the transaction.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(iso_currency_code:, value:, additional_properties: nil) ⇒ WalletTransactionAmount
constructor
A new instance of WalletTransactionAmount.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(iso_currency_code:, value:, additional_properties: nil) ⇒ WalletTransactionAmount
Returns a new instance of WalletTransactionAmount.
39 40 41 42 43 44 45 46 |
# File 'lib/the_plaid_api/models/wallet_transaction_amount.rb', line 39 def initialize(iso_currency_code:, value:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @iso_currency_code = iso_currency_code @value = value @additional_properties = additional_properties end |
Instance Attribute Details
#iso_currency_code ⇒ IsoCurrencyCode
An ISO-4217 currency code, used with e-wallets and transactions.
14 15 16 |
# File 'lib/the_plaid_api/models/wallet_transaction_amount.rb', line 14 def iso_currency_code @iso_currency_code end |
#value ⇒ Float
The amount of the transaction. Must contain at most two digits of precision e.g. ‘1.23`.
19 20 21 |
# File 'lib/the_plaid_api/models/wallet_transaction_amount.rb', line 19 def value @value end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/the_plaid_api/models/wallet_transaction_amount.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. iso_currency_code = hash.key?('iso_currency_code') ? hash['iso_currency_code'] : nil value = hash.key?('value') ? hash['value'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. WalletTransactionAmount.new(iso_currency_code: iso_currency_code, value: value, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/the_plaid_api/models/wallet_transaction_amount.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['iso_currency_code'] = 'iso_currency_code' @_hash['value'] = 'value' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/the_plaid_api/models/wallet_transaction_amount.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/the_plaid_api/models/wallet_transaction_amount.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/the_plaid_api/models/wallet_transaction_amount.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} iso_currency_code: #{@iso_currency_code.inspect}, value: #{@value.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/the_plaid_api/models/wallet_transaction_amount.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} iso_currency_code: #{@iso_currency_code}, value: #{@value},"\ " additional_properties: #{@additional_properties}>" end |