Class: ThePlaidApi::WalletTransactionCounterpartyNumbers
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::WalletTransactionCounterpartyNumbers
- Defined in:
- lib/the_plaid_api/models/wallet_transaction_counterparty_numbers.rb
Overview
The counterparty’s bank account numbers. Exactly one of IBAN or BACS data is required.
Instance Attribute Summary collapse
-
#bacs ⇒ WalletTransactionCounterpartyBacs
The account number and sort code of the counterparty’s account.
-
#international ⇒ WalletTransactionCounterpartyInternational
International Bank Account Number for a Wallet Transaction.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(bacs: SKIP, international: SKIP, additional_properties: nil) ⇒ WalletTransactionCounterpartyNumbers
constructor
A new instance of WalletTransactionCounterpartyNumbers.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(bacs: SKIP, international: SKIP, additional_properties: nil) ⇒ WalletTransactionCounterpartyNumbers
Returns a new instance of WalletTransactionCounterpartyNumbers.
45 46 47 48 49 50 51 52 |
# File 'lib/the_plaid_api/models/wallet_transaction_counterparty_numbers.rb', line 45 def initialize(bacs: SKIP, international: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @bacs = bacs unless bacs == SKIP @international = international unless international == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#bacs ⇒ WalletTransactionCounterpartyBacs
The account number and sort code of the counterparty’s account
15 16 17 |
# File 'lib/the_plaid_api/models/wallet_transaction_counterparty_numbers.rb', line 15 def bacs @bacs end |
#international ⇒ WalletTransactionCounterpartyInternational
International Bank Account Number for a Wallet Transaction
19 20 21 |
# File 'lib/the_plaid_api/models/wallet_transaction_counterparty_numbers.rb', line 19 def international @international end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/the_plaid_api/models/wallet_transaction_counterparty_numbers.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. bacs = WalletTransactionCounterpartyBacs.from_hash(hash['bacs']) if hash['bacs'] international = WalletTransactionCounterpartyInternational.from_hash(hash['international']) if hash['international'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. WalletTransactionCounterpartyNumbers.new(bacs: bacs, international: international, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/the_plaid_api/models/wallet_transaction_counterparty_numbers.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['bacs'] = 'bacs' @_hash['international'] = 'international' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 41 42 43 |
# File 'lib/the_plaid_api/models/wallet_transaction_counterparty_numbers.rb', line 38 def self.nullables %w[ bacs international ] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/the_plaid_api/models/wallet_transaction_counterparty_numbers.rb', line 30 def self.optionals %w[ bacs international ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/the_plaid_api/models/wallet_transaction_counterparty_numbers.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} bacs: #{@bacs.inspect}, international: #{@international.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 81 |
# File 'lib/the_plaid_api/models/wallet_transaction_counterparty_numbers.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} bacs: #{@bacs}, international: #{@international}, additional_properties:"\ " #{@additional_properties}>" end |