Class: ThePlaidApi::WalletTransactionListResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::WalletTransactionListResponse
- Defined in:
- lib/the_plaid_api/models/wallet_transaction_list_response.rb
Overview
WalletTransactionListResponse defines the response schema for ‘/wallet/transaction/list`
Instance Attribute Summary collapse
-
#next_cursor ⇒ String
The value that, when used as the optional ‘cursor` parameter to `/wallet/transaction/list`, will return the corresponding transaction as its first entry.
-
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting.
-
#transactions ⇒ Array[WalletTransaction]
An array of transactions of an e-wallet, associated with the given ‘wallet_id`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(transactions:, request_id:, next_cursor: SKIP, additional_properties: nil) ⇒ WalletTransactionListResponse
constructor
A new instance of WalletTransactionListResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(transactions:, request_id:, next_cursor: SKIP, additional_properties: nil) ⇒ WalletTransactionListResponse
Returns a new instance of WalletTransactionListResponse.
51 52 53 54 55 56 57 58 59 60 |
# File 'lib/the_plaid_api/models/wallet_transaction_list_response.rb', line 51 def initialize(transactions:, request_id:, next_cursor: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @transactions = transactions @next_cursor = next_cursor unless next_cursor == SKIP @request_id = request_id @additional_properties = additional_properties end |
Instance Attribute Details
#next_cursor ⇒ String
The value that, when used as the optional ‘cursor` parameter to `/wallet/transaction/list`, will return the corresponding transaction as its first entry.
22 23 24 |
# File 'lib/the_plaid_api/models/wallet_transaction_list_response.rb', line 22 def next_cursor @next_cursor end |
#request_id ⇒ String
A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
28 29 30 |
# File 'lib/the_plaid_api/models/wallet_transaction_list_response.rb', line 28 def request_id @request_id end |
#transactions ⇒ Array[WalletTransaction]
An array of transactions of an e-wallet, associated with the given ‘wallet_id`
16 17 18 |
# File 'lib/the_plaid_api/models/wallet_transaction_list_response.rb', line 16 def transactions @transactions end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/the_plaid_api/models/wallet_transaction_list_response.rb', line 63 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it transactions = nil unless hash['transactions'].nil? transactions = [] hash['transactions'].each do |structure| transactions << (WalletTransaction.from_hash(structure) if structure) end end transactions = nil unless hash.key?('transactions') request_id = hash.key?('request_id') ? hash['request_id'] : nil next_cursor = hash.key?('next_cursor') ? hash['next_cursor'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. WalletTransactionListResponse.new(transactions: transactions, request_id: request_id, next_cursor: next_cursor, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
31 32 33 34 35 36 37 |
# File 'lib/the_plaid_api/models/wallet_transaction_list_response.rb', line 31 def self.names @_hash = {} if @_hash.nil? @_hash['transactions'] = 'transactions' @_hash['next_cursor'] = 'next_cursor' @_hash['request_id'] = 'request_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
47 48 49 |
# File 'lib/the_plaid_api/models/wallet_transaction_list_response.rb', line 47 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
40 41 42 43 44 |
# File 'lib/the_plaid_api/models/wallet_transaction_list_response.rb', line 40 def self.optionals %w[ next_cursor ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
102 103 104 105 106 107 |
# File 'lib/the_plaid_api/models/wallet_transaction_list_response.rb', line 102 def inspect class_name = self.class.name.split('::').last "<#{class_name} transactions: #{@transactions.inspect}, next_cursor:"\ " #{@next_cursor.inspect}, request_id: #{@request_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
95 96 97 98 99 |
# File 'lib/the_plaid_api/models/wallet_transaction_list_response.rb', line 95 def to_s class_name = self.class.name.split('::').last "<#{class_name} transactions: #{@transactions}, next_cursor: #{@next_cursor}, request_id:"\ " #{@request_id}, additional_properties: #{@additional_properties}>" end |