Class: ThePlaidApi::WatchlistScreeningIndividualUpdateRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::WatchlistScreeningIndividualUpdateRequest
- Defined in:
- lib/the_plaid_api/models/watchlist_screening_individual_update_request.rb
Overview
Request input for editing an individual watchlist screening
Instance Attribute Summary collapse
-
#assignee ⇒ String
ID of the associated user.
-
#client_id ⇒ String
Your Plaid API ‘client_id`.
-
#client_user_id ⇒ String
A unique ID that identifies the end user in your system.
-
#reset_fields ⇒ Array[WatchlistScreeningIndividualUpdateRequestResettableField]
A list of fields to reset back to null.
-
#search_terms ⇒ UpdateIndividualScreeningRequestSearchTerms
Search terms for editing an individual watchlist screening.
-
#secret ⇒ String
Your Plaid API ‘secret`.
-
#status ⇒ WatchlistScreeningStatus
A status enum indicating whether a screening is still pending review, has been rejected, or has been cleared.
-
#watchlist_screening_id ⇒ String
ID of the associated screening.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(watchlist_screening_id:, search_terms: SKIP, assignee: SKIP, status: SKIP, client_user_id: SKIP, client_id: SKIP, secret: SKIP, reset_fields: SKIP, additional_properties: nil) ⇒ WatchlistScreeningIndividualUpdateRequest
constructor
A new instance of WatchlistScreeningIndividualUpdateRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(watchlist_screening_id:, search_terms: SKIP, assignee: SKIP, status: SKIP, client_user_id: SKIP, client_id: SKIP, secret: SKIP, reset_fields: SKIP, additional_properties: nil) ⇒ WatchlistScreeningIndividualUpdateRequest
Returns a new instance of WatchlistScreeningIndividualUpdateRequest.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_update_request.rb', line 90 def initialize(watchlist_screening_id:, search_terms: SKIP, assignee: SKIP, status: SKIP, client_user_id: SKIP, client_id: SKIP, secret: SKIP, reset_fields: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @watchlist_screening_id = watchlist_screening_id @search_terms = search_terms unless search_terms == SKIP @assignee = assignee unless assignee == SKIP @status = status unless status == SKIP @client_user_id = client_user_id unless client_user_id == SKIP @client_id = client_id unless client_id == SKIP @secret = secret unless secret == SKIP @reset_fields = reset_fields unless reset_fields == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#assignee ⇒ String
ID of the associated user. To retrieve the email address or other details of the person corresponding to this id, use ‘/dashboard_user/get`.
23 24 25 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_update_request.rb', line 23 def assignee @assignee end |
#client_id ⇒ String
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
44 45 46 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_update_request.rb', line 44 def client_id @client_id end |
#client_user_id ⇒ String
A unique ID that identifies the end user in your system. Either a ‘user_id` or the `client_user_id` must be provided. This ID can also be used to associate user-specific data from other Plaid products. Financial Account Matching requires this field and the `/link/token/create` `client_user_id` to be consistent. Personally identifiable information, such as an email address or phone number, should not be used in the `client_user_id`.
38 39 40 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_update_request.rb', line 38 def client_user_id @client_user_id end |
#reset_fields ⇒ Array[WatchlistScreeningIndividualUpdateRequestResettableField]
A list of fields to reset back to null
53 54 55 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_update_request.rb', line 53 def reset_fields @reset_fields end |
#search_terms ⇒ UpdateIndividualScreeningRequestSearchTerms
Search terms for editing an individual watchlist screening
18 19 20 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_update_request.rb', line 18 def search_terms @search_terms end |
#secret ⇒ String
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
49 50 51 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_update_request.rb', line 49 def secret @secret end |
#status ⇒ WatchlistScreeningStatus
A status enum indicating whether a screening is still pending review, has been rejected, or has been cleared.
28 29 30 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_update_request.rb', line 28 def status @status end |
#watchlist_screening_id ⇒ String
ID of the associated screening.
14 15 16 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_update_request.rb', line 14 def watchlist_screening_id @watchlist_screening_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_update_request.rb', line 108 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. watchlist_screening_id = hash.key?('watchlist_screening_id') ? hash['watchlist_screening_id'] : nil search_terms = UpdateIndividualScreeningRequestSearchTerms.from_hash(hash['search_terms']) if hash['search_terms'] assignee = hash.key?('assignee') ? hash['assignee'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP client_user_id = hash.key?('client_user_id') ? hash['client_user_id'] : SKIP client_id = hash.key?('client_id') ? hash['client_id'] : SKIP secret = hash.key?('secret') ? hash['secret'] : SKIP reset_fields = hash.key?('reset_fields') ? hash['reset_fields'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. WatchlistScreeningIndividualUpdateRequest.new(watchlist_screening_id: watchlist_screening_id, search_terms: search_terms, assignee: assignee, status: status, client_user_id: client_user_id, client_id: client_id, secret: secret, reset_fields: reset_fields, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_update_request.rb', line 56 def self.names @_hash = {} if @_hash.nil? @_hash['watchlist_screening_id'] = 'watchlist_screening_id' @_hash['search_terms'] = 'search_terms' @_hash['assignee'] = 'assignee' @_hash['status'] = 'status' @_hash['client_user_id'] = 'client_user_id' @_hash['client_id'] = 'client_id' @_hash['secret'] = 'secret' @_hash['reset_fields'] = 'reset_fields' @_hash end |
.nullables ⇒ Object
An array for nullable fields
83 84 85 86 87 88 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_update_request.rb', line 83 def self.nullables %w[ search_terms reset_fields ] end |
.optionals ⇒ Object
An array for optional fields
70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_update_request.rb', line 70 def self.optionals %w[ search_terms assignee status client_user_id client_id secret reset_fields ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
153 154 155 156 157 158 159 160 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_update_request.rb', line 153 def inspect class_name = self.class.name.split('::').last "<#{class_name} watchlist_screening_id: #{@watchlist_screening_id.inspect}, search_terms:"\ " #{@search_terms.inspect}, assignee: #{@assignee.inspect}, status: #{@status.inspect},"\ " client_user_id: #{@client_user_id.inspect}, client_id: #{@client_id.inspect}, secret:"\ " #{@secret.inspect}, reset_fields: #{@reset_fields.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
144 145 146 147 148 149 150 |
# File 'lib/the_plaid_api/models/watchlist_screening_individual_update_request.rb', line 144 def to_s class_name = self.class.name.split('::').last "<#{class_name} watchlist_screening_id: #{@watchlist_screening_id}, search_terms:"\ " #{@search_terms}, assignee: #{@assignee}, status: #{@status}, client_user_id:"\ " #{@client_user_id}, client_id: #{@client_id}, secret: #{@secret}, reset_fields:"\ " #{@reset_fields}, additional_properties: #{@additional_properties}>" end |