Class: ThePlaidApi::WatchlistScreeningReview
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ThePlaidApi::WatchlistScreeningReview
- Defined in:
- lib/the_plaid_api/models/watchlist_screening_review.rb
Overview
A review submitted by a team member for an individual watchlist screening. A review can be either a comment on the current screening state, actions taken against hits attached to the watchlist screening, or both.
Instance Attribute Summary collapse
-
#audit_trail ⇒ WatchlistScreeningAuditTrail
Information about the last change made to the parent object specifying what caused the change as well as when it occurred.
-
#comment ⇒ String
A comment submitted by a team member as part of reviewing a watchlist screening.
-
#confirmed_hits ⇒ Array[String]
Hits marked as a true positive after thorough manual review.
-
#dismissed_hits ⇒ Array[String]
Hits marked as a false positive after thorough manual review.
-
#id ⇒ String
ID of the associated review.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id:, confirmed_hits:, dismissed_hits:, comment:, audit_trail:, additional_properties: nil) ⇒ WatchlistScreeningReview
constructor
A new instance of WatchlistScreeningReview.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id:, confirmed_hits:, dismissed_hits:, comment:, audit_trail:, additional_properties: nil) ⇒ WatchlistScreeningReview
Returns a new instance of WatchlistScreeningReview.
62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/the_plaid_api/models/watchlist_screening_review.rb', line 62 def initialize(id:, confirmed_hits:, dismissed_hits:, comment:, audit_trail:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id @confirmed_hits = confirmed_hits @dismissed_hits = dismissed_hits @comment = comment @audit_trail = audit_trail @additional_properties = additional_properties end |
Instance Attribute Details
#audit_trail ⇒ WatchlistScreeningAuditTrail
Information about the last change made to the parent object specifying what caused the change as well as when it occurred.
37 38 39 |
# File 'lib/the_plaid_api/models/watchlist_screening_review.rb', line 37 def audit_trail @audit_trail end |
#comment ⇒ String
A comment submitted by a team member as part of reviewing a watchlist screening.
32 33 34 |
# File 'lib/the_plaid_api/models/watchlist_screening_review.rb', line 32 def comment @comment end |
#confirmed_hits ⇒ Array[String]
Hits marked as a true positive after thorough manual review. These hits will never recur or be updated once dismissed. In most cases, confirmed hits indicate that the customer should be rejected.
22 23 24 |
# File 'lib/the_plaid_api/models/watchlist_screening_review.rb', line 22 def confirmed_hits @confirmed_hits end |
#dismissed_hits ⇒ Array[String]
Hits marked as a false positive after thorough manual review. These hits will never recur or be updated once dismissed.
27 28 29 |
# File 'lib/the_plaid_api/models/watchlist_screening_review.rb', line 27 def dismissed_hits @dismissed_hits end |
#id ⇒ String
ID of the associated review.
16 17 18 |
# File 'lib/the_plaid_api/models/watchlist_screening_review.rb', line 16 def id @id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/the_plaid_api/models/watchlist_screening_review.rb', line 76 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil confirmed_hits = hash.key?('confirmed_hits') ? hash['confirmed_hits'] : nil dismissed_hits = hash.key?('dismissed_hits') ? hash['dismissed_hits'] : nil comment = hash.key?('comment') ? hash['comment'] : nil audit_trail = WatchlistScreeningAuditTrail.from_hash(hash['audit_trail']) if hash['audit_trail'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. WatchlistScreeningReview.new(id: id, confirmed_hits: confirmed_hits, dismissed_hits: dismissed_hits, comment: comment, audit_trail: audit_trail, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
40 41 42 43 44 45 46 47 48 |
# File 'lib/the_plaid_api/models/watchlist_screening_review.rb', line 40 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['confirmed_hits'] = 'confirmed_hits' @_hash['dismissed_hits'] = 'dismissed_hits' @_hash['comment'] = 'comment' @_hash['audit_trail'] = 'audit_trail' @_hash end |
.nullables ⇒ Object
An array for nullable fields
56 57 58 59 60 |
# File 'lib/the_plaid_api/models/watchlist_screening_review.rb', line 56 def self.nullables %w[ comment ] end |
.optionals ⇒ Object
An array for optional fields
51 52 53 |
# File 'lib/the_plaid_api/models/watchlist_screening_review.rb', line 51 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
114 115 116 117 118 119 |
# File 'lib/the_plaid_api/models/watchlist_screening_review.rb', line 114 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, confirmed_hits: #{@confirmed_hits.inspect},"\ " dismissed_hits: #{@dismissed_hits.inspect}, comment: #{@comment.inspect}, audit_trail:"\ " #{@audit_trail.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
106 107 108 109 110 111 |
# File 'lib/the_plaid_api/models/watchlist_screening_review.rb', line 106 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, confirmed_hits: #{@confirmed_hits}, dismissed_hits:"\ " #{@dismissed_hits}, comment: #{@comment}, audit_trail: #{@audit_trail},"\ " additional_properties: #{@additional_properties}>" end |